=== modified file 'bzrlib/__init__.py'
--- bzrlib/__init__.py	2011-09-13 12:29:22 +0000
+++ bzrlib/__init__.py	2011-09-15 15:07:02 +0000
@@ -52,7 +52,7 @@
 # Python version 2.0 is (2, 0, 0, 'final', 0)."  Additionally we use a
 # releaselevel of 'dev' for unreleased under-development code.
 
-version_info = (2, 5, 0, 'dev', 1)
+version_info = (2, 5, 0, 'dev', 2)
 
 # API compatibility version
 api_minimum_version = (2, 4, 0)

=== modified file 'bzrlib/add.py'
--- bzrlib/add.py	2011-08-19 21:01:49 +0000
+++ bzrlib/add.py	2011-09-16 12:04:16 +0000
@@ -23,7 +23,7 @@
     osutils,
     ui, 
     )
-
+from bzrlib.i18n import gettext
 
 class AddAction(object):
     """A class which defines what action to take when adding a file."""
@@ -91,9 +91,9 @@
         else:
             file_size = stat_value.st_size;
         if self._maxSize > 0 and file_size > self._maxSize:
-            ui.ui_factory.show_warning(
-                "skipping %s (larger than %s of %d bytes)" % 
-                (path, self._optionName,  self._maxSize))
+            ui.ui_factory.show_warning(gettext(
+                "skipping {0} (larger than {1} of {2} bytes)").format(
+                path, self._optionName,  self._maxSize))
             return True
         return False
 

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2011-09-12 11:43:03 +0000
+++ bzrlib/branch.py	2011-09-22 12:13:12 +0000
@@ -40,6 +40,7 @@
         ui,
         urlutils,
         )
+from bzrlib.i18n import gettext, ngettext
 """)
 
 from bzrlib import (
@@ -214,6 +215,16 @@
         """
         return _mod_config.BranchConfig(self)
 
+    def get_config_stack(self):
+        """Get a bzrlib.config.BranchStack for this Branch.
+
+        This can then be used to get and set configuration options for the
+        branch.
+
+        :return: A bzrlib.config.BranchStack.
+        """
+        return _mod_config.BranchStack(self)
+
     def _get_config(self):
         """Get the concrete config for just the config in this branch.
 
@@ -848,7 +859,7 @@
         """
         pb = ui.ui_factory.nested_progress_bar()
         try:
-            pb.update("Unstacking")
+            pb.update(gettext("Unstacking"))
             # The basic approach here is to fetch the tip of the branch,
             # including all available ghosts, from the existing stacked
             # repository into a new repository object without the fallbacks. 
@@ -3134,14 +3145,14 @@
         tag_updates = getattr(self, "tag_updates", None)
         if not is_quiet():
             if self.old_revid != self.new_revid:
-                note('Pushed up to revision %d.' % self.new_revno)
+                note(gettext('Pushed up to revision %d.') % self.new_revno)
             if tag_updates:
-                note('%d tag(s) updated.' % len(tag_updates))
+                note(ngettext('%d tag updated.', '%d tags updated.', len(tag_updates)) % len(tag_updates))
             if self.old_revid == self.new_revid and not tag_updates:
                 if not tag_conflicts:
-                    note('No new revisions or tags to push.')
+                    note(gettext('No new revisions or tags to push.'))
                 else:
-                    note('No new revisions to push.')
+                    note(gettext('No new revisions to push.'))
         self._show_tag_conficts(to_file)
 
 
@@ -3161,10 +3172,10 @@
         :param verbose: Requests more detailed display of what was checked,
             if any.
         """
-        note('checked branch %s format %s', self.branch.user_url,
-            self.branch._format)
+        note(gettext('checked branch {0} format {1}').format(
+                                self.branch.user_url, self.branch._format))
         for error in self.errors:
-            note('found error:%s', error)
+            note(gettext('found error:%s'), error)
 
 
 class Converter5to6(object):

=== modified file 'bzrlib/builtins.py'
--- bzrlib/builtins.py	2011-09-15 13:10:03 +0000
+++ bzrlib/builtins.py	2011-09-26 07:56:05 +0000
@@ -57,6 +57,7 @@
 from bzrlib.revisionspec import RevisionSpec, RevisionInfo
 from bzrlib.smtp_connection import SMTPConnection
 from bzrlib.workingtree import WorkingTree
+from bzrlib.i18n import gettext, ngettext
 """)
 
 from bzrlib.commands import (
@@ -112,7 +113,7 @@
             if view_files:
                 file_list = view_files
                 view_str = views.view_display_str(view_files)
-                note("Ignoring files outside view. View is %s" % view_str)
+                note(gettext("Ignoring files outside view. View is %s") % view_str)
     return tree, file_list
 
 
@@ -120,8 +121,8 @@
     if revisions is None:
         return None
     if len(revisions) != 1:
-        raise errors.BzrCommandError(
-            'bzr %s --revision takes exactly one revision identifier' % (
+        raise errors.BzrCommandError(gettext(
+            'bzr %s --revision takes exactly one revision identifier') % (
                 command_name,))
     return revisions[0]
 
@@ -288,8 +289,8 @@
         from bzrlib.status import show_tree_status
 
         if revision and len(revision) > 2:
-            raise errors.BzrCommandError('bzr status --revision takes exactly'
-                                         ' one or two revision specifiers')
+            raise errors.BzrCommandError(gettext('bzr status --revision takes exactly'
+                                         ' one or two revision specifiers'))
 
         tree, relfile_list = WorkingTree.open_containing_paths(file_list)
         # Avoid asking for specific files when that is not needed.
@@ -332,18 +333,18 @@
     @display_command
     def run(self, revision_id=None, revision=None, directory=u'.'):
         if revision_id is not None and revision is not None:
-            raise errors.BzrCommandError('You can only supply one of'
-                                         ' revision_id or --revision')
+            raise errors.BzrCommandError(gettext('You can only supply one of'
+                                         ' revision_id or --revision'))
         if revision_id is None and revision is None:
-            raise errors.BzrCommandError('You must supply either'
-                                         ' --revision or a revision_id')
+            raise errors.BzrCommandError(gettext('You must supply either'
+                                         ' --revision or a revision_id'))
 
         b = bzrdir.BzrDir.open_containing_tree_or_branch(directory)[1]
 
         revisions = b.repository.revisions
         if revisions is None:
-            raise errors.BzrCommandError('Repository %r does not support '
-                'access to raw revision texts')
+            raise errors.BzrCommandError(gettext('Repository %r does not support '
+                'access to raw revision texts'))
 
         b.repository.lock_read()
         try:
@@ -353,14 +354,14 @@
                 try:
                     self.print_revision(revisions, revision_id)
                 except errors.NoSuchRevision:
-                    msg = "The repository %s contains no revision %s." % (
+                    msg = gettext("The repository {0} contains no revision {1}.").format(
                         b.repository.base, revision_id)
                     raise errors.BzrCommandError(msg)
             elif revision is not None:
                 for rev in revision:
                     if rev is None:
                         raise errors.BzrCommandError(
-                            'You cannot specify a NULL revision.')
+                            gettext('You cannot specify a NULL revision.'))
                     rev_id = rev.as_revision_id(b)
                     self.print_revision(revisions, rev_id)
         finally:
@@ -477,10 +478,10 @@
             try:
                 working = d.open_workingtree()
             except errors.NoWorkingTree:
-                raise errors.BzrCommandError("No working tree to remove")
+                raise errors.BzrCommandError(gettext("No working tree to remove"))
             except errors.NotLocalUrl:
-                raise errors.BzrCommandError("You cannot remove the working tree"
-                                             " of a remote path")
+                raise errors.BzrCommandError(gettext("You cannot remove the working tree"
+                                             " of a remote path"))
             if not force:
                 if (working.has_changes()):
                     raise errors.UncommittedChanges(working)
@@ -488,8 +489,8 @@
                     raise errors.ShelvedChanges(working)
 
             if working.user_url != working.branch.user_url:
-                raise errors.BzrCommandError("You cannot remove the working tree"
-                                             " from a lightweight checkout")
+                raise errors.BzrCommandError(gettext("You cannot remove the working tree"
+                                             " from a lightweight checkout"))
 
             d.destroy_workingtree()
 
@@ -527,10 +528,10 @@
                 pass # There seems to be a real error here, so we'll reset
             else:
                 # Refuse
-                raise errors.BzrCommandError(
+                raise errors.BzrCommandError(gettext(
                     'The tree does not appear to be corrupt. You probably'
                     ' want "bzr revert" instead. Use "--force" if you are'
-                    ' sure you want to reset the working tree.')
+                    ' sure you want to reset the working tree.'))
         if revision is None:
             revision_ids = None
         else:
@@ -539,12 +540,11 @@
             tree.reset_state(revision_ids)
         except errors.BzrError, e:
             if revision_ids is None:
-                extra = (', the header appears corrupt, try passing -r -1'
-                         ' to set the state to the last commit')
+                extra = (gettext(', the header appears corrupt, try passing -r -1'
+                         ' to set the state to the last commit'))
             else:
                 extra = ''
-            raise errors.BzrCommandError('failed to reset the tree state'
-                                         + extra)
+            raise errors.BzrCommandError(gettext('failed to reset the tree state{0}').format(extra))
 
 
 class cmd_revno(Command):
@@ -653,6 +653,9 @@
     are added.  This search proceeds recursively into versioned
     directories.  If no names are given '.' is assumed.
 
+    A warning will be printed when nested trees are encountered,
+    unless they are explicitly ignored.
+
     Therefore simply saying 'bzr add' will version all files that
     are currently unknown.
 
@@ -723,8 +726,9 @@
             if verbose:
                 for glob in sorted(ignored.keys()):
                     for path in ignored[glob]:
-                        self.outf.write("ignored %s matching \"%s\"\n"
-                                        % (path, glob))
+                        self.outf.write(
+                         gettext("ignored {0} matching \"{1}\"\n").format(
+                         path, glob))
 
 
 class cmd_mkdir(Command):
@@ -744,7 +748,7 @@
             if id != None:
                 os.mkdir(d)
                 wt.add([dd])
-                self.outf.write('added %s\n' % d)
+                self.outf.write(gettext('added %s\n') % d)
             else:
                 raise errors.NotVersionedError(path=base)
 
@@ -788,7 +792,7 @@
     @display_command
     def run(self, revision=None, show_ids=False, kind=None, file_list=None):
         if kind and kind not in ['file', 'directory', 'symlink']:
-            raise errors.BzrCommandError('invalid kind %r specified' % (kind,))
+            raise errors.BzrCommandError(gettext('invalid kind %r specified') % (kind,))
 
         revision = _get_one_revision('inventory', revision)
         work_tree, file_list = WorkingTree.open_containing_paths(file_list)
@@ -858,22 +862,22 @@
         if auto:
             return self.run_auto(names_list, after, dry_run)
         elif dry_run:
-            raise errors.BzrCommandError('--dry-run requires --auto.')
+            raise errors.BzrCommandError(gettext('--dry-run requires --auto.'))
         if names_list is None:
             names_list = []
         if len(names_list) < 2:
-            raise errors.BzrCommandError("missing file argument")
+            raise errors.BzrCommandError(gettext("missing file argument"))
         tree, rel_names = WorkingTree.open_containing_paths(names_list, canonicalize=False)
         self.add_cleanup(tree.lock_tree_write().unlock)
         self._run(tree, names_list, rel_names, after)
 
     def run_auto(self, names_list, after, dry_run):
         if names_list is not None and len(names_list) > 1:
-            raise errors.BzrCommandError('Only one path may be specified to'
-                                         ' --auto.')
+            raise errors.BzrCommandError(gettext('Only one path may be specified to'
+                                         ' --auto.'))
         if after:
-            raise errors.BzrCommandError('--after cannot be specified with'
-                                         ' --auto.')
+            raise errors.BzrCommandError(gettext('--after cannot be specified with'
+                                         ' --auto.'))
         work_tree, file_list = WorkingTree.open_containing_paths(
             names_list, default_directory='.')
         self.add_cleanup(work_tree.lock_tree_write().unlock)
@@ -909,9 +913,9 @@
                     self.outf.write("%s => %s\n" % (src, dest))
         else:
             if len(names_list) != 2:
-                raise errors.BzrCommandError('to mv multiple files the'
+                raise errors.BzrCommandError(gettext('to mv multiple files the'
                                              ' destination must be a versioned'
-                                             ' directory')
+                                             ' directory'))
 
             # for cicp file-systems: the src references an existing inventory
             # item:
@@ -1023,7 +1027,7 @@
             self.add_cleanup(branch_to.lock_write().unlock)
 
         if tree_to is None and show_base:
-            raise errors.BzrCommandError("Need working tree for --show-base.")
+            raise errors.BzrCommandError(gettext("Need working tree for --show-base."))
 
         if local and not branch_to.get_bound_location():
             raise errors.LocalRequiresBoundBranch()
@@ -1039,20 +1043,20 @@
         stored_loc = branch_to.get_parent()
         if location is None:
             if stored_loc is None:
-                raise errors.BzrCommandError("No pull location known or"
-                                             " specified.")
+                raise errors.BzrCommandError(gettext("No pull location known or"
+                                             " specified."))
             else:
                 display_url = urlutils.unescape_for_display(stored_loc,
                         self.outf.encoding)
                 if not is_quiet():
-                    self.outf.write("Using saved parent location: %s\n" % display_url)
+                    self.outf.write(gettext("Using saved parent location: %s\n") % display_url)
                 location = stored_loc
 
         revision = _get_one_revision('pull', revision)
         if mergeable is not None:
             if revision is not None:
-                raise errors.BzrCommandError(
-                    'Cannot use -r with merge directives or bundles')
+                raise errors.BzrCommandError(gettext(
+                    'Cannot use -r with merge directives or bundles'))
             mergeable.install_revisions(branch_to.repository)
             base_revision_id, revision_id, verified = \
                 mergeable.get_merge_request(branch_to.repository)
@@ -1186,19 +1190,19 @@
                     # error by the feedback given to them. RBC 20080227.
                     stacked_on = parent_url
             if not stacked_on:
-                raise errors.BzrCommandError(
-                    "Could not determine branch to refer to.")
+                raise errors.BzrCommandError(gettext(
+                    "Could not determine branch to refer to."))
 
         # Get the destination location
         if location is None:
             stored_loc = br_from.get_push_location()
             if stored_loc is None:
-                raise errors.BzrCommandError(
-                    "No push location known or specified.")
+                raise errors.BzrCommandError(gettext(
+                    "No push location known or specified."))
             else:
                 display_url = urlutils.unescape_for_display(stored_loc,
                         self.outf.encoding)
-                note("Using saved push location: %s" % display_url)
+                note(gettext("Using saved push location: %s") % display_url)
                 location = stored_loc
 
         _show_push_branch(br_from, revision_id, location, self.outf,
@@ -1287,8 +1291,8 @@
             to_transport.mkdir('.')
         except errors.FileExists:
             if not use_existing_dir:
-                raise errors.BzrCommandError('Target directory "%s" '
-                    'already exists.' % to_location)
+                raise errors.BzrCommandError(gettext('Target directory "%s" '
+                    'already exists.') % to_location)
             else:
                 try:
                     bzrdir.BzrDir.open_from_transport(to_transport)
@@ -1297,7 +1301,7 @@
                 else:
                     raise errors.AlreadyBranchError(to_location)
         except errors.NoSuchFile:
-            raise errors.BzrCommandError('Parent of "%s" does not exist.'
+            raise errors.BzrCommandError(gettext('Parent of "%s" does not exist.')
                                          % to_location)
         try:
             # preserve whatever source format we have.
@@ -1311,29 +1315,29 @@
             branch = dir.open_branch()
         except errors.NoSuchRevision:
             to_transport.delete_tree('.')
-            msg = "The branch %s has no revision %s." % (from_location,
-                revision)
+            msg = gettext("The branch {0} has no revision {1}.").format(
+                from_location, revision)
             raise errors.BzrCommandError(msg)
         _merge_tags_if_possible(br_from, branch)
         # If the source branch is stacked, the new branch may
         # be stacked whether we asked for that explicitly or not.
         # We therefore need a try/except here and not just 'if stacked:'
         try:
-            note('Created new stacked branch referring to %s.' %
+            note(gettext('Created new stacked branch referring to %s.') %
                 branch.get_stacked_on_url())
         except (errors.NotStacked, errors.UnstackableBranchFormat,
             errors.UnstackableRepositoryFormat), e:
-            note('Branched %d revision(s).' % branch.revno())
+            note(ngettext('Branched %d revision.', 'Branched %d revisions.', branch.revno()) % branch.revno())
         if bind:
             # Bind to the parent
             parent_branch = Branch.open(from_location)
             branch.bind(parent_branch)
-            note('New branch bound to %s' % from_location)
+            note(gettext('New branch bound to %s') % from_location)
         if switch:
             # Switch to the new branch
             wt, _ = WorkingTree.open_containing('.')
             _mod_switch.switch(wt.bzrdir, branch)
-            note('Switched to branch: %s',
+            note(gettext('Switched to branch: %s'),
                 urlutils.unescape_for_display(branch.base, 'utf-8'))
 
 
@@ -1349,7 +1353,7 @@
         dir = bzrdir.BzrDir.open_containing(location)[0]
         for branch in dir.list_branches():
             if branch.name is None:
-                self.outf.write(" (default)\n")
+                self.outf.write(gettext(" (default)\n"))
             else:
                 self.outf.write(" %s\n" % branch.name.encode(self.outf.encoding))
 
@@ -1485,8 +1489,8 @@
 
     def run(self, dir='.', revision=None, show_base=None):
         if revision is not None and len(revision) != 1:
-            raise errors.BzrCommandError(
-                        "bzr update --revision takes exactly one revision")
+            raise errors.BzrCommandError(gettext(
+                        "bzr update --revision takes exactly one revision"))
         tree = WorkingTree.open_containing(dir)[0]
         branch = tree.branch
         possible_transports = []
@@ -1517,8 +1521,8 @@
             revision_id = branch.last_revision()
         if revision_id == _mod_revision.ensure_null(tree.last_revision()):
             revno = branch.revision_id_to_dotted_revno(revision_id)
-            note("Tree is up to date at revision %s of branch %s" %
-                ('.'.join(map(str, revno)), branch_location))
+            note(gettext("Tree is up to date at revision {0} of branch {1}"
+                        ).format('.'.join(map(str, revno)), branch_location))
             return 0
         view_info = _get_view_info_for_change_reporter(tree)
         change_reporter = delta._ChangeReporter(
@@ -1532,19 +1536,19 @@
                 old_tip=old_tip,
                 show_base=show_base)
         except errors.NoSuchRevision, e:
-            raise errors.BzrCommandError(
+            raise errors.BzrCommandError(gettext(
                                   "branch has no revision %s\n"
                                   "bzr update --revision only works"
-                                  " for a revision in the branch history"
+                                  " for a revision in the branch history")
                                   % (e.revision))
         revno = tree.branch.revision_id_to_dotted_revno(
             _mod_revision.ensure_null(tree.last_revision()))
-        note('Updated to revision %s of branch %s' %
-             ('.'.join(map(str, revno)), branch_location))
+        note(gettext('Updated to revision {0} of branch {1}').format(
+             '.'.join(map(str, revno)), branch_location))
         parent_ids = tree.get_parent_ids()
         if parent_ids[1:] and parent_ids[1:] != existing_pending_merges:
-            note('Your local commits will now show as pending merges with '
-                 "'bzr status', and can be committed with 'bzr commit'.")
+            note(gettext('Your local commits will now show as pending merges with '
+                 "'bzr status', and can be committed with 'bzr commit'."))
         if conflicts != 0:
             return 1
         else:
@@ -1622,8 +1626,8 @@
     def run(self, file_list, verbose=False, new=False,
         file_deletion_strategy='safe'):
         if file_deletion_strategy == 'force':
-            note("(The --force option is deprecated, rather use --no-backup "
-                "in future.)")
+            note(gettext("(The --force option is deprecated, rather use --no-backup "
+                "in future.)"))
             file_deletion_strategy = 'no-backup'
 
         tree, file_list = WorkingTree.open_containing_paths(file_list)
@@ -1639,7 +1643,7 @@
                 specific_files=file_list).added
             file_list = sorted([f[0] for f in added], reverse=True)
             if len(file_list) == 0:
-                raise errors.BzrCommandError('No matching files.')
+                raise errors.BzrCommandError(gettext('No matching files.'))
         elif file_list is None:
             # missing files show up in iter_changes(basis) as
             # versioned-with-no-kind.
@@ -1839,10 +1843,10 @@
             to_transport.ensure_base()
         except errors.NoSuchFile:
             if not create_prefix:
-                raise errors.BzrCommandError("Parent directory of %s"
+                raise errors.BzrCommandError(gettext("Parent directory of %s"
                     " does not exist."
                     "\nYou may supply --create-prefix to create all"
-                    " leading parent directories."
+                    " leading parent directories.")
                     % location)
             to_transport.create_prefix()
 
@@ -1873,8 +1877,8 @@
             try:
                 branch.set_append_revisions_only(True)
             except errors.UpgradeRequired:
-                raise errors.BzrCommandError('This branch format cannot be set'
-                    ' to append-revisions-only.  Try --default.')
+                raise errors.BzrCommandError(gettext('This branch format cannot be set'
+                    ' to append-revisions-only.  Try --default.'))
         if not is_quiet():
             from bzrlib.info import describe_layout, describe_format
             try:
@@ -1884,7 +1888,8 @@
             repository = branch.repository
             layout = describe_layout(repository, branch, tree).lower()
             format = describe_format(a_bzrdir, repository, branch, tree)
-            self.outf.write("Created a %s (format: %s)\n" % (layout, format))
+            self.outf.write(gettext("Created a {0} (format: {1})\n").format(
+                  layout, format))
             if repository.is_shared():
                 #XXX: maybe this can be refactored into transport.path_or_url()
                 url = repository.bzrdir.root_transport.external_url()
@@ -1892,7 +1897,7 @@
                     url = urlutils.local_path_from_url(url)
                 except errors.InvalidURL:
                     pass
-                self.outf.write("Using shared repository: %s\n" % url)
+                self.outf.write(gettext("Using shared repository: %s\n") % url)
 
 
 class cmd_init_repository(Command):
@@ -2089,17 +2094,18 @@
         elif ':' in prefix:
             old_label, new_label = prefix.split(":")
         else:
-            raise errors.BzrCommandError(
+            raise errors.BzrCommandError(gettext(
                 '--prefix expects two values separated by a colon'
-                ' (eg "old/:new/")')
+                ' (eg "old/:new/")'))
 
         if revision and len(revision) > 2:
-            raise errors.BzrCommandError('bzr diff --revision takes exactly'
-                                         ' one or two revision specifiers')
+            raise errors.BzrCommandError(gettext('bzr diff --revision takes exactly'
+                                         ' one or two revision specifiers'))
 
         if using is not None and format is not None:
-            raise errors.BzrCommandError('--using and --format are mutually '
-                'exclusive.')
+            raise errors.BzrCommandError(gettext(
+                '{0} and {1} are mutually exclusive').format(
+                '--using', '--format'))
 
         (old_tree, new_tree,
          old_branch, new_branch,
@@ -2213,7 +2219,7 @@
     try:
         return int(limitstring)
     except ValueError:
-        msg = "The limit argument must be an integer."
+        msg = gettext("The limit argument must be an integer.")
         raise errors.BzrCommandError(msg)
 
 
@@ -2221,7 +2227,7 @@
     try:
         return int(s)
     except ValueError:
-        msg = "The levels argument must be an integer."
+        msg = gettext("The levels argument must be an integer.")
         raise errors.BzrCommandError(msg)
 
 
@@ -2419,8 +2425,12 @@
             Option('show-diff',
                    short_name='p',
                    help='Show changes made in each revision as a patch.'),
-            Option('include-merges',
+            Option('include-merged',
                    help='Show merged revisions like --levels 0 does.'),
+            Option('include-merges', hidden=True,
+                   help='Historical alias for --include-merged.'),
+            Option('omit-merges',
+                   help='Do not report commits with more than one parent.'),
             Option('exclude-common-ancestry',
                    help='Display only the revisions that are not part'
                    ' of both ancestries (require -rX..Y)'
@@ -2463,7 +2473,7 @@
             message=None,
             limit=None,
             show_diff=False,
-            include_merges=False,
+            include_merged=None,
             authors=None,
             exclude_common_ancestry=False,
             signatures=False,
@@ -2472,6 +2482,8 @@
             match_committer=None,
             match_author=None,
             match_bugs=None,
+            omit_merges=False,
+            include_merges=symbol_versioning.DEPRECATED_PARAMETER,
             ):
         from bzrlib.log import (
             Logger,
@@ -2479,23 +2491,40 @@
             _get_info_for_log_files,
             )
         direction = (forward and 'forward') or 'reverse'
+        if symbol_versioning.deprecated_passed(include_merges):
+            ui.ui_factory.show_user_warning(
+                'deprecated_command_option',
+                deprecated_name='--include-merges',
+                recommended_name='--include-merged',
+                deprecated_in_version='2.5',
+                command=self.invoked_as)
+            if include_merged is None:
+                include_merged = include_merges
+            else:
+                raise errors.BzrCommandError(gettext(
+                    '{0} and {1} are mutually exclusive').format(
+                    '--include-merges', '--include-merged'))
+        if include_merged is None:
+            include_merged = False
         if (exclude_common_ancestry
             and (revision is None or len(revision) != 2)):
-            raise errors.BzrCommandError(
-                '--exclude-common-ancestry requires -r with two revisions')
-        if include_merges:
+            raise errors.BzrCommandError(gettext(
+                '--exclude-common-ancestry requires -r with two revisions'))
+        if include_merged:
             if levels is None:
                 levels = 0
             else:
-                raise errors.BzrCommandError(
-                    '--levels and --include-merges are mutually exclusive')
+                raise errors.BzrCommandError(gettext(
+                    '{0} and {1} are mutually exclusive').format(
+                    '--levels', '--include-merged'))
 
         if change is not None:
             if len(change) > 1:
                 raise errors.RangeInChangeOption()
             if revision is not None:
-                raise errors.BzrCommandError(
-                    '--revision and --change are mutually exclusive')
+                raise errors.BzrCommandError(gettext(
+                    '{0} and {1} are mutually exclusive').format(
+                    '--revision', '--change'))
             else:
                 revision = change
 
@@ -2507,8 +2536,8 @@
                 revision, file_list, self.add_cleanup)
             for relpath, file_id, kind in file_info_list:
                 if file_id is None:
-                    raise errors.BzrCommandError(
-                        "Path unknown at end or start of revision range: %s" %
+                    raise errors.BzrCommandError(gettext(
+                        "Path unknown at end or start of revision range: %s") %
                         relpath)
                 # If the relpath is the top of the tree, we log everything
                 if relpath == '':
@@ -2591,7 +2620,7 @@
             match_dict['author'] = match_author
         if match_bugs:
             match_dict['bugs'] = match_bugs
-            
+
         # Build the LogRequest and execute it
         if len(file_ids) == 0:
             file_ids = None
@@ -2601,7 +2630,7 @@
             message_search=message, delta_type=delta_type,
             diff_type=diff_type, _match_using_deltas=match_using_deltas,
             exclude_common_ancestry=exclude_common_ancestry, match=match_dict,
-            signature=signatures
+            signature=signatures, omit_merges=omit_merges,
             )
         Logger(b, rqst).show(lf)
 
@@ -2624,9 +2653,9 @@
             # b is taken from revision[0].get_branch(), and
             # show_log will use its revision_history. Having
             # different branches will lead to weird behaviors.
-            raise errors.BzrCommandError(
+            raise errors.BzrCommandError(gettext(
                 "bzr %s doesn't accept two revisions in different"
-                " branches." % command_name)
+                " branches.") % command_name)
         if start_spec.spec is None:
             # Avoid loading all the history.
             rev1 = RevisionInfo(branch, None, None)
@@ -2640,8 +2669,8 @@
         else:
             rev2 = end_spec.in_history(branch)
     else:
-        raise errors.BzrCommandError(
-            'bzr %s --revision takes one or two values.' % command_name)
+        raise errors.BzrCommandError(gettext(
+            'bzr %s --revision takes one or two values.') % command_name)
     return rev1, rev2
 
 
@@ -2718,10 +2747,10 @@
             null=False, kind=None, show_ids=False, path=None, directory=None):
 
         if kind and kind not in ('file', 'directory', 'symlink'):
-            raise errors.BzrCommandError('invalid kind specified')
+            raise errors.BzrCommandError(gettext('invalid kind specified'))
 
         if verbose and null:
-            raise errors.BzrCommandError('Cannot set both --verbose and --null')
+            raise errors.BzrCommandError(gettext('Cannot set both --verbose and --null'))
         all = not (unknown or versioned or ignored)
 
         selection = {'I':ignored, '?':unknown, 'V':versioned}
@@ -2730,8 +2759,8 @@
             fs_path = '.'
         else:
             if from_root:
-                raise errors.BzrCommandError('cannot specify both --from-root'
-                                             ' and PATH')
+                raise errors.BzrCommandError(gettext('cannot specify both --from-root'
+                                             ' and PATH'))
             fs_path = path
         tree, branch, relpath = \
             _open_directory_or_containing_tree_or_branch(fs_path, directory)
@@ -2753,7 +2782,7 @@
             if view_files:
                 apply_view = True
                 view_str = views.view_display_str(view_files)
-                note("Ignoring files outside view. View is %s" % view_str)
+                note(gettext("Ignoring files outside view. View is %s") % view_str)
 
         self.add_cleanup(tree.lock_read().unlock)
         for fp, fc, fkind, fid, entry in tree.list_files(include_root=False,
@@ -2906,23 +2935,27 @@
                 self.outf.write("%s\n" % pattern)
             return
         if not name_pattern_list:
-            raise errors.BzrCommandError("ignore requires at least one "
-                "NAME_PATTERN or --default-rules.")
+            raise errors.BzrCommandError(gettext("ignore requires at least one "
+                "NAME_PATTERN or --default-rules."))
         name_pattern_list = [globbing.normalize_pattern(p)
                              for p in name_pattern_list]
         bad_patterns = ''
+        bad_patterns_count = 0
         for p in name_pattern_list:
             if not globbing.Globster.is_pattern_valid(p):
+                bad_patterns_count += 1
                 bad_patterns += ('\n  %s' % p)
         if bad_patterns:
-            msg = ('Invalid ignore pattern(s) found. %s' % bad_patterns)
+            msg = (ngettext('Invalid ignore pattern found. %s', 
+                            'Invalid ignore patterns found. %s',
+                            bad_patterns_count) % bad_patterns)
             ui.ui_factory.show_error(msg)
             raise errors.InvalidPattern('')
         for name_pattern in name_pattern_list:
             if (name_pattern[0] == '/' or
                 (len(name_pattern) > 1 and name_pattern[1] == ':')):
-                raise errors.BzrCommandError(
-                    "NAME_PATTERN should not be an absolute path")
+                raise errors.BzrCommandError(gettext(
+                    "NAME_PATTERN should not be an absolute path"))
         tree, relpath = WorkingTree.open_containing(directory)
         ignores.tree_ignores_add_patterns(tree, name_pattern_list)
         ignored = globbing.Globster(name_pattern_list)
@@ -2935,10 +2968,10 @@
                 if ignored.match(filename):
                     matches.append(filename)
         if len(matches) > 0:
-            self.outf.write("Warning: the following files are version controlled and"
-                  " match your ignore pattern:\n%s"
+            self.outf.write(gettext("Warning: the following files are version "
+                  "controlled and match your ignore pattern:\n%s"
                   "\nThese files will continue to be version controlled"
-                  " unless you 'bzr remove' them.\n" % ("\n".join(matches),))
+                  " unless you 'bzr remove' them.\n") % ("\n".join(matches),))
 
 
 class cmd_ignored(Command):
@@ -2983,7 +3016,7 @@
         try:
             revno = int(revno)
         except ValueError:
-            raise errors.BzrCommandError("not a valid revision-number: %r"
+            raise errors.BzrCommandError(gettext("not a valid revision-number: %r")
                                          % revno)
         revid = WorkingTree.open_containing(directory)[0].branch.get_rev_id(revno)
         self.outf.write("%s\n" % revid)
@@ -3050,7 +3083,7 @@
             export(rev_tree, dest, format, root, subdir, filtered=filters,
                    per_file_timestamps=per_file_timestamps)
         except errors.NoSuchExportFormat, e:
-            raise errors.BzrCommandError('Unsupported export format: %s' % e.format)
+            raise errors.BzrCommandError(gettext('Unsupported export format: %s') % e.format)
 
 
 class cmd_cat(Command):
@@ -3076,8 +3109,8 @@
     def run(self, filename, revision=None, name_from_revision=False,
             filters=False, directory=None):
         if revision is not None and len(revision) != 1:
-            raise errors.BzrCommandError("bzr cat --revision takes exactly"
-                                         " one revision specifier")
+            raise errors.BzrCommandError(gettext("bzr cat --revision takes exactly"
+                                         " one revision specifier"))
         tree, branch, relpath = \
             _open_directory_or_containing_tree_or_branch(filename, directory)
         self.add_cleanup(branch.lock_read().unlock)
@@ -3100,8 +3133,8 @@
         if name_from_revision:
             # Try in revision if requested
             if old_file_id is None:
-                raise errors.BzrCommandError(
-                    "%r is not present in revision %s" % (
+                raise errors.BzrCommandError(gettext(
+                    "{0!r} is not present in revision {1}").format(
                         filename, rev_tree.get_revision_id()))
             else:
                 actual_file_id = old_file_id
@@ -3112,8 +3145,8 @@
             elif old_file_id is not None:
                 actual_file_id = old_file_id
             else:
-                raise errors.BzrCommandError(
-                    "%r is not present in revision %s" % (
+                raise errors.BzrCommandError(gettext(
+                    "{0!r} is not present in revision {1}").format(
                         filename, rev_tree.get_revision_id()))
         if filtered:
             from bzrlib.filter_tree import ContentFilterTree
@@ -3246,29 +3279,29 @@
                     default_bugtracker = branch_config.get_user_option(
                         "bugtracker")
                 if default_bugtracker is None:
-                    raise errors.BzrCommandError(
+                    raise errors.BzrCommandError(gettext(
                         "No tracker specified for bug %s. Use the form "
                         "'tracker:id' or specify a default bug tracker "
                         "using the `bugtracker` option.\nSee "
                         "\"bzr help bugs\" for more information on this "
-                        "feature. Commit refused." % fixed_bug)
+                        "feature. Commit refused.") % fixed_bug)
                 tag = default_bugtracker
                 bug_id = tokens[0]
             elif len(tokens) != 2:
-                raise errors.BzrCommandError(
+                raise errors.BzrCommandError(gettext(
                     "Invalid bug %s. Must be in the form of 'tracker:id'. "
                     "See \"bzr help bugs\" for more information on this "
-                    "feature.\nCommit refused." % fixed_bug)
+                    "feature.\nCommit refused.") % fixed_bug)
             else:
                 tag, bug_id = tokens
             try:
                 yield bugtracker.get_bug_url(tag, branch, bug_id)
             except errors.UnknownBugTrackerAbbreviation:
-                raise errors.BzrCommandError(
-                    'Unrecognized bug %s. Commit refused.' % fixed_bug)
+                raise errors.BzrCommandError(gettext(
+                    'Unrecognized bug %s. Commit refused.') % fixed_bug)
             except errors.MalformedBugIdentifier, e:
-                raise errors.BzrCommandError(
-                    "%s\nCommit refused." % (str(e),))
+                raise errors.BzrCommandError(gettext(
+                    "%s\nCommit refused.") % (str(e),))
 
     def run(self, message=None, file=None, verbose=False, selected_list=None,
             unchanged=False, strict=False, local=False, fixes=None,
@@ -3291,8 +3324,8 @@
             try:
                 commit_stamp, offset = timestamp.parse_patch_date(commit_time)
             except ValueError, e:
-                raise errors.BzrCommandError(
-                    "Could not parse --commit-time: " + str(e))
+                raise errors.BzrCommandError(gettext(
+                    "Could not parse --commit-time: " + str(e)))
 
         properties = {}
 
@@ -3331,8 +3364,8 @@
                 message = message.replace('\r\n', '\n')
                 message = message.replace('\r', '\n')
             if file:
-                raise errors.BzrCommandError(
-                    "please specify either --message or --file")
+                raise errors.BzrCommandError(gettext(
+                    "please specify either --message or --file"))
 
         def get_message(commit_obj):
             """Callback to get commit message"""
@@ -3361,13 +3394,13 @@
                     my_message = edit_commit_message_encoded(text,
                         start_message=start_message)
                 if my_message is None:
-                    raise errors.BzrCommandError("please specify a commit"
-                        " message with either --message or --file")
+                    raise errors.BzrCommandError(gettext("please specify a commit"
+                        " message with either --message or --file"))
                 if my_message == "":
-                    raise errors.BzrCommandError("Empty commit message specified."
+                    raise errors.BzrCommandError(gettext("Empty commit message specified."
                             " Please specify a commit message with either"
                             " --message or --file or leave a blank message"
-                            " with --message \"\".")
+                            " with --message \"\"."))
             return my_message
 
         # The API permits a commit with a filter of [] to mean 'select nothing'
@@ -3384,21 +3417,21 @@
                         exclude=tree.safe_relpath_files(exclude),
                         lossy=lossy)
         except PointlessCommit:
-            raise errors.BzrCommandError("No changes to commit."
+            raise errors.BzrCommandError(gettext("No changes to commit."
                 " Please 'bzr add' the files you want to commit, or use"
-                " --unchanged to force an empty commit.")
+                " --unchanged to force an empty commit."))
         except ConflictsInTree:
-            raise errors.BzrCommandError('Conflicts detected in working '
+            raise errors.BzrCommandError(gettext('Conflicts detected in working '
                 'tree.  Use "bzr conflicts" to list, "bzr resolve FILE" to'
-                ' resolve.')
+                ' resolve.'))
         except StrictCommitFailed:
-            raise errors.BzrCommandError("Commit refused because there are"
-                              " unknown files in the working tree.")
+            raise errors.BzrCommandError(gettext("Commit refused because there are"
+                              " unknown files in the working tree."))
         except errors.BoundBranchOutOfDate, e:
-            e.extra_help = ("\n"
+            e.extra_help = (gettext("\n"
                 'To commit to master branch, run update and then commit.\n'
                 'You can also pass --local to commit to continue working '
-                'disconnected.')
+                'disconnected.'))
             raise
 
 
@@ -3571,8 +3604,8 @@
             return
 
         if email:
-            raise errors.BzrCommandError("--email can only be used to display existing "
-                                         "identity")
+            raise errors.BzrCommandError(gettext("--email can only be used to display existing "
+                                         "identity"))
 
         # display a warning if an email address isn't included in the given name.
         try:
@@ -3657,8 +3690,8 @@
 
     def remove_alias(self, alias_name):
         if alias_name is None:
-            raise errors.BzrCommandError(
-                'bzr alias --remove expects an alias to remove.')
+            raise errors.BzrCommandError(gettext(
+                'bzr alias --remove expects an alias to remove.'))
         # If alias is not found, print something like:
         # unalias: foo: not found
         c = _mod_config.GlobalConfig()
@@ -3830,8 +3863,8 @@
             try:
                 from bzrlib.tests import SubUnitBzrRunner
             except ImportError:
-                raise errors.BzrCommandError("subunit not available. subunit "
-                    "needs to be installed to use --subunit.")
+                raise errors.BzrCommandError(gettext("subunit not available. subunit "
+                    "needs to be installed to use --subunit."))
             self.additional_selftest_args['runner_class'] = SubUnitBzrRunner
             # On Windows, disable automatic conversion of '\n' to '\r\n' in
             # stdout, which would corrupt the subunit stream. 
@@ -3846,9 +3879,9 @@
             self.additional_selftest_args.setdefault(
                 'suite_decorators', []).append(parallel)
         if benchmark:
-            raise errors.BzrCommandError(
+            raise errors.BzrCommandError(gettext(
                 "--benchmark is no longer supported from bzr 2.2; "
-                "use bzr-usertest instead")
+                "use bzr-usertest instead"))
         test_suite_factory = None
         if not exclude:
             exclude_pattern = None
@@ -3917,7 +3950,7 @@
 
     @display_command
     def run(self):
-        self.outf.write("It sure does!\n")
+        self.outf.write(gettext("It sure does!\n"))
 
 
 class cmd_find_merge_base(Command):
@@ -3941,7 +3974,7 @@
         graph = branch1.repository.get_graph(branch2.repository)
         base_rev_id = graph.find_unique_lca(last1, last2)
 
-        self.outf.write('merge base is revision %s\n' % base_rev_id)
+        self.outf.write(gettext('merge base is revision %s\n') % base_rev_id)
 
 
 class cmd_merge(Command):
@@ -4072,8 +4105,8 @@
 
         tree = WorkingTree.open_containing(directory)[0]
         if tree.branch.revno() == 0:
-            raise errors.BzrCommandError('Merging into empty branches not currently supported, '
-                                         'https://bugs.launchpad.net/bzr/+bug/308562')
+            raise errors.BzrCommandError(gettext('Merging into empty branches not currently supported, '
+                                         'https://bugs.launchpad.net/bzr/+bug/308562'))
 
         try:
             basis_tree = tree.revision_tree(tree.last_revision())
@@ -4099,19 +4132,19 @@
                 mergeable = None
             else:
                 if uncommitted:
-                    raise errors.BzrCommandError('Cannot use --uncommitted'
-                        ' with bundles or merge directives.')
+                    raise errors.BzrCommandError(gettext('Cannot use --uncommitted'
+                        ' with bundles or merge directives.'))
 
                 if revision is not None:
-                    raise errors.BzrCommandError(
-                        'Cannot use -r with merge directives or bundles')
+                    raise errors.BzrCommandError(gettext(
+                        'Cannot use -r with merge directives or bundles'))
                 merger, verified = _mod_merge.Merger.from_mergeable(tree,
                    mergeable, None)
 
         if merger is None and uncommitted:
             if revision is not None and len(revision) > 0:
-                raise errors.BzrCommandError('Cannot use --uncommitted and'
-                    ' --revision at the same time.')
+                raise errors.BzrCommandError(gettext('Cannot use --uncommitted and'
+                    ' --revision at the same time.'))
             merger = self.get_merger_from_uncommitted(tree, location, None)
             allow_pending = False
 
@@ -4130,22 +4163,22 @@
             if merger.interesting_files:
                 if not merger.other_tree.has_filename(
                     merger.interesting_files[0]):
-                    note("merger: " + str(merger))
+                    note(gettext("merger: ") + str(merger))
                     raise errors.PathsDoNotExist([location])
-            note('Nothing to do.')
+            note(gettext('Nothing to do.'))
             return 0
         if pull and not preview:
             if merger.interesting_files is not None:
-                raise errors.BzrCommandError('Cannot pull individual files')
+                raise errors.BzrCommandError(gettext('Cannot pull individual files'))
             if (merger.base_rev_id == tree.last_revision()):
                 result = tree.pull(merger.other_branch, False,
                                    merger.other_rev_id)
                 result.report(self.outf)
                 return 0
         if merger.this_basis is None:
-            raise errors.BzrCommandError(
+            raise errors.BzrCommandError(gettext(
                 "This branch has no commits."
-                " (perhaps you would prefer 'bzr pull')")
+                " (perhaps you would prefer 'bzr pull')"))
         if preview:
             return self._do_preview(merger)
         elif interactive:
@@ -4202,8 +4235,8 @@
     def sanity_check_merger(self, merger):
         if (merger.show_base and
             not merger.merge_type is _mod_merge.Merge3Merger):
-            raise errors.BzrCommandError("Show-base is not supported for this"
-                                         " merge type. %s" % merger.merge_type)
+            raise errors.BzrCommandError(gettext("Show-base is not supported for this"
+                                         " merge type. %s") % merger.merge_type)
         if merger.reprocess is None:
             if merger.show_base:
                 merger.reprocess = False
@@ -4211,12 +4244,12 @@
                 # Use reprocess if the merger supports it
                 merger.reprocess = merger.merge_type.supports_reprocess
         if merger.reprocess and not merger.merge_type.supports_reprocess:
-            raise errors.BzrCommandError("Conflict reduction is not supported"
-                                         " for merge type %s." %
+            raise errors.BzrCommandError(gettext("Conflict reduction is not supported"
+                                         " for merge type %s.") %
                                          merger.merge_type)
         if merger.reprocess and merger.show_base:
-            raise errors.BzrCommandError("Cannot do conflict reduction and"
-                                         " show base.")
+            raise errors.BzrCommandError(gettext("Cannot do conflict reduction and"
+                                         " show base."))
 
     def _get_merger_from_branch(self, tree, location, revision, remember,
                                 possible_transports, pb):
@@ -4326,10 +4359,10 @@
             stored_location_type = "parent"
         mutter("%s", stored_location)
         if stored_location is None:
-            raise errors.BzrCommandError("No location specified or remembered")
+            raise errors.BzrCommandError(gettext("No location specified or remembered"))
         display_url = urlutils.unescape_for_display(stored_location, 'utf-8')
-        note(u"%s remembered %s location %s", verb_string,
-                stored_location_type, display_url)
+        note(gettext("{0} remembered {1} location {2}").format(verb_string,
+                stored_location_type, display_url))
         return stored_location
 
 
@@ -4372,9 +4405,9 @@
         self.add_cleanup(tree.lock_write().unlock)
         parents = tree.get_parent_ids()
         if len(parents) != 2:
-            raise errors.BzrCommandError("Sorry, remerge only works after normal"
+            raise errors.BzrCommandError(gettext("Sorry, remerge only works after normal"
                                          " merges.  Not cherrypicking or"
-                                         " multi-merges.")
+                                         " multi-merges."))
         repository = tree.branch.repository
         interesting_ids = None
         new_conflicts = []
@@ -4599,8 +4632,10 @@
             type=_parse_revision_str,
             help='Filter on local branch revisions (inclusive). '
                 'See "help revisionspec" for details.'),
-        Option('include-merges',
+        Option('include-merged',
                'Show all revisions in addition to the mainline ones.'),
+        Option('include-merges', hidden=True,
+               help='Historical alias for --include-merged.'),
         ]
     encoding_type = 'replace'
 
@@ -4609,13 +4644,29 @@
             theirs_only=False,
             log_format=None, long=False, short=False, line=False,
             show_ids=False, verbose=False, this=False, other=False,
-            include_merges=False, revision=None, my_revision=None,
-            directory=u'.'):
+            include_merged=None, revision=None, my_revision=None,
+            directory=u'.',
+            include_merges=symbol_versioning.DEPRECATED_PARAMETER):
         from bzrlib.missing import find_unmerged, iter_log_revisions
         def message(s):
             if not is_quiet():
                 self.outf.write(s)
 
+        if symbol_versioning.deprecated_passed(include_merges):
+            ui.ui_factory.show_user_warning(
+                'deprecated_command_option',
+                deprecated_name='--include-merges',
+                recommended_name='--include-merged',
+                deprecated_in_version='2.5',
+                command=self.invoked_as)
+            if include_merged is None:
+                include_merged = include_merges
+            else:
+                raise errors.BzrCommandError(gettext(
+                    '{0} and {1} are mutually exclusive').format(
+                    '--include-merges', '--include-merged'))
+        if include_merged is None:
+            include_merged = False
         if this:
             mine_only = this
         if other:
@@ -4636,12 +4687,12 @@
         if other_branch is None:
             other_branch = parent
             if other_branch is None:
-                raise errors.BzrCommandError("No peer location known"
-                                             " or specified.")
+                raise errors.BzrCommandError(gettext("No peer location known"
+                                             " or specified."))
             display_url = urlutils.unescape_for_display(parent,
                                                         self.outf.encoding)
-            message("Using saved parent location: "
-                    + display_url + "\n")
+            message(gettext("Using saved parent location: {0}\n").format(
+                    display_url))
 
         remote_branch = Branch.open(other_branch)
         if remote_branch.base == local_branch.base:
@@ -4660,7 +4711,7 @@
         local_extra, remote_extra = find_unmerged(
             local_branch, remote_branch, restrict,
             backward=not reverse,
-            include_merges=include_merges,
+            include_merged=include_merged,
             local_revid_range=local_revid_range,
             remote_revid_range=remote_revid_range)
 
@@ -4673,7 +4724,9 @@
 
         status_code = 0
         if local_extra and not theirs_only:
-            message("You have %d extra revision(s):\n" %
+            message(ngettext("You have %d extra revision:\n",
+                             "You have %d extra revisions:\n", 
+                             len(local_extra)) %
                 len(local_extra))
             for revision in iter_log_revisions(local_extra,
                                 local_branch.repository,
@@ -4687,7 +4740,9 @@
         if remote_extra and not mine_only:
             if printed_local is True:
                 message("\n\n\n")
-            message("You are missing %d revision(s):\n" %
+            message(ngettext("You are missing %d revision:\n",
+                             "You are missing %d revisions:\n",
+                             len(remote_extra)) %
                 len(remote_extra))
             for revision in iter_log_revisions(remote_extra,
                                 remote_branch.repository,
@@ -4697,15 +4752,15 @@
 
         if mine_only and not local_extra:
             # We checked local, and found nothing extra
-            message('This branch has no new revisions.\n')
+            message(gettext('This branch has no new revisions.\n'))
         elif theirs_only and not remote_extra:
             # We checked remote, and found nothing extra
-            message('Other branch has no new revisions.\n')
+            message(gettext('Other branch has no new revisions.\n'))
         elif not (mine_only or theirs_only or local_extra or
                   remote_extra):
             # We checked both branches, and neither one had extra
             # revisions
-            message("Branches are up to date.\n")
+            message(gettext("Branches are up to date.\n"))
         self.cleanup_now()
         if not status_code and parent is None and other_branch is not None:
             self.add_cleanup(local_branch.lock_write().unlock)
@@ -4872,9 +4927,9 @@
 
     def run(self, revision_id_list=None, revision=None, directory=u'.'):
         if revision_id_list is not None and revision is not None:
-            raise errors.BzrCommandError('You can only supply one of revision_id or --revision')
+            raise errors.BzrCommandError(gettext('You can only supply one of revision_id or --revision'))
         if revision_id_list is None and revision is None:
-            raise errors.BzrCommandError('You must supply either --revision or a revision_id')
+            raise errors.BzrCommandError(gettext('You must supply either --revision or a revision_id'))
         b = WorkingTree.open_containing(directory)[0].branch
         self.add_cleanup(b.lock_write().unlock)
         return self._run(b, revision_id_list, revision)
@@ -4912,7 +4967,7 @@
                 if to_revid is None:
                     to_revno = b.revno()
                 if from_revno is None or to_revno is None:
-                    raise errors.BzrCommandError('Cannot sign a range of non-revision-history revisions')
+                    raise errors.BzrCommandError(gettext('Cannot sign a range of non-revision-history revisions'))
                 b.repository.start_write_group()
                 try:
                     for revno in range(from_revno, to_revno + 1):
@@ -4924,7 +4979,7 @@
                 else:
                     b.repository.commit_write_group()
             else:
-                raise errors.BzrCommandError('Please supply either one revision, or a range.')
+                raise errors.BzrCommandError(gettext('Please supply either one revision, or a range.'))
 
 
 class cmd_bind(Command):
@@ -4949,21 +5004,21 @@
             try:
                 location = b.get_old_bound_location()
             except errors.UpgradeRequired:
-                raise errors.BzrCommandError('No location supplied.  '
-                    'This format does not remember old locations.')
+                raise errors.BzrCommandError(gettext('No location supplied.  '
+                    'This format does not remember old locations.'))
             else:
                 if location is None:
                     if b.get_bound_location() is not None:
-                        raise errors.BzrCommandError('Branch is already bound')
+                        raise errors.BzrCommandError(gettext('Branch is already bound'))
                     else:
-                        raise errors.BzrCommandError('No location supplied '
-                            'and no previous location known')
+                        raise errors.BzrCommandError(gettext('No location supplied '
+                            'and no previous location known'))
         b_other = Branch.open(location)
         try:
             b.bind(b_other)
         except errors.DivergedBranches:
-            raise errors.BzrCommandError('These branches have diverged.'
-                                         ' Try merging, and then bind again.')
+            raise errors.BzrCommandError(gettext('These branches have diverged.'
+                                         ' Try merging, and then bind again.'))
         if b.get_config().has_explicit_nickname():
             b.nick = b_other.nick
 
@@ -4982,7 +5037,7 @@
     def run(self, directory=u'.'):
         b, relpath = Branch.open_containing(directory)
         if not b.unbind():
-            raise errors.BzrCommandError('Local branch is not bound')
+            raise errors.BzrCommandError(gettext('Local branch is not bound'))
 
 
 class cmd_uncommit(Command):
@@ -5061,7 +5116,7 @@
                 rev_id = b.get_rev_id(revno)
 
         if rev_id is None or _mod_revision.is_null(rev_id):
-            self.outf.write('No revisions to uncommit.\n')
+            self.outf.write(gettext('No revisions to uncommit.\n'))
             return 1
 
         lf = log_formatter('short',
@@ -5076,25 +5131,25 @@
                  end_revision=last_revno)
 
         if dry_run:
-            self.outf.write('Dry-run, pretending to remove'
-                            ' the above revisions.\n')
+            self.outf.write(gettext('Dry-run, pretending to remove'
+                            ' the above revisions.\n'))
         else:
-            self.outf.write('The above revision(s) will be removed.\n')
+            self.outf.write(gettext('The above revision(s) will be removed.\n'))
 
         if not force:
             if not ui.ui_factory.confirm_action(
-                    u'Uncommit these revisions',
+                    gettext(u'Uncommit these revisions'),
                     'bzrlib.builtins.uncommit',
                     {}):
-                self.outf.write('Canceled\n')
+                self.outf.write(gettext('Canceled\n'))
                 return 0
 
         mutter('Uncommitting from {%s} to {%s}',
                last_rev_id, rev_id)
         uncommit(b, tree=tree, dry_run=dry_run, verbose=verbose,
                  revno=revno, local=local, keep_tags=keep_tags)
-        self.outf.write('You can restore the old tip by running:\n'
-             '  bzr pull . -r revid:%s\n' % last_rev_id)
+        self.outf.write(gettext('You can restore the old tip by running:\n'
+             '  bzr pull . -r revid:%s\n') % last_rev_id)
 
 
 class cmd_break_lock(Command):
@@ -5260,9 +5315,9 @@
         containing_tree = WorkingTree.open_containing(parent_dir)[0]
         repo = containing_tree.branch.repository
         if not repo.supports_rich_root():
-            raise errors.BzrCommandError(
+            raise errors.BzrCommandError(gettext(
                 "Can't join trees because %s doesn't support rich root data.\n"
-                "You can use bzr upgrade on the repository."
+                "You can use bzr upgrade on the repository.")
                 % (repo,))
         if reference:
             try:
@@ -5270,14 +5325,14 @@
             except errors.BadReferenceTarget, e:
                 # XXX: Would be better to just raise a nicely printable
                 # exception from the real origin.  Also below.  mbp 20070306
-                raise errors.BzrCommandError("Cannot join %s.  %s" %
-                                             (tree, e.reason))
+                raise errors.BzrCommandError(
+                       gettext("Cannot join {0}.  {1}").format(tree, e.reason))
         else:
             try:
                 containing_tree.subsume(sub_tree)
             except errors.BadSubsumeSource, e:
-                raise errors.BzrCommandError("Cannot join %s.  %s" %
-                                             (tree, e.reason))
+                raise errors.BzrCommandError(
+                       gettext("Cannot join {0}.  {1}").format(tree, e.reason))
 
 
 class cmd_split(Command):
@@ -5367,7 +5422,7 @@
         if submit_branch is None:
             submit_branch = branch.get_parent()
         if submit_branch is None:
-            raise errors.BzrCommandError('No submit branch specified or known')
+            raise errors.BzrCommandError(gettext('No submit branch specified or known'))
 
         stored_public_branch = branch.get_public_branch()
         if public_branch is None:
@@ -5375,13 +5430,13 @@
         elif stored_public_branch is None:
             branch.set_public_branch(public_branch)
         if not include_bundle and public_branch is None:
-            raise errors.BzrCommandError('No public branch specified or'
-                                         ' known')
+            raise errors.BzrCommandError(gettext('No public branch specified or'
+                                         ' known'))
         base_revision_id = None
         if revision is not None:
             if len(revision) > 2:
-                raise errors.BzrCommandError('bzr merge-directive takes '
-                    'at most two one revision identifiers')
+                raise errors.BzrCommandError(gettext('bzr merge-directive takes '
+                    'at most two one revision identifiers'))
             revision_id = revision[-1].as_revision_id(branch)
             if len(revision) == 2:
                 base_revision_id = revision[0].as_revision_id(branch)
@@ -5389,7 +5444,7 @@
             revision_id = branch.last_revision()
         revision_id = ensure_null(revision_id)
         if revision_id == NULL_REVISION:
-            raise errors.BzrCommandError('No revisions to bundle.')
+            raise errors.BzrCommandError(gettext('No revisions to bundle.'))
         directive = merge_directive.MergeDirective2.from_objects(
             branch.repository, revision_id, time.time(),
             osutils.local_time_offset(), submit_branch,
@@ -5649,23 +5704,23 @@
         self.add_cleanup(branch.lock_write().unlock)
         if delete:
             if tag_name is None:
-                raise errors.BzrCommandError("No tag specified to delete.")
+                raise errors.BzrCommandError(gettext("No tag specified to delete."))
             branch.tags.delete_tag(tag_name)
-            note('Deleted tag %s.' % tag_name)
+            note(gettext('Deleted tag %s.') % tag_name)
         else:
             if revision:
                 if len(revision) != 1:
-                    raise errors.BzrCommandError(
+                    raise errors.BzrCommandError(gettext(
                         "Tags can only be placed on a single revision, "
-                        "not on a range")
+                        "not on a range"))
                 revision_id = revision[0].as_revision_id(branch)
             else:
                 revision_id = branch.last_revision()
             if tag_name is None:
                 tag_name = branch.automatic_tag_name(revision_id)
                 if tag_name is None:
-                    raise errors.BzrCommandError(
-                        "Please specify a tag name.")
+                    raise errors.BzrCommandError(gettext(
+                        "Please specify a tag name."))
             try:
                 existing_target = branch.tags.lookup_tag(tag_name)
             except errors.NoSuchTag:
@@ -5673,13 +5728,13 @@
             if not force and existing_target not in (None, revision_id):
                 raise errors.TagAlreadyExists(tag_name)
             if existing_target == revision_id:
-                note('Tag %s already exists for that revision.' % tag_name)
+                note(gettext('Tag %s already exists for that revision.') % tag_name)
             else:
                 branch.tags.set_tag(tag_name, revision_id)
                 if existing_target is None:
-                    note('Created tag %s.' % tag_name)
+                    note(gettext('Created tag %s.') % tag_name)
                 else:
-                    note('Updated tag %s.' % tag_name)
+                    note(gettext('Updated tag %s.') % tag_name)
 
 
 class cmd_tags(Command):
@@ -5711,12 +5766,8 @@
 
         self.add_cleanup(branch.lock_read().unlock)
         if revision:
-            graph = branch.repository.get_graph()
-            rev1, rev2 = _get_revision_range(revision, branch, self.name())
-            revid1, revid2 = rev1.rev_id, rev2.rev_id
-            # only show revisions between revid1 and revid2 (inclusive)
-            tags = [(tag, revid) for tag, revid in tags if
-                graph.is_between(revid, revid1, revid2)]
+            # Restrict to the specified range
+            tags = self._tags_for_range(branch, revision)
         if sort is None:
             sort = tag_sort_methods.get()
         sort(branch, tags)
@@ -5727,7 +5778,8 @@
                     revno = branch.revision_id_to_dotted_revno(revid)
                     if isinstance(revno, tuple):
                         revno = '.'.join(map(str, revno))
-                except (errors.NoSuchRevision, errors.GhostRevisionsHaveNoRevno):
+                except (errors.NoSuchRevision,
+                        errors.GhostRevisionsHaveNoRevno):
                     # Bad tag data/merges can lead to tagged revisions
                     # which are not in this branch. Fail gracefully ...
                     revno = '?'
@@ -5736,6 +5788,32 @@
         for tag, revspec in tags:
             self.outf.write('%-20s %s\n' % (tag, revspec))
 
+    def _tags_for_range(self, branch, revision):
+        range_valid = True
+        rev1, rev2 = _get_revision_range(revision, branch, self.name())
+        revid1, revid2 = rev1.rev_id, rev2.rev_id
+        # _get_revision_range will always set revid2 if it's not specified.
+        # If revid1 is None, it means we want to start from the branch
+        # origin which is always a valid ancestor. If revid1 == revid2, the
+        # ancestry check is useless.
+        if revid1 and revid1 != revid2:
+            # FIXME: We really want to use the same graph than
+            # branch.iter_merge_sorted_revisions below, but this is not
+            # easily available -- vila 2011-09-23
+            if branch.repository.get_graph().is_ancestor(revid2, revid1):
+                # We don't want to output anything in this case...
+                return []
+        # only show revisions between revid1 and revid2 (inclusive)
+        tagged_revids = branch.tags.get_reverse_tag_dict()
+        found = []
+        for r in branch.iter_merge_sorted_revisions(
+            start_revision_id=revid2, stop_revision_id=revid1,
+            stop_rule='include'):
+            revid_tags = tagged_revids.get(r[0], None)
+            if revid_tags:
+                found.extend([(tag, r[0]) for tag in revid_tags])
+        return found
+
 
 class cmd_reconfigure(Command):
     __doc__ = """Reconfigure the type of a bzr directory.
@@ -5803,7 +5881,7 @@
             stacked_on=None, unstacked=None):
         directory = bzrdir.BzrDir.open(location)
         if stacked_on and unstacked:
-            raise errors.BzrCommandError("Can't use both --stacked-on and --unstacked")
+            raise errors.BzrCommandError(gettext("Can't use both --stacked-on and --unstacked"))
         elif stacked_on is not None:
             reconfigure.ReconfigureStackedOn().apply(directory, stacked_on)
         elif unstacked:
@@ -5817,8 +5895,8 @@
             if stacked_on or unstacked:
                 return
             else:
-                raise errors.BzrCommandError('No target configuration '
-                    'specified')
+                raise errors.BzrCommandError(gettext('No target configuration '
+                    'specified'))
         reconfiguration = None
         if tree_type == 'branch':
             reconfiguration = reconfigure.Reconfigure.to_branch(directory)
@@ -5892,8 +5970,8 @@
         control_dir = bzrdir.BzrDir.open_containing(tree_location)[0]
         if to_location is None:
             if revision is None:
-                raise errors.BzrCommandError('You must supply either a'
-                                             ' revision or a location')
+                raise errors.BzrCommandError(gettext('You must supply either a'
+                                             ' revision or a location'))
             to_location = tree_location
         try:
             branch = control_dir.open_branch()
@@ -5903,8 +5981,8 @@
             had_explicit_nick = False
         if create_branch:
             if branch is None:
-                raise errors.BzrCommandError('cannot create branch without'
-                                             ' source branch')
+                raise errors.BzrCommandError(gettext('cannot create branch without'
+                                             ' source branch'))
             to_location = directory_service.directories.dereference(
                               to_location)
             if '/' not in to_location and '\\' not in to_location:
@@ -5927,7 +6005,7 @@
         if had_explicit_nick:
             branch = control_dir.open_branch() #get the new branch!
             branch.nick = to_branch.nick
-        note('Switched to branch: %s',
+        note(gettext('Switched to branch: %s'),
             urlutils.unescape_for_display(to_branch.base, 'utf-8'))
 
     def _get_branch_location(self, control_dir):
@@ -6042,38 +6120,38 @@
             name = current_view
         if delete:
             if file_list:
-                raise errors.BzrCommandError(
-                    "Both --delete and a file list specified")
+                raise errors.BzrCommandError(gettext(
+                    "Both --delete and a file list specified"))
             elif switch:
-                raise errors.BzrCommandError(
-                    "Both --delete and --switch specified")
+                raise errors.BzrCommandError(gettext(
+                    "Both --delete and --switch specified"))
             elif all:
                 tree.views.set_view_info(None, {})
-                self.outf.write("Deleted all views.\n")
+                self.outf.write(gettext("Deleted all views.\n"))
             elif name is None:
-                raise errors.BzrCommandError("No current view to delete")
+                raise errors.BzrCommandError(gettext("No current view to delete"))
             else:
                 tree.views.delete_view(name)
-                self.outf.write("Deleted '%s' view.\n" % name)
+                self.outf.write(gettext("Deleted '%s' view.\n") % name)
         elif switch:
             if file_list:
-                raise errors.BzrCommandError(
-                    "Both --switch and a file list specified")
+                raise errors.BzrCommandError(gettext(
+                    "Both --switch and a file list specified"))
             elif all:
-                raise errors.BzrCommandError(
-                    "Both --switch and --all specified")
+                raise errors.BzrCommandError(gettext(
+                    "Both --switch and --all specified"))
             elif switch == 'off':
                 if current_view is None:
-                    raise errors.BzrCommandError("No current view to disable")
+                    raise errors.BzrCommandError(gettext("No current view to disable"))
                 tree.views.set_view_info(None, view_dict)
-                self.outf.write("Disabled '%s' view.\n" % (current_view))
+                self.outf.write(gettext("Disabled '%s' view.\n") % (current_view))
             else:
                 tree.views.set_view_info(switch, view_dict)
                 view_str = views.view_display_str(tree.views.lookup_view())
-                self.outf.write("Using '%s' view: %s\n" % (switch, view_str))
+                self.outf.write(gettext("Using '{0}' view: {1}\n").format(switch, view_str))
         elif all:
             if view_dict:
-                self.outf.write('Views defined:\n')
+                self.outf.write(gettext('Views defined:\n'))
                 for view in sorted(view_dict):
                     if view == current_view:
                         active = "=>"
@@ -6082,25 +6160,25 @@
                     view_str = views.view_display_str(view_dict[view])
                     self.outf.write('%s %-20s %s\n' % (active, view, view_str))
             else:
-                self.outf.write('No views defined.\n')
+                self.outf.write(gettext('No views defined.\n'))
         elif file_list:
             if name is None:
                 # No name given and no current view set
                 name = 'my'
             elif name == 'off':
-                raise errors.BzrCommandError(
-                    "Cannot change the 'off' pseudo view")
+                raise errors.BzrCommandError(gettext(
+                    "Cannot change the 'off' pseudo view"))
             tree.views.set_view(name, sorted(file_list))
             view_str = views.view_display_str(tree.views.lookup_view())
-            self.outf.write("Using '%s' view: %s\n" % (name, view_str))
+            self.outf.write(gettext("Using '{0}' view: {1}\n").format(name, view_str))
         else:
             # list the files
             if name is None:
                 # No name given and no current view set
-                self.outf.write('No current view.\n')
+                self.outf.write(gettext('No current view.\n'))
             else:
                 view_str = views.view_display_str(tree.views.lookup_view(name))
-                self.outf.write("'%s' view is: %s\n" % (name, view_str))
+                self.outf.write(gettext("'{0}' view is: {1}\n").format(name, view_str))
 
 
 class cmd_hooks(Command):
@@ -6120,7 +6198,7 @@
                         self.outf.write("    %s\n" %
                                         (some_hooks.get_hook_name(hook),))
                 else:
-                    self.outf.write("    <no hooks installed>\n")
+                    self.outf.write(gettext("    <no hooks installed>\n"))
 
 
 class cmd_remove_branch(Command):
@@ -6227,7 +6305,7 @@
         manager = tree.get_shelf_manager()
         shelves = manager.active_shelves()
         if len(shelves) == 0:
-            note('No shelved changes.')
+            note(gettext('No shelved changes.'))
             return 0
         for shelf_id in reversed(shelves):
             message = manager.get_metadata(shelf_id).get('message')

=== modified file 'bzrlib/bundle/__init__.py'
--- bzrlib/bundle/__init__.py	2011-07-23 16:33:38 +0000
+++ bzrlib/bundle/__init__.py	2011-09-15 14:21:33 +0000
@@ -25,6 +25,7 @@
     )
 from bzrlib.bundle import serializer as _serializer
 from bzrlib.merge_directive import MergeDirective
+from bzrlib.i18n import gettext
 """)
 from bzrlib.trace import note
 
@@ -53,7 +54,7 @@
         url, filename = urlutils.split(exception.target,
                                        exclude_trailing_slash=False)
         if not filename:
-            raise errors.NotABundle('A directory cannot be a bundle')
+            raise errors.NotABundle(gettext('A directory cannot be a bundle'))
         return _mod_transport.get_transport_from_url(url)
 
     try:

=== modified file 'bzrlib/bundle/apply_bundle.py'
--- bzrlib/bundle/apply_bundle.py	2011-05-02 15:29:58 +0000
+++ bzrlib/bundle/apply_bundle.py	2011-09-20 11:46:28 +0000
@@ -18,10 +18,11 @@
 """
 
 from bzrlib import ui
+from bzrlib.i18n import gettext
+from bzrlib.merge import Merger
 from bzrlib.progress import ProgressPhase
-from bzrlib.merge import Merger
+from bzrlib.trace import note
 from bzrlib.vf_repository import install_revision
-from bzrlib.trace import note
 
 
 def install_bundle(repository, bundle_reader):
@@ -33,7 +34,7 @@
     try:
         real_revisions = bundle_reader.real_revisions
         for i, revision in enumerate(reversed(real_revisions)):
-            pb.update("Install revisions",i, len(real_revisions))
+            pb.update(gettext("Install revisions"),i, len(real_revisions))
             if repository.has_revision(revision.revision_id):
                 continue
             cset_tree = bundle_reader.revision_tree(repository,
@@ -64,7 +65,7 @@
         merger.pp.next_phase()
         merger.find_base()
         if merger.base_rev_id == merger.other_rev_id:
-            note("Nothing to do.")
+            note(gettext("Nothing to do."))
             return 0
         merger.merge_type = merge_type
         merger.show_base = show_base

=== modified file 'bzrlib/bundle/commands.py'
--- bzrlib/bundle/commands.py	2011-04-07 10:36:24 +0000
+++ bzrlib/bundle/commands.py	2011-09-20 13:31:00 +0000
@@ -32,6 +32,7 @@
     urlutils,
     transport,
     )
+from bzrlib.i18n import gettext
 """)
 
 from bzrlib.commands import Command
@@ -56,11 +57,11 @@
             bundle_info = read_bundle(bundle_file)
         else:
             if verbose:
-                raise errors.BzrCommandError('--verbose requires a merge'
-                    ' directive')
+                raise errors.BzrCommandError(gettext(
+                            '--verbose requires a merge directive'))
         reader_method = getattr(bundle_info, 'get_bundle_reader', None)
         if reader_method is None:
-            raise errors.BzrCommandError('Bundle format not supported')
+            raise errors.BzrCommandError(gettext('Bundle format not supported'))
 
         by_kind = {}
         file_ids = set()
@@ -70,13 +71,13 @@
                 (bytes, parents, repo_kind, revision_id, file_id))
             if file_id is not None:
                 file_ids.add(file_id)
-        self.outf.write('Records\n')
+        self.outf.write(gettext('Records\n'))
         for kind, records in sorted(by_kind.iteritems()):
             multiparent = sum(1 for b, m, k, r, f in records if
                               len(m.get('parents', [])) > 1)
-            self.outf.write('%s: %d (%d multiparent)\n' % \
-                (kind, len(records), multiparent))
-        self.outf.write('unique files: %d\n' % len(file_ids))
+            self.outf.write(gettext('{0}: {1} ({2} multiparent)\n').format(
+                kind, len(records), multiparent))
+        self.outf.write(gettext('unique files: %d\n') % len(file_ids))
         self.outf.write('\n')
         nicks = set()
         committers = set()
@@ -85,10 +86,10 @@
                 nicks.add(revision.properties['branch-nick'])
             committers.add(revision.committer)
 
-        self.outf.write('Revisions\n')
-        self.outf.write(('nicks: %s\n'
+        self.outf.write(gettext('Revisions\n'))
+        self.outf.write((gettext('nicks: %s\n')
             % ', '.join(sorted(nicks))).encode(term_encoding, 'replace'))
-        self.outf.write(('committers: \n%s\n' %
+        self.outf.write((gettext('committers: \n%s\n') %
         '\n'.join(sorted(committers)).encode(term_encoding, 'replace')))
         if verbose:
             self.outf.write('\n')
@@ -96,6 +97,6 @@
             line = bundle_file.readline()
             line = bundle_file.readline()
             content = bundle_file.read().decode('bz2')
-            self.outf.write("Decoded contents\n")
+            self.outf.write(gettext("Decoded contents\n"))
             self.outf.write(content)
             self.outf.write('\n')

=== modified file 'bzrlib/bundle/serializer/v4.py'
--- bzrlib/bundle/serializer/v4.py	2010-08-10 20:03:44 +0000
+++ bzrlib/bundle/serializer/v4.py	2011-09-16 14:13:48 +0000
@@ -33,6 +33,7 @@
     versionedfile as _mod_versionedfile,
     )
 from bzrlib.bundle import bundle_data, serializer as bundle_serializer
+from bzrlib.i18n import gettext, ngettext
 from bzrlib import bencode
 
 
@@ -322,7 +323,8 @@
 
     def do_write(self):
         """Write all data to the bundle"""
-        trace.note('Bundling %d revision(s).', len(self.revision_ids))
+        trace.note(ngettext('Bundling %d revision.', 'Bundling %d revisions.',
+                            len(self.revision_ids)), len(self.revision_ids))
         self.repository.lock_read()
         try:
             self.bundle.begin()

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2011-09-08 17:55:39 +0000
+++ bzrlib/bzrdir.py	2011-09-20 10:47:29 +0000
@@ -55,6 +55,7 @@
     do_catching_redirections,
     local,
     )
+from bzrlib.i18n import gettext
 """)
 
 from bzrlib.trace import (
@@ -632,7 +633,7 @@
             old_path = self.root_transport.abspath('.bzr')
             backup_dir = self._available_backup_name('backup.bzr')
             new_path = self.root_transport.abspath(backup_dir)
-            ui.ui_factory.note('making backup of %s\n  to %s' % (
+            ui.ui_factory.note(gettext('making backup of {0}\n  to {1}').format(
                 urlutils.unescape_for_display(old_path, 'utf-8'),
                 urlutils.unescape_for_display(new_path, 'utf-8')))
             self.root_transport.copy_tree('.bzr', backup_dir)
@@ -655,8 +656,8 @@
             try:
                 to_path = '.bzr.retired.%d' % i
                 self.root_transport.rename('.bzr', to_path)
-                note("renamed %s to %s"
-                    % (self.root_transport.abspath('.bzr'), to_path))
+                note(gettext("renamed {0} to {1}").format(
+                    self.root_transport.abspath('.bzr'), to_path))
                 return
             except (errors.TransportError, IOError, errors.PathError):
                 i += 1
@@ -847,8 +848,8 @@
             redirected_transport = transport._redirected_to(e.source, e.target)
             if redirected_transport is None:
                 raise errors.NotBranchError(base)
-            note('%s is%s redirected to %s',
-                 transport.base, e.permanently, redirected_transport.base)
+            note(gettext('{0} is{1} redirected to {2}').format(
+                 transport.base, e.permanently, redirected_transport.base))
             return redirected_transport
 
         try:
@@ -1723,8 +1724,8 @@
                     new_repo_format = None
             if new_repo_format is not None:
                 self.repository_format = new_repo_format
-                note('Source repository format does not support stacking,'
-                     ' using format:\n  %s',
+                note(gettext('Source repository format does not support stacking,'
+                     ' using format:\n  %s'),
                      new_repo_format.get_format_description())
 
         if not self.get_branch_format().supports_stacking():
@@ -1743,8 +1744,8 @@
             if new_branch_format is not None:
                 # Does support stacking, use its format.
                 self.set_branch_format(new_branch_format)
-                note('Source branch format does not support stacking,'
-                     ' using format:\n  %s',
+                note(gettext('Source branch format does not support stacking,'
+                     ' using format:\n  %s'),
                      new_branch_format.get_format_description())
 
     def get_converter(self, format=None):
@@ -1854,7 +1855,7 @@
         else:
             if not isinstance(repo._format, self.target_format.repository_format.__class__):
                 from bzrlib.repository import CopyConverter
-                ui.ui_factory.note('starting repository conversion')
+                ui.ui_factory.note(gettext('starting repository conversion'))
                 converter = CopyConverter(self.target_format.repository_format)
                 converter.convert(repo, pb)
         for branch in self.bzrdir.list_branches():
@@ -2033,8 +2034,8 @@
                                     possible_transports=[self._bzrdir.root_transport])
             if not self._require_stacking:
                 # We have picked up automatic stacking somewhere.
-                note('Using default stacking branch %s at %s', self._stack_on,
-                    self._stack_on_pwd)
+                note(gettext('Using default stacking branch {0} at {1}').format(
+                    self._stack_on, self._stack_on_pwd))
         repository = self._bzrdir.create_repository(shared=shared)
         self._add_fallback(repository,
                            possible_transports=[self._bzrdir.transport])

=== modified file 'bzrlib/check.py'
--- bzrlib/check.py	2011-05-18 16:42:48 +0000
+++ bzrlib/check.py	2011-09-16 10:08:09 +0000
@@ -56,7 +56,7 @@
 from bzrlib.revision import NULL_REVISION
 from bzrlib.trace import note
 from bzrlib.workingtree import WorkingTree
-
+from bzrlib.i18n import gettext
 
 class Check(object):
     """Check a repository"""
@@ -103,17 +103,17 @@
         self.repository.lock_read()
         self.progress = ui.ui_factory.nested_progress_bar()
         try:
-            self.progress.update('check', 0, 4)
+            self.progress.update(gettext('check'), 0, 4)
             if self.check_repo:
-                self.progress.update('checking revisions', 0)
+                self.progress.update(gettext('checking revisions'), 0)
                 self.check_revisions()
-                self.progress.update('checking commit contents', 1)
+                self.progress.update(gettext('checking commit contents'), 1)
                 self.repository._check_inventories(self)
-                self.progress.update('checking file graphs', 2)
+                self.progress.update(gettext('checking file graphs'), 2)
                 # check_weaves is done after the revision scan so that
                 # revision index is known to be valid.
                 self.check_weaves()
-            self.progress.update('checking branches and trees', 3)
+            self.progress.update(gettext('checking branches and trees'), 3)
             if callback_refs:
                 repo = self.repository
                 # calculate all refs, and callback the objects requesting them.
@@ -200,56 +200,57 @@
             result.report_results(verbose)
 
     def _report_repo_results(self, verbose):
-        note('checked repository %s format %s',
+        note(gettext('checked repository {0} format {1}').format(
             self.repository.user_url,
-            self.repository._format)
-        note('%6d revisions', self.checked_rev_cnt)
-        note('%6d file-ids', len(self.checked_weaves))
+            self.repository._format))
+        note(gettext('%6d revisions'), self.checked_rev_cnt)
+        note(gettext('%6d file-ids'), len(self.checked_weaves))
         if verbose:
-            note('%6d unreferenced text versions',
+            note(gettext('%6d unreferenced text versions'),
                 len(self.unreferenced_versions))
         if verbose and len(self.unreferenced_versions):
                 for file_id, revision_id in self.unreferenced_versions:
-                    note('unreferenced version: {%s} in %s', revision_id,
-                        file_id)
+                    note(gettext('unreferenced version: {{{0}}} in {1}').format(revision_id,
+                        file_id))
         if self.missing_inventory_sha_cnt:
-            note('%6d revisions are missing inventory_sha1',
+            note(gettext('%6d revisions are missing inventory_sha1'),
                  self.missing_inventory_sha_cnt)
         if self.missing_revision_cnt:
-            note('%6d revisions are mentioned but not present',
+            note(gettext('%6d revisions are mentioned but not present'),
                  self.missing_revision_cnt)
         if len(self.ghosts):
-            note('%6d ghost revisions', len(self.ghosts))
+            note(gettext('%6d ghost revisions'), len(self.ghosts))
             if verbose:
                 for ghost in self.ghosts:
                     note('      %s', ghost)
         if len(self.missing_parent_links):
-            note('%6d revisions missing parents in ancestry',
+            note(gettext('%6d revisions missing parents in ancestry'),
                  len(self.missing_parent_links))
             if verbose:
                 for link, linkers in self.missing_parent_links.items():
-                    note('      %s should be in the ancestry for:', link)
+                    note(gettext('      %s should be in the ancestry for:'), link)
                     for linker in linkers:
                         note('       * %s', linker)
         if len(self.inconsistent_parents):
-            note('%6d inconsistent parents', len(self.inconsistent_parents))
+            note(gettext('%6d inconsistent parents'), len(self.inconsistent_parents))
             if verbose:
                 for info in self.inconsistent_parents:
                     revision_id, file_id, found_parents, correct_parents = info
-                    note('      * %s version %s has parents %r '
-                         'but should have %r'
-                         % (file_id, revision_id, found_parents,
+                    note(gettext('      * {0} version {1} has parents {2!r} '
+                         'but should have {3!r}').format(
+                         file_id, revision_id, found_parents,
                              correct_parents))
         if self.revs_with_bad_parents_in_index:
-            note('%6d revisions have incorrect parents in the revision index',
+            note(gettext(
+                 '%6d revisions have incorrect parents in the revision index'),
                  len(self.revs_with_bad_parents_in_index))
             if verbose:
                 for item in self.revs_with_bad_parents_in_index:
                     revision_id, index_parents, actual_parents = item
-                    note(
-                        '       %s has wrong parents in index: '
-                        '%r should be %r',
-                        revision_id, index_parents, actual_parents)
+                    note(gettext(
+                        '       {0} has wrong parents in index: '
+                        '{1!r} should be {2!r}').format(
+                        revision_id, index_parents, actual_parents))
         for item in self._report_items:
             note(item)
 
@@ -260,8 +261,8 @@
         :param rev: A revision or None to indicate a missing revision.
         """
         if rev.revision_id != rev_id:
-            self._report_items.append(
-                'Mismatched internal revid {%s} and index revid {%s}' % (
+            self._report_items.append(gettext(
+                'Mismatched internal revid {{{0}}} and index revid {{{1}}}').format(
                 rev.revision_id, rev_id))
             rev_id = rev.revision_id
         # Check this revision tree etc, and count as seen when we encounter a
@@ -290,8 +291,8 @@
         existing = self.pending_keys.get(key)
         if existing:
             if sha1 != existing[1]:
-                self._report_items.append('Multiple expected sha1s for %s. {%s}'
-                    ' expects {%s}, {%s} expects {%s}', (
+                self._report_items.append(gettext('Multiple expected sha1s for {0}. {{{1}}}'
+                    ' expects {{{2}}}, {{{3}}} expects {{{4}}}').format(
                     key, referer, sha1, existing[1], existing[0]))
         else:
             self.pending_keys[key] = (kind, sha1, referer)
@@ -348,7 +349,7 @@
     :param needed_refs: Refs we are accumulating.
     :param to_unlock: The unlock list accumulating.
     """
-    note("Checking branch at '%s'." % (branch.base,))
+    note(gettext("Checking branch at '%s'.") % (branch.base,))
     branch.lock_read()
     to_unlock.append(branch)
     branch_refs = branch._get_check_refs()
@@ -368,7 +369,7 @@
     """
     if base_tree is not None and tree.basedir == base_tree.basedir:
         return
-    note("Checking working tree at '%s'." % (tree.basedir,))
+    note(gettext("Checking working tree at '%s'.") % (tree.basedir,))
     tree.lock_read()
     to_unlock.append(tree)
     tree_refs = tree._get_check_refs()
@@ -421,23 +422,23 @@
                     if do_branch:
                         scan_branch(branch, needed_refs, to_unlock)
             if do_branch and not branches:
-                note("No branch found at specified location.")
+                note(gettext("No branch found at specified location."))
             if do_tree and base_tree is None and not saw_tree:
-                note("No working tree found at specified location.")
+                note(gettext("No working tree found at specified location."))
             if do_repo or do_branch or do_tree:
                 if do_repo:
-                    note("Checking repository at '%s'."
+                    note(gettext("Checking repository at '%s'.")
                          % (repo.user_url,))
                 result = repo.check(None, callback_refs=needed_refs,
                     check_repo=do_repo)
                 result.report_results(verbose)
         else:
             if do_tree:
-                note("No working tree found at specified location.")
+                note(gettext("No working tree found at specified location."))
             if do_branch:
-                note("No branch found at specified location.")
+                note(gettext("No branch found at specified location."))
             if do_repo:
-                note("No repository found at specified location.")
+                note(gettext("No repository found at specified location."))
     finally:
         for thing in to_unlock:
             thing.unlock()

=== modified file 'bzrlib/clean_tree.py'
--- bzrlib/clean_tree.py	2010-08-23 17:54:07 +0000
+++ bzrlib/clean_tree.py	2011-09-19 15:59:40 +0000
@@ -27,7 +27,7 @@
 from bzrlib.osutils import isdir
 from bzrlib.trace import note
 from bzrlib.workingtree import WorkingTree
-
+from bzrlib.i18n import gettext
 
 def is_detritus(subp):
     """Return True if the supplied path is detritus, False otherwise"""
@@ -59,7 +59,7 @@
             ignored=ignored, detritus=detritus))
         deletables = _filter_out_nested_bzrdirs(deletables)
         if len(deletables) == 0:
-            note('Nothing to delete.')
+            note(gettext('Nothing to delete.'))
             return 0
         if not no_prompt:
             for path, subp in deletables:
@@ -105,11 +105,11 @@
         # Other errors are re-raised.
         if function is not os.remove or excinfo[1].errno != errno.EACCES:
             raise
-        ui.ui_factory.show_warning('unable to remove %s' % path)
+        ui.ui_factory.show_warning(gettext('unable to remove %s') % path)
     has_deleted = False
     for path, subp in deletables:
         if not has_deleted:
-            note("deleting paths:")
+            note(gettext("deleting paths:"))
             has_deleted = True
         if not dry_run:
             if isdir(path):
@@ -122,9 +122,10 @@
                     # We handle only permission error here
                     if e.errno != errno.EACCES:
                         raise e
-                    ui.ui_factory.show_warning(
-                        'unable to remove "%s": %s.' % (path, e.strerror))
+                    ui.ui_factory.show_warning(gettext(
+                        'unable to remove "{0}": {1}.').format(
+                                                    path, e.strerror))
         else:
             note('  ' + subp)
     if not has_deleted:
-        note("No files deleted.")
+        note(gettext("No files deleted."))

=== modified file 'bzrlib/cmd_version_info.py'
--- bzrlib/cmd_version_info.py	2011-04-07 10:36:24 +0000
+++ bzrlib/cmd_version_info.py	2011-09-16 10:41:45 +0000
@@ -25,6 +25,7 @@
     version_info_formats,
     workingtree,
     )
+from bzrlib.i18n import gettext
 """)
 
 from bzrlib.commands import Command
@@ -41,9 +42,9 @@
         return version_info_formats.get_builder(format)
     except KeyError:
         formats = version_info_formats.get_builder_formats()
-        raise errors.BzrCommandError('No known version info format %s.'
-                                     ' Supported types are: %s'
-                                     % (format, formats))
+        raise errors.BzrCommandError(gettext('No known version info format {0}.'
+                                     ' Supported types are: {1}').format(
+                                     format, formats))
 
 
 class cmd_version_info(Command):

=== modified file 'bzrlib/commands.py'
--- bzrlib/commands.py	2011-09-01 11:27:37 +0000
+++ bzrlib/commands.py	2011-09-19 15:59:40 +0000
@@ -229,7 +229,7 @@
     try:
         return _get_cmd_object(cmd_name, plugins_override)
     except KeyError:
-        raise errors.BzrCommandError('unknown command "%s"' % cmd_name)
+        raise errors.BzrCommandError(gettext('unknown command "%s"') % cmd_name)
 
 
 def _get_cmd_object(cmd_name, plugins_override=True, check_missing=True):
@@ -554,7 +554,8 @@
                         see_also_links.append(item)
                     else:
                         # Use a Sphinx link for this entry
-                        link_text = gettext(":doc:`%s <%s-help>`") % (item, item)
+                        link_text = gettext(":doc:`{0} <{1}-help>`").format(
+                                                                    item, item)
                         see_also_links.append(link_text)
                 see_also = see_also_links
             result += gettext(':See also: %s') % ', '.join(see_also) + '\n'
@@ -815,7 +816,7 @@
     try:
         options, args = parser.parse_args(args)
     except UnicodeEncodeError,e:
-        raise errors.BzrCommandError('Only ASCII permitted in option names')
+        raise errors.BzrCommandError(gettext('Only ASCII permitted in option names'))
 
     opts = dict([(k, v) for k, v in options.__dict__.iteritems() if
                  v is not option.OptionParser.DEFAULT_VALUE])
@@ -839,29 +840,33 @@
                 argdict[argname + '_list'] = None
         elif ap[-1] == '+':
             if not args:
-                raise errors.BzrCommandError("command %r needs one or more %s"
-                                             % (cmd, argname.upper()))
+                raise errors.BzrCommandError(gettext(
+                      "command {0!r} needs one or more {1}").format(
+                      cmd, argname.upper()))
             else:
                 argdict[argname + '_list'] = args[:]
                 args = []
         elif ap[-1] == '$': # all but one
             if len(args) < 2:
-                raise errors.BzrCommandError("command %r needs one or more %s"
-                                             % (cmd, argname.upper()))
+                raise errors.BzrCommandError(
+                      gettext("command {0!r} needs one or more {1}").format(
+                                             cmd, argname.upper()))
             argdict[argname + '_list'] = args[:-1]
             args[:-1] = []
         else:
             # just a plain arg
             argname = ap
             if not args:
-                raise errors.BzrCommandError("command %r requires argument %s"
-                               % (cmd, argname.upper()))
+                raise errors.BzrCommandError(
+                     gettext("command {0!r} requires argument {1}").format(
+                               cmd, argname.upper()))
             else:
                 argdict[argname] = args.pop(0)
 
     if args:
-        raise errors.BzrCommandError("extra argument to command %s: %s"
-                                     % (cmd, args[0]))
+        raise errors.BzrCommandError( gettext(
+                              "extra argument to command {0}: {1}").format(
+                                       cmd, args[0]) )
 
     return argdict
 
@@ -957,7 +962,7 @@
         stats.pprint()
     else:
         stats.save(filename)
-        trace.note('Profile data written to "%s".', filename)
+        trace.note(gettext('Profile data written to "%s".'), filename)
     return ret
 
 

=== modified file 'bzrlib/commit.py'
--- bzrlib/commit.py	2011-09-09 02:12:38 +0000
+++ bzrlib/commit.py	2011-09-16 10:08:09 +0000
@@ -72,7 +72,7 @@
 from bzrlib.inventory import Inventory, InventoryEntry, make_entry
 from bzrlib import symbol_versioning
 from bzrlib.urlutils import unescape_for_display
-
+from bzrlib.i18n import gettext
 
 class NullCommitReporter(object):
     """I report on progress of a commit."""
@@ -113,7 +113,7 @@
         note(format, *args)
 
     def snapshot_change(self, change, path):
-        if path == '' and change in ('added', 'modified'):
+        if path == '' and change in (gettext('added'), gettext('modified')):
             return
         self._note("%s %s", change, path)
 
@@ -127,10 +127,10 @@
                                    "to started.", DeprecationWarning,
                                    stacklevel=2)
             location = ''
-        self._note('Committing%s', location)
+        self._note(gettext('Committing%s'), location)
 
     def completed(self, revno, rev_id):
-        self._note('Committed revision %d.', revno)
+        self._note(gettext('Committed revision %d.'), revno)
         # self._note goes to the console too; so while we want to log the
         # rev_id, we can't trivially only log it. (See bug 526425). Long
         # term we should rearrange the reporting structure, but for now
@@ -139,10 +139,10 @@
         mutter('Committed revid %s as revno %d.', rev_id, revno)
 
     def deleted(self, path):
-        self._note('deleted %s', path)
+        self._note(gettext('deleted %s'), path)
 
     def missing(self, path):
-        self._note('missing %s', path)
+        self._note(gettext('missing %s'), path)
 
     def renamed(self, change, old_path, new_path):
         self._note('%s %s => %s', change, old_path, new_path)
@@ -468,8 +468,8 @@
                 self.master_branch.tags)
             if tag_conflicts:
                 warning_lines = ['    ' + name for name, _, _ in tag_conflicts]
-                note("Conflicting tags in bound branch:\n" +
-                    "\n".join(warning_lines))
+                note( gettext("Conflicting tags in bound branch:\n{0}".format(
+                    "\n".join(warning_lines))) )
 
         # Make the working tree be up to date with the branch. This
         # includes automatic changes scheduled to be made to the tree, such
@@ -706,15 +706,15 @@
                     if new_path is None:
                         reporter.deleted(old_path)
                     elif old_path is None:
-                        reporter.snapshot_change('added', new_path)
+                        reporter.snapshot_change(gettext('added'), new_path)
                     elif old_path != new_path:
-                        reporter.renamed('renamed', old_path, new_path)
+                        reporter.renamed(gettext('renamed'), old_path, new_path)
                     else:
                         if (new_path or 
                             self.work_tree.branch.repository._format.rich_root_data):
                             # Don't report on changes to '' in non rich root
                             # repositories.
-                            reporter.snapshot_change('modified', new_path)
+                            reporter.snapshot_change(gettext('modified'), new_path)
             self._next_progress_entry()
         # Unversion IDs that were found to be deleted
         self.deleted_ids = deleted_ids
@@ -943,7 +943,7 @@
             self.reporter.renamed(change, old_path, path)
             self._next_progress_entry()
         else:
-            if change == 'unchanged':
+            if change == gettext('unchanged'):
                 return
             self.reporter.snapshot_change(change, path)
             self._next_progress_entry()
@@ -965,10 +965,10 @@
 
     def _emit_progress(self):
         if self.pb_entries_count is not None:
-            text = "%s [%d] - Stage" % (self.pb_stage_name,
+            text = gettext("{0} [{1}] - Stage").format(self.pb_stage_name,
                 self.pb_entries_count)
         else:
-            text = "%s - Stage" % (self.pb_stage_name, )
+            text = gettext("%s - Stage") % (self.pb_stage_name, )
         self.pb.update(text, self.pb_stage_count, self.pb_stage_total)
 
     def _set_specific_file_ids(self):

=== modified file 'bzrlib/commit_signature_commands.py'
--- bzrlib/commit_signature_commands.py	2011-08-04 10:28:02 +0000
+++ bzrlib/commit_signature_commands.py	2011-09-14 14:57:54 +0000
@@ -141,8 +141,8 @@
                 if to_revid is None:
                     to_revno = branch.revno()
                 if from_revno is None or to_revno is None:
-                    raise errors.BzrCommandError('Cannot verify a range of '\
-                                               'non-revision-history revisions')
+                    raise errors.BzrCommandError(gettext(
+                    'Cannot verify a range of non-revision-history revisions'))
                 for revno in range(from_revno, to_revno + 1):
                     revisions.append(branch.get_rev_id(revno))
         else:

=== modified file 'bzrlib/config.py'
--- bzrlib/config.py	2011-09-15 15:10:24 +0000
+++ bzrlib/config.py	2011-09-26 07:56:05 +0000
@@ -445,9 +445,9 @@
                         elif m.group(2).lower() == 'g':
                             val *= 10**9
                 else:
-                    ui.ui_factory.show_warning('Invalid config value for "%s" '
-                                               ' value %r is not an SI unit.'
-                                                % (option_name, val))
+                    ui.ui_factory.show_warning(gettext('Invalid config value for "{0}" '
+                                               ' value {1!r} is not an SI unit.').format(
+                                                option_name, val))
                     val = default
             except TypeError:
                 val = default
@@ -2533,6 +2533,16 @@
     Option('default_format', default='2a',
            help='Format used when creating branches.'))
 option_registry.register(
+    Option('dpush_strict', default=None,
+           from_unicode=bool_from_store,
+           help='''\
+The default value for ``dpush --strict``.
+
+If present, defines the ``--strict`` option default value for checking
+uncommitted changes before pushing into a different VCS without any
+custom bzr metadata.
+'''))
+option_registry.register(
     Option('editor',
            help='The command called to launch an editor to enter a message.'))
 option_registry.register(
@@ -2563,6 +2573,15 @@
            help= 'Unicode encoding for output'
            ' (terminal encoding if not specified).'))
 option_registry.register(
+    Option('push_strict', default=None,
+           from_unicode=bool_from_store,
+           help='''\
+The default value for ``push --strict``.
+
+If present, defines the ``--strict`` option default value for checking
+uncommitted changes before sending a merge directive.
+'''))
+option_registry.register(
     Option('repository.fdatasync', default=True,
            from_unicode=bool_from_store,
            help='''\
@@ -2572,6 +2591,15 @@
 to physical disk.  This is somewhat slower, but means data should not be
 lost if the machine crashes.  See also dirstate.fdatasync.
 '''))
+option_registry.register(
+    Option('send_strict', default=None,
+           from_unicode=bool_from_store,
+           help='''\
+The default value for ``send --strict``.
+
+If present, defines the ``--strict`` option default value for checking
+uncommitted changes before pushing.
+'''))
 
 option_registry.register(
     Option('serve.client_timeout',

=== modified file 'bzrlib/conflicts.py'
--- bzrlib/conflicts.py	2011-06-21 15:19:18 +0000
+++ bzrlib/conflicts.py	2011-09-16 15:39:47 +0000
@@ -32,6 +32,7 @@
     transform,
     workingtree,
     )
+from bzrlib.i18n import gettext, ngettext
 """)
 from bzrlib import (
     commands,
@@ -120,8 +121,8 @@
     def run(self, file_list=None, all=False, action=None, directory=None):
         if all:
             if file_list:
-                raise errors.BzrCommandError("If --all is specified,"
-                                             " no FILE may be provided")
+                raise errors.BzrCommandError(gettext("If --all is specified,"
+                                             " no FILE may be provided"))
             if directory is None:
                 directory = u'.'
             tree = workingtree.WorkingTree.open_containing(directory)[0]
@@ -145,13 +146,15 @@
             if file_list is None:
                 un_resolved, resolved = tree.auto_resolve()
                 if len(un_resolved) > 0:
-                    trace.note('%d conflict(s) auto-resolved.', len(resolved))
-                    trace.note('Remaining conflicts:')
+                    trace.note(ngettext('%d conflict auto-resolved.',
+                        '%d conflicts auto-resolved.', len(resolved)),
+                        len(resolved))
+                    trace.note(gettext('Remaining conflicts:'))
                     for conflict in un_resolved:
                         trace.note(unicode(conflict))
                     return 1
                 else:
-                    trace.note('All conflicts resolved.')
+                    trace.note(gettext('All conflicts resolved.'))
                     return 0
             else:
                 # FIXME: This can never occur but the block above needs some
@@ -160,8 +163,9 @@
                 pass
         else:
             before, after = resolve(tree, file_list, action=action)
-            trace.note('%d conflict(s) resolved, %d remaining'
-                       % (before - after, after))
+            trace.note(ngettext('{0} conflict resolved, {1} remaining',
+                                '{0} conflicts resolved, {1} remaining',
+                                before-after).format(before - after, after))
 
 
 def resolve(tree, paths=None, ignore_misses=False, recursive=False,

=== modified file 'bzrlib/controldir.py'
--- bzrlib/controldir.py	2011-09-08 17:55:39 +0000
+++ bzrlib/controldir.py	2011-09-21 19:45:15 +0000
@@ -75,7 +75,6 @@
         return self.user_transport.base
 
 
-
 class ControlDir(ControlComponent):
     """A control directory.
 

=== modified file 'bzrlib/diff.py'
--- bzrlib/diff.py	2011-07-15 15:31:01 +0000
+++ bzrlib/diff.py	2011-09-15 11:31:47 +0000
@@ -39,6 +39,7 @@
     )
 
 from bzrlib.workingtree import WorkingTree
+from bzrlib.i18n import gettext
 """)
 
 from bzrlib.registry import (
@@ -393,7 +394,7 @@
             if view_files:
                 specific_files = view_files
                 view_str = views.view_display_str(view_files)
-                note("*** Ignoring files outside view. View is %s" % view_str)
+                note(gettext("*** Ignoring files outside view. View is %s") % view_str)
 
     # Get extra trees that ought to be searched for file-ids
     extra_trees = None

=== modified file 'bzrlib/export_pot.py'
--- bzrlib/export_pot.py	2011-08-31 10:23:47 +0000
+++ bzrlib/export_pot.py	2011-09-16 15:34:05 +0000
@@ -34,6 +34,7 @@
     mutter,
     note,
     )
+from bzrlib.i18n import gettext
 
 
 def _escape(s):
@@ -119,13 +120,13 @@
         if getattr(opt, 'title', None):
             lineno = offsets.get(opt.title, 9999)
             if lineno == 9999:
-                note("%r is not found in bzrlib/option.py" % opt.title)
+                note(gettext("%r is not found in bzrlib/option.py") % opt.title)
             _poentry(outf, path, lineno, opt.title,
                      'title of %r option' % name)
         if getattr(opt, 'help', None):
             lineno = offsets.get(opt.help, 9999)
             if lineno == 9999:
-                note("%r is not found in bzrlib/option.py" % opt.help)
+                note(gettext("%r is not found in bzrlib/option.py") % opt.help)
             _poentry(outf, path, lineno, opt.help,
                      'help of %r option' % name)
 
@@ -181,7 +182,7 @@
         command = _mod_commands.get_cmd_object(cmd_name, False)
         if command.hidden:
             continue
-        note("Exporting messages from builtin command: %s", cmd_name)
+        note(gettext("Exporting messages from builtin command: %s"), cmd_name)
         _write_command_help(outf, command)
 
     plugin_path = plugin.get_core_plugin_path()
@@ -197,8 +198,8 @@
             # skip non-core plugins
             # TODO: Support extracting from third party plugins.
             continue
-        note("Exporting messages from plugin command: %s in %s",
-             cmd_name, command.plugin_name())
+        note(gettext("Exporting messages from plugin command: {0} in {1}").format(
+             cmd_name, command.plugin_name() ))
         _write_command_help(outf, command)
 
 
@@ -222,7 +223,7 @@
             continue
         fmt = getattr(klass, "_fmt", None)
         if fmt:
-            note("Exporting message from error: %s", name)
+            note(gettext("Exporting message from error: %s"), name)
             _poentry(outf, 'bzrlib/errors.py',
                      offsets.get(fmt, 9999), fmt)
 

=== modified file 'bzrlib/fetch.py'
--- bzrlib/fetch.py	2011-05-20 08:25:15 +0000
+++ bzrlib/fetch.py	2011-09-16 15:32:49 +0000
@@ -37,6 +37,7 @@
     errors,
     ui,
     )
+from bzrlib.i18n import gettext
 from bzrlib.revision import NULL_REVISION
 from bzrlib.trace import mutter
 
@@ -93,12 +94,12 @@
         pb = ui.ui_factory.nested_progress_bar()
         pb.show_pct = pb.show_count = False
         try:
-            pb.update("Finding revisions", 0, 2)
+            pb.update(gettext("Finding revisions"), 0, 2)
             search_result = self._revids_to_fetch()
             mutter('fetching: %s', search_result)
             if search_result.is_empty():
                 return
-            pb.update("Fetching revisions", 1, 2)
+            pb.update(gettext("Fetching revisions"), 1, 2)
             self._fetch_everything_for_search(search_result)
         finally:
             pb.finished()

=== modified file 'bzrlib/foreign.py'
--- bzrlib/foreign.py	2011-05-14 07:56:12 +0000
+++ bzrlib/foreign.py	2011-09-16 12:04:04 +0000
@@ -31,6 +31,7 @@
     registry,
     transform,
     )
+from bzrlib.i18n import gettext
 """)
 
 class VcsMapping(object):
@@ -302,11 +303,12 @@
         stored_loc = source_branch.get_push_location()
         if location is None:
             if stored_loc is None:
-                raise BzrCommandError("No push location known or specified.")
+                raise BzrCommandError(gettext("No push location known or specified."))
             else:
                 display_url = urlutils.unescape_for_display(stored_loc,
                         self.outf.encoding)
-                self.outf.write("Using saved location: %s\n" % display_url)
+                self.outf.write(
+                       gettext("Using saved location: %s\n") % display_url)
                 location = stored_loc
 
         bzrdir = BzrDir.open(location)
@@ -316,9 +318,9 @@
             try:
                 push_result = source_branch.push(target_branch, lossy=True)
             except errors.LossyPushToSameVCS:
-                raise BzrCommandError("%r and %r are in the same VCS, lossy "
-                    "push not necessary. Please use regular push." %
-                    (source_branch, target_branch))
+                raise BzrCommandError(gettext("{0!r} and {1!r} are in the same VCS, lossy "
+                    "push not necessary. Please use regular push.").format(
+                    source_branch, target_branch))
             # We successfully created the target, remember it
             if source_branch.get_push_location() is None or remember:
                 source_branch.set_push_location(target_branch.base)

=== modified file 'bzrlib/gpg.py'
--- bzrlib/gpg.py	2011-09-12 11:39:44 +0000
+++ bzrlib/gpg.py	2011-09-16 10:41:45 +0000
@@ -314,7 +314,7 @@
                 acceptable_keys_config = str(acceptable_keys_config)
         except UnicodeEncodeError:
             #gpg Context.keylist(pattern) does not like unicode
-            raise errors.BzrCommandError('Only ASCII permitted in option names')
+            raise errors.BzrCommandError(gettext('Only ASCII permitted in option names'))
 
         if acceptable_keys_config is not None:
             key_patterns = acceptable_keys_config

=== modified file 'bzrlib/groupcompress.py'
--- bzrlib/groupcompress.py	2011-05-31 13:52:18 +0000
+++ bzrlib/groupcompress.py	2011-09-15 11:31:47 +0000
@@ -39,6 +39,7 @@
     )
 
 from bzrlib.repofmt import pack_repo
+from bzrlib.i18n import gettext
 """)
 
 from bzrlib.btree_index import BTreeBuilder
@@ -1754,8 +1755,8 @@
                 raise errors.RevisionNotPresent(record.key, self)
             if random_id:
                 if record.key in inserted_keys:
-                    trace.note('Insert claimed random_id=True,'
-                               ' but then inserted %r two times', record.key)
+                    trace.note(gettext('Insert claimed random_id=True,'
+                               ' but then inserted %r two times'), record.key)
                     continue
                 inserted_keys.add(record.key)
             if reuse_blocks:

=== modified file 'bzrlib/hooks.py'
--- bzrlib/hooks.py	2011-06-14 10:07:16 +0000
+++ bzrlib/hooks.py	2011-09-20 11:01:37 +0000
@@ -30,6 +30,7 @@
     errors,
     pyutils,
     )
+from bzrlib.i18n import gettext
 """)
 
 
@@ -310,10 +311,10 @@
             introduced_string = _format_version_tuple(self.introduced)
         else:
             introduced_string = 'unknown'
-        strings.append('Introduced in: %s' % introduced_string)
+        strings.append(gettext('Introduced in: %s') % introduced_string)
         if self.deprecated:
             deprecated_string = _format_version_tuple(self.deprecated)
-            strings.append('Deprecated in: %s' % deprecated_string)
+            strings.append(gettext('Deprecated in: %s') % deprecated_string)
         strings.append('')
         strings.extend(textwrap.wrap(self.__doc__,
             break_long_words=False))

=== modified file 'bzrlib/knit.py'
--- bzrlib/knit.py	2011-05-18 16:42:48 +0000
+++ bzrlib/knit.py	2011-09-24 09:03:00 +0000
@@ -76,6 +76,7 @@
     )
 
 from bzrlib.repofmt import pack_repo
+from bzrlib.i18n import gettext
 """)
 from bzrlib import (
     annotate,
@@ -1760,7 +1761,7 @@
                         key_records.append((key, details[0]))
                 records_iter = enumerate(self._read_records_iter(key_records))
                 for (key_idx, (key, data, sha_value)) in records_iter:
-                    pb.update('Walking content', key_idx, total)
+                    pb.update(gettext('Walking content'), key_idx, total)
                     compression_parent = build_details[key][1]
                     if compression_parent is None:
                         # fulltext
@@ -1796,7 +1797,7 @@
                 source_keys.add(key)
                 yield line, key
             keys.difference_update(source_keys)
-        pb.update('Walking content', total, total)
+        pb.update(gettext('Walking content'), total, total)
 
     def _make_line_delta(self, delta_seq, new_content):
         """Generate a line delta from delta_seq and new_content."""
@@ -3209,145 +3210,6 @@
                 yield data
 
 
-class _DirectPackAccess(object):
-    """Access to data in one or more packs with less translation."""
-
-    def __init__(self, index_to_packs, reload_func=None, flush_func=None):
-        """Create a _DirectPackAccess object.
-
-        :param index_to_packs: A dict mapping index objects to the transport
-            and file names for obtaining data.
-        :param reload_func: A function to call if we determine that the pack
-            files have moved and we need to reload our caches. See
-            bzrlib.repo_fmt.pack_repo.AggregateIndex for more details.
-        """
-        self._container_writer = None
-        self._write_index = None
-        self._indices = index_to_packs
-        self._reload_func = reload_func
-        self._flush_func = flush_func
-
-    def add_raw_records(self, key_sizes, raw_data):
-        """Add raw knit bytes to a storage area.
-
-        The data is spooled to the container writer in one bytes-record per
-        raw data item.
-
-        :param sizes: An iterable of tuples containing the key and size of each
-            raw data segment.
-        :param raw_data: A bytestring containing the data.
-        :return: A list of memos to retrieve the record later. Each memo is an
-            opaque index memo. For _DirectPackAccess the memo is (index, pos,
-            length), where the index field is the write_index object supplied
-            to the PackAccess object.
-        """
-        if type(raw_data) is not str:
-            raise AssertionError(
-                'data must be plain bytes was %s' % type(raw_data))
-        result = []
-        offset = 0
-        for key, size in key_sizes:
-            p_offset, p_length = self._container_writer.add_bytes_record(
-                raw_data[offset:offset+size], [])
-            offset += size
-            result.append((self._write_index, p_offset, p_length))
-        return result
-
-    def flush(self):
-        """Flush pending writes on this access object.
-
-        This will flush any buffered writes to a NewPack.
-        """
-        if self._flush_func is not None:
-            self._flush_func()
-            
-    def get_raw_records(self, memos_for_retrieval):
-        """Get the raw bytes for a records.
-
-        :param memos_for_retrieval: An iterable containing the (index, pos,
-            length) memo for retrieving the bytes. The Pack access method
-            looks up the pack to use for a given record in its index_to_pack
-            map.
-        :return: An iterator over the bytes of the records.
-        """
-        # first pass, group into same-index requests
-        request_lists = []
-        current_index = None
-        for (index, offset, length) in memos_for_retrieval:
-            if current_index == index:
-                current_list.append((offset, length))
-            else:
-                if current_index is not None:
-                    request_lists.append((current_index, current_list))
-                current_index = index
-                current_list = [(offset, length)]
-        # handle the last entry
-        if current_index is not None:
-            request_lists.append((current_index, current_list))
-        for index, offsets in request_lists:
-            try:
-                transport, path = self._indices[index]
-            except KeyError:
-                # A KeyError here indicates that someone has triggered an index
-                # reload, and this index has gone missing, we need to start
-                # over.
-                if self._reload_func is None:
-                    # If we don't have a _reload_func there is nothing that can
-                    # be done
-                    raise
-                raise errors.RetryWithNewPacks(index,
-                                               reload_occurred=True,
-                                               exc_info=sys.exc_info())
-            try:
-                reader = pack.make_readv_reader(transport, path, offsets)
-                for names, read_func in reader.iter_records():
-                    yield read_func(None)
-            except errors.NoSuchFile:
-                # A NoSuchFile error indicates that a pack file has gone
-                # missing on disk, we need to trigger a reload, and start over.
-                if self._reload_func is None:
-                    raise
-                raise errors.RetryWithNewPacks(transport.abspath(path),
-                                               reload_occurred=False,
-                                               exc_info=sys.exc_info())
-
-    def set_writer(self, writer, index, transport_packname):
-        """Set a writer to use for adding data."""
-        if index is not None:
-            self._indices[index] = transport_packname
-        self._container_writer = writer
-        self._write_index = index
-
-    def reload_or_raise(self, retry_exc):
-        """Try calling the reload function, or re-raise the original exception.
-
-        This should be called after _DirectPackAccess raises a
-        RetryWithNewPacks exception. This function will handle the common logic
-        of determining when the error is fatal versus being temporary.
-        It will also make sure that the original exception is raised, rather
-        than the RetryWithNewPacks exception.
-
-        If this function returns, then the calling function should retry
-        whatever operation was being performed. Otherwise an exception will
-        be raised.
-
-        :param retry_exc: A RetryWithNewPacks exception.
-        """
-        is_error = False
-        if self._reload_func is None:
-            is_error = True
-        elif not self._reload_func():
-            # The reload claimed that nothing changed
-            if not retry_exc.reload_occurred:
-                # If there wasn't an earlier reload, then we really were
-                # expecting to find changes. We didn't find them, so this is a
-                # hard error
-                is_error = True
-        if is_error:
-            exc_class, exc_value, exc_traceback = retry_exc.exc_info
-            raise exc_class, exc_value, exc_traceback
-
-
 def annotate_knit(knit, revision_id):
     """Annotate a knit with no cached annotations.
 
@@ -3463,7 +3325,7 @@
                 for idx, (sub_key, text, num_lines) in enumerate(
                                                 self._extract_texts(records)):
                     if pb is not None:
-                        pb.update('annotating', idx, len(records))
+                        pb.update(gettext('annotating'), idx, len(records))
                     yield sub_key, text, num_lines
                 for sub_key in ann_keys:
                     text = self._text_cache[sub_key]

=== modified file 'bzrlib/lock.py'
--- bzrlib/lock.py	2011-08-17 16:11:26 +0000
+++ bzrlib/lock.py	2011-09-19 15:59:40 +0000
@@ -46,7 +46,7 @@
     trace,
     )
 from bzrlib.hooks import Hooks
-
+from bzrlib.i18n import gettext
 
 class LockHooks(Hooks):
 
@@ -544,6 +544,6 @@
                 type_name = 'read'
             else:
                 type_name = 'write'
-            trace.note('%r was %s locked again', self, type_name)
+            trace.note(gettext('{0!r} was {1} locked again'), self, type_name)
         self._prev_lock = lock_type
 

=== modified file 'bzrlib/lockdir.py'
--- bzrlib/lockdir.py	2011-08-12 12:11:44 +0000
+++ bzrlib/lockdir.py	2011-09-20 13:31:00 +0000
@@ -137,6 +137,7 @@
         )
 from bzrlib.trace import mutter, note
 from bzrlib.osutils import format_delta, rand_chars, get_host_name
+from bzrlib.i18n import gettext
 
 from bzrlib.lazy_import import lazy_import
 lazy_import(globals(), """
@@ -316,7 +317,7 @@
             self.transport.delete(tmpname + self.__INFO_NAME)
             self.transport.rmdir(tmpname)
         except PathError, e:
-            note("error removing pending lock: %s", e)
+            note(gettext("error removing pending lock: %s"), e)
 
     def _create_pending_dir(self):
         tmpname = '%s/%s.tmp' % (self.path, rand_chars(10))
@@ -611,19 +612,20 @@
             new_info = self.peek()
             if new_info is not None and new_info != last_info:
                 if last_info is None:
-                    start = 'Unable to obtain'
+                    start = gettext('Unable to obtain')
                 else:
-                    start = 'Lock owner changed for'
+                    start = gettext('Lock owner changed for')
                 last_info = new_info
-                msg = u'%s lock %s %s.' % (start, lock_url, new_info)
+                msg = gettext('{0} lock {1} {2}.').format(start, lock_url,
+                                                                    new_info)
                 if deadline_str is None:
                     deadline_str = time.strftime('%H:%M:%S',
                                                     time.localtime(deadline))
                 if timeout > 0:
-                    msg += ('\nWill continue to try until %s, unless '
-                        'you press Ctrl-C.'
-                        % deadline_str)
-                msg += '\nSee "bzr help break-lock" for more.'
+                    msg += '\n' + gettext(
+                             'Will continue to try until %s, unless '
+                             'you press Ctrl-C.') % deadline_str
+                msg += '\n' + gettext('See "bzr help break-lock" for more.')
                 self._report_function(msg)
             if (max_attempts is not None) and (attempt_count >= max_attempts):
                 self._trace("exceeded %d attempts")
@@ -732,9 +734,9 @@
     def __unicode__(self):
         """Return a user-oriented description of this object."""
         d = self.to_readable_dict()
-        return (
+        return ( gettext(
             u'held by %(user)s on %(hostname)s (process #%(pid)s), '
-            u'acquired %(time_ago)s' % d)
+            u'acquired %(time_ago)s') % d)
 
     def to_readable_dict(self):
         """Turn the holder info into a dict of human-readable attributes.

=== modified file 'bzrlib/log.py'
--- bzrlib/log.py	2011-07-25 07:41:52 +0000
+++ bzrlib/log.py	2011-09-19 15:22:23 +0000
@@ -74,8 +74,8 @@
     revision as _mod_revision,
     revisionspec,
     tsort,
-    i18n,
     )
+from bzrlib.i18n import gettext, ngettext
 """)
 
 from bzrlib import (
@@ -215,7 +215,7 @@
     Logger(branch, rqst).show(lf)
 
 
-# Note: This needs to be kept this in sync with the defaults in
+# Note: This needs to be kept in sync with the defaults in
 # make_log_request_dict() below
 _DEFAULT_REQUEST_PARAMS = {
     'direction': 'reverse',
@@ -232,7 +232,7 @@
                           delta_type=None,
                           diff_type=None, _match_using_deltas=True,
                           exclude_common_ancestry=False, match=None,
-                          signature=False,
+                          signature=False, omit_merges=False,
                           ):
     """Convenience function for making a logging request dictionary.
 
@@ -288,6 +288,9 @@
       revisions. Keys can be 'message', 'author', 'committer', 'bugs' or
       the empty string to match any of the preceding properties.
 
+    :param omit_merges: If True, commits with more than one parent are
+      omitted.
+
     """
     # Take care of old style message_search parameter
     if message_search:
@@ -311,6 +314,7 @@
         'exclude_common_ancestry': exclude_common_ancestry,
         'signature': signature,
         'match': match,
+        'omit_merges': omit_merges,
         # Add 'private' attributes for features that may be deprecated
         '_match_using_deltas': _match_using_deltas,
     }
@@ -447,6 +451,7 @@
         limit = rqst.get('limit')
         diff_type = rqst.get('diff_type')
         show_signature = rqst.get('signature')
+        omit_merges = rqst.get('omit_merges')
         log_count = 0
         revision_iterator = self._create_log_revision_iterator()
         for revs in revision_iterator:
@@ -454,6 +459,8 @@
                 # 0 levels means show everything; merge_depth counts from 0
                 if levels != 0 and merge_depth >= levels:
                     continue
+                if omit_merges and len(rev.parent_ids) > 1:
+                    continue
                 if diff_type is None:
                     diff = None
                 else:
@@ -558,10 +565,10 @@
              a list of the same tuples.
     """
     if (exclude_common_ancestry and start_rev_id == end_rev_id):
-        raise errors.BzrCommandError(
-            '--exclude-common-ancestry requires two different revisions')
+        raise errors.BzrCommandError(gettext(
+            '--exclude-common-ancestry requires two different revisions'))
     if direction not in ('reverse', 'forward'):
-        raise ValueError('invalid direction %r' % direction)
+        raise ValueError(gettext('invalid direction %r') % direction)
     br_revno, br_rev_id = branch.last_revision_info()
     if br_revno == 0:
         return []
@@ -608,8 +615,8 @@
         try:
             result = list(result)
         except _StartNotLinearAncestor:
-            raise errors.BzrCommandError('Start revision not found in'
-                ' left-hand history of end revision.')
+            raise errors.BzrCommandError(gettext('Start revision not found in'
+                ' left-hand history of end revision.'))
     return result
 
 
@@ -654,8 +661,8 @@
         except _StartNotLinearAncestor:
             # A merge was never detected so the lower revision limit can't
             # be nested down somewhere
-            raise errors.BzrCommandError('Start revision not found in'
-                ' history of end revision.')
+            raise errors.BzrCommandError(gettext('Start revision not found in'
+                ' history of end revision.'))
 
     # We exit the loop above because we encounter a revision with merges, from
     # this revision, we need to switch to _graph_view_revisions.
@@ -1072,10 +1079,10 @@
     if branch_revno != 0:
         if (start_rev_id == _mod_revision.NULL_REVISION
             or end_rev_id == _mod_revision.NULL_REVISION):
-            raise errors.BzrCommandError('Logging revision 0 is invalid.')
+            raise errors.BzrCommandError(gettext('Logging revision 0 is invalid.'))
         if start_revno > end_revno:
-            raise errors.BzrCommandError("Start revision must be older than "
-                                         "the end revision.")
+            raise errors.BzrCommandError(gettext("Start revision must be "
+                                         "older than the end revision."))
     return (start_rev_id, end_rev_id)
 
 
@@ -1130,10 +1137,10 @@
 
     if ((start_rev_id == _mod_revision.NULL_REVISION)
         or (end_rev_id == _mod_revision.NULL_REVISION)):
-        raise errors.BzrCommandError('Logging revision 0 is invalid.')
+        raise errors.BzrCommandError(gettext('Logging revision 0 is invalid.'))
     if start_revno > end_revno:
-        raise errors.BzrCommandError("Start revision must be older than "
-                                     "the end revision.")
+        raise errors.BzrCommandError(gettext("Start revision must be older "
+                                     "than the end revision."))
 
     if end_revno < start_revno:
         return None, None, None, None
@@ -1405,7 +1412,7 @@
             if advice_sep:
                 self.to_file.write(advice_sep)
             self.to_file.write(
-                "Use --include-merges or -n0 to see merged revisions.\n")
+                "Use --include-merged or -n0 to see merged revisions.\n")
 
     def get_advice_separator(self):
         """Get the text separating the log from the closing advice."""
@@ -1818,7 +1825,7 @@
     try:
         return log_formatter_registry.make_formatter(name, *args, **kwargs)
     except KeyError:
-        raise errors.BzrCommandError("unknown log formatter: %r" % name)
+        raise errors.BzrCommandError(gettext("unknown log formatter: %r") % name)
 
 
 def author_list_all(rev):
@@ -2113,7 +2120,8 @@
                           len(row) > 1 and row[1] == 'fixed']
 
         if fixed_bug_urls:
-            return {'fixes bug(s)': ' '.join(fixed_bug_urls)}
+            return {ngettext('fixes bug', 'fixes bugs', len(fixed_bug_urls)):\
+                    ' '.join(fixed_bug_urls)}
     return {}
 
 properties_handler_registry.register('bugs_properties_handler',

=== modified file 'bzrlib/merge.py'
--- bzrlib/merge.py	2011-07-06 09:22:00 +0000
+++ bzrlib/merge.py	2011-09-16 10:08:09 +0000
@@ -38,6 +38,7 @@
     versionedfile,
     workingtree,
     )
+from bzrlib.i18n import gettext
 """)
 from bzrlib import (
     decorators,
@@ -711,9 +712,9 @@
         merge = operation.run_simple()
         if len(merge.cooked_conflicts) == 0:
             if not self.ignore_zero and not trace.is_quiet():
-                trace.note("All changes applied successfully.")
+                trace.note(gettext("All changes applied successfully."))
         else:
-            trace.note("%d conflicts encountered."
+            trace.note(gettext("%d conflicts encountered.")
                        % len(merge.cooked_conflicts))
 
         return len(merge.cooked_conflicts)
@@ -858,7 +859,7 @@
             self.active_hooks = [hook for hook in hooks if hook is not None]
             for num, (file_id, changed, parents3, names3,
                       executable3) in enumerate(entries):
-                child_pb.update('Preparing file merge', num, len(entries))
+                child_pb.update(gettext('Preparing file merge'), num, len(entries))
                 self._merge_names(file_id, parents3, names3, resolver=resolver)
                 if changed:
                     file_status = self._do_merge_contents(file_id)
@@ -1906,7 +1907,7 @@
             entries = self._entries_to_incorporate()
             entries = list(entries)
             for num, (entry, parent_id) in enumerate(entries):
-                child_pb.update('Preparing file merge', num, len(entries))
+                child_pb.update(gettext('Preparing file merge'), num, len(entries))
                 parent_trans_id = self.tt.trans_id_file_id(parent_id)
                 trans_id = transform.new_by_entry(self.tt, entry,
                     parent_trans_id, self.other_tree)

=== modified file 'bzrlib/missing.py'
--- bzrlib/missing.py	2010-04-30 11:03:59 +0000
+++ bzrlib/missing.py	2011-09-19 08:42:37 +0000
@@ -18,6 +18,7 @@
 
 from bzrlib import (
     log,
+    symbol_versioning,
     )
 import bzrlib.revision as _mod_revision
 
@@ -42,8 +43,9 @@
 
 
 def find_unmerged(local_branch, remote_branch, restrict='all',
-                  include_merges=False, backward=False,
-                  local_revid_range=None, remote_revid_range=None):
+                  include_merged=None, backward=False,
+                  local_revid_range=None, remote_revid_range=None,
+                  include_merges=symbol_versioning.DEPRECATED_PARAMETER):
     """Find revisions from each side that have not been merged.
 
     :param local_branch: Compare the history of local_branch
@@ -53,7 +55,7 @@
         unique revisions from both sides. If 'local', we will return None
         for the remote revisions, similarly if 'remote' we will return None for
         the local revisions.
-    :param include_merges: Show mainline revisions only if False,
+    :param include_merged: Show mainline revisions only if False,
         all revisions otherwise.
     :param backward: Show oldest versions first when True, newest versions
         first when False.
@@ -61,17 +63,27 @@
         revisions (lower bound, upper bound)
     :param remote_revid_range: Revision-id range for filtering remote_branch
         revisions (lower bound, upper bound)
+    :param include_merges: Deprecated historical alias for include_merged
 
     :return: A list of [(revno, revision_id)] for the mainline revisions on
         each side.
     """
+    if symbol_versioning.deprecated_passed(include_merges):
+        symbol_versioning.warn(
+            'include_merges was deprecated in 2.5.'
+            ' Use include_merged instead.',
+            DeprecationWarning, stacklevel=2)
+        if include_merged is None:
+            include_merged = include_merges
+    if include_merged is None:
+        include_merged = False
     local_branch.lock_read()
     try:
         remote_branch.lock_read()
         try:
             return _find_unmerged(
                 local_branch, remote_branch, restrict=restrict,
-                include_merges=include_merges, backward=backward,
+                include_merged=include_merged, backward=backward,
                 local_revid_range=local_revid_range,
                 remote_revid_range=remote_revid_range)
         finally:
@@ -160,7 +172,7 @@
 
 
 def _find_unmerged(local_branch, remote_branch, restrict,
-                   include_merges, backward,
+                   include_merged, backward,
                    local_revid_range=None, remote_revid_range=None):
     """See find_unmerged.
 
@@ -186,7 +198,7 @@
                              ' "remote": %r' % (restrict,))
         local_extra, remote_extra = graph.find_difference(local_revision_id,
                                                           remote_revision_id)
-    if include_merges:
+    if include_merged:
         locals = _enumerate_with_merges(local_branch, local_extra,
                                         graph, local_revno,
                                         local_revision_id, backward)

=== modified file 'bzrlib/multiparent.py'
--- bzrlib/multiparent.py	2011-04-05 01:12:15 +0000
+++ bzrlib/multiparent.py	2011-09-16 10:08:09 +0000
@@ -421,7 +421,7 @@
                             if not (lines == self.get_line_list([revision])[0]):
                                 raise AssertionError()
                             self.clear_cache()
-                    pb.update('Importing revisions',
+                    pb.update(gettext('Importing revisions'),
                               (total - len(revisions)) + len(added), total)
                 revisions = [r for r in revisions if r not in added]
         finally:

=== modified file 'bzrlib/mutabletree.py'
--- bzrlib/mutabletree.py	2011-09-06 09:51:45 +0000
+++ bzrlib/mutabletree.py	2011-09-22 12:13:12 +0000
@@ -260,7 +260,7 @@
         :param more_warning: Details about what is happening.
         """
         if strict is None:
-            strict = self.branch.get_config().get_user_option_as_bool(opt_name)
+            strict = self.branch.get_config_stack().get(opt_name)
         if strict is not False:
             err_class = None
             if (self.has_changes()):

=== modified file 'bzrlib/option.py'
--- bzrlib/option.py	2011-09-01 15:45:57 +0000
+++ bzrlib/option.py	2011-09-22 14:30:17 +0000
@@ -332,7 +332,8 @@
         :param short_name: The short name for the enum switch, if any
         :param short_value_switches: A dict mapping values to short names
         """
-        Option.__init__(self, name, help, type=self.convert, short_name=short_name)
+        Option.__init__(self, name, help, type=self.convert,
+                        short_name=short_name)
         self._registry = registry
         if registry is None:
             if lazy_registry is None:
@@ -437,6 +438,7 @@
     def error(self, message):
         raise errors.BzrCommandError(message)
 
+
 class GettextIndentedHelpFormatter(optparse.IndentedHelpFormatter):
     """Adds gettext() call to format_option()"""
     def __init__(self):
@@ -448,6 +450,7 @@
             option.help = i18n.gettext(option.help)
         return optparse.IndentedHelpFormatter.format_option(self, option)
 
+
 def get_optparser(options):
     """Generate an optparse parser for bzrlib-style options"""
 
@@ -516,14 +519,14 @@
 
 
 _merge_type_registry = MergeTypeRegistry()
+_merge_type_registry.register_lazy('diff3', 'bzrlib.merge', 'Diff3Merger',
+                                   "Merge using external diff3")
+_merge_type_registry.register_lazy('lca', 'bzrlib.merge', 'LCAMerger',
+                                   "LCA-newness merge")
 _merge_type_registry.register_lazy('merge3', 'bzrlib.merge', 'Merge3Merger',
                                    "Native diff3-style merge")
-_merge_type_registry.register_lazy('diff3', 'bzrlib.merge', 'Diff3Merger',
-                                   "Merge using external diff3")
 _merge_type_registry.register_lazy('weave', 'bzrlib.merge', 'WeaveMerger',
                                    "Weave-based merge")
-_merge_type_registry.register_lazy('lca', 'bzrlib.merge', 'LCAMerger',
-                                   "LCA-newness merge")
 
 # Declare the standard options
 _standard_option('help', short_name='h',
@@ -539,65 +542,68 @@
 
 # Declare commonly used options
 _global_option('all')
-_global_option('overwrite', help='Ignore differences between branches and '
-               'overwrite unconditionally.')
 _global_option('basis', type=str)
 _global_option('bound')
+_global_option('change',
+               type=_parse_change_str,
+               short_name='c',
+               param_name='revision',
+               help='Select changes introduced by the specified revision. See also "help revisionspec".')
 _global_option('diff-options', type=str)
+_global_option('directory', short_name='d', type=unicode,
+               help='Branch to operate on, instead of working directory')
+_global_option('dry-run',
+               help="Show what would be done, but don't actually do anything.")
+_global_option('email')
 _global_option('file', type=unicode, short_name='F')
 _global_option('force')
 _global_option('format', type=unicode)
 _global_option('forward')
+_global_option('kind', type=str)
+_global_option('line', help='Use log format with one line per revision.'
+               ' Same as --log-format line')
+_global_registry_option('log-format', "Use specified log format.",
+                        lazy_registry=('bzrlib.log', 'log_formatter_registry'),
+                        value_switches=True, title='Log format',
+                        short_value_switches={'short': 'S'})
+_global_option('long', help='Use detailed log format.'
+               ' Same as --log-format long',
+               short_name='l')
+_global_registry_option('merge-type', 'Select a particular merge algorithm.',
+                        _merge_type_registry, value_switches=True,
+                        title='Merge algorithm')
 _global_option('message', type=unicode,
                short_name='m',
                help='Message string.')
+_global_option('name-from-revision', help='The path name in the old tree.')
+_global_option('no-backup')
 _global_option('no-recurse')
 _global_option('null', short_name='0',
                  help='Use an ASCII NUL (\\0) separator rather than '
                       'a newline.')
+_global_option('overwrite', help='Ignore differences between branches and '
+               'overwrite unconditionally.')
+_global_option('pattern', type=str)
 _global_option('profile',
                help='Show performance profiling information.')
+_global_option('reprocess', help='Reprocess to reduce spurious conflicts.')
+_global_option('remember', help='Remember the specified location as a'
+               ' default.')
 _global_option('revision',
                type=_parse_revision_str,
                short_name='r',
                help='See "help revisionspec" for details.')
-_global_option('change',
-               type=_parse_change_str,
-               short_name='c',
-               param_name='revision',
-               help='Select changes introduced by the specified revision. See also "help revisionspec".')
+_global_option('short', help='Use moderately short log format.'
+               ' Same as --log-format short')
 _global_option('show-ids',
                help='Show internal object ids.')
 _global_option('timezone',
                type=str,
                help='Display timezone as local, original, or utc.')
+_global_option('root', type=str)
 _global_option('unbound')
+_global_option('update')
 _global_option('version')
-_global_option('email')
-_global_option('update')
-_global_registry_option('log-format', "Use specified log format.",
-                        lazy_registry=('bzrlib.log', 'log_formatter_registry'),
-                        value_switches=True, title='Log format',
-                        short_value_switches={'short': 'S'})
-_global_option('long', help='Use detailed log format. Same as --log-format long',
-               short_name='l')
-_global_option('short', help='Use moderately short log format. Same as --log-format short')
-_global_option('line', help='Use log format with one line per revision. Same as --log-format line')
-_global_option('root', type=str)
-_global_option('no-backup')
-_global_registry_option('merge-type', 'Select a particular merge algorithm.',
-                        _merge_type_registry, value_switches=True,
-                        title='Merge algorithm')
-_global_option('pattern', type=str)
-_global_option('remember', help='Remember the specified location as a'
-               ' default.')
-_global_option('reprocess', help='Reprocess to reduce spurious conflicts.')
-_global_option('kind', type=str)
-_global_option('dry-run',
-               help="Show what would be done, but don't actually do anything.")
-_global_option('name-from-revision', help='The path name in the old tree.')
-_global_option('directory', short_name='d', type=unicode,
-               help='Branch to operate on, instead of working directory')
 
 diff_writer_registry = _mod_registry.Registry()
 diff_writer_registry.register('plain', lambda x: x, 'Plaintext diff output.')

=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2011-08-24 23:55:03 +0000
+++ bzrlib/osutils.py	2011-09-16 10:41:45 +0000
@@ -47,6 +47,7 @@
     trace,
     win32utils,
     )
+from bzrlib.i18n import gettext
 """)
 
 from bzrlib.symbol_versioning import (
@@ -89,8 +90,8 @@
         user_encoding = get_user_encoding()
         return [a.decode(user_encoding) for a in sys.argv[1:]]
     except UnicodeDecodeError:
-        raise errors.BzrError("Parameter %r encoding is unsupported by %s "
-            "application locale." % (a, user_encoding))
+        raise errors.BzrError(gettext("Parameter {0!r} encoding is unsupported by {1} "
+            "application locale.").format(a, user_encoding))
 
 
 def make_readonly(filename):
@@ -190,7 +191,7 @@
             if e.errno == errno.ENOENT:
                 return False;
             else:
-                raise errors.BzrError("lstat/stat of (%r): %r" % (f, e))
+                raise errors.BzrError(gettext("lstat/stat of ({0!r}): {1!r}").format(f, e))
 
 
 def fancy_rename(old, new, rename_func, unlink_func):
@@ -925,7 +926,7 @@
     rps = []
     for f in ps:
         if f == '..':
-            raise errors.BzrError("sorry, %r not allowed in path" % f)
+            raise errors.BzrError(gettext("sorry, %r not allowed in path") % f)
         elif (f == '.') or (f == ''):
             pass
         else:
@@ -936,7 +937,7 @@
 def joinpath(p):
     for f in p:
         if (f == '..') or (f is None) or (f == ''):
-            raise errors.BzrError("sorry, %r not allowed in path" % f)
+            raise errors.BzrError(gettext("sorry, %r not allowed in path") % f)
     return pathjoin(*p)
 
 
@@ -1154,7 +1155,7 @@
 
     if len(base) < MIN_ABS_PATHLENGTH:
         # must have space for e.g. a drive letter
-        raise ValueError('%r is too short to calculate a relative path'
+        raise ValueError(gettext('%r is too short to calculate a relative path')
             % (base,))
 
     rp = abspath(path)

=== modified file 'bzrlib/plugin.py'
--- bzrlib/plugin.py	2011-08-12 07:32:22 +0000
+++ bzrlib/plugin.py	2011-09-20 11:01:37 +0000
@@ -48,6 +48,7 @@
     errors,
     trace,
     )
+from bzrlib.i18n import gettext
 from bzrlib import plugins as _mod_plugins
 """)
 
@@ -137,8 +138,8 @@
         try:
             name, path = spec.split('@')
         except ValueError:
-            raise errors.BzrCommandError(
-                '"%s" is not a valid <plugin_name>@<plugin_path> description '
+            raise errors.BzrCommandError(gettext(
+                '"%s" is not a valid <plugin_name>@<plugin_path> description ')
                 % spec)
         specs.append((name, path))
     return specs

=== modified file 'bzrlib/plugins/launchpad/__init__.py'
--- bzrlib/plugins/launchpad/__init__.py	2011-08-21 09:24:01 +0000
+++ bzrlib/plugins/launchpad/__init__.py	2011-09-20 10:19:58 +0000
@@ -46,6 +46,7 @@
     ui,
     trace,
     )
+from bzrlib.i18n import gettext
 """)
 
 from bzrlib import (
@@ -144,14 +145,16 @@
             try:
                 b = _mod_branch.Branch.open_containing('.')[0]
             except NotBranchError:
-                raise BzrCommandError('register-branch requires a public '
-                    'branch url - see bzr help register-branch.')
+                raise BzrCommandError(gettext(
+                            'register-branch requires a public '
+                            'branch url - see bzr help register-branch.'))
             public_url = b.get_public_branch()
             if public_url is None:
                 raise NoPublicBranch(b)
         if product is not None:
             project = product
-            trace.note('--product is deprecated; please use --project.')
+            trace.note(gettext(
+                '--product is deprecated; please use --project.'))
 
 
         rego = BranchRegistrationRequest(branch_url=public_url,
@@ -223,7 +226,7 @@
         if location is None:
             location = u'.'
         web_url = self._get_web_url(LaunchpadService(), location)
-        trace.note('Opening %s in web browser' % web_url)
+        trace.note(gettext('Opening %s in web browser') % web_url)
         if not dry_run:
             import webbrowser   # this import should not be lazy
                                 # otherwise bzr.exe lacks this module
@@ -267,22 +270,23 @@
                 if check_account:
                     account.check_lp_login(username)
                     if verbose:
-                        self.outf.write(
-                            "Launchpad user ID exists and has SSH keys.\n")
+                        self.outf.write(gettext(
+                            "Launchpad user ID exists and has SSH keys.\n"))
                 self.outf.write(username + '\n')
             else:
-                self.outf.write('No Launchpad user ID configured.\n')
+                self.outf.write(gettext('No Launchpad user ID configured.\n'))
                 return 1
         else:
             name = name.lower()
             if check_account:
                 account.check_lp_login(name)
                 if verbose:
-                    self.outf.write(
-                        "Launchpad user ID exists and has SSH keys.\n")
+                    self.outf.write(gettext(
+                        "Launchpad user ID exists and has SSH keys.\n"))
             account.set_lp_login(name)
             if verbose:
-                self.outf.write("Launchpad user ID set to '%s'.\n" % (name,))
+                self.outf.write(gettext("Launchpad user ID set to '%s'.\n") %
+                                                                        (name,))
 
 register_command(cmd_launchpad_login)
 
@@ -400,8 +404,8 @@
             revno = self._find_merged_revno(revision, b, pb)
             merged = self._find_proposals(revno, b, pb)
             if len(merged) == 0:
-                raise BzrCommandError('No review found.')
-            trace.note('%d proposals(s) found.' % len(merged))
+                raise BzrCommandError(gettext('No review found.'))
+            trace.note(gettext('%d proposals(s) found.') % len(merged))
             for mp in merged:
                 webbrowser.open(lp_api.canonical_url(mp))
         finally:
@@ -411,27 +415,27 @@
     def _find_merged_revno(self, revision, b, pb):
         if revision is None:
             return b.revno()
-        pb.update('Finding revision-id')
+        pb.update(gettext('Finding revision-id'))
         revision_id = revision[0].as_revision_id(b)
         # a revno spec is necessarily on the mainline.
         if self._is_revno_spec(revision[0]):
             merging_revision = revision_id
         else:
             graph = b.repository.get_graph()
-            pb.update('Finding merge')
+            pb.update(gettext('Finding merge'))
             merging_revision = graph.find_lefthand_merger(
                 revision_id, b.last_revision())
             if merging_revision is None:
                 raise InvalidRevisionSpec(revision[0].user_spec, b)
-        pb.update('Finding revno')
+        pb.update(gettext('Finding revno'))
         return b.revision_id_to_revno(merging_revision)
 
     def _find_proposals(self, revno, b, pb):
         launchpad = lp_api.login(lp_registration.LaunchpadService())
-        pb.update('Finding Launchpad branch')
+        pb.update(gettext('Finding Launchpad branch'))
         lpb = lp_api.LaunchpadBranch.from_bzr(launchpad, b,
                                               create_missing=False)
-        pb.update('Finding proposals')
+        pb.update(gettext('Finding proposals'))
         return list(lpb.lp.getMergeProposals(status=['Merged'],
                                              merged_revnos=[revno]))
 

=== modified file 'bzrlib/plugins/launchpad/account.py'
--- bzrlib/plugins/launchpad/account.py	2011-07-23 16:33:38 +0000
+++ bzrlib/plugins/launchpad/account.py	2011-09-20 10:47:22 +0000
@@ -26,7 +26,7 @@
     transport,
     )
 from bzrlib.config import AuthenticationConfig, GlobalConfig
-
+from bzrlib.i18n import gettext
 
 LAUNCHPAD_BASE = 'https://launchpad.net/'
 
@@ -61,7 +61,7 @@
         auth_username = _get_auth_user(auth)
         # Auto-upgrading
         if auth_username is None:
-            trace.note('Setting ssh/sftp usernames for launchpad.net.')
+            trace.note(gettext('Setting ssh/sftp usernames for launchpad.net.'))
             _set_auth_user(username, auth)
         elif auth_username != username:
             raise MismatchedUsernames()

=== modified file 'bzrlib/plugins/launchpad/lp_api.py'
--- bzrlib/plugins/launchpad/lp_api.py	2011-02-11 05:27:33 +0000
+++ bzrlib/plugins/launchpad/lp_api.py	2011-09-20 10:19:58 +0000
@@ -33,6 +33,7 @@
     trace,
     transport,
     )
+from bzrlib.i18n import gettext
 from bzrlib.plugins.launchpad.lp_registration import (
     InvalidLaunchpadInstance,
     )
@@ -235,12 +236,13 @@
         """Create a Bazaar branch on Launchpad for the supplied branch."""
         url = cls.tweak_url(bzr_branch.get_push_location(), launchpad)
         if not cls.plausible_launchpad_url(url):
-            raise errors.BzrError('%s is not registered on Launchpad' %
+            raise errors.BzrError(gettext('%s is not registered on Launchpad') %
                                   bzr_branch.base)
         bzr_branch.create_clone_on_transport(transport.get_transport(url))
         lp_branch = launchpad.branches.getByUrl(url=url)
         if lp_branch is None:
-            raise errors.BzrError('%s is not registered on Launchpad' % url)
+            raise errors.BzrError(gettext('%s is not registered on Launchpad') %
+                                                                            url)
         return lp_branch
 
     def get_target(self):
@@ -249,18 +251,21 @@
         if lp_branch.project is not None:
             dev_focus = lp_branch.project.development_focus
             if dev_focus is None:
-                raise errors.BzrError('%s has no development focus.' %
+                raise errors.BzrError(gettext('%s has no development focus.') %
                                   lp_branch.bzr_identity)
             target = dev_focus.branch
             if target is None:
-                raise errors.BzrError('development focus %s has no branch.' % dev_focus)
+                raise errors.BzrError(gettext(
+                        'development focus %s has no branch.') % dev_focus)
         elif lp_branch.sourcepackage is not None:
             target = lp_branch.sourcepackage.getBranch(pocket="Release")
             if target is None:
-                raise errors.BzrError('source package %s has no branch.' %
+                raise errors.BzrError(gettext(
+                                      'source package %s has no branch.') %
                                       lp_branch.sourcepackage)
         else:
-            raise errors.BzrError('%s has no associated product or source package.' %
+            raise errors.BzrError(gettext(
+                        '%s has no associated product or source package.') %
                                   lp_branch.bzr_identity)
         return LaunchpadBranch(target, target.bzr_identity)
 
@@ -272,14 +277,14 @@
         try:
             if self.lp.last_scanned_id is not None:
                 if self.bzr.last_revision() == self.lp.last_scanned_id:
-                    trace.note('%s is already up-to-date.' %
+                    trace.note(gettext('%s is already up-to-date.') %
                                self.lp.bzr_identity)
                     return
                 graph = self.bzr.repository.get_graph()
                 if not graph.is_ancestor(self.lp.last_scanned_id,
                                          self.bzr.last_revision()):
                     raise errors.DivergedBranches(self.bzr, self.push_bzr)
-                trace.note('Pushing to %s' % self.lp.bzr_identity)
+                trace.note(gettext('Pushing to %s') % self.lp.bzr_identity)
             self.bzr.push(self.push_bzr)
         finally:
             self.bzr.unlock()

=== modified file 'bzrlib/plugins/launchpad/lp_directory.py'
--- bzrlib/plugins/launchpad/lp_directory.py	2011-03-24 11:38:25 +0000
+++ bzrlib/plugins/launchpad/lp_directory.py	2011-09-20 14:11:27 +0000
@@ -26,6 +26,7 @@
     trace,
     transport,
     )
+from bzrlib.i18n import gettext
 
 from bzrlib.plugins.launchpad.lp_registration import (
     LaunchpadService, ResolveLaunchpadPathRequest)
@@ -164,8 +165,9 @@
             if 'launchpad' in debug.debug_flags:
                 local_res = result
                 result = self._resolve_via_xmlrpc(path, url, _request_factory)
-                trace.note('resolution for %s\n  local: %s\n remote: %s'
-                           % (url, local_res['urls'], result['urls']))
+                trace.note(gettext(
+                    'resolution for {0}\n  local: {1}\n remote: {2}').format(
+                           url, local_res['urls'], result['urls']))
         else:
             result = self._resolve_via_xmlrpc(path, url, _request_factory)
 

=== modified file 'bzrlib/plugins/launchpad/lp_propose.py'
--- bzrlib/plugins/launchpad/lp_propose.py	2011-04-07 10:36:24 +0000
+++ bzrlib/plugins/launchpad/lp_propose.py	2011-09-20 10:19:58 +0000
@@ -142,8 +142,8 @@
             if mp.queue_status in ('Merged', 'Rejected'):
                 continue
             if mp.target_branch.self_link == self.target_branch.lp.self_link:
-                raise errors.BzrCommandError(
-                    'There is already a branch merge proposal: %s' %
+                raise errors.BzrCommandError(gettext(
+                    'There is already a branch merge proposal: %s') %
                     lp_api.canonical_url(mp))
 
     def _get_prerequisite_branch(self):

=== modified file 'bzrlib/plugins/weave_fmt/bzrdir.py'
--- bzrlib/plugins/weave_fmt/bzrdir.py	2011-09-08 17:55:39 +0000
+++ bzrlib/plugins/weave_fmt/bzrdir.py	2011-09-20 13:31:00 +0000
@@ -44,6 +44,7 @@
     weave,
     xml5,
     )
+from bzrlib.i18n import gettext
 from bzrlib.store.versioned import VersionedFileStore
 from bzrlib.transactions import WriteTransaction
 from bzrlib.transport import (
@@ -222,10 +223,10 @@
         """See Converter.convert()."""
         self.bzrdir = to_convert
         if pb is not None:
-            warnings.warn("pb parameter to convert() is deprecated")
+            warnings.warn(gettext("pb parameter to convert() is deprecated"))
         self.pb = ui.ui_factory.nested_progress_bar()
         try:
-            ui.ui_factory.note('starting upgrade from format 4 to 5')
+            ui.ui_factory.note(gettext('starting upgrade from format 4 to 5'))
             if isinstance(self.bzrdir.transport, local.LocalTransport):
                 self.bzrdir.get_workingtree_transport(None).delete('stat-cache')
             self._convert_to_weaves()
@@ -234,7 +235,8 @@
             self.pb.finished()
 
     def _convert_to_weaves(self):
-        ui.ui_factory.note('note: upgrade may be faster if all store files are ungzipped first')
+        ui.ui_factory.note(gettext(
+          'note: upgrade may be faster if all store files are ungzipped first'))
         try:
             # TODO permissions
             stat = self.bzrdir.transport.stat('weaves')
@@ -263,15 +265,17 @@
         self.pb.clear()
         to_import = self._make_order()
         for i, rev_id in enumerate(to_import):
-            self.pb.update('converting revision', i, len(to_import))
+            self.pb.update(gettext('converting revision'), i, len(to_import))
             self._convert_one_rev(rev_id)
         self.pb.clear()
         self._write_all_weaves()
         self._write_all_revs()
-        ui.ui_factory.note('upgraded to weaves:')
-        ui.ui_factory.note('  %6d revisions and inventories' % len(self.revisions))
-        ui.ui_factory.note('  %6d revisions not present' % len(self.absent_revisions))
-        ui.ui_factory.note('  %6d texts' % self.text_count)
+        ui.ui_factory.note(gettext('upgraded to weaves:'))
+        ui.ui_factory.note('  ' + gettext('%6d revisions and inventories') %
+                                                        len(self.revisions))
+        ui.ui_factory.note('  ' + gettext('%6d revisions not present') %
+                                                    len(self.absent_revisions))
+        ui.ui_factory.note('  ' + gettext('%6d texts') % self.text_count)
         self._cleanup_spare_files_after_format4()
         self.branch._transport.put_bytes(
             'branch-format',
@@ -307,12 +311,13 @@
         try:
             i = 0
             for file_id, file_weave in self.text_weaves.items():
-                self.pb.update('writing weave', i, len(self.text_weaves))
+                self.pb.update(gettext('writing weave'), i,
+                                                        len(self.text_weaves))
                 weaves._put_weave(file_id, file_weave, transaction)
                 i += 1
-            self.pb.update('inventory', 0, 1)
+            self.pb.update(gettext('inventory'), 0, 1)
             controlweaves._put_weave('inventory', self.inv_weave, transaction)
-            self.pb.update('inventory', 1, 1)
+            self.pb.update(gettext('inventory'), 1, 1)
         finally:
             self.pb.clear()
 
@@ -329,7 +334,8 @@
             lambda:True, lambda:True)
         try:
             for i, rev_id in enumerate(self.converted_revs):
-                self.pb.update('write revision', i, len(self.converted_revs))
+                self.pb.update(gettext('write revision'), i,
+                                                len(self.converted_revs))
                 text = serializer_v5.write_revision_to_string(
                     self.revisions[rev_id])
                 key = (rev_id,)
@@ -342,13 +348,13 @@
 
         Any parents not either loaded or abandoned get queued to be
         loaded."""
-        self.pb.update('loading revision',
+        self.pb.update(gettext('loading revision'),
                        len(self.revisions),
                        len(self.known_revisions))
         if not self.branch.repository.has_revision(rev_id):
             self.pb.clear()
-            ui.ui_factory.note('revision {%s} not present in branch; '
-                         'will be converted as a ghost' %
+            ui.ui_factory.note(gettext('revision {%s} not present in branch; '
+                         'will be converted as a ghost') %
                          rev_id)
             self.absent_revisions.add(rev_id)
         else:
@@ -487,7 +493,7 @@
         self.bzrdir = to_convert
         pb = ui.ui_factory.nested_progress_bar()
         try:
-            ui.ui_factory.note('starting upgrade from format 5 to 6')
+            ui.ui_factory.note(gettext('starting upgrade from format 5 to 6'))
             self._convert_to_prefixed()
             return BzrDir.open(self.bzrdir.user_url)
         finally:
@@ -497,7 +503,7 @@
         from bzrlib.store import TransportStore
         self.bzrdir.transport.delete('branch-format')
         for store_name in ["weaves", "revision-store"]:
-            ui.ui_factory.note("adding prefixes to %s" % store_name)
+            ui.ui_factory.note(gettext("adding prefixes to %s") % store_name)
             store_transport = self.bzrdir.transport.clone(store_name)
             store = TransportStore(store_transport, prefixed=True)
             for urlfilename in store_transport.list_dir('.'):
@@ -537,7 +543,7 @@
         self.dir_mode = self.bzrdir._get_dir_mode()
         self.file_mode = self.bzrdir._get_file_mode()
 
-        ui.ui_factory.note('starting upgrade from format 6 to metadir')
+        ui.ui_factory.note(gettext('starting upgrade from format 6 to metadir'))
         self.bzrdir.transport.put_bytes(
                 'branch-format',
                 "Converting to format 6",
@@ -545,12 +551,12 @@
         # its faster to move specific files around than to open and use the apis...
         # first off, nuke ancestry.weave, it was never used.
         try:
-            self.step('Removing ancestry.weave')
+            self.step(gettext('Removing ancestry.weave'))
             self.bzrdir.transport.delete('ancestry.weave')
         except errors.NoSuchFile:
             pass
         # find out whats there
-        self.step('Finding branch files')
+        self.step(gettext('Finding branch files'))
         last_revision = self.bzrdir.open_branch().last_revision()
         bzrcontents = self.bzrdir.transport.list_dir('.')
         for name in bzrcontents:
@@ -560,7 +566,7 @@
         repository_names = [('inventory.weave', True),
                             ('revision-store', True),
                             ('weaves', True)]
-        self.step('Upgrading repository  ')
+        self.step(gettext('Upgrading repository') + '  ')
         self.bzrdir.transport.mkdir('repository', mode=self.dir_mode)
         self.make_lock('repository')
         # we hard code the formats here because we are converting into
@@ -570,7 +576,7 @@
         for entry in repository_names:
             self.move_entry('repository', entry)
 
-        self.step('Upgrading branch      ')
+        self.step(gettext('Upgrading branch') + '      ')
         self.bzrdir.transport.mkdir('branch', mode=self.dir_mode)
         self.make_lock('branch')
         self.put_format('branch', BzrBranchFormat5())
@@ -593,14 +599,14 @@
         else:
             has_checkout = True
         if not has_checkout:
-            ui.ui_factory.note('No working tree.')
+            ui.ui_factory.note(gettext('No working tree.'))
             # If some checkout files are there, we may as well get rid of them.
             for name, mandatory in checkout_files:
                 if name in bzrcontents:
                     self.bzrdir.transport.delete(name)
         else:
             from bzrlib.workingtree_3 import WorkingTreeFormat3
-            self.step('Upgrading working tree')
+            self.step(gettext('Upgrading working tree'))
             self.bzrdir.transport.mkdir('checkout', mode=self.dir_mode)
             self.make_lock('checkout')
             self.put_format(
@@ -621,7 +627,7 @@
 
     def make_lock(self, name):
         """Make a lock for the new control dir name."""
-        self.step('Make %s lock' % name)
+        self.step(gettext('Make %s lock') % name)
         ld = lockdir.LockDir(self.bzrdir.transport,
                              '%s/lock' % name,
                              file_modebits=self.file_mode,
@@ -632,7 +638,7 @@
         """Move then entry name into new_dir."""
         name = entry[0]
         mandatory = entry[1]
-        self.step('Moving %s' % name)
+        self.step(gettext('Moving %s') % name)
         try:
             self.bzrdir.transport.move(name, '%s/%s' % (new_dir, name))
         except errors.NoSuchFile:

=== modified file 'bzrlib/plugins/weave_fmt/repository.py'
--- bzrlib/plugins/weave_fmt/repository.py	2011-05-18 10:41:51 +0000
+++ bzrlib/plugins/weave_fmt/repository.py	2011-09-18 14:57:54 +0000
@@ -272,6 +272,7 @@
     supports_ghosts = False
     supports_external_lookups = False
     supports_chks = False
+    supports_nesting_repositories = True
     _fetch_order = 'topological'
     _fetch_reconcile = True
     fast_deltas = False

=== modified file 'bzrlib/push.py'
--- bzrlib/push.py	2011-05-17 15:01:58 +0000
+++ bzrlib/push.py	2011-09-16 10:37:07 +0000
@@ -26,6 +26,7 @@
     note,
     warning,
     )
+from bzrlib.i18n import gettext
 
 
 class PushResult(object):
@@ -47,10 +48,10 @@
         """Write a human-readable description of the result."""
         if self.branch_push_result is None:
             if self.stacked_on is not None:
-                note('Created new stacked branch referring to %s.' %
+                note(gettext('Created new stacked branch referring to %s.') %
                     self.stacked_on)
             else:
-                note('Created new branch.')
+                note(gettext('Created new branch.'))
         else:
             self.branch_push_result.report(to_file)
 
@@ -91,23 +92,23 @@
                 no_tree=no_tree)
         except errors.FileExists, err:
             if err.path.endswith('/.bzr'):
-                raise errors.BzrCommandError(
+                raise errors.BzrCommandError(gettext(
                     "Target directory %s already contains a .bzr directory, "
-                    "but it is not valid." % (location,))
+                    "but it is not valid.") % (location,))
             if not use_existing_dir:
-                raise errors.BzrCommandError("Target directory %s"
+                raise errors.BzrCommandError(gettext("Target directory %s"
                      " already exists, but does not have a .bzr"
                      " directory. Supply --use-existing-dir to push"
-                     " there anyway." % location)
+                     " there anyway.") % location)
             # This shouldn't occur, but if it does the FileExists error will be
             # more informative than an UnboundLocalError for br_to.
             raise
         except errors.NoSuchFile:
             if not create_prefix:
-                raise errors.BzrCommandError("Parent directory of %s"
+                raise errors.BzrCommandError(gettext("Parent directory of %s"
                     " does not exist."
                     "\nYou may supply --create-prefix to create all"
-                    " leading parent directories."
+                    " leading parent directories.")
                     % location)
             # This shouldn't occur (because create_prefix is true, so
             # create_clone_on_transport should be catching NoSuchFile and
@@ -116,8 +117,8 @@
             # UnboundLocalError for br_to.
             raise
         except errors.TooManyRedirections:
-            raise errors.BzrCommandError("Too many redirections trying "
-                                         "to make %s." % location)
+            raise errors.BzrCommandError(gettext("Too many redirections trying "
+                                         "to make %s.") % location)
         push_result = PushResult()
         # TODO: Some more useful message about what was copied
         try:
@@ -141,20 +142,20 @@
             push_result = dir_to.push_branch(br_from, revision_id, overwrite, 
                 remember, create_prefix)
         except errors.DivergedBranches:
-            raise errors.BzrCommandError('These branches have diverged.'
+            raise errors.BzrCommandError(gettext('These branches have diverged.'
                                     '  See "bzr help diverged-branches"'
-                                    ' for more information.')
+                                    ' for more information.'))
         except errors.NoRoundtrippingSupport, e:
-            raise errors.BzrCommandError("It is not possible to losslessly "
-                "push to %s. You may want to use dpush instead." % 
+            raise errors.BzrCommandError(gettext("It is not possible to losslessly "
+                "push to %s. You may want to use dpush instead.") % 
                     e.target_branch.mapping.vcs.abbreviation)
         except errors.NoRepositoryPresent:
             # we have a bzrdir but no branch or repository
             # XXX: Figure out what to do other than complain.
-            raise errors.BzrCommandError("At %s you have a valid .bzr"
+            raise errors.BzrCommandError(gettext("At %s you have a valid .bzr"
                 " control directory, but not a branch or repository. This"
                 " is an unsupported configuration. Please move the target"
-                " directory out of the way and try again." % location)
+                " directory out of the way and try again.") % location)
         if push_result.workingtree_updated == False:
             warning("This transport does not update the working " 
                     "tree of: %s. See 'bzr help working-trees' for "

=== modified file 'bzrlib/reconcile.py'
--- bzrlib/reconcile.py	2011-06-16 16:06:33 +0000
+++ bzrlib/reconcile.py	2011-09-19 15:59:40 +0000
@@ -35,6 +35,7 @@
 from bzrlib.trace import mutter
 from bzrlib.tsort import topo_sort
 from bzrlib.versionedfile import AdapterFactory, FulltextContentFactory
+from bzrlib.i18n import gettext
 
 
 def reconcile(dir, canonicalize_chks=False):
@@ -92,33 +93,33 @@
             # Nothing to check here
             self.fixed_branch_history = None
             return
-        ui.ui_factory.note('Reconciling branch %s' % self.branch.base)
+        ui.ui_factory.note(gettext('Reconciling branch %s') % self.branch.base)
         branch_reconciler = self.branch.reconcile(thorough=True)
         self.fixed_branch_history = branch_reconciler.fixed_history
 
     def _reconcile_repository(self):
         self.repo = self.bzrdir.find_repository()
-        ui.ui_factory.note('Reconciling repository %s' %
+        ui.ui_factory.note(gettext('Reconciling repository %s') %
             self.repo.user_url)
-        self.pb.update("Reconciling repository", 0, 1)
+        self.pb.update(gettext("Reconciling repository"), 0, 1)
         if self.canonicalize_chks:
             try:
                 self.repo.reconcile_canonicalize_chks
             except AttributeError:
                 raise errors.BzrError(
-                    "%s cannot canonicalize CHKs." % (self.repo,))
+                    gettext("%s cannot canonicalize CHKs.") % (self.repo,))
             repo_reconciler = self.repo.reconcile_canonicalize_chks()
         else:
             repo_reconciler = self.repo.reconcile(thorough=True)
         self.inconsistent_parents = repo_reconciler.inconsistent_parents
         self.garbage_inventories = repo_reconciler.garbage_inventories
         if repo_reconciler.aborted:
-            ui.ui_factory.note(
-                'Reconcile aborted: revision index has inconsistent parents.')
-            ui.ui_factory.note(
-                'Run "bzr check" for more details.')
+            ui.ui_factory.note(gettext(
+                'Reconcile aborted: revision index has inconsistent parents.'))
+            ui.ui_factory.note(gettext(
+                'Run "bzr check" for more details.'))
         else:
-            ui.ui_factory.note('Reconciliation complete.')
+            ui.ui_factory.note(gettext('Reconciliation complete.'))
 
 
 class BranchReconciler(object):
@@ -161,13 +162,14 @@
             # set_revision_history, as this will regenerate it again.
             # Not really worth a whole BranchReconciler class just for this,
             # though.
-            ui.ui_factory.note('Fixing last revision info %s => %s' % (
-                 last_revno, len(real_history)))
+            ui.ui_factory.note(gettext('Fixing last revision info {0} '\
+                                       ' => {1}').format(
+                                       last_revno, len(real_history)))
             self.branch.set_last_revision_info(len(real_history),
                                                last_revision_id)
         else:
             self.fixed_history = False
-            ui.ui_factory.note('revision_history ok.')
+            ui.ui_factory.note(gettext('revision_history ok.'))
 
 
 class RepoReconciler(object):
@@ -228,7 +230,7 @@
         (self.thorough) are treated as requiring the reweave.
         """
         transaction = self.repo.get_transaction()
-        self.pb.update('Reading inventory data')
+        self.pb.update(gettext('Reading inventory data'))
         self.inventory = self.repo.inventories
         self.revisions = self.repo.revisions
         # the total set of revisions to process
@@ -248,11 +250,11 @@
         # (no garbage inventories or we are not doing a thorough check)
         if (not self.inconsistent_parents and
             (not self.garbage_inventories or not self.thorough)):
-            ui.ui_factory.note('Inventory ok.')
+            ui.ui_factory.note(gettext('Inventory ok.'))
             return
-        self.pb.update('Backing up inventory', 0, 0)
+        self.pb.update(gettext('Backing up inventory'), 0, 0)
         self.repo._backup_inventory()
-        ui.ui_factory.note('Backup inventory created.')
+        ui.ui_factory.note(gettext('Backup inventory created.'))
         new_inventories = self.repo._temp_inventories()
 
         # we have topological order of revisions and non ghost parents ready.
@@ -268,10 +270,10 @@
         if not (set(new_inventories.keys()) ==
             set([(revid,) for revid in self.pending])):
             raise AssertionError()
-        self.pb.update('Writing weave')
+        self.pb.update(gettext('Writing weave'))
         self.repo._activate_new_inventory()
         self.inventory = None
-        ui.ui_factory.note('Inventory regenerated.')
+        ui.ui_factory.note(gettext('Inventory regenerated.'))
 
     def _new_inv_parents(self, revision_key):
         """Lookup ghost-filtered parents for revision_key."""
@@ -365,24 +367,24 @@
     def _load_indexes(self):
         """Load indexes for the reconciliation."""
         self.transaction = self.repo.get_transaction()
-        self.pb.update('Reading indexes', 0, 2)
+        self.pb.update(gettext('Reading indexes'), 0, 2)
         self.inventory = self.repo.inventories
-        self.pb.update('Reading indexes', 1, 2)
+        self.pb.update(gettext('Reading indexes'), 1, 2)
         self.repo._check_for_inconsistent_revision_parents()
         self.revisions = self.repo.revisions
-        self.pb.update('Reading indexes', 2, 2)
+        self.pb.update(gettext('Reading indexes'), 2, 2)
 
     def _gc_inventory(self):
         """Remove inventories that are not referenced from the revision store."""
-        self.pb.update('Checking unused inventories', 0, 1)
+        self.pb.update(gettext('Checking unused inventories'), 0, 1)
         self._check_garbage_inventories()
-        self.pb.update('Checking unused inventories', 1, 3)
+        self.pb.update(gettext('Checking unused inventories'), 1, 3)
         if not self.garbage_inventories:
-            ui.ui_factory.note('Inventory ok.')
+            ui.ui_factory.note(gettext('Inventory ok.'))
             return
-        self.pb.update('Backing up inventory', 0, 0)
+        self.pb.update(gettext('Backing up inventory'), 0, 0)
         self.repo._backup_inventory()
-        ui.ui_factory.note('Backup Inventory created')
+        ui.ui_factory.note(gettext('Backup Inventory created'))
         # asking for '' should never return a non-empty weave
         new_inventories = self.repo._temp_inventories()
         # we have topological order of revisions and non ghost parents ready.
@@ -399,10 +401,10 @@
         # the revisionds list
         if not(set(new_inventories.keys()) == set(revision_keys)):
             raise AssertionError()
-        self.pb.update('Writing weave')
+        self.pb.update(gettext('Writing weave'))
         self.repo._activate_new_inventory()
         self.inventory = None
-        ui.ui_factory.note('Inventory regenerated.')
+        ui.ui_factory.note(gettext('Inventory regenerated.'))
 
     def _fix_text_parents(self):
         """Fix bad versionedfile parent entries.
@@ -440,7 +442,7 @@
             versions_list.append(text_key[1])
         # Do the reconcile of individual weaves.
         for num, file_id in enumerate(per_id_bad_parents):
-            self.pb.update('Fixing text parents', num,
+            self.pb.update(gettext('Fixing text parents'), num,
                            len(per_id_bad_parents))
             versions_with_bad_parents = per_id_bad_parents[file_id]
             id_unused_versions = set(key[-1] for key in unused_versions

=== modified file 'bzrlib/reconfigure.py'
--- bzrlib/reconfigure.py	2010-04-23 00:44:15 +0000
+++ bzrlib/reconfigure.py	2011-09-15 11:31:47 +0000
@@ -29,7 +29,7 @@
     ui,
     urlutils,
     )
-
+from bzrlib.i18n import gettext
 
 # TODO: common base class for all reconfigure operations, making no
 # assumptions about what kind of change will be done.
@@ -48,9 +48,9 @@
         try:
             branch.set_stacked_on_url(on_url)
             if not trace.is_quiet():
-                ui.ui_factory.note(
-                    "%s is now stacked on %s\n"
-                    % (branch.base, branch.get_stacked_on_url()))
+                ui.ui_factory.note(gettext(
+                    "{0} is now stacked on {1}\n").format(
+                      branch.base, branch.get_stacked_on_url()))
         finally:
             branch.unlock()
 
@@ -63,8 +63,8 @@
         try:
             branch.set_stacked_on_url(None)
             if not trace.is_quiet():
-                ui.ui_factory.note(
-                    "%s is now not stacked\n"
+                ui.ui_factory.note(gettext(
+                    "%s is now not stacked\n")
                     % (branch.base,))
         finally:
             branch.unlock()

=== modified file 'bzrlib/remote.py'
--- bzrlib/remote.py	2011-09-12 09:51:52 +0000
+++ bzrlib/remote.py	2011-09-18 14:57:54 +0000
@@ -40,6 +40,7 @@
     NoSuchRevision,
     SmartProtocolError,
     )
+from bzrlib.i18n import gettext
 from bzrlib.lockable_files import LockableFiles
 from bzrlib.smart import client, vfs, repository as smart_repo
 from bzrlib.smart.client import _SmartClient
@@ -741,6 +742,7 @@
         self._supports_external_lookups = None
         self._supports_tree_reference = None
         self._supports_funky_characters = None
+        self._supports_nesting_repositories = None
         self._rich_root_data = None
 
     def __repr__(self):
@@ -783,6 +785,14 @@
         return self._supports_funky_characters
 
     @property
+    def supports_nesting_repositories(self):
+        if self._supports_nesting_repositories is None:
+            self._ensure_real()
+            self._supports_nesting_repositories = \
+                self._custom_format.supports_nesting_repositories
+        return self._supports_nesting_repositories
+
+    @property
     def supports_tree_reference(self):
         if self._supports_tree_reference is None:
             self._ensure_real()
@@ -1873,7 +1883,7 @@
         from bzrlib import osutils
         import tarfile
         # TODO: Maybe a progress bar while streaming the tarball?
-        note("Copying repository content as tarball...")
+        note(gettext("Copying repository content as tarball..."))
         tar_file = self._get_tarball('bz2')
         if tar_file is None:
             return None

=== modified file 'bzrlib/rename_map.py'
--- bzrlib/rename_map.py	2009-03-24 15:47:32 +0000
+++ bzrlib/rename_map.py	2011-09-16 10:08:09 +0000
@@ -23,7 +23,7 @@
     trace,
 )
 from bzrlib.ui import ui_factory
-
+from bzrlib.i18n import gettext
 
 class RenameMap(object):
     """Determine a mapping of renames."""
@@ -65,7 +65,7 @@
         try:
             for num, (file_id, contents) in enumerate(
                 tree.iter_files_bytes(desired_files)):
-                task.update('Calculating hashes', num, len(file_ids))
+                task.update(gettext('Calculating hashes'), num, len(file_ids))
                 s = StringIO()
                 s.writelines(contents)
                 s.seek(0)
@@ -103,7 +103,7 @@
         task = ui_factory.nested_progress_bar()
         try:
             for num, path in enumerate(paths):
-                task.update('Determining hash hits', num, len(paths))
+                task.update(gettext('Determining hash hits'), num, len(paths))
                 hits = self.hitcounts(self.tree.get_file_lines(None,
                                                                path=path))
                 all_hits.extend((v, path, k) for k, v in hits.items())
@@ -238,7 +238,7 @@
             pp.next_phase()
             delta = rn._make_inventory_delta(matches)
             for old, new, file_id, entry in delta:
-                trace.note("%s => %s", old, new)
+                trace.note( gettext("{0} => {1}").format(old, new) )
             if not dry_run:
                 tree.add(required_parents)
                 tree.apply_inventory_delta(delta)

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2011-09-06 11:01:30 +0000
+++ bzrlib/repository.py	2011-09-21 19:45:01 +0000
@@ -35,6 +35,7 @@
     gpg,
     )
 from bzrlib.bundle import serializer
+from bzrlib.i18n import gettext
 """)
 
 from bzrlib import (
@@ -280,7 +281,7 @@
                 raise
             mutter('abort_write_group failed')
             log_exception_quietly()
-            note('bzr: ERROR (ignored): %s', exc)
+            note(gettext('bzr: ERROR (ignored): %s'), exc)
         self._write_group = None
 
     def _abort_write_group(self):
@@ -360,8 +361,6 @@
         # the following are part of the public API for Repository:
         self.bzrdir = a_bzrdir
         self.control_files = control_files
-        self._transport = control_files._transport
-        self.base = self._transport.base
         # for tests
         self._write_group = None
         # Additional places to query for data.
@@ -405,7 +404,7 @@
         """
         if self.__class__ is not other.__class__:
             return False
-        return (self._transport.base == other._transport.base)
+        return (self.control_url == other.control_url)
 
     def is_in_write_group(self):
         """Return True if there is an open write group.
@@ -1418,6 +1417,8 @@
     rich_root_data = None
     # Does this format support explicitly versioned directories?
     supports_versioned_directories = None
+    # Can other repositories be nested into one of this format?
+    supports_nesting_repositories = None
 
     def __repr__(self):
         return "%s()" % self.__class__.__name__
@@ -1549,6 +1550,7 @@
     supports_tree_reference = False
     supports_external_lookups = False
     supports_leaving_lock = True
+    supports_nesting_repositories = True
 
     @property
     def _matchingbzrdir(self):
@@ -1799,25 +1801,25 @@
         # trigger an assertion if not such
         repo._format.get_format_string()
         self.repo_dir = repo.bzrdir
-        pb.update('Moving repository to repository.backup')
+        pb.update(gettext('Moving repository to repository.backup'))
         self.repo_dir.transport.move('repository', 'repository.backup')
         backup_transport =  self.repo_dir.transport.clone('repository.backup')
         repo._format.check_conversion_target(self.target_format)
         self.source_repo = repo._format.open(self.repo_dir,
             _found=True,
             _override_transport=backup_transport)
-        pb.update('Creating new repository')
+        pb.update(gettext('Creating new repository'))
         converted = self.target_format.initialize(self.repo_dir,
                                                   self.source_repo.is_shared())
         converted.lock_write()
         try:
-            pb.update('Copying content')
+            pb.update(gettext('Copying content'))
             self.source_repo.copy_content_into(converted)
         finally:
             converted.unlock()
-        pb.update('Deleting old repository content')
+        pb.update(gettext('Deleting old repository content'))
         self.repo_dir.transport.delete_tree('repository.backup')
-        ui.ui_factory.note('repository converted')
+        ui.ui_factory.note(gettext('repository converted'))
         pb.finished()
 
 

=== modified file 'bzrlib/revisionspec.py'
--- bzrlib/revisionspec.py	2011-03-03 12:50:21 +0000
+++ bzrlib/revisionspec.py	2011-09-19 15:59:40 +0000
@@ -27,6 +27,7 @@
     symbol_versioning,
     workingtree,
     )
+from bzrlib.i18n import gettext
 """)
 
 from bzrlib import (
@@ -910,7 +911,8 @@
             location_type = 'parent branch'
         if submit_location is None:
             raise errors.NoSubmitBranch(branch)
-        trace.note('Using %s %s', location_type, submit_location)
+        trace.note(gettext('Using {0} {1}').format(location_type,
+                                                        submit_location))
         return submit_location
 
     def _match_on(self, branch, revs):

=== modified file 'bzrlib/send.py'
--- bzrlib/send.py	2011-05-17 12:12:09 +0000
+++ bzrlib/send.py	2011-09-19 15:59:40 +0000
@@ -25,6 +25,7 @@
     registry,
     trace,
     )
+from bzrlib.i18n import gettext
 from bzrlib.branch import (
     Branch,
     )
@@ -51,12 +52,12 @@
             mail_client = config.get_mail_client()
             if (not getattr(mail_client, 'supports_body', False)
                 and body is not None):
-                raise errors.BzrCommandError(
-                    'Mail client "%s" does not support specifying body' %
+                raise errors.BzrCommandError(gettext(
+                    'Mail client "%s" does not support specifying body') %
                     mail_client.__class__.__name__)
         if remember and submit_branch is None:
-            raise errors.BzrCommandError(
-                '--remember requires a branch to be specified.')
+            raise errors.BzrCommandError(gettext(
+                '--remember requires a branch to be specified.'))
         stored_submit_branch = branch.get_submit_branch()
         remembered_submit_branch = None
         if submit_branch is None:
@@ -70,12 +71,12 @@
             submit_branch = branch.get_parent()
             remembered_submit_branch = "parent"
         if submit_branch is None:
-            raise errors.BzrCommandError('No submit branch known or'
-                                         ' specified')
+            raise errors.BzrCommandError(gettext('No submit branch known or'
+                                         ' specified'))
         if remembered_submit_branch is not None:
-            trace.note('Using saved %s location "%s" to determine what '
-                       'changes to submit.', remembered_submit_branch,
-                       submit_branch)
+            trace.note(gettext('Using saved {0} location "{1}" to determine '
+                       'what changes to submit.').format(
+                                    remembered_submit_branch, submit_branch))
 
         if mail_to is None or format is None:
             # TODO: jam 20090716 we open the submit_branch here, but we *don't*
@@ -90,7 +91,7 @@
                 try:
                     format = format_registry.get(formatname)
                 except KeyError:
-                    raise errors.BzrCommandError("No such send format '%s'." % 
+                    raise errors.BzrCommandError(gettext("No such send format '%s'.") % 
                                                  formatname)
 
         stored_public_branch = branch.get_public_branch()
@@ -101,14 +102,14 @@
               or (remember is None and stored_public_branch is None)):
             branch.set_public_branch(public_branch)
         if no_bundle and public_branch is None:
-            raise errors.BzrCommandError('No public branch specified or'
-                                         ' known')
+            raise errors.BzrCommandError(gettext('No public branch specified or'
+                                         ' known'))
         base_revision_id = None
         revision_id = None
         if revision is not None:
             if len(revision) > 2:
-                raise errors.BzrCommandError('bzr send takes '
-                    'at most two one revision identifiers')
+                raise errors.BzrCommandError(gettext('bzr send takes '
+                    'at most two one revision identifiers'))
             revision_id = revision[-1].as_revision_id(branch)
             if len(revision) == 2:
                 base_revision_id = revision[0].as_revision_id(branch)
@@ -120,7 +121,7 @@
                     more_warning='Uncommitted changes will not be sent.')
             revision_id = branch.last_revision()
         if revision_id == NULL_REVISION:
-            raise errors.BzrCommandError('No revisions to submit.')
+            raise errors.BzrCommandError(gettext('No revisions to submit.'))
         if format is None:
             format = format_registry.get()
         directive = format(branch, revision_id, submit_branch,
@@ -131,8 +132,8 @@
         else:
             if directive.multiple_output_files:
                 if output == '-':
-                    raise errors.BzrCommandError('- not supported for '
-                        'merge directives that use more than one output file.')
+                    raise errors.BzrCommandError(gettext('- not supported for '
+                        'merge directives that use more than one output file.'))
                 if not os.path.exists(output):
                     os.mkdir(output, 0755)
                 for (filename, lines) in directive.to_files():
@@ -173,8 +174,8 @@
         if not no_patch:
             patch_type = 'bundle'
         else:
-            raise errors.BzrCommandError('Format 0.9 does not'
-                ' permit bundle with no patch')
+            raise errors.BzrCommandError(gettext('Format 0.9 does not'
+                ' permit bundle with no patch'))
     else:
         if not no_patch:
             patch_type = 'diff'

=== modified file 'bzrlib/shelf_ui.py'
--- bzrlib/shelf_ui.py	2010-11-04 17:48:47 +0000
+++ bzrlib/shelf_ui.py	2011-09-16 15:39:47 +0000
@@ -34,7 +34,7 @@
     ui,
     workingtree,
 )
-
+from bzrlib.i18n import gettext
 
 class UseEditor(Exception):
     """Use an editor instead of selecting hunks."""
@@ -42,17 +42,17 @@
 
 class ShelfReporter(object):
 
-    vocab = {'add file': 'Shelve adding file "%(path)s"?',
-             'binary': 'Shelve binary changes?',
-             'change kind': 'Shelve changing "%s" from %(other)s'
-             ' to %(this)s?',
-             'delete file': 'Shelve removing file "%(path)s"?',
-             'final': 'Shelve %d change(s)?',
-             'hunk': 'Shelve?',
-             'modify target': 'Shelve changing target of'
-             ' "%(path)s" from "%(other)s" to "%(this)s"?',
-             'rename': 'Shelve renaming "%(other)s" =>'
-                        ' "%(this)s"?'
+    vocab = {'add file': gettext('Shelve adding file "%(path)s"?'),
+             'binary': gettext('Shelve binary changes?'),
+             'change kind': gettext('Shelve changing "%s" from %(other)s'
+             ' to %(this)s?'),
+             'delete file': gettext('Shelve removing file "%(path)s"?'),
+             'final': gettext('Shelve %d change(s)?'),
+             'hunk': gettext('Shelve?'),
+             'modify target': gettext('Shelve changing target of'
+             ' "%(path)s" from "%(other)s" to "%(this)s"?'),
+             'rename': gettext('Shelve renaming "%(other)s" =>'
+                        ' "%(this)s"?')
              }
 
     invert_diff = False
@@ -66,15 +66,15 @@
 
     def shelved_id(self, shelf_id):
         """Report the id changes were shelved to."""
-        trace.note('Changes shelved with id "%d".' % shelf_id)
+        trace.note(gettext('Changes shelved with id "%d".') % shelf_id)
 
     def changes_destroyed(self):
         """Report that changes were made without shelving."""
-        trace.note('Selected changes destroyed.')
+        trace.note(gettext('Selected changes destroyed.'))
 
     def selected_changes(self, transform):
         """Report the changes that were selected."""
-        trace.note("Selected changes:")
+        trace.note(gettext("Selected changes:"))
         changes = transform.iter_changes()
         delta.report_changes(changes, self.delta_reporter)
 
@@ -94,16 +94,16 @@
 
 class ApplyReporter(ShelfReporter):
 
-    vocab = {'add file': 'Delete file "%(path)s"?',
-             'binary': 'Apply binary changes?',
-             'change kind': 'Change "%(path)s" from %(this)s'
-             ' to %(other)s?',
-             'delete file': 'Add file "%(path)s"?',
-             'final': 'Apply %d change(s)?',
-             'hunk': 'Apply change?',
-             'modify target': 'Change target of'
-             ' "%(path)s" from "%(this)s" to "%(other)s"?',
-             'rename': 'Rename "%(this)s" => "%(other)s"?',
+    vocab = {'add file': gettext('Delete file "%(path)s"?'),
+             'binary': gettext('Apply binary changes?'),
+             'change kind': gettext('Change "%(path)s" from %(this)s'
+             ' to %(other)s?'),
+             'delete file': gettext('Add file "%(path)s"?'),
+             'final': gettext('Apply %d change(s)?'),
+             'hunk': gettext('Apply change?'),
+             'modify target': gettext('Change target of'
+             ' "%(path)s" from "%(this)s" to "%(other)s"?'),
+             'rename': gettext('Rename "%(this)s" => "%(other)s"?'),
              }
 
     invert_diff = True
@@ -262,7 +262,7 @@
             # to prompt the user, better abort now.  See
             # https://code.launchpad.net/~bialix/bzr/shelve-no-tty/+merge/14905
             # for more context.
-            raise errors.BzrError("You need a controlling terminal.")
+            raise errors.BzrError(gettext("You need a controlling terminal."))
         sys.stdout.write(message)
         char = osutils.getchar()
         sys.stdout.write("\r" + ' ' * len(message) + '\r')
@@ -412,7 +412,7 @@
             else:
                 shelf_id = manager.last_shelf()
                 if shelf_id is None:
-                    raise errors.BzrCommandError('No changes are shelved.')
+                    raise errors.BzrCommandError(gettext('No changes are shelved.'))
             apply_changes = True
             delete_shelf = True
             read_shelf = True
@@ -470,11 +470,11 @@
         cleanups = [self.tree.unlock]
         try:
             if self.read_shelf:
-                trace.note('Using changes with id "%d".' % self.shelf_id)
+                trace.note(gettext('Using changes with id "%d".') % self.shelf_id)
                 unshelver = self.manager.get_unshelver(self.shelf_id)
                 cleanups.append(unshelver.finalize)
                 if unshelver.message is not None:
-                    trace.note('Message: %s' % unshelver.message)
+                    trace.note(gettext('Message: %s') % unshelver.message)
                 change_reporter = delta._ChangeReporter()
                 merger = unshelver.make_merger(None)
                 merger.change_reporter = change_reporter
@@ -486,7 +486,7 @@
                     self.show_changes(merger)
             if self.delete_shelf:
                 self.manager.delete_shelf(self.shelf_id)
-                trace.note('Deleted changes with id "%d".' % self.shelf_id)
+                trace.note(gettext('Deleted changes with id "%d".') % self.shelf_id)
         finally:
             for cleanup in reversed(cleanups):
                 cleanup()

=== modified file 'bzrlib/smart/bzrdir.py'
--- bzrlib/smart/bzrdir.py	2011-05-19 09:32:38 +0000
+++ bzrlib/smart/bzrdir.py	2011-09-21 19:45:57 +0000
@@ -150,9 +150,7 @@
         control_format = self._bzrdir.cloning_metadir(
             require_stacking=require_stacking)
         control_name = control_format.network_name()
-        # XXX: There should be a method that tells us that the format does/does
-        # not have subformats.
-        if isinstance(control_format, BzrDirMetaFormat1):
+        if not control_format.fixed_components:
             branch_name = ('branch',
                 control_format.get_branch_format().network_name())
             repository_name = control_format.repository_format.network_name()

=== modified file 'bzrlib/smart/medium.py'
--- bzrlib/smart/medium.py	2011-09-23 20:51:16 +0000
+++ bzrlib/smart/medium.py	2011-09-26 07:56:05 +0000
@@ -45,6 +45,7 @@
     ui,
     urlutils,
     )
+from bzrlib.i18n import gettext
 from bzrlib.smart import client, protocol, request, signals, vfs
 from bzrlib.transport import ssh
 """)
@@ -711,8 +712,8 @@
         value['count'] = 0
         value['vfs_count'] = 0
         if count != 0:
-            trace.note('HPSS calls: %d (%d vfs) %s',
-                       count, vfs_count, medium_repr)
+            trace.note(gettext('HPSS calls: {0} ({1} vfs) {2}').format(
+                       count, vfs_count, medium_repr))
 
     def flush_all(self):
         for ref in list(self.counts.keys()):

=== modified file 'bzrlib/smart/server.py'
--- bzrlib/smart/server.py	2011-09-23 20:09:50 +0000
+++ bzrlib/smart/server.py	2011-09-26 07:56:05 +0000
@@ -29,6 +29,7 @@
     trace,
     transport as _mod_transport,
 )
+from bzrlib.i18n import gettext
 from bzrlib.lazy_import import lazy_import
 lazy_import(globals(), """
 from bzrlib.smart import (
@@ -450,7 +451,7 @@
             smart_server = SmartTCPServer(self.transport,
                                           client_timeout=timeout)
             smart_server.start_server(host, port)
-            trace.note('listening on port: %s' % smart_server.port)
+            trace.note(gettext('listening on port: %s') % smart_server.port)
         self.smart_server = smart_server
 
     def _change_globals(self):

=== modified file 'bzrlib/switch.py'
--- bzrlib/switch.py	2011-05-04 13:26:14 +0000
+++ bzrlib/switch.py	2011-09-16 10:41:45 +0000
@@ -18,9 +18,9 @@
 
 from bzrlib import errors, merge, revision
 from bzrlib.branch import Branch
+from bzrlib.i18n import gettext
 from bzrlib.trace import note
 
-
 def _run_post_switch_hooks(control_dir, to_branch, force, revision_id):
     from bzrlib.branch import SwitchHookParams
     hooks = Branch.hooks['post_switch']
@@ -64,8 +64,8 @@
     # XXX: Should the tree be locked for get_parent_ids?
     existing_pending_merges = tree.get_parent_ids()[1:]
     if len(existing_pending_merges) > 0:
-        raise errors.BzrCommandError('Pending merges must be '
-            'committed or reverted before using switch.')
+        raise errors.BzrCommandError(gettext('Pending merges must be '
+            'committed or reverted before using switch.'))
 
 
 def _set_branch_location(control, to_branch, force=False):
@@ -90,14 +90,14 @@
             possible_transports = []
             try:
                 if not force and _any_local_commits(b, possible_transports):
-                    raise errors.BzrCommandError(
+                    raise errors.BzrCommandError(gettext(
                         'Cannot switch as local commits found in the checkout. '
                         'Commit these to the bound branch or use --force to '
-                        'throw them away.')
+                        'throw them away.'))
             except errors.BoundBranchConnectionFailure, e:
-                raise errors.BzrCommandError(
+                raise errors.BzrCommandError(gettext(
                         'Unable to connect to current master branch %(target)s: '
-                        '%(error)s To switch anyway, use --force.' %
+                        '%(error)s To switch anyway, use --force.') %
                         e.__dict__)
             b.set_bound_location(None)
             b.pull(to_branch, overwrite=True,
@@ -105,8 +105,8 @@
             b.set_bound_location(to_branch.base)
             b.set_parent(b.get_master_branch().get_parent())
         else:
-            raise errors.BzrCommandError('Cannot switch a branch, '
-                'only a checkout.')
+            raise errors.BzrCommandError(gettext('Cannot switch a branch, '
+                'only a checkout.'))
 
 
 def _any_local_commits(this_branch, possible_transports):
@@ -141,12 +141,12 @@
             revision_id = to_branch.last_revision()
         if tree.last_revision() == revision_id:
             if not quiet:
-                note("Tree is up to date at revision %d.", to_branch.revno())
+                note(gettext("Tree is up to date at revision %d."), to_branch.revno())
             return
         base_tree = source_repository.revision_tree(tree.last_revision())
         merge.Merge3Merger(tree, tree, base_tree, to_branch.repository.revision_tree(revision_id))
         tree.set_last_revision(to_branch.last_revision())
         if not quiet:
-            note('Updated to revision %d.' % to_branch.revno())
+            note(gettext('Updated to revision %d.') % to_branch.revno())
     finally:
         tree.unlock()

=== modified file 'bzrlib/tag.py'
--- bzrlib/tag.py	2011-09-05 14:16:12 +0000
+++ bzrlib/tag.py	2011-09-22 13:26:14 +0000
@@ -344,11 +344,11 @@
         updates = {}
         result = dict(dest_dict) # copy
         for name, target in source_dict.items():
-            if name not in result or overwrite:
+            if result.get(name) == target:
+                pass
+            elif name not in result or overwrite:
+                updates[name] = target
                 result[name] = target
-                updates[name] = target
-            elif result[name] == target:
-                pass
             else:
                 conflicts.append((name, target, result[name]))
         return result, updates, conflicts

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2011-09-22 14:35:58 +0000
+++ bzrlib/tests/__init__.py	2011-09-26 07:56:05 +0000
@@ -2677,7 +2677,7 @@
         except errors.UninitializableFormat:
             raise TestSkipped("Format %s is not initializable." % format)
 
-    def make_repository(self, relpath, shared=False, format=None):
+    def make_repository(self, relpath, shared=None, format=None):
         """Create a repository on our default transport at relpath.
 
         Note that relpath must be a relative path, not a full url.

=== modified file 'bzrlib/tests/blackbox/test_branch.py'
--- bzrlib/tests/blackbox/test_branch.py	2011-08-12 09:49:24 +0000
+++ bzrlib/tests/blackbox/test_branch.py	2011-09-22 16:33:49 +0000
@@ -66,11 +66,21 @@
     def test_branch_broken_pack(self):
         """branching with a corrupted pack file."""
         self.example_branch('a')
-        #now add some random corruption
-        fname = 'a/.bzr/repository/packs/' + os.listdir('a/.bzr/repository/packs')[0]
+        # add some corruption
+        packs_dir = 'a/.bzr/repository/packs/'
+        fname = packs_dir + os.listdir(packs_dir)[0]
         with open(fname, 'rb+') as f:
-            f.seek(750)
-            f.write("\xff")
+            # Start from the end of the file to avoid choosing a place bigger
+            # than the file itself.
+            f.seek(-5, os.SEEK_END)
+            c = f.read(1)
+            f.seek(-5, os.SEEK_END)
+            # Make sure we inject a value different than the one we just read
+            if c == '\xFF':
+                corrupt = '\x00'
+            else:
+                corrupt = '\xFF'
+            f.write(corrupt) # make sure we corrupt something
         self.run_bzr_error(['Corruption while decompressing repository file'], 
                             'branch a b', retcode=3)
 
@@ -334,7 +344,7 @@
         # mainline.
         out, err = self.run_bzr(['branch', 'branch', 'newbranch'])
         self.assertEqual('', out)
-        self.assertEqual('Branched 2 revision(s).\n',
+        self.assertEqual('Branched 2 revisions.\n',
             err)
         # it should have preserved the branch format, and so it should be
         # capable of supporting stacking, but not actually have a stacked_on
@@ -441,7 +451,7 @@
         # being too low. If rpc_count increases, more network roundtrips have
         # become necessary for this use case. Please do not adjust this number
         # upwards without agreement from bzr's network support maintainers.
-        self.assertLength(37, self.hpss_calls)
+        self.assertLength(39, self.hpss_calls)
 
     def test_branch_from_trivial_branch_streaming_acceptance(self):
         self.setup_smart_server_with_call_log()
@@ -561,7 +571,7 @@
                 $ bzr checkout %(option)s repo/trunk checkout
                 $ cd checkout
                 $ bzr branch --switch ../repo/trunk ../repo/branched
-                2>Branched 0 revision(s).
+                2>Branched 0 revisions.
                 2>Tree is up to date at revision 0.
                 2>Switched to branch:...branched...
                 $ cd ..

=== modified file 'bzrlib/tests/blackbox/test_dpush.py'
--- bzrlib/tests/blackbox/test_dpush.py	2011-04-16 08:41:33 +0000
+++ bzrlib/tests/blackbox/test_dpush.py	2011-09-22 12:13:12 +0000
@@ -146,8 +146,8 @@
     def set_config_push_strict(self, value):
         # set config var (any of bazaar.conf, locations.conf, branch.conf
         # should do)
-        conf = self.tree.branch.get_config()
-        conf.set_user_option('dpush_strict', value)
+        conf = self.tree.branch.get_config_stack()
+        conf.set('dpush_strict', value)
 
     _default_command = ['dpush', '../to']
 

=== modified file 'bzrlib/tests/blackbox/test_log.py'
--- bzrlib/tests/blackbox/test_log.py	2011-08-04 00:17:53 +0000
+++ bzrlib/tests/blackbox/test_log.py	2011-09-19 08:42:37 +0000
@@ -89,8 +89,12 @@
     def get_captured_revisions(self):
         return self.log_catcher.revisions
 
-    def assertLogRevnos(self, args, expected_revnos, working_dir='.'):
-        self.run_bzr(['log'] + args, working_dir=working_dir)
+    def assertLogRevnos(self, args, expected_revnos, working_dir='.',
+                        out='', err=''):
+        actual_out, actual_err = self.run_bzr(['log'] + args,
+                                              working_dir=working_dir)
+        self.assertEqual(out, actual_out)
+        self.assertEqual(err, actual_err)
         self.assertEqual(expected_revnos,
                          [r.revno for r in self.get_captured_revisions()])
 
@@ -536,19 +540,30 @@
 
     def test_include_merges(self):
         # Confirm --include-merges gives the same output as -n0
-        self.assertLogRevnos(['--include-merges'],
-                             ['2', '1.1.2', '1.2.1', '1.1.1', '1'],
-                             working_dir='level0')
-        self.assertLogRevnos(['--include-merges'],
-                             ['2', '1.1.2', '1.2.1', '1.1.1', '1'],
-                             working_dir='level0')
+        msg = ("The option '--include-merges' to 'bzr log' "
+               "has been deprecated in bzr 2.5. "
+               "Please use '--include-merged' instead.\n")
+        self.assertLogRevnos(['--include-merges'],
+                             ['2', '1.1.2', '1.2.1', '1.1.1', '1'],
+                             working_dir='level0', err=msg)
+        self.assertLogRevnos(['--include-merges'],
+                             ['2', '1.1.2', '1.2.1', '1.1.1', '1'],
+                             working_dir='level0', err=msg)
         out_im, err_im = self.run_bzr('log --include-merges',
                                       working_dir='level0')
         out_n0, err_n0 = self.run_bzr('log -n0', working_dir='level0')
-        self.assertEqual('', err_im)
+        self.assertEqual(msg, err_im)
         self.assertEqual('', err_n0)
         self.assertEqual(out_im, out_n0)
 
+    def test_include_merged(self):
+        # Confirm --include-merged gives the same output as -n0
+        expected = ['2', '1.1.2', '1.2.1', '1.1.1', '1']
+        self.assertLogRevnos(['--include-merged'],
+                             expected, working_dir='level0')
+        self.assertLogRevnos(['--include-merged'],
+                             expected, working_dir='level0')
+
     def test_force_merge_revisions_N(self):
         self.assertLogRevnos(['-n2'],
                              ['2', '1.1.2', '1.1.1', '1'],
@@ -572,6 +587,14 @@
                 [('2', 0), ('1.1.2', 1), ('1.2.1', 2)],
                 working_dir='level0')
 
+    def test_omit_merges_with_sidelines(self):
+        self.assertLogRevnos(['--omit-merges', '-n0'], ['1.2.1', '1.1.1', '1'],
+                             working_dir='level0')
+
+    def test_omit_merges_without_sidelines(self):
+        self.assertLogRevnos(['--omit-merges', '-n1'], ['1'],
+                             working_dir='level0')
+
 
 class TestLogDiff(TestLogWithLogCatcher):
 

=== modified file 'bzrlib/tests/blackbox/test_missing.py'
--- bzrlib/tests/blackbox/test_missing.py	2011-07-26 06:38:46 +0000
+++ bzrlib/tests/blackbox/test_missing.py	2011-09-16 15:37:58 +0000
@@ -49,7 +49,7 @@
         self.assertEqual('', err)
 
     def test_missing(self):
-        missing = "You are missing 1 revision(s):"
+        missing = "You are missing 1 revision:"
 
         # create a source branch
         a_tree = self.make_branch_and_tree('a')
@@ -92,7 +92,7 @@
 
         # compare again, but now we have the 'merge' commit extra
         lines = self.run_bzr('missing ../b', retcode=1)[0].splitlines()
-        self.assertEqual("You have 1 extra revision(s):", lines[0])
+        self.assertEqual("You have 1 extra revision:", lines[0])
         self.assertEqual(8, len(lines))
         lines2 = self.run_bzr('missing ../b --mine-only', retcode=1)[0]
         lines2 = lines2.splitlines()

=== modified file 'bzrlib/tests/blackbox/test_pull.py'
--- bzrlib/tests/blackbox/test_pull.py	2011-08-31 16:48:52 +0000
+++ bzrlib/tests/blackbox/test_pull.py	2011-09-22 13:13:43 +0000
@@ -543,3 +543,14 @@
         out = self.run_bzr(['pull', '-d', 'to', 'from'])
         self.assertEqual(out,
             ('1 tag(s) updated.\n', ''))
+
+    def test_pull_tag_overwrite(self):
+        """pulling tags with --overwrite only reports changed tags."""
+        # create a branch, see that --show-base fails
+        from_tree = self.make_branch_and_tree('from')
+        from_tree.branch.tags.set_tag("mytag", "somerevid")
+        to_tree = self.make_branch_and_tree('to')
+        to_tree.branch.tags.set_tag("mytag", "somerevid")
+        out = self.run_bzr(['pull', '--overwrite', '-d', 'to', 'from'])
+        self.assertEqual(out,
+            ('No revisions or tags to pull.\n', ''))

=== modified file 'bzrlib/tests/blackbox/test_push.py'
--- bzrlib/tests/blackbox/test_push.py	2011-08-31 17:22:53 +0000
+++ bzrlib/tests/blackbox/test_push.py	2011-09-22 12:13:12 +0000
@@ -676,8 +676,8 @@
     def set_config_push_strict(self, value):
         # set config var (any of bazaar.conf, locations.conf, branch.conf
         # should do)
-        conf = self.tree.branch.get_config()
-        conf.set_user_option('push_strict', value)
+        conf = self.tree.branch.get_config_stack()
+        conf.set('push_strict', value)
 
     _default_command = ['push', '../to']
     _default_wd = 'local'

=== modified file 'bzrlib/tests/blackbox/test_resolve.py'
--- bzrlib/tests/blackbox/test_resolve.py	2011-06-15 11:36:05 +0000
+++ bzrlib/tests/blackbox/test_resolve.py	2011-09-16 15:37:58 +0000
@@ -36,18 +36,18 @@
 Path conflict: mydir3 / mydir2
 Text conflict in myfile
 $ bzr resolve myfile
-2>1 conflict(s) resolved, 2 remaining
+2>1 conflict resolved, 2 remaining
 $ bzr resolve my_other_file
-2>1 conflict(s) resolved, 1 remaining
+2>1 conflict resolved, 1 remaining
 $ bzr resolve mydir2
-2>1 conflict(s) resolved, 0 remaining
+2>1 conflict resolved, 0 remaining
 """)
 
     def test_resolve_all(self):
         self.run_script("""\
 $ cd branch
 $ bzr resolve --all
-2>3 conflict(s) resolved, 0 remaining
+2>3 conflicts resolved, 0 remaining
 $ bzr conflicts
 """)
 
@@ -56,19 +56,19 @@
 $ mkdir branch/subdir
 $ cd branch/subdir
 $ bzr resolve ../myfile
-2>1 conflict(s) resolved, 2 remaining
+2>1 conflict resolved, 2 remaining
 """)
 
     def test_resolve_via_directory_option(self):
         self.run_script("""\
 $ bzr resolve -d branch myfile
-2>1 conflict(s) resolved, 2 remaining
+2>1 conflict resolved, 2 remaining
 """)
 
     def test_resolve_all_via_directory_option(self):
         self.run_script("""\
 $ bzr resolve -d branch --all
-2>3 conflict(s) resolved, 0 remaining
+2>3 conflicts resolved, 0 remaining
 $ bzr conflicts -d branch
 """)
 
@@ -107,7 +107,7 @@
 $ bzr resolve --take-other
 2>deleted dir/file.THIS
 2>deleted dir
-2>3 conflict(s) resolved, 0 remaining
+2>3 conflicts resolved, 0 remaining
 ''')
 
 
@@ -123,7 +123,7 @@
         file_conflict = conflicts.TextConflict('file', file_id='file_id')
         tree.set_conflicts(conflicts.ConflictList([file_conflict]))
         note = self.run_bzr('resolve', retcode=1, working_dir='tree')[1]
-        self.assertContainsRe(note, '0 conflict\\(s\\) auto-resolved.')
+        self.assertContainsRe(note, '0 conflicts auto-resolved.')
         self.assertContainsRe(note,
             'Remaining conflicts:\nText conflict in file')
         self.build_tree_contents([('tree/file', 'a\n')])

=== modified file 'bzrlib/tests/blackbox/test_send.py'
--- bzrlib/tests/blackbox/test_send.py	2011-05-17 15:01:58 +0000
+++ bzrlib/tests/blackbox/test_send.py	2011-09-22 12:13:12 +0000
@@ -189,7 +189,7 @@
 
     def test_note_revisions(self):
         stderr = self.run_send([])[1]
-        self.assertEndsWith(stderr, '\nBundling 1 revision(s).\n')
+        self.assertEndsWith(stderr, '\nBundling 1 revision.\n')
 
     def test_mailto_option(self):
         b = branch.Branch.open('branch')
@@ -296,8 +296,8 @@
     def set_config_send_strict(self, value):
         # set config var (any of bazaar.conf, locations.conf, branch.conf
         # should do)
-        conf = self.local_tree.branch.get_config()
-        conf.set_user_option('send_strict', value)
+        conf = self.local_tree.branch.get_config_stack()
+        conf.set('send_strict', value)
 
     def assertSendFails(self, args):
         out, err = self.run_send(args, rc=3, err_re=self._default_errors)
@@ -311,7 +311,10 @@
         if revs is None:
             revs = self._default_sent_revs
         out, err = self.run_send(args, err_re=err_re)
-        bundling_revs = 'Bundling %d revision(s).\n' % len(revs)
+        if len(revs) == 1:
+            bundling_revs = 'Bundling %d revision.\n'% len(revs)
+        else:
+            bundling_revs = 'Bundling %d revisions.\n' % len(revs)
         if with_warning:
             self.assertContainsRe(err, self._default_additional_warning)
             self.assertEndsWith(err, bundling_revs)

=== modified file 'bzrlib/tests/per_branch/__init__.py'
--- bzrlib/tests/per_branch/__init__.py	2011-09-12 09:51:52 +0000
+++ bzrlib/tests/per_branch/__init__.py	2011-09-19 18:25:05 +0000
@@ -91,7 +91,7 @@
         return super(TestCaseWithBranch, self).make_branch_builder(
             relpath, format=format)
 
-    def make_repository(self, relpath, shared=False, format=None):
+    def make_repository(self, relpath, shared=None, format=None):
         made_control = self.make_bzrdir(relpath, format=format)
         return made_control.create_repository(shared=shared)
 

=== modified file 'bzrlib/tests/per_branch/test_branch.py'
--- bzrlib/tests/per_branch/test_branch.py	2011-09-12 11:43:03 +0000
+++ bzrlib/tests/per_branch/test_branch.py	2011-09-22 12:55:04 +0000
@@ -537,6 +537,12 @@
             looked_up_format = registry.get(network_name)
             self.assertEqual(format.__class__, looked_up_format.__class__)
 
+    def get_get_config_calls(self):
+        # Smoke test that all branch succeed getting a config
+        br = self.make_branch('.')
+        br.get_config()
+        br.get_config_stack()
+
 
 class ChrootedTests(per_branch.TestCaseWithBranch):
     """A support class that provides readonly urls outside the local namespace.
@@ -1070,7 +1076,7 @@
 
 class TestBranchControlComponent(per_branch.TestCaseWithBranch):
     """Branch implementations adequately implement ControlComponent."""
-    
+
     def test_urls(self):
         br = self.make_branch('branch')
         self.assertIsInstance(br.user_url, str)

=== modified file 'bzrlib/tests/per_branch/test_locking.py'
--- bzrlib/tests/per_branch/test_locking.py	2011-01-13 06:18:13 +0000
+++ bzrlib/tests/per_branch/test_locking.py	2011-09-19 18:25:53 +0000
@@ -42,13 +42,13 @@
         self.locks = []
         b = lock_helpers.LockWrapper(self.locks, self.get_branch(), 'b')
         b.repository = lock_helpers.LockWrapper(self.locks, b.repository, 'r')
-        bcf = b.control_files
+        bcf = getattr(b, "control_files", None)
         rcf = getattr(b.repository, 'control_files', None)
         if rcf is None:
             self.combined_branch = False
         else:
             # Look out for branch types that reuse their control files
-            self.combined_control = bcf is rcf
+            self.combined_control = bcf is rcf and bcf is not None
         try:
             b.control_files = lock_helpers.LockWrapper(
                 self.locks, b.control_files, 'bc')

=== modified file 'bzrlib/tests/per_branch/test_push.py'
--- bzrlib/tests/per_branch/test_push.py	2011-08-31 22:53:09 +0000
+++ bzrlib/tests/per_branch/test_push.py	2011-09-18 14:42:26 +0000
@@ -157,6 +157,8 @@
         except (errors.IncompatibleFormat, errors.UninitializableFormat):
             # This Branch format cannot create shared repositories
             return
+        if not repo._format.supports_nesting_repositories:
+            return
         # This is a little bit trickier because make_branch_and_tree will not
         # re-use a shared repository.
         a_bzrdir = self.make_bzrdir('repo/tree')

=== modified file 'bzrlib/tests/per_branch/test_stacking.py'
--- bzrlib/tests/per_branch/test_stacking.py	2011-02-24 16:45:27 +0000
+++ bzrlib/tests/per_branch/test_stacking.py	2011-09-18 14:42:26 +0000
@@ -511,6 +511,8 @@
             repo = self.make_repository('repo', shared=True)
         except errors.IncompatibleFormat:
             raise TestNotApplicable()
+        if not repo._format.supports_nesting_repositories:
+            raise TestNotApplicable()
         # Avoid make_branch, which produces standalone branches.
         bzrdir = self.make_bzrdir('repo/stack-on')
         try:

=== modified file 'bzrlib/tests/per_controldir/test_controldir.py'
--- bzrlib/tests/per_controldir/test_controldir.py	2011-09-12 12:20:19 +0000
+++ bzrlib/tests/per_controldir/test_controldir.py	2011-09-19 18:24:48 +0000
@@ -172,6 +172,9 @@
         tree.commit('revision 1', rev_id='1')
         dir = self.make_bzrdir('source')
         repo = dir.create_repository()
+        if not repo._format.supports_nesting_repositories:
+            raise TestNotApplicable("repository format does not support "
+                "nesting")
         repo.fetch(tree.branch.repository)
         self.assertTrue(repo.has_revision('1'))
         try:
@@ -188,6 +191,9 @@
             shared_repo = self.make_repository('shared', shared=True)
         except errors.IncompatibleFormat:
             return
+        if not shared_repo._format.supports_nesting_repositories:
+            raise TestNotApplicable("format does not support nesting "
+                "repositories")
         # Make a branch, 'commit_tree', and working tree outside of the shared
         # repository, and commit some revisions to it.
         tree = self.make_branch_and_tree('commit_tree')
@@ -219,6 +225,9 @@
             shared_repo = self.make_repository('shared', shared=True)
         except errors.IncompatibleFormat:
             return
+        if not shared_repo._format.supports_nesting_repositories:
+            raise TestNotApplicable("format does not support nesting "
+                "repositories")
         tree = self.make_branch_and_tree('commit_tree')
         self.build_tree(['commit_tree/foo'])
         tree.add('foo')
@@ -292,9 +301,12 @@
         tree.branch.repository.copy_content_into(source.repository)
         tree.branch.copy_content_into(source)
         try:
-            self.make_repository('target', shared=True)
+            shared_repo = self.make_repository('target', shared=True)
         except errors.IncompatibleFormat:
             return
+        if not shared_repo._format.supports_nesting_repositories:
+            raise TestNotApplicable("format does not support nesting "
+                "repositories")
         dir = source.bzrdir
         target = dir.clone(self.get_url('target/child'))
         self.assertNotEqual(dir.transport.base, target.transport.base)
@@ -470,6 +482,9 @@
             shared_repo = self.make_repository('shared', shared=True)
         except errors.IncompatibleFormat:
             return
+        if not shared_repo._format.supports_nesting_repositories:
+            raise TestNotApplicable("format does not support nesting "
+                "repositories")
         tree = self.make_branch_and_tree('commit_tree')
         self.build_tree(['commit_tree/foo'])
         tree.add('foo')
@@ -491,6 +506,9 @@
             shared_repo = self.make_repository('shared', shared=True)
         except errors.IncompatibleFormat:
             return
+        if not shared_repo._format.supports_nesting_repositories:
+            raise TestNotApplicable("format does not support nesting "
+                "repositories")
         tree = self.make_branch_and_tree('commit_tree')
         self.build_tree(['commit_tree/foo'])
         tree.add('foo')
@@ -535,7 +553,9 @@
         except errors.IncompatibleFormat:
             return
         target = dir.sprout(self.get_url('target/child'), force_new_repo=True)
-        self.assertNotEqual(dir.transport.base, target.transport.base)
+        self.assertNotEqual(
+            dir.control_transport.base,
+            target.control_transport.base)
         self.assertFalse(shared_repo.has_revision('1'))
 
     def test_sprout_bzrdir_repository_revision(self):
@@ -1367,6 +1387,8 @@
         except errors.IncompatibleFormat:
             # need a shared repository to test this.
             return
+        if not repo._format.supports_nesting_repositories:
+            raise TestNotApplicable("requires nesting repositories")
         url = self.get_url('intermediate')
         t = self.get_transport()
         t.mkdir('intermediate')
@@ -1393,6 +1415,8 @@
         except errors.IncompatibleFormat:
             # need a shared repository to test this.
             return
+        if not repo._format.supports_nesting_repositories:
+            return
         url = self.get_url('childbzrdir')
         self.get_transport().mkdir('childbzrdir')
         made_control = self.bzrdir_format.initialize(url)
@@ -1408,12 +1432,16 @@
                          found_repo.bzrdir.root_transport.base)
 
     def test_find_repository_standalone_with_containing_shared_repository(self):
-        # find repo inside a standalone repo inside a shared repo finds the standalone repo
+        # find repo inside a standalone repo inside a shared repo finds the
+        # standalone repo
         try:
             containing_repo = self.make_repository('.', shared=True)
         except errors.IncompatibleFormat:
             # need a shared repository to test this.
             return
+        if not containing_repo._format.supports_nesting_repositories:
+            raise TestNotApplicable("format does not support "
+                "nesting repositories")
         child_repo = self.make_repository('childrepo')
         opened_control = bzrdir.BzrDir.open(self.get_url('childrepo'))
         found_repo = opened_control.find_repository()
@@ -1427,6 +1455,8 @@
         except errors.IncompatibleFormat:
             # need a shared repository to test this.
             return
+        if not containing_repo._format.supports_nesting_repositories:
+            return
         url = self.get_url('childrepo')
         self.get_transport().mkdir('childrepo')
         child_control = self.bzrdir_format.initialize(url)
@@ -1446,6 +1476,8 @@
         except errors.IncompatibleFormat:
             # need a shared repository to test this.
             return
+        if not repo._format.supports_nesting_repositories:
+            return
         url = self.get_url('intermediate')
         t = self.get_transport()
         t.mkdir('intermediate')

=== modified file 'bzrlib/tests/per_controldir_colo/test_unsupported.py'
--- bzrlib/tests/per_controldir_colo/test_unsupported.py	2011-03-05 03:53:34 +0000
+++ bzrlib/tests/per_controldir_colo/test_unsupported.py	2011-09-19 18:25:37 +0000
@@ -23,7 +23,6 @@
 from bzrlib import (
     errors,
     tests,
-    transport,
     )
 from bzrlib.tests import (
     per_controldir,

=== modified file 'bzrlib/tests/per_interbranch/test_pull.py'
--- bzrlib/tests/per_interbranch/test_pull.py	2011-09-02 00:53:06 +0000
+++ bzrlib/tests/per_interbranch/test_pull.py	2011-09-21 19:45:34 +0000
@@ -79,7 +79,7 @@
         other = self.sprout_to(master_tree.branch.bzrdir, 'other').open_branch()
         # move the branch out of the way on disk to cause a connection
         # error.
-        os.rename('master', 'master_gone')
+        master_tree.branch.bzrdir.destroy_branch()
         # try to pull, which should raise a BoundBranchConnectionFailure.
         self.assertRaises(errors.BoundBranchConnectionFailure,
                 checkout.branch.pull, other)

=== modified file 'bzrlib/tests/per_repository/test_repository.py'
--- bzrlib/tests/per_repository/test_repository.py	2011-09-12 09:51:52 +0000
+++ bzrlib/tests/per_repository/test_repository.py	2011-09-19 18:25:05 +0000
@@ -68,6 +68,11 @@
         """Test the format.fast_deltas attribute."""
         self.assertFormatAttribute('fast_deltas', (True, False))
 
+    def test_attribute_supports_nesting_repositories(self):
+        """Test the format.supports_nesting_repositories."""
+        self.assertFormatAttribute('supports_nesting_repositories',
+            (True, False))
+
     def test_attribute__fetch_reconcile(self):
         """Test the _fetch_reconcile attribute."""
         self.assertFormatAttribute('_fetch_reconcile', (True, False))
@@ -747,9 +752,12 @@
         repo = self.make_repository('repo')
         repo._make_parents_provider().get_parent_map
 
-    def make_repository_and_foo_bar(self, shared):
+    def make_repository_and_foo_bar(self, shared=None):
         made_control = self.make_bzrdir('repository')
         repo = made_control.create_repository(shared=shared)
+        if not repo._format.supports_nesting_repositories:
+            raise tests.TestNotApplicable("repository does not support "
+                "nesting repositories")
         bzrdir.BzrDir.create_branch_convenience(self.get_url('repository/foo'),
                                                 force_new_repo=False)
         bzrdir.BzrDir.create_branch_convenience(self.get_url('repository/bar'),
@@ -760,7 +768,7 @@
         return repo
 
     def test_find_branches(self):
-        repo = self.make_repository_and_foo_bar(shared=False)
+        repo = self.make_repository_and_foo_bar()
         branches = repo.find_branches()
         self.assertContainsRe(branches[-1].base, 'repository/foo/$')
         self.assertContainsRe(branches[-3].base, 'repository/baz/qux/$')
@@ -789,6 +797,9 @@
 
     def test_find_branches_using_standalone(self):
         branch = self.make_branch('branch')
+        if not branch.repository._format.supports_nesting_repositories:
+            raise tests.TestNotApplicable("format does not support nesting "
+                "repositories")
         contained = self.make_branch('branch/contained')
         branches = branch.repository.find_branches(using=True)
         self.assertEqual([branch.base], [b.base for b in branches])

=== modified file 'bzrlib/tests/per_tree/test_get_file_mtime.py'
--- bzrlib/tests/per_tree/test_get_file_mtime.py	2011-05-13 12:51:05 +0000
+++ bzrlib/tests/per_tree/test_get_file_mtime.py	2011-09-21 00:30:44 +0000
@@ -18,6 +18,8 @@
 
 import time
 
+from bzrlib import errors
+
 from bzrlib.tests.per_tree import TestCaseWithTree
 
 
@@ -42,3 +44,10 @@
                         'now: %f, mtime_file_id: %f' % (now, mtime_file_id ))
         mtime_path = tree.get_file_mtime(file_id='one-id', path='one')
         self.assertEqual(mtime_file_id, mtime_path)
+
+    def test_nonexistant(self):
+        tree = self.get_basic_tree()
+        tree.lock_read()
+        self.addCleanup(tree.unlock)
+        self.assertRaises(errors.NoSuchId,
+            tree.get_file_mtime, file_id='unexistant')

=== modified file 'bzrlib/tests/per_workingtree/test_get_file_mtime.py'
--- bzrlib/tests/per_workingtree/test_get_file_mtime.py	2009-07-10 07:14:02 +0000
+++ bzrlib/tests/per_workingtree/test_get_file_mtime.py	2011-09-21 00:30:34 +0000
@@ -18,6 +18,7 @@
 
 import os
 
+from bzrlib import errors
 from bzrlib.tests.per_workingtree import TestCaseWithWorkingTree
 
 
@@ -98,3 +99,15 @@
             self.assertAlmostEqual(st.st_mtime, mtime)
         finally:
             tree.unlock()
+
+    def test_missing(self):
+        tree = self.make_basic_tree()
+
+        os.remove('tree/one')
+        tree.lock_read()
+        try:
+            self.assertRaises(errors.FileTimestampUnavailable,
+                tree.get_file_mtime, file_id='one-id')
+        finally:
+            tree.unlock()
+

=== modified file 'bzrlib/tests/test_conflicts.py'
--- bzrlib/tests/test_conflicts.py	2011-08-04 00:17:53 +0000
+++ bzrlib/tests/test_conflicts.py	2011-09-16 15:37:58 +0000
@@ -741,14 +741,14 @@
         self.run_script("""
 $ bzr rm -q dir  --force
 $ bzr resolve dir
-2>2 conflict(s) resolved, 0 remaining
+2>2 conflicts resolved, 0 remaining
 $ bzr commit -q --strict -m 'No more conflicts nor unknown files'
 """)
 
     def test_take_other(self):
         self.run_script("""
 $ bzr resolve dir
-2>2 conflict(s) resolved, 0 remaining
+2>2 conflicts resolved, 0 remaining
 $ bzr commit -q --strict -m 'No more conflicts nor unknown files'
 """)
 
@@ -782,7 +782,7 @@
     def test_keep_them_all(self):
         self.run_script("""
 $ bzr resolve dir
-2>2 conflict(s) resolved, 0 remaining
+2>2 conflicts resolved, 0 remaining
 $ bzr commit -q --strict -m 'No more conflicts nor unknown files'
 """)
 
@@ -791,7 +791,7 @@
 $ bzr mv -q dir/file2 file2
 $ bzr rm -q dir --force
 $ bzr resolve dir
-2>2 conflict(s) resolved, 0 remaining
+2>2 conflicts resolved, 0 remaining
 $ bzr commit -q --strict -m 'No more conflicts nor unknown files'
 """)
 
@@ -799,7 +799,7 @@
         self.run_script("""
 $ bzr rm -q dir --force
 $ bzr resolve dir
-2>2 conflict(s) resolved, 0 remaining
+2>2 conflicts resolved, 0 remaining
 $ bzr commit -q --strict -m 'No more conflicts nor unknown files'
 """)
 
@@ -846,7 +846,7 @@
     def test_keep_them_all(self):
         self.run_script("""
 $ bzr resolve dir
-2>2 conflict(s) resolved, 0 remaining
+2>2 conflicts resolved, 0 remaining
 $ bzr commit -q --strict -m 'No more conflicts nor unknown files'
 """)
 
@@ -855,7 +855,7 @@
 $ bzr mv -q dir/file2 file2
 $ bzr rm -q dir --force
 $ bzr resolve dir
-2>2 conflict(s) resolved, 0 remaining
+2>2 conflicts resolved, 0 remaining
 $ bzr commit -q --strict -m 'No more conflicts nor unknown files'
 """)
 
@@ -863,14 +863,14 @@
         self.run_script("""
 $ bzr rm -q dir --force
 $ bzr resolve dir
-2>2 conflict(s) resolved, 0 remaining
+2>2 conflicts resolved, 0 remaining
 $ bzr commit -q --strict -m 'No more conflicts nor unknown files'
 """)
 
     def test_resolve_taking_this(self):
         self.run_script("""
 $ bzr resolve --take-this dir
-2>2 conflict(s) resolved, 0 remaining
+2>2 conflicts resolved, 0 remaining
 $ bzr commit -q --strict -m 'No more conflicts nor unknown files'
 """)
 
@@ -879,7 +879,7 @@
 $ bzr resolve --take-other dir
 2>deleted dir/file2
 2>deleted dir
-2>2 conflict(s) resolved, 0 remaining
+2>2 conflicts resolved, 0 remaining
 $ bzr commit -q --strict -m 'No more conflicts nor unknown files'
 """)
 
@@ -1009,7 +1009,7 @@
 # aside ? -- vila 090916
 $ bzr add -q foo
 $ bzr resolve foo.new
-2>1 conflict(s) resolved, 0 remaining
+2>1 conflict resolved, 0 remaining
 $ bzr commit -q --strict -m 'No more conflicts nor unknown files'
 """)
 
@@ -1018,7 +1018,7 @@
 $ bzr rm -q foo --force
 $ bzr mv -q foo.new foo
 $ bzr resolve foo
-2>1 conflict(s) resolved, 0 remaining
+2>1 conflict resolved, 0 remaining
 $ bzr commit -q --strict -m 'No more conflicts nor unknown files'
 """)
 
@@ -1080,7 +1080,7 @@
 # Create a debian branch based on trunk
 $ cd ..
 $ bzr branch trunk -r 1 debian
-2>Branched 1 revision(s).
+2>Branched 1 revision.
 $ cd debian
 $ mkdir dir
 $ bzr add

=== modified file 'bzrlib/tests/test_http.py'
--- bzrlib/tests/test_http.py	2011-08-19 22:34:02 +0000
+++ bzrlib/tests/test_http.py	2011-09-19 12:18:34 +0000
@@ -1997,6 +1997,7 @@
         self.assertIsInstance(r, type(t))
         # Both transports share the some connection
         self.assertEqual(t._get_connection(), r._get_connection())
+        self.assertEquals('http://www.example.com/foo/subdir/', r.base)
 
     def test_redirected_to_self_with_slash(self):
         t = self._transport('http://www.example.com/foo')
@@ -2013,18 +2014,29 @@
         r = t._redirected_to('http://www.example.com/foo',
                              'http://foo.example.com/foo/subdir')
         self.assertIsInstance(r, type(t))
+        self.assertEquals('http://foo.example.com/foo/subdir/',
+            r.external_url())
 
     def test_redirected_to_same_host_sibling_protocol(self):
         t = self._transport('http://www.example.com/foo')
         r = t._redirected_to('http://www.example.com/foo',
                              'https://www.example.com/foo')
         self.assertIsInstance(r, type(t))
+        self.assertEquals('https://www.example.com/foo/',
+            r.external_url())
 
     def test_redirected_to_same_host_different_protocol(self):
         t = self._transport('http://www.example.com/foo')
         r = t._redirected_to('http://www.example.com/foo',
                              'ftp://www.example.com/foo')
         self.assertNotEquals(type(r), type(t))
+        self.assertEquals('ftp://www.example.com/foo/', r.external_url())
+
+    def test_redirected_to_same_host_specific_implementation(self):
+        t = self._transport('http://www.example.com/foo')
+        r = t._redirected_to('http://www.example.com/foo',
+                             'https+urllib://www.example.com/foo')
+        self.assertEquals('https://www.example.com/foo/', r.external_url())
 
     def test_redirected_to_different_host_same_user(self):
         t = self._transport('http://joe@www.example.com/foo')
@@ -2032,6 +2044,7 @@
                              'https://foo.example.com/foo')
         self.assertIsInstance(r, type(t))
         self.assertEqual(t._parsed_url.user, r._parsed_url.user)
+        self.assertEquals('https://joe@foo.example.com/foo/', r.external_url())
 
 
 class PredefinedRequestHandler(http_server.TestingHTTPRequestHandler):

=== modified file 'bzrlib/tests/test_log.py'
--- bzrlib/tests/test_log.py	2011-07-25 07:41:52 +0000
+++ bzrlib/tests/test_log.py	2011-09-19 15:22:23 +0000
@@ -323,7 +323,7 @@
     1 Joe Foo\t2005-11-22
       rev-1
 
-Use --include-merges or -n0 to see merged revisions.
+Use --include-merged or -n0 to see merged revisions.
 """,
             wt.branch, log.ShortLogFormatter,
             formatter_kwargs=dict(show_advice=True))
@@ -1335,7 +1335,7 @@
         self.assertFormatterResult("""\
 ------------------------------------------------------------
 revno: 2
-fixes bug(s): test://bug/id test://bug/2
+fixes bugs: test://bug/id test://bug/2
 author: Joe Bar <joe@bar.com>
 committer: Joe Foo <joe@foo.com>
 branch nick: work
@@ -1346,7 +1346,7 @@
   message
 ------------------------------------------------------------
 revno: 1
-fixes bug(s): test://bug/id
+fixes bug: test://bug/id
 committer: Joe Foo <joe@foo.com>
 branch nick: work
 timestamp: Tue 2005-11-22 00:00:00 +0000
@@ -1359,13 +1359,13 @@
         tree = self.make_commits_with_bugs()
         self.assertFormatterResult("""\
     2 Joe Bar\t2005-11-22
-      fixes bug(s): test://bug/id test://bug/2
+      fixes bugs: test://bug/id test://bug/2
       multiline
       log
       message
 
     1 Joe Foo\t2005-11-22
-      fixes bug(s): test://bug/id
+      fixes bug: test://bug/id
       simple log message
 
 """,

=== modified file 'bzrlib/tests/test_missing.py'
--- bzrlib/tests/test_missing.py	2011-01-12 01:01:53 +0000
+++ bzrlib/tests/test_missing.py	2011-09-19 08:49:15 +0000
@@ -134,12 +134,12 @@
 class TestFindUnmerged(tests.TestCaseWithTransport):
 
     def assertUnmerged(self, local, remote, local_branch, remote_branch,
-            restrict='all', include_merges=False, backward=False,
+            restrict='all', include_merged=False, backward=False,
             local_revid_range=None, remote_revid_range=None):
         """Check the output of find_unmerged_mainline_revisions"""
         local_extra, remote_extra = missing.find_unmerged(
             local_branch, remote_branch, restrict,
-            include_merges=include_merges, backward=backward,
+            include_merged=include_merged, backward=backward,
             local_revid_range=local_revid_range,
             remote_revid_range=remote_revid_range)
         self.assertEqual(local, local_extra)
@@ -187,7 +187,7 @@
         self.assertUnmerged([], [], tree.branch, tree2.branch,
             local_revid_range=(rev1, rev1))
 
-    def test_include_merges(self):
+    def test_include_merged(self):
         tree = self.make_branch_and_tree('tree')
         rev1 = tree.commit('one', rev_id='rev1')
 
@@ -207,27 +207,27 @@
                                  ('3.1.1', 'rev4', 1), ('3.1.2', 'rev5', 1),
                                  ],
                             tree.branch, tree2.branch,
-                            include_merges=True)
+                            include_merged=True)
 
         self.assertUnmerged([], [('4', 'rev6', 0),
                                  ('3.1.2', 'rev5', 1), ('3.1.1', 'rev4', 1),
                                  ('3', 'rev3', 0), ('2', 'rev2', 0),
                                  ],
                             tree.branch, tree2.branch,
-                            include_merges=True,
+                            include_merged=True,
                             backward=True)
 
         self.assertUnmerged([], [('4', 'rev6', 0)],
             tree.branch, tree2.branch,
-            include_merges=True, remote_revid_range=(rev6, rev6))
+            include_merged=True, remote_revid_range=(rev6, rev6))
 
         self.assertUnmerged([], [('3', 'rev3', 0), ('3.1.1', 'rev4', 1)],
                     tree.branch, tree2.branch,
-                    include_merges=True, remote_revid_range=(rev3, rev4))
+                    include_merged=True, remote_revid_range=(rev3, rev4))
 
         self.assertUnmerged([], [('4', 'rev6', 0), ('3.1.2', 'rev5', 1)],
                     tree.branch, tree2.branch,
-                    include_merges=True, remote_revid_range=(rev5, rev6))
+                    include_merged=True, remote_revid_range=(rev5, rev6))
 
     def test_revision_range(self):
         local = self.make_branch_and_tree('local')

=== modified file 'bzrlib/tests/test_tag.py'
--- bzrlib/tests/test_tag.py	2011-08-31 17:11:32 +0000
+++ bzrlib/tests/test_tag.py	2011-09-22 13:26:14 +0000
@@ -116,7 +116,7 @@
         # overwrite conflicts
         updates, conflicts = a.tags.merge_to(b.tags, overwrite=True)
         self.assertEqual(list(conflicts), [])
-        self.assertEqual({u'tag-1': 'x', u'tag-2': 'z'}, updates)
+        self.assertEqual({u'tag-2': 'z'}, updates)
         self.assertEqual('z', b.tags.lookup_tag('tag-2'))
 
 

=== modified file 'bzrlib/tests/test_trace.py'
--- bzrlib/tests/test_trace.py	2011-08-23 09:29:27 +0000
+++ bzrlib/tests/test_trace.py	2011-09-16 12:03:53 +0000
@@ -113,8 +113,9 @@
         msg = _format_exception()
         # Even though Windows and Linux differ for 'os.rmdir', they both give
         # 'No such file' for open()
+        # However it now gets translated so we can not test for a specific message
         self.assertContainsRe(msg,
-            r'^bzr: ERROR: \[Errno .*\] No such file.*nosuchfile')
+            r'^bzr: ERROR: \[Errno .*\] .*nosuchfile')
 
     def test_format_pywintypes_error(self):
         self.requireFeature(features.pywintypes)

=== modified file 'bzrlib/transform.py'
--- bzrlib/transform.py	2011-08-05 13:34:40 +0000
+++ bzrlib/transform.py	2011-09-16 15:32:49 +0000
@@ -42,6 +42,7 @@
     ui,
     urlutils,
     )
+from bzrlib.i18n import gettext
 """)
 from bzrlib.errors import (DuplicateKey, MalformedTransform, NoSuchFile,
                            ReusingTransform, CantMoveRoot,
@@ -1726,7 +1727,7 @@
         child_pb = ui.ui_factory.nested_progress_bar()
         try:
             if precomputed_delta is None:
-                child_pb.update('Apply phase', 0, 2)
+                child_pb.update(gettext('Apply phase'), 0, 2)
                 inventory_delta = self._generate_inventory_delta()
                 offset = 1
             else:
@@ -1737,9 +1738,9 @@
             else:
                 mover = _mover
             try:
-                child_pb.update('Apply phase', 0 + offset, 2 + offset)
+                child_pb.update(gettext('Apply phase'), 0 + offset, 2 + offset)
                 self._apply_removals(mover)
-                child_pb.update('Apply phase', 1 + offset, 2 + offset)
+                child_pb.update(gettext('Apply phase'), 1 + offset, 2 + offset)
                 modified_paths = self._apply_insertions(mover)
             except:
                 mover.rollback()
@@ -1765,7 +1766,7 @@
         try:
             for num, trans_id in enumerate(self._removed_id):
                 if (num % 10) == 0:
-                    child_pb.update('removing file', num, total_entries)
+                    child_pb.update(gettext('removing file'), num, total_entries)
                 if trans_id == self._new_root:
                     file_id = self._tree.get_root_id()
                 else:
@@ -1783,7 +1784,7 @@
             final_kinds = {}
             for num, (path, trans_id) in enumerate(new_paths):
                 if (num % 10) == 0:
-                    child_pb.update('adding file',
+                    child_pb.update(gettext('adding file'),
                                     num + len(self._removed_id), total_entries)
                 file_id = new_path_file_ids[trans_id]
                 if file_id is None:
@@ -1833,7 +1834,7 @@
                 # do not attempt to move root into a subdirectory of itself.
                 if path == '':
                     continue
-                child_pb.update('removing file', num, len(tree_paths))
+                child_pb.update(gettext('removing file'), num, len(tree_paths))
                 full_path = self._tree.abspath(path)
                 if trans_id in self._removed_contents:
                     delete_path = os.path.join(self._deletiondir, trans_id)
@@ -1868,7 +1869,7 @@
         try:
             for num, (path, trans_id) in enumerate(new_paths):
                 if (num % 10) == 0:
-                    child_pb.update('adding file', num, len(new_paths))
+                    child_pb.update(gettext('adding file'), num, len(new_paths))
                 full_path = self._tree.abspath(path)
                 if trans_id in self._needs_rename:
                     try:
@@ -2583,7 +2584,7 @@
                     existing_files.update(f[0] for f in files)
             for num, (tree_path, entry) in \
                 enumerate(tree.inventory.iter_entries_by_dir()):
-                pb.update("Building tree", num - len(deferred_contents), total)
+                pb.update(gettext("Building tree"), num - len(deferred_contents), total)
                 if entry.parent_id is None:
                     continue
                 reparent = False
@@ -2673,7 +2674,7 @@
                 new_desired_files.append((file_id,
                     (trans_id, tree_path, text_sha1)))
                 continue
-            pb.update('Adding file contents', count + offset, total)
+            pb.update(gettext('Adding file contents'), count + offset, total)
             if hardlink:
                 tt.create_hardlink(accelerator_tree.abspath(accelerator_path),
                                    trans_id)
@@ -2700,7 +2701,7 @@
             contents = filtered_output_bytes(contents, filters,
                 ContentFilterContext(tree_path, tree))
         tt.create_file(contents, trans_id, sha1=text_sha1)
-        pb.update('Adding file contents', count + offset, total)
+        pb.update(gettext('Adding file contents'), count + offset, total)
 
 
 def _reparent_children(tt, old_parent, new_parent):
@@ -3047,7 +3048,7 @@
     pb = ui.ui_factory.nested_progress_bar()
     try:
         for n in range(10):
-            pb.update('Resolution pass', n+1, 10)
+            pb.update(gettext('Resolution pass'), n+1, 10)
             conflicts = tt.find_conflicts()
             if len(conflicts) == 0:
                 return new_conflicts

=== modified file 'bzrlib/transport/ftp/_gssapi.py'
--- bzrlib/transport/ftp/_gssapi.py	2010-05-31 21:31:18 +0000
+++ bzrlib/transport/ftp/_gssapi.py	2011-09-20 10:49:47 +0000
@@ -24,6 +24,7 @@
 from bzrlib import (
     errors,
     )
+from bzrlib.i18n import gettext
 from bzrlib.trace import mutter
 from bzrlib.transport.ftp import FtpTransport
 
@@ -79,8 +80,8 @@
                         if not ((resp.startswith('235 ') and rc == 1) or
                                 (resp.startswith('335 ') and rc == 0)):
                             raise ftplib.error_reply, resp
-            trace.note("Authenticated as %s" % kerberos.authGSSClientUserName(
-                    self.vc))
+            trace.note(gettext("Authenticated as %s") %
+                            kerberos.authGSSClientUserName(self.vc))
 
             # Monkey patch ftplib
             self.putcmd = self.mic_putcmd

=== modified file 'bzrlib/transport/http/__init__.py'
--- bzrlib/transport/http/__init__.py	2011-09-03 16:30:53 +0000
+++ bzrlib/transport/http/__init__.py	2011-09-19 13:02:42 +0000
@@ -511,66 +511,57 @@
 
         :returns: A transport or None.
         """
-        def relpath(abspath):
-            """Returns the path relative to our base.
-
-            The constraints are weaker than the real relpath method because the
-            abspath is coming from the server and may slightly differ from our
-            base. We don't check the scheme, host, port, user, password parts,
-            relying on the caller to give us a proper url (i.e. one returned by
-            the server mirroring the one we sent).
-            """
-            parsed_url = self._split_url(abspath)
-            pl = len(self._parsed_url.path)
-            return parsed_url.path[pl:].strip('/')
-
-        relpath = relpath(source)
-        if not target.endswith(relpath):
+        parsed_source = self._split_url(source)
+        parsed_target = self._split_url(target)
+        pl = len(self._parsed_url.path)
+        # determine the excess tail - the relative path that was in
+        # the original request but not part of this transports' URL.
+        excess_tail = parsed_source.path[pl:].strip("/")
+        if not target.endswith(excess_tail):
             # The final part of the url has been renamed, we can't handle the
             # redirection.
             return None
-        new_transport = None
-        parsed_url = self._split_url(target)
-        # Recalculate base path. This is needed to ensure that when the
-        # redirected transport will be used to re-try whatever request was
-        # redirected, we end up with the same url
-        base_path = parsed_url.path[:-len(relpath)]
-        if parsed_url.scheme in ('http', 'https'):
+
+        target_path = parsed_target.path
+        if excess_tail:
+            # Drop the tail that was in the redirect but not part of
+            # the path of this transport.
+            target_path = target_path[:-len(excess_tail)]
+
+        if parsed_target.scheme in ('http', 'https'):
             # Same protocol family (i.e. http[s]), we will preserve the same
             # http client implementation when a redirection occurs from one to
             # the other (otherwise users may be surprised that bzr switches
             # from one implementation to the other, and devs may suffer
             # debugging it).
-            if (parsed_url.scheme == self._unqualified_scheme
-                and parsed_url.host == self._parsed_url.host
-                and parsed_url.port == self._parsed_url.port
-                and (parsed_url.user is None or
-                     parsed_url.user == self._parsed_url.user)):
+            if (parsed_target.scheme == self._unqualified_scheme
+                and parsed_target.host == self._parsed_url.host
+                and parsed_target.port == self._parsed_url.port
+                and (parsed_target.user is None or
+                     parsed_target.user == self._parsed_url.user)):
                 # If a user is specified, it should match, we don't care about
                 # passwords, wrong passwords will be rejected anyway.
-                new_transport = self.clone(base_path)
+                return self.clone(target_path)
             else:
                 # Rebuild the url preserving the scheme qualification and the
                 # credentials (if they don't apply, the redirected to server
                 # will tell us, but if they do apply, we avoid prompting the
                 # user)
-                redir_scheme = parsed_url.scheme + '+' + self._impl_name
+                redir_scheme = parsed_target.scheme + '+' + self._impl_name
                 new_url = self._unsplit_url(redir_scheme,
-                                            self._parsed_url.user,
-                                            self._parsed_url.password,
-                                            parsed_url.host, parsed_url.port,
-                                            base_path)
-                new_transport = transport.get_transport_from_url(
-                    new_url)
+                    self._parsed_url.user,
+                    self._parsed_url.password,
+                    parsed_target.host, parsed_target.port,
+                    target_path)
+                return transport.get_transport_from_url(new_url)
         else:
             # Redirected to a different protocol
-            new_url = self._unsplit_url(parsed_url.scheme,
-                                        parsed_url.user, parsed_url.password,
-                                        parsed_url.host, parsed_url.port,
-                                        base_path)
-            new_transport = transport.get_transport_from_url(
-                new_url)
-        return new_transport
+            new_url = self._unsplit_url(parsed_target.scheme,
+                    parsed_target.user,
+                    parsed_target.password,
+                    parsed_target.host, parsed_target.port,
+                    target_path)
+            return transport.get_transport_from_url(new_url)
 
 
 # TODO: May be better located in smart/medium.py with the other

=== modified file 'bzrlib/tree.py'
--- bzrlib/tree.py	2011-08-29 19:06:57 +0000
+++ bzrlib/tree.py	2011-09-15 11:31:47 +0000
@@ -35,6 +35,7 @@
     rules,
     trace,
     )
+from bzrlib.i18n import gettext
 """)
 
 from bzrlib.decorators import needs_read_lock
@@ -631,7 +632,7 @@
         prefs = self.iter_search_rules([path], filter_pref_names).next()
         stk = filters._get_filter_stack_for(prefs)
         if 'filters' in debug.debug_flags:
-            trace.note("*** %s content-filter: %s => %r" % (path,prefs,stk))
+            trace.note(gettext("*** {0} content-filter: {1} => {2!r}").format(path,prefs,stk))
         return stk
 
     def _content_filter_stack_provider(self):

=== modified file 'bzrlib/ui/__init__.py'
--- bzrlib/ui/__init__.py	2011-08-08 15:57:57 +0000
+++ bzrlib/ui/__init__.py	2011-09-19 08:28:03 +0000
@@ -154,6 +154,10 @@
             "The command 'bzr %(deprecated_name)s' "
             "has been deprecated in bzr %(deprecated_in_version)s. "
             "Please use 'bzr %(recommended_name)s' instead."),
+        deprecated_command_option=(
+            "The option '%(deprecated_name)s' to 'bzr %(command)s' "
+            "has been deprecated in bzr %(deprecated_in_version)s. "
+            "Please use '%(recommended_name)s' instead."),
         recommend_upgrade=("%(current_format_name)s is deprecated "
             "and a better format is available.\n"
             "It is recommended that you upgrade by "

=== modified file 'bzrlib/upgrade.py'
--- bzrlib/upgrade.py	2011-08-17 09:27:29 +0000
+++ bzrlib/upgrade.py	2011-09-15 11:31:47 +0000
@@ -27,6 +27,7 @@
     BzrDir,
     format_registry,
     )
+from bzrlib.i18n import gettext
 from bzrlib.remote import RemoteBzrDir
 
 
@@ -71,9 +72,9 @@
         try:
             branch = self.bzrdir.open_branch()
             if branch.user_url != self.bzrdir.user_url:
-                ui.ui_factory.note(
+                ui.ui_factory.note(gettext(
                     'This is a checkout. The branch (%s) needs to be upgraded'
-                    ' separately.' % (urlutils.unescape_for_display(
+                    ' separately.') % (urlutils.unescape_for_display(
                         branch.user_url, 'utf-8')))
             del branch
         except (errors.NotBranchError, errors.IncompatibleRepositories):
@@ -95,17 +96,17 @@
         if not self.bzrdir.needs_format_conversion(format):
             raise errors.UpToDateFormat(self.bzrdir._format)
         if not self.bzrdir.can_convert_format():
-            raise errors.BzrError("cannot upgrade from bzrdir format %s" %
+            raise errors.BzrError(gettext("cannot upgrade from bzrdir format %s") %
                            self.bzrdir._format)
         self.bzrdir.check_conversion_target(format)
-        ui.ui_factory.note('starting upgrade of %s' % 
+        ui.ui_factory.note(gettext('starting upgrade of %s') % 
             urlutils.unescape_for_display(self.transport.base, 'utf-8'))
 
         self.backup_oldpath, self.backup_newpath = self.bzrdir.backup_bzrdir()
         while self.bzrdir.needs_format_conversion(format):
             converter = self.bzrdir._format.get_converter(format)
             self.bzrdir = converter.convert(self.bzrdir, None)
-        ui.ui_factory.note('finished')
+        ui.ui_factory.note(gettext('finished'))
 
     def clean_up(self):
         """Clean-up after a conversion.
@@ -115,7 +116,7 @@
         transport = self.transport
         backup_relpath = transport.relpath(self.backup_newpath)
         child_pb = ui.ui_factory.nested_progress_bar()
-        child_pb.update('Deleting backup.bzr')
+        child_pb.update(gettext('Deleting backup.bzr'))
         try:
             transport.delete_tree(backup_relpath)
         finally:
@@ -146,8 +147,9 @@
         succeeded_count = len(succeeded)
         failed_count = attempted_count - succeeded_count
         ui.ui_factory.note(
-            '\nSUMMARY: %d upgrades attempted, %d succeeded, %d failed'
-            % (attempted_count, succeeded_count, failed_count))
+            gettext('\nSUMMARY: {0} upgrades attempted, {1} succeeded,'\
+                    ' {2} failed').format(
+                     attempted_count, succeeded_count, failed_count))
     return exceptions
 
 
@@ -202,7 +204,7 @@
     succeeded, exceptions = _convert_items([control_dir], format, clean_up,
                                            dry_run)
     if succeeded and dependents:
-        ui.ui_factory.note('Found %d dependent branches - upgrading ...'
+        ui.ui_factory.note(gettext('Found %d dependent branches - upgrading ...')
                            % (len(dependents),))
         # Convert dependent branches
         branch_cdirs = [b.bzrdir for b in dependents]
@@ -270,14 +272,14 @@
     succeeded = []
     exceptions = []
     child_pb = ui.ui_factory.nested_progress_bar()
-    child_pb.update('Upgrading bzrdirs', 0, len(items))
+    child_pb.update(gettext('Upgrading bzrdirs'), 0, len(items))
     for i, control_dir in enumerate(items):
         # Do the conversion
         location = control_dir.root_transport.base
         bzr_object, bzr_label = _get_object_and_label(control_dir)
         type_label = label or bzr_label
-        child_pb.update("Upgrading %s" % (type_label), i+1, len(items))
-        ui.ui_factory.note('Upgrading %s %s ...' % (type_label, 
+        child_pb.update(gettext("Upgrading %s") % (type_label), i+1, len(items))
+        ui.ui_factory.note(gettext('Upgrading {0} {1} ...').format(type_label, 
             urlutils.unescape_for_display(location, 'utf-8'),))
         try:
             if not dry_run:
@@ -291,11 +293,11 @@
         succeeded.append(control_dir)
         if clean_up:
             try:
-                ui.ui_factory.note('Removing backup ...')
+                ui.ui_factory.note(gettext('Removing backup ...'))
                 if not dry_run:
                     cv.clean_up()
             except Exception, ex:
-                trace.warning('failed to clean-up %s: %s' % (location, ex))
+                trace.warning(gettext('failed to clean-up {0}: {1}') % (location, ex))
                 exceptions.append(ex)
 
     child_pb.finished()

=== modified file 'bzrlib/vf_repository.py'
--- bzrlib/vf_repository.py	2011-09-06 11:01:30 +0000
+++ bzrlib/vf_repository.py	2011-09-24 13:53:25 +0000
@@ -43,6 +43,7 @@
 from bzrlib.recordcounter import RecordCounter
 from bzrlib.revisiontree import InventoryRevisionTree
 from bzrlib.testament import Testament
+from bzrlib.i18n import gettext
 """)
 
 from bzrlib import (
@@ -1087,7 +1088,7 @@
         keys = {'chk_bytes':set(), 'inventories':set(), 'texts':set()}
         kinds = ['chk_bytes', 'texts']
         count = len(checker.pending_keys)
-        bar.update("inventories", 0, 2)
+        bar.update(gettext("inventories"), 0, 2)
         current_keys = checker.pending_keys
         checker.pending_keys = {}
         # Accumulate current checks.
@@ -1113,7 +1114,7 @@
             del keys['inventories']
         else:
             return
-        bar.update("texts", 1)
+        bar.update(gettext("texts"), 1)
         while (checker.pending_keys or keys['chk_bytes']
             or keys['texts']):
             # Something to check.
@@ -1206,6 +1207,8 @@
         # this construct will accept instances of those things.
         super(VersionedFileRepository, self).__init__(_format, a_bzrdir,
             control_files)
+        self._transport = control_files._transport
+        self.base = self._transport.base
         # for tests
         self._reconcile_does_inventory_gc = True
         self._reconcile_fixes_text_parents = False
@@ -1568,7 +1571,7 @@
         batch_size = 10 # should be ~150MB on a 55K path tree
         batch_count = len(revision_order) / batch_size + 1
         processed_texts = 0
-        pb.update("Calculating text parents", processed_texts, text_count)
+        pb.update(gettext("Calculating text parents"), processed_texts, text_count)
         for offset in xrange(batch_count):
             to_query = revision_order[offset * batch_size:(offset + 1) *
                 batch_size]
@@ -1577,7 +1580,7 @@
             for revision_id in to_query:
                 parent_ids = ancestors[revision_id]
                 for text_key in revision_keys[revision_id]:
-                    pb.update("Calculating text parents", processed_texts)
+                    pb.update(gettext("Calculating text parents"), processed_texts)
                     processed_texts += 1
                     candidate_parents = []
                     for parent_id in parent_ids:
@@ -1653,7 +1656,7 @@
         num_file_ids = len(file_ids)
         for file_id, altered_versions in file_ids.iteritems():
             if pb is not None:
-                pb.update("Fetch texts", count, num_file_ids)
+                pb.update(gettext("Fetch texts"), count, num_file_ids)
             count += 1
             yield ("file", file_id, altered_versions)
 
@@ -2464,13 +2467,13 @@
             self.text_index.iterkeys()])
         # text keys is now grouped by file_id
         n_versions = len(self.text_index)
-        progress_bar.update('loading text store', 0, n_versions)
+        progress_bar.update(gettext('loading text store'), 0, n_versions)
         parent_map = self.repository.texts.get_parent_map(self.text_index)
         # On unlistable transports this could well be empty/error...
         text_keys = self.repository.texts.keys()
         unused_keys = frozenset(text_keys) - set(self.text_index)
         for num, key in enumerate(self.text_index.iterkeys()):
-            progress_bar.update('checking text graph', num, n_versions)
+            progress_bar.update(gettext('checking text graph'), num, n_versions)
             correct_parents = self.calculate_file_version_parents(key)
             try:
                 knit_parents = parent_map[key]
@@ -2920,7 +2923,7 @@
         for offset in range(0, len(revision_ids), batch_size):
             self.target.start_write_group()
             try:
-                pb.update('Transferring revisions', offset,
+                pb.update(gettext('Transferring revisions'), offset,
                           len(revision_ids))
                 batch = revision_ids[offset:offset+batch_size]
                 basis_id = self._fetch_batch(batch, basis_id, cache)
@@ -2934,7 +2937,7 @@
                     hints.extend(hint)
         if hints and self.target._format.pack_compresses:
             self.target.pack(hint=hints)
-        pb.update('Transferring revisions', len(revision_ids),
+        pb.update(gettext('Transferring revisions'), len(revision_ids),
                   len(revision_ids))
 
     @needs_write_lock
@@ -3049,7 +3052,7 @@
             _install_revision(repository, revision, revision_tree, signature,
                 inventory_cache)
             if pb is not None:
-                pb.update('Transferring revisions', n + 1, num_revisions)
+                pb.update(gettext('Transferring revisions'), n + 1, num_revisions)
     except:
         repository.abort_write_group()
         raise

=== modified file 'bzrlib/win32utils.py'
--- bzrlib/win32utils.py	2011-06-11 01:11:43 +0000
+++ bzrlib/win32utils.py	2011-09-19 15:59:40 +0000
@@ -25,6 +25,7 @@
 import sys
 
 from bzrlib import cmdline
+from bzrlib.i18n import gettext
 
 # Windows version
 if sys.platform == 'win32':
@@ -128,7 +129,7 @@
             ctypes.byref(mem_struct),
             ctypes.sizeof(mem_struct))
         if not ret:
-            trace.note('Failed to GetProcessMemoryInfo()')
+            trace.note(gettext('Failed to GetProcessMemoryInfo()'))
             return
         info = {'PageFaultCount': mem_struct.PageFaultCount,
                 'PeakWorkingSetSize': mem_struct.PeakWorkingSetSize,
@@ -149,26 +150,26 @@
         proc = win32process.GetCurrentProcess()
         info = win32process.GetProcessMemoryInfo(proc)
     else:
-        trace.note('Cannot debug memory on win32 without ctypes'
-                   ' or win32process')
+        trace.note(gettext('Cannot debug memory on win32 without ctypes'
+                   ' or win32process'))
         return
     if short:
         # using base-2 units (see HACKING.txt).
-        trace.note('WorkingSize %7dKiB'
-                   '\tPeakWorking %7dKiB\t%s',
+        trace.note(gettext('WorkingSize {0:>7}KiB'
+                   '\tPeakWorking {1:>7}KiB\t{2}').format(
                    info['WorkingSetSize'] / 1024,
                    info['PeakWorkingSetSize'] / 1024,
-                   message)
+                   message))
         return
     if message:
         trace.note('%s', message)
-    trace.note('WorkingSize       %8d KiB', info['WorkingSetSize'] / 1024)
-    trace.note('PeakWorking       %8d KiB', info['PeakWorkingSetSize'] / 1024)
-    trace.note('PagefileUsage     %8d KiB', info.get('PagefileUsage', 0) / 1024)
-    trace.note('PeakPagefileUsage %8d KiB',
+    trace.note(gettext('WorkingSize       %8d KiB'), info['WorkingSetSize'] / 1024)
+    trace.note(gettext('PeakWorking       %8d KiB'), info['PeakWorkingSetSize'] / 1024)
+    trace.note(gettext('PagefileUsage     %8d KiB'), info.get('PagefileUsage', 0) / 1024)
+    trace.note(gettext('PeakPagefileUsage %8d KiB'),
                info.get('PeakPagefileUsage', 0) / 1024)
-    trace.note('PrivateUsage      %8d KiB', info.get('PrivateUsage', 0) / 1024)
-    trace.note('PageFaultCount    %8d', info.get('PageFaultCount', 0))
+    trace.note(gettext('PrivateUsage      %8d KiB'), info.get('PrivateUsage', 0) / 1024)
+    trace.note(gettext('PageFaultCount    %8d'), info.get('PageFaultCount', 0))
 
 
 def get_console_size(defaultx=80, defaulty=25):

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2011-09-01 10:55:26 +0000
+++ bzrlib/workingtree.py	2011-09-21 00:18:47 +0000
@@ -71,6 +71,7 @@
 
 from bzrlib import symbol_versioning
 from bzrlib.decorators import needs_read_lock, needs_write_lock
+from bzrlib.i18n import gettext
 from bzrlib.lock import LogicalLockResult
 import bzrlib.mutabletree
 from bzrlib.mutabletree import needs_tree_write_lock
@@ -302,7 +303,7 @@
                 if view_files:
                     file_list = view_files
                     view_str = views.view_display_str(view_files)
-                    note("Ignoring files outside view. View is %s" % view_str)
+                    note(gettext("Ignoring files outside view. View is %s") % view_str)
             return tree, file_list
         if default_directory == u'.':
             seed = file_list[0]
@@ -1498,7 +1499,7 @@
                                              show_base=show_base)
             if nb_conflicts:
                 self.add_parent_tree((old_tip, other_tree))
-                note('Rerun update after fixing the conflicts.')
+                note(gettext('Rerun update after fixing the conflicts.'))
                 return nb_conflicts
 
         if last_rev != _mod_revision.ensure_null(revision):
@@ -2133,7 +2134,12 @@
         """See Tree.get_file_mtime."""
         if not path:
             path = self.inventory.id2path(file_id)
-        return os.lstat(self.abspath(path)).st_mtime
+        try:
+            return os.lstat(self.abspath(path)).st_mtime
+        except OSError, e:
+            if e.errno == errno.ENOENT:
+                raise errors.FileTimestampUnavailable(path)
+            raise
 
     def _is_executable_from_path_and_stat_from_basis(self, path, stat_result):
         file_id = self.path2id(path)

=== modified file 'bzrlib/workingtree_4.py'
--- bzrlib/workingtree_4.py	2011-08-12 14:47:42 +0000
+++ bzrlib/workingtree_4.py	2011-09-21 00:30:51 +0000
@@ -1849,7 +1849,7 @@
         # Make sure the file exists
         entry = self._get_entry(file_id, path=path)
         if entry == (None, None): # do we raise?
-            return None
+            raise errors.NoSuchId(self, file_id)
         parent_index = self._get_parent_index()
         last_changed_revision = entry[1][parent_index][4]
         try:

=== modified file 'doc/developers/releasing.txt'
--- doc/developers/releasing.txt	2011-09-13 12:38:44 +0000
+++ doc/developers/releasing.txt	2011-09-21 14:45:29 +0000
@@ -244,7 +244,8 @@
    Released' or setting a different milestone if the bug hasn't been
    fixed). A few false positives may remain in the older series, don't let
    this slow you down too much. This script accepts options you may find
-   useful, use ``./tools/check-newsbugs.py`` to display its usage.
+   useful, use ``./tools/check-newsbugs.py`` to display its usage (``-w``
+   will open each bug in your browser for example).
 
 #. For beta releases update the translation template::
 
@@ -474,12 +475,12 @@
 Announcing the source freeze
 ----------------------------
 
-#. Post to the ``bazaar`` list, saying that the source has been frozen
-   (gone gold). Be extra clear that this is only a *source* release
-   targeted at packagers and installer builders (see
-   <https://bugs.launchpad.net/launchpad/+bug/645084>).  This is the cue
-   for platform maintainers and plugin authors to update their code.  This
-   is done before the general public announcement of the release. 
+#. Post to the ``bazaar@lists.canonical.com`` list, saying that the source
+   has been frozen (gone gold). Be extra clear that this is only a *source*
+   release targeted at packagers and installer builders (see
+   <https://bugs.launchpad.net/launchpad/+bug/645084>).  This is the cue for
+   platform maintainers and plugin authors to update their code.  This is
+   done before the general public announcement of the release.
 
    The freeze announcement generally guess the date of the official public
    announcement, for the most recent stable series (the one supported by the
@@ -521,12 +522,8 @@
 
 #. Make an announcement mail.
 
-   For beta releases, this is sent to the ``bazaar@lists.canonical.com``
-   list only to inform plugin authors and people responsible for building
-   packages or installers.
-
-   Once the installers are available, the mail can be sent to the
-   ``bazaar-announce`` list too.
+   For beta releases, this is sent to the ``bazaar@lists.canonical.com`` and
+   ``bazaar-announce@lists.canonical.com`` lists.
 
    For stable releases (excluding SRUs which are for older stable releases),
    it should also be cc'd to ``info-gnu@gnu.org``,
@@ -542,8 +539,9 @@
       The Bazaar team is happy to announce availability of a new
       release of the bzr adaptive version control system.
 
-      Bazaar <http://bazaar.canonical.com/> is part of the GNU project
-      <http://gnu.org/> to produce a free operating system.
+      Bazaar <http://bazaar.canonical.com/> is a Canonical project and part
+      of the GNU project <http://gnu.org/> to produce a free operating
+      system.
 
       <<Summary paragraph from news>>
 

=== modified file 'doc/en/release-notes/bzr-2.5.txt'
--- doc/en/release-notes/bzr-2.5.txt	2011-09-15 12:56:23 +0000
+++ doc/en/release-notes/bzr-2.5.txt	2011-09-26 07:56:05 +0000
@@ -5,10 +5,10 @@
 .. toctree::
    :maxdepth: 1
 
-bzr 2.5b1
+bzr 2.5b2
 #########
 
-:2.5b1: NOT RELEASED YET
+:2.5b2: NOT RELEASED YET
 
 External Compatibility Breaks
 *****************************
@@ -20,10 +20,80 @@
 
 .. New commands, options, etc that users may wish to try out.
 
-* A ``from_unicode`` parameter can be specified when registering a config
-  option. This implements boolean and integer config options when the
-  provided ``bool_from_store`` and ``int_from_store`` are used.
-  (Vincent Ladeuil)
+Improvements
+************
+
+.. Improvements to existing commands, especially improved performance 
+   or memory usage, or better results.
+
+* Stop reloading all ancestry for each tag when searching tags in a revision
+  range. (Vincent Ladeuil, #857335)
+
+Bug Fixes
+*********
+
+.. Fixes for situations where bzr would previously crash or give incorrect
+   or undesirable results.
+
+* Redirects between http and https no longer discard path information
+  in some cases. (Jelmer Vernooij, #853765)
+
+* The ``--overwrite`` argument to ``bzr push`` and ``bzr pull`` no longer
+  reports all tags as changed. (Jelmer Vernooij, #845396)
+
+* ``WorkingTree.get_file_mtime`` now raises NoSuchId if a file id is
+  specified that is unknown. (Jelmer Vernooij, #847435)
+
+Documentation
+*************
+
+.. Improved or updated documentation.
+
+API Changes
+***********
+
+.. Changes that may require updates in plugins or other code that uses
+   bzrlib.
+
+Internals
+*********
+
+.. Major internal changes, unlikely to be visible to users or plugin 
+   developers, but interesting for bzr developers.
+
+* ``Branch`` objects can now use a config stack with the newly introduced
+  ``get_config_stack()``. Both ``get_config`` and ``get_config_stack`` can
+  be used for the same branch but it's recommended to stick to one for a
+  given option.
+
+Testing
+*******
+
+.. Fixes and changes that are only relevant to bzr's test framework and 
+   suite.  This can include new facilities for writing tests, fixes to 
+   spurious test failures and changes to the way things should be tested.
+
+* Really corrupt the pack file without depending on a special length or value.
+  (Vincent Ladeuil, #807032)
+
+
+bzr 2.5b1
+#########
+
+:2.5b1: 2011-09-15
+
+This is the first beta of the 2.5 series, leading up to a 2.5.0
+release in February 2012.  Beta releases are suitable for everyday use
+but may cause some incompatibilities with plugins.  Some plugins may need
+small updates to work with 2.5b1.
+
+External Compatibility Breaks
+*****************************
+
+None
+
+New Features
+************
 
 * A ``from_unicode`` parameter can be specified when registering a config
   option. This implements boolean, integer and list config options when the
@@ -56,21 +126,35 @@
 
 * Add a config option gpg_signing_key for setting which GPG key should
   be used to sign commits. Also default to using the gpg user identity
-  which matches user_email() as set by whoami. (Jonathan Riddell,
-  #68501)
+  which matches user_email() as set by whoami.
+  (Jonathan Riddell, #68501)
 
 * An ``invalid`` parameter can be specified when registering a config option
   to decide what should be done when invalid values are
-  encountered. 'warning' and 'eeror' will respectively emit a warning and
+  encountered. 'warning' and 'error' will respectively emit a warning and
   ignore the value or errors out. (Vincent Ladeuil)
 
+* bzr add now skips large files in recursive mode. The default "large"
+  size is 20MB, and is configurable via the add.maximum_file_size
+  option. A value of 0 disables skipping. Named items passed to add are
+  never skipped. (Shannon Weyrick, #54624)
+
 * ``bzr help configuration/<option>`` display the help for ``option`` for
   all registered configuration options. (Vincent Ladeuil, #747050)
 
-* bzr log -m now matches message, author, committer and bugs instead
-  of just matching the message.  --message keeps its original meaning,
-  while --match-message, --match-author, --match-committer and
-  --match-bugs match each of those fields.
+* ``bzr log -m`` now matches message, author, committer and bugs instead
+  of just matching the message.  ``--message`` keeps its original meaning,
+  while ``--match-message, --match-author, --match-committer`` and
+  ``--match-bugs`` match each of those fields. (Jacek Sieka)
+
+* ``bzr log`` now has an option called ``--omit-merges`` to ommit
+  those commits that merged branches, i.e. those having more than one
+  parent.
+  In order to avoid confusion, the previous command line option
+  ``--include-merges`` has been renamed to ``--include-merged``.
+  The old name of the command line option will still be accepted.
+  The name change also affects ``bzr missing``.
+  (Martin von Gagern)
 
 * ``bzr serve`` will now disconnect clients if they have not issued an RPC
   request after 5minutes. On POSIX platforms, this will also happen for
@@ -91,14 +175,9 @@
 * Relative local paths can now be specified in URL syntax by using the
   "file:" prefix.  (Jelmer Vernooij)
 
-* Report commits signed with expired keys in "verify-signatures".
+* Report commits signed with expired keys in ``verify-signatures``.
   (Jonathan Riddell, #804254)
 
-* bzr add now skips large files in recursive mode. The default "large"
-  size is 20MB, and is configurable via the add.maximum_file_size
-  option. A value of 0 disables skipping. Named items passed to add are
-  never skipped. (Shannon Weyrick, #54624)
-
 * Translations are now enabled for command help, errors and globally
   for any message using gettext given on output.  (Jonathan Riddell,
   INADA Naoki, #83941)
@@ -106,9 +185,6 @@
 Improvements
 ************
 
-.. Improvements to existing commands, especially improved performance 
-   or memory usage, or better results.
-
 * ``bzr add`` will now warn about nested subtrees that are skipped.
   (Jelmer Vernooij, #187342)
 
@@ -150,9 +226,6 @@
 Bug Fixes
 *********
 
-.. Fixes for situations where bzr would previously crash or give incorrect
-   or undesirable results.
-
 * ``bzr commit`` now correctly reports missing files as "removed", not
   "modified". (Jelmer Vernooij, #553955)
 
@@ -160,11 +233,6 @@
   in a single invocation, e.g. ``--branch`` and ``--use-shared``.
   (Martin von Gagern, #842993)
 
-* The pull command will now always use separate connections for the
-  case where the destination is a heavyweight checkout of some remote
-  branch on the same host as the source branch.
-  (Martin von Gagern, #483661)
-
 * A call to CHKInventory's filter-method will not result in a
   DuplicateFileId error, if you move a subfolder and change a file in
   that subfolder.
@@ -183,30 +251,30 @@
   raised whenever a transport at the drive root was opened on windows.
   (Martin [gz], #841322)
 
+* Fixed loading of external merge tools from config to properly decode
+  command-lines which contain embedded quotes. (Gordon Tyler, #828803)
+
 * Rather than an error being raised, a warning is now printed when the
   current user does not have permission to read a configuration file.
   (Jelmer Vernooij, #837324)
 
+* The pull command will now always use separate connections for the
+  case where the destination is a heavyweight checkout of some remote
+  branch on the same host as the source branch.
+  (Martin von Gagern, #483661)
+
 * TreeTransformBase.fixup_new_roots no longer forces trees to have a root, so
   operations that use it, like merge, can now create trees without a root.
   (Aaron Bentley)
 
-* Fixed loading of external merge tools from config to properly decode
-  command-lines which contain embedded quotes. (Gordon Tyler, #828803)
-
 Documentation
 *************
 
-.. Improved or updated documentation.
-
 * Release instructions refreshed. (Vincent Ladeuil)
 
 API Changes
 ***********
 
-.. Changes that may require updates in plugins or other code that uses
-   bzrlib.
-
 * ``BranchFormat.initialize`` now takes a ``append_revisions_only``
   argument. (Jelmer Vernooij)
 
@@ -220,18 +288,22 @@
 * New class ``URL`` in ``bzrlib.utils`` for managing parsed URLs.
   (Jelmer Vernooij)
 
+* New method ``Config.get_user_option_as_int_from_SI`` added for expanding a
+  value in SI format (i.e. "20MB", "1GB") into its integer equivalent. 
+  (Shannon Weyrick)
+
+* New method ``InterTree.file_content_matches`` which checks that
+  two files in different trees have the same contents.
+  (Jelmer Vernooij)
+
+* New method ``Tree.get_file_verifier`` which allows tree implementations
+  to return non-sha1 checksums to verify files.
+  (Jelmer Vernooij, #720831)
+
 * New methods ``get_transport_from_path`` and ``get_transport_from_url``
   have been added that only support opening from a path or a URL,
   unlike ``get_transport``. (Jelmer Vernooij)
 
-* New method ``Tree.get_file_verifier`` which allows tree implementations
-  to return non-sha1 checksums to verify files.
-  (Jelmer Vernooij, #720831)
-
-* New method ``InterTree.file_content_matches`` which checks that
-  two files in different trees have the same contents.
-  (Jelmer Vernooij)
-
 * New registry ``OptionRegistry`` specialized for configuration options.
   (Vincent Ladeuil)
 
@@ -264,36 +336,33 @@
   ``UIFactory.warn_experimental_format_fetch`` in favor of
   ``UIFactory.show_user_warning``. (Jelmer Vernooij)
 
+* ``Tags`` containers can now declare whether they support versioned
+  tags and whether tags can refer to ghost tags.
+  (Jelmer Vernooij)
+
+* ``Tags.merge_to`` now returns a dictionary with the updated tags
+  and a set of conflicts, rather than just conflicts. (Jelmer Vernooij)
+
 * There is a new class `ContentFilterTree` that provides a facade for 
   content filtering.  The `filtered` parameter to `export` is deprecated 
   in favor of passing a filtered tree, and the specific exporter plugins
   no longer support it.
   (Martin Pool)
 
-* New method ``Config.get_user_option_as_int_from_SI`` added for expanding a
-  value in SI format (i.e. "20MB", "1GB") into its integer equivalent. 
-  (Shannon Weyrick)
-
-* ``Tags`` containers can now declare whether they support versioned
-  tags and whether tags can refer to ghost tags.
-  (Jelmer Vernooij)
-
-* ``Tags.merge_to`` now returns a dictionary with the updated tags
-  and a set of conflicts, rather than just conflicts. (Jelmer Vernooij)
-
 * ``Transport`` now has a ``_parsed_url`` attribute instead of
   separate ``_user``, ``_password``, ``_port``, ``_scheme``, ``_host``
   and ``_path`` attributes. Proxies are provided for the moment but
   may be removed in the future. (Jelmer Vernooij)
 
+* The argument ``include_merges`` to ``missing.find_unmerged`` has
+  been renamed to ``include_merged``. The old name is still supported
+  for now but will cause a deprecation warning. (Martin von Gagern)
+
 
 Internals
 *********
 
-.. Major internal changes, unlikely to be visible to users or plugin 
-   developers, but interesting for bzr developers.
-
-* A new debug flags ``hpss_client_no_vfs`` will now cause the HPSS client
+* A new debug flag ``hpss_client_no_vfs`` will now cause the HPSS client
   to raise a ``HpssVfsRequestNotAllowed`` exception when a VFS request
   is attempted. (Jelmer Vernooij)
 
@@ -304,12 +373,8 @@
 Testing
 *******
 
-.. Fixes and changes that are only relevant to bzr's test framework and 
-   suite.  This can include new facilities for writing tests, fixes to 
-   spurious test failures and changes to the way things should be tested.
-
-* Blackbox tests can be debugged interactively (see bzrlib.debug.BzrPdb for
-  details). (Vincent Ladeuil)
+* Blackbox tests (including test scripts) can be debugged interactively (see
+  bzrlib.debug.BzrPdb for details). (Vincent Ladeuil)
 
 * `BranchBuilder.build_snapshot` now supports a "flush" action.  This
   cleanly and reliably allows tests using `BranchBuilder` to construct

=== modified file 'po/bzr.pot'
--- po/bzr.pot	2011-09-07 14:32:52 +0000
+++ po/bzr.pot	2011-09-20 09:41:21 +0000
@@ -8,7 +8,7 @@
 msgstr ""
 "Project-Id-Version: bzr\n"
 "Report-Msgid-Bugs-To: <bazaar@canonical.com>\n"
-"POT-Creation-Date: 2011-09-07 15:32+0100\n"
+"POT-Creation-Date: 2011-09-20 10:41+0100\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
 "Language-Team: LANGUAGE <LL@li.org>\n"
@@ -18,30 +18,77 @@
 "Content-Transfer-Encoding: 8bit\n"
 "Plural-Forms: nplurals=INTEGER; plural=EXPRESSION;\n"
 
-#: bzrlib/builtins.py:209
+#: bzrlib/add.py:95
+msgid "skipping {0} (larger than {1} of {2} bytes)"
+msgstr ""
+
+#: bzrlib/branch.py:852
+msgid "Unstacking"
+msgstr ""
+
+#: bzrlib/branch.py:3138
+#, python-format
+msgid "Pushed up to revision %d."
+msgstr ""
+
+#: bzrlib/branch.py:3140
+#, python-format
+msgid "%d tag updated."
+msgid_plural "%d tags updated."
+msgstr[0] ""
+msgstr[1] ""
+
+#: bzrlib/branch.py:3143
+msgid "No new revisions or tags to push."
+msgstr ""
+
+#: bzrlib/branch.py:3145
+msgid "No new revisions to push."
+msgstr ""
+
+#: bzrlib/branch.py:3165
+msgid "checked branch {0} format {1}"
+msgstr ""
+
+#: bzrlib/branch.py:3168
+#, python-format
+msgid "found error:%s"
+msgstr ""
+
+#: bzrlib/builtins.py:116 bzrlib/builtins.py:2782 bzrlib/workingtree.py:306
+#, python-format
+msgid "Ignoring files outside view. View is %s"
+msgstr ""
+
+#: bzrlib/builtins.py:125
+#, python-format
+msgid "bzr %s --revision takes exactly one revision identifier"
+msgstr ""
+
+#: bzrlib/builtins.py:210
 msgid "Display status summary."
 msgstr ""
 
-#: bzrlib/builtins.py:211
+#: bzrlib/builtins.py:212
 msgid ""
 "This reports on versioned and unknown files, reporting them\n"
 "grouped by state.  Possible states are:"
 msgstr ""
 
-#: bzrlib/builtins.py:214
+#: bzrlib/builtins.py:215
 msgid ""
 "added\n"
 "    Versioned in the working copy but not in the previous revision."
 msgstr ""
 
-#: bzrlib/builtins.py:217
+#: bzrlib/builtins.py:218
 msgid ""
 "removed\n"
 "    Versioned in the previous revision but removed or deleted\n"
 "    in the working copy."
 msgstr ""
 
-#: bzrlib/builtins.py:221
+#: bzrlib/builtins.py:222
 msgid ""
 "renamed\n"
 "    Path of this file changed from the previous revision;\n"
@@ -49,25 +96,25 @@
 "    parent directory was renamed."
 msgstr ""
 
-#: bzrlib/builtins.py:226
+#: bzrlib/builtins.py:227
 msgid ""
 "modified\n"
 "    Text has changed since the previous revision."
 msgstr ""
 
-#: bzrlib/builtins.py:229
+#: bzrlib/builtins.py:230
 msgid ""
 "kind changed\n"
 "    File kind has been changed (e.g. from file to directory)."
 msgstr ""
 
-#: bzrlib/builtins.py:232
+#: bzrlib/builtins.py:233
 msgid ""
 "unknown\n"
 "    Not versioned and not matching an ignore pattern."
 msgstr ""
 
-#: bzrlib/builtins.py:235
+#: bzrlib/builtins.py:236
 msgid ""
 "Additionally for directories, symlinks and files with a changed\n"
 "executable bit, Bazaar indicates their type using a trailing\n"
@@ -75,20 +122,20 @@
 "disabled using the '--no-classify' option."
 msgstr ""
 
-#: bzrlib/builtins.py:240
+#: bzrlib/builtins.py:241
 msgid ""
 "To see ignored files use 'bzr ignored'.  For details on the\n"
 "changes to file texts, use 'bzr diff'."
 msgstr ""
 
-#: bzrlib/builtins.py:243
+#: bzrlib/builtins.py:244
 msgid ""
 "Note that --short or -S gives status flags for each item, similar\n"
 "to Subversion's status command. To get output similar to svn -q,\n"
 "use bzr status -SV."
 msgstr ""
 
-#: bzrlib/builtins.py:247
+#: bzrlib/builtins.py:248
 msgid ""
 "If no arguments are specified, the status of the entire working\n"
 "directory is shown.  Otherwise, only the status of the specified\n"
@@ -96,7 +143,7 @@
 "is reported for everything inside that directory."
 msgstr ""
 
-#: bzrlib/builtins.py:252
+#: bzrlib/builtins.py:253
 msgid ""
 "Before merges are committed, the pending merge tip revisions are\n"
 "shown. To see all pending merge revisions, use the -v option.\n"
@@ -104,13 +151,13 @@
 "the no-pending option or specify a file/directory."
 msgstr ""
 
-#: bzrlib/builtins.py:257
+#: bzrlib/builtins.py:258
 msgid ""
 "To compare the working directory to a specific revision, pass a\n"
 "single revision to the revision argument."
 msgstr ""
 
-#: bzrlib/builtins.py:260
+#: bzrlib/builtins.py:261
 msgid ""
 "To see which files have changed in a specific revision, or between\n"
 "two revisions, pass a revision range to the revision argument.\n"
@@ -118,44 +165,97 @@
 msgstr ""
 
 # help of 'short' option of 'status' command
-#: bzrlib/builtins.py:269
+#: bzrlib/builtins.py:270
 msgid "Use short status indicators."
 msgstr ""
 
 # help of 'versioned' option of 'status' command
-#: bzrlib/builtins.py:271
+#: bzrlib/builtins.py:272
 msgid "Only show versioned files."
 msgstr ""
 
 # help of 'no-pending' option of 'status' command
-#: bzrlib/builtins.py:273
+#: bzrlib/builtins.py:274
 msgid "Don't show pending merges."
 msgstr ""
 
 # help of 'no-classify' option of 'status' command
-#: bzrlib/builtins.py:276
+#: bzrlib/builtins.py:277
 msgid "Do not mark object type using indicator."
 msgstr ""
 
-#: bzrlib/builtins.py:455
+#: bzrlib/builtins.py:292
+msgid "bzr status --revision takes exactly one or two revision specifiers"
+msgstr ""
+
+#: bzrlib/builtins.py:336 bzrlib/builtins.py:4927
+msgid "You can only supply one of revision_id or --revision"
+msgstr ""
+
+#: bzrlib/builtins.py:339 bzrlib/builtins.py:4929
+msgid "You must supply either --revision or a revision_id"
+msgstr ""
+
+#: bzrlib/builtins.py:346
+#, python-format
+msgid "Repository %r does not support access to raw revision texts"
+msgstr ""
+
+#: bzrlib/builtins.py:357
+msgid "The repository {0} contains no revision {1}."
+msgstr ""
+
+#: bzrlib/builtins.py:364
+msgid "You cannot specify a NULL revision."
+msgstr ""
+
+#: bzrlib/builtins.py:456
 msgid "Remove the working tree from a given branch/checkout."
 msgstr ""
 
-#: bzrlib/builtins.py:457
+#: bzrlib/builtins.py:458
 msgid ""
 "Since a lightweight checkout is little more than a working tree\n"
 "this will refuse to run against one."
 msgstr ""
 
-#: bzrlib/builtins.py:460
+#: bzrlib/builtins.py:461
 msgid "To re-create the working tree, use \"bzr checkout\"."
 msgstr ""
 
 # help of 'force' option of 'remove-tree' command
-#: bzrlib/builtins.py:466
+#: bzrlib/builtins.py:467
 msgid "Remove the working tree even if it has uncommitted or shelved changes."
 msgstr ""
 
+#: bzrlib/builtins.py:481
+msgid "No working tree to remove"
+msgstr ""
+
+#: bzrlib/builtins.py:483
+msgid "You cannot remove the working tree of a remote path"
+msgstr ""
+
+#: bzrlib/builtins.py:492
+msgid "You cannot remove the working tree from a lightweight checkout"
+msgstr ""
+
+#: bzrlib/builtins.py:532
+msgid ""
+"The tree does not appear to be corrupt. You probably want \"bzr revert\" "
+"instead. Use \"--force\" if you are sure you want to reset the working tree."
+msgstr ""
+
+#: bzrlib/builtins.py:543
+msgid ""
+", the header appears corrupt, try passing -r -1 to set the state to the last "
+"commit"
+msgstr ""
+
+#: bzrlib/builtins.py:547
+msgid "failed to reset the tree state{0}"
+msgstr ""
+
 #: bzrlib/builtins.py:551
 msgid "Show current revision number."
 msgstr ""
@@ -245,30 +345,44 @@
 msgid "Lookup file ids from this tree."
 msgstr ""
 
-#: bzrlib/builtins.py:731
+#: bzrlib/builtins.py:727
+msgid "ignored {0} matching \"{1}\"\n"
+msgstr ""
+
+#: bzrlib/builtins.py:732
 msgid "Create a new versioned directory."
 msgstr ""
 
-#: bzrlib/builtins.py:733
+#: bzrlib/builtins.py:734
 msgid "This is equivalent to creating the directory and then adding it."
 msgstr ""
 
-#: bzrlib/builtins.py:828
+#: bzrlib/builtins.py:748
+#, python-format
+msgid "added %s\n"
+msgstr ""
+
+#: bzrlib/builtins.py:792
+#, python-format
+msgid "invalid kind %r specified"
+msgstr ""
+
+#: bzrlib/builtins.py:829
 msgid "Move or rename a file."
 msgstr ""
 
-#: bzrlib/builtins.py:830
+#: bzrlib/builtins.py:831
 msgid "    bzr mv SOURCE... DESTINATION"
 msgstr ""
 
-#: bzrlib/builtins.py:832
+#: bzrlib/builtins.py:833
 msgid ""
 "If the last argument is a versioned directory, all the other names\n"
 "are moved into it.  Otherwise, there must be exactly two arguments\n"
 "and the file is changed to a new name."
 msgstr ""
 
-#: bzrlib/builtins.py:836
+#: bzrlib/builtins.py:837
 msgid ""
 "If OLDNAME does not exist on the filesystem but is versioned and\n"
 "NEWNAME does exist on the filesystem but is not versioned, mv\n"
@@ -277,32 +391,52 @@
 "The same is valid when moving many SOURCE files to a DESTINATION."
 msgstr ""
 
-#: bzrlib/builtins.py:842
+#: bzrlib/builtins.py:843
 msgid "Files cannot be moved between branches."
 msgstr ""
 
 # help of 'after' option of 'mv' command
-#: bzrlib/builtins.py:849
+#: bzrlib/builtins.py:850
 msgid ""
 "Move only the bzr identifier of the file, because the file has already been "
 "moved."
 msgstr ""
 
 # help of 'auto' option of 'mv' command
-#: bzrlib/builtins.py:851
+#: bzrlib/builtins.py:852
 msgid "Automatically guess renames."
 msgstr ""
 
 # help of 'dry-run' option of 'mv' command
-#: bzrlib/builtins.py:852
+#: bzrlib/builtins.py:853
 msgid "Avoid making changes when guessing renames."
 msgstr ""
 
-#: bzrlib/builtins.py:964
+#: bzrlib/builtins.py:862
+msgid "--dry-run requires --auto."
+msgstr ""
+
+#: bzrlib/builtins.py:866
+msgid "missing file argument"
+msgstr ""
+
+#: bzrlib/builtins.py:873
+msgid "Only one path may be specified to --auto."
+msgstr ""
+
+#: bzrlib/builtins.py:876
+msgid "--after cannot be specified with --auto."
+msgstr ""
+
+#: bzrlib/builtins.py:913
+msgid "to mv multiple files the destination must be a versioned directory"
+msgstr ""
+
+#: bzrlib/builtins.py:965
 msgid "Turn this branch into a mirror of another branch."
 msgstr ""
 
-#: bzrlib/builtins.py:966
+#: bzrlib/builtins.py:967
 msgid ""
 "By default, this command only works on branches that have not diverged.\n"
 "Branches are considered diverged if the destination branch's most recent \n"
@@ -310,21 +444,21 @@
 "parent."
 msgstr ""
 
-#: bzrlib/builtins.py:971
+#: bzrlib/builtins.py:972
 msgid ""
 "If branches have diverged, you can use 'bzr merge' to integrate the changes\n"
 "from one into the other.  Once one branch has merged, the other should\n"
 "be able to pull it again."
 msgstr ""
 
-#: bzrlib/builtins.py:975
+#: bzrlib/builtins.py:976
 msgid ""
 "If you want to replace your local changes and just want your branch to\n"
 "match the remote one, use pull --overwrite. This will work even if the two\n"
 "branches have diverged."
 msgstr ""
 
-#: bzrlib/builtins.py:979
+#: bzrlib/builtins.py:980
 msgid ""
 "If there is no default location set, the first pull will set it (use\n"
 "--no-remember to avoid setting it). After that, you can omit the\n"
@@ -332,7 +466,7 @@
 "value will only be saved if the remote location can be accessed."
 msgstr ""
 
-#: bzrlib/builtins.py:984
+#: bzrlib/builtins.py:985
 msgid ""
 "Note: The location can be specified either in the form of a branch,\n"
 "or in the form of a path to a file containing a merge directive generated\n"
@@ -340,60 +474,77 @@
 msgstr ""
 
 # help of 'verbose' option of 'pull' command
-#: bzrlib/builtins.py:992
+#: bzrlib/builtins.py:993
 msgid "Show logs of pulled revisions."
 msgstr ""
 
 # help of 'directory' option of 'pull' command
-#: bzrlib/builtins.py:994
+#: bzrlib/builtins.py:995
 msgid ""
 "Branch to pull into, rather than the one containing the working directory."
 msgstr ""
 
 # help of 'local' option of 'pull' command
-#: bzrlib/builtins.py:997
+#: bzrlib/builtins.py:998
 msgid ""
 "Perform a local pull in a bound branch.  Local pulls are not applied to the "
 "master branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1096
+#: bzrlib/builtins.py:1027
+msgid "Need working tree for --show-base."
+msgstr ""
+
+#: bzrlib/builtins.py:1043
+msgid "No pull location known or specified."
+msgstr ""
+
+#: bzrlib/builtins.py:1049
+#, python-format
+msgid "Using saved parent location: %s\n"
+msgstr ""
+
+#: bzrlib/builtins.py:1056 bzrlib/builtins.py:4137
+msgid "Cannot use -r with merge directives or bundles"
+msgstr ""
+
+#: bzrlib/builtins.py:1097
 msgid "Update a mirror of this branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1098
+#: bzrlib/builtins.py:1099
 msgid ""
 "The target branch will not have its working tree populated because this\n"
 "is both expensive, and is not supported on remote file systems."
 msgstr ""
 
-#: bzrlib/builtins.py:1101
+#: bzrlib/builtins.py:1102
 msgid ""
 "Some smart servers or protocols *may* put the working tree in place in\n"
 "the future."
 msgstr ""
 
-#: bzrlib/builtins.py:1104
+#: bzrlib/builtins.py:1105
 msgid ""
 "This command only works on branches that have not diverged.  Branches are\n"
 "considered diverged if the destination branch's most recent commit is one\n"
 "that has not been merged (directly or indirectly) by the source branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1108
+#: bzrlib/builtins.py:1109
 msgid ""
 "If branches have diverged, you can use 'bzr push --overwrite' to replace\n"
 "the other branch completely, discarding its unmerged changes."
 msgstr ""
 
-#: bzrlib/builtins.py:1111
+#: bzrlib/builtins.py:1112
 msgid ""
 "If you want to ensure you have the different changes in the other branch,\n"
 "do a merge (see bzr help merge) from the other branch, and commit that.\n"
 "After that you will be able to do a push without '--overwrite'."
 msgstr ""
 
-#: bzrlib/builtins.py:1115
+#: bzrlib/builtins.py:1116
 msgid ""
 "If there is no default push location set, the first push will set it (use\n"
 "--no-remember to avoid setting it).  After that, you can omit the\n"
@@ -402,27 +553,27 @@
 msgstr ""
 
 # help of 'directory' option of 'push' command
-#: bzrlib/builtins.py:1127
+#: bzrlib/builtins.py:1128
 msgid ""
 "Branch to push from, rather than the one containing the working directory."
 msgstr ""
 
 # help of 'use-existing-dir' option of 'push' command
-#: bzrlib/builtins.py:1130
+#: bzrlib/builtins.py:1131
 msgid ""
 "By default push will fail if the target directory exists, but does not "
 "already have a control directory.  This flag will allow push to proceed."
 msgstr ""
 
 # help of 'stacked' option of 'push' command
-#: bzrlib/builtins.py:1135
+#: bzrlib/builtins.py:1136
 msgid ""
 "Create a stacked branch that references the public location of the parent "
 "branch."
 msgstr ""
 
 # help of 'stacked-on' option of 'push' command
-#: bzrlib/builtins.py:1138
+#: bzrlib/builtins.py:1139
 msgid ""
 "Create a stacked branch that refers to another branch for the commit "
 "history. Only the work not present in the referenced branch is included in "
@@ -430,22 +581,35 @@
 msgstr ""
 
 # help of 'strict' option of 'push' command
-#: bzrlib/builtins.py:1143
+#: bzrlib/builtins.py:1144
 msgid ""
 "Refuse to push if there are uncommitted changes in the working tree, --no-"
 "strict disables the check."
 msgstr ""
 
 # help of 'no-tree' option of 'push' command
-#: bzrlib/builtins.py:1146
+#: bzrlib/builtins.py:1147
 msgid "Don't populate the working tree, even for protocols that support it."
 msgstr ""
 
-#: bzrlib/builtins.py:1211
+#: bzrlib/builtins.py:1191
+msgid "Could not determine branch to refer to."
+msgstr ""
+
+#: bzrlib/builtins.py:1198 bzrlib/foreign.py:306
+msgid "No push location known or specified."
+msgstr ""
+
+#: bzrlib/builtins.py:1202
+#, python-format
+msgid "Using saved push location: %s"
+msgstr ""
+
+#: bzrlib/builtins.py:1212
 msgid "Create a new branch that is a copy of an existing branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1213
+#: bzrlib/builtins.py:1214
 msgid ""
 "If the TO_LOCATION is omitted, the last component of the FROM_LOCATION will\n"
 "be used.  In other words, \"branch ../foo/bar\" will attempt to create ./"
@@ -456,65 +620,105 @@
 "create ./foo-bar."
 msgstr ""
 
-#: bzrlib/builtins.py:1220
+#: bzrlib/builtins.py:1221
 msgid ""
 "To retrieve the branch as of a particular revision, supply the --revision\n"
 "parameter, as in \"branch foo/bar -r 5\"."
 msgstr ""
 
-#: bzrlib/builtins.py:1223
+#: bzrlib/builtins.py:1224
 msgid "The synonyms 'clone' and 'get' for this command are deprecated."
 msgstr ""
 
 # help of 'no-tree' option of 'branch' command
-#: bzrlib/builtins.py:1233
+#: bzrlib/builtins.py:1234
 msgid "Create a branch without a working-tree."
 msgstr ""
 
 # help of 'switch' option of 'branch' command
-#: bzrlib/builtins.py:1235
+#: bzrlib/builtins.py:1236
 msgid "Switch the checkout in the current directory to the new branch."
 msgstr ""
 
 # help of 'stacked' option of 'branch' command
-#: bzrlib/builtins.py:1238
+#: bzrlib/builtins.py:1239
 msgid ""
 "Create a stacked branch referring to the source branch. The new branch will "
 "depend on the availability of the source branch for all operations."
 msgstr ""
 
 # help of 'standalone' option of 'branch' command
-#: bzrlib/builtins.py:1242
+#: bzrlib/builtins.py:1243
 msgid "Do not use a shared repository, even if available."
 msgstr ""
 
 # help of 'use-existing-dir' option of 'branch' command
-#: bzrlib/builtins.py:1244
+#: bzrlib/builtins.py:1245
 msgid ""
 "By default branch will fail if the target directory exists, but does not "
 "already have a control directory.  This flag will allow branch to proceed."
 msgstr ""
 
 # help of 'bind' option of 'branch' command
-#: bzrlib/builtins.py:1249
+#: bzrlib/builtins.py:1250
 msgid "Bind new branch to from location."
 msgstr ""
 
-#: bzrlib/builtins.py:1341
+#: bzrlib/builtins.py:1291
+#, python-format
+msgid "Target directory \"%s\" already exists."
+msgstr ""
+
+#: bzrlib/builtins.py:1301
+#, python-format
+msgid "Parent of \"%s\" does not exist."
+msgstr ""
+
+#: bzrlib/builtins.py:1315
+msgid "The branch {0} has no revision {1}."
+msgstr ""
+
+#: bzrlib/builtins.py:1323 bzrlib/push.py:51
+#, python-format
+msgid "Created new stacked branch referring to %s."
+msgstr ""
+
+#: bzrlib/builtins.py:1327
+#, python-format
+msgid "Branched %d revision."
+msgid_plural "Branched %d revisions."
+msgstr[0] ""
+msgstr[1] ""
+
+#: bzrlib/builtins.py:1332
+#, python-format
+msgid "New branch bound to %s"
+msgstr ""
+
+#: bzrlib/builtins.py:1337 bzrlib/builtins.py:5968
+#, python-format
+msgid "Switched to branch: %s"
+msgstr ""
+
+#: bzrlib/builtins.py:1342
 msgid "List the branches available at the current location."
 msgstr ""
 
-#: bzrlib/builtins.py:1343
+#: bzrlib/builtins.py:1344
 msgid ""
 "This command will print the names of all the branches at the current "
 "location."
 msgstr ""
 
-#: bzrlib/builtins.py:1358
+#: bzrlib/builtins.py:1353
+msgid " (default)\n"
+msgstr ""
+
+#: bzrlib/builtins.py:1359
 msgid "Create a new checkout of an existing branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1360
+#: bzrlib/builtins.py:1361
 msgid ""
 "If BRANCH_LOCATION is omitted, checkout will reconstitute a working tree "
 "for\n"
@@ -524,7 +728,7 @@
 "location using SFTP."
 msgstr ""
 
-#: bzrlib/builtins.py:1365
+#: bzrlib/builtins.py:1366
 msgid ""
 "If the TO_LOCATION is omitted, the last component of the BRANCH_LOCATION "
 "will\n"
@@ -536,7 +740,7 @@
 "create ./foo-bar."
 msgstr ""
 
-#: bzrlib/builtins.py:1372
+#: bzrlib/builtins.py:1373
 msgid ""
 "To retrieve the branch as of a particular revision, supply the --revision\n"
 "parameter, as in \"checkout foo/bar -r 5\". Note that this will be "
@@ -547,7 +751,7 @@
 msgstr ""
 
 # help of 'lightweight' option of 'checkout' command
-#: bzrlib/builtins.py:1382
+#: bzrlib/builtins.py:1383
 msgid ""
 "Perform a lightweight checkout.  Lightweight checkouts depend on access to "
 "the branch for every operation.  Normal checkouts can perform common "
@@ -556,103 +760,128 @@
 msgstr ""
 
 # help of 'files-from' option of 'branch' command
-#: bzrlib/builtins.py:1389
+#: bzrlib/builtins.py:1390
 msgid "Get file contents from this tree."
 msgstr ""
 
 # help of 'hardlink' option of 'branch' command
-#: bzrlib/builtins.py:1391
+#: bzrlib/builtins.py:1392
 msgid "Hard-link working tree files where possible."
 msgstr ""
 
-#: bzrlib/builtins.py:1432
+#: bzrlib/builtins.py:1433
 msgid ""
 "Show list of renamed files.\n"
 "    "
 msgstr ""
 
-#: bzrlib/builtins.py:1462
+#: bzrlib/builtins.py:1463
 msgid "Update a tree to have the latest code committed to its branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1464
+#: bzrlib/builtins.py:1465
 msgid ""
 "This will perform a merge into the working tree, and may generate\n"
 "conflicts. If you have any local changes, you will still\n"
 "need to commit them after the update for the update to be complete."
 msgstr ""
 
-#: bzrlib/builtins.py:1468
+#: bzrlib/builtins.py:1469
 msgid ""
 "If you want to discard your local changes, you can just do a\n"
 "'bzr revert' instead of 'bzr commit' after the update."
 msgstr ""
 
-#: bzrlib/builtins.py:1471
+#: bzrlib/builtins.py:1472
 msgid ""
 "If you want to restore a file that has been removed locally, use\n"
 "'bzr revert' instead of 'bzr update'."
 msgstr ""
 
-#: bzrlib/builtins.py:1474
+#: bzrlib/builtins.py:1475
 msgid ""
 "If the tree's branch is bound to a master branch, it will also update\n"
 "the branch from the master."
 msgstr ""
 
-#: bzrlib/builtins.py:1555
+#: bzrlib/builtins.py:1490
+msgid "bzr update --revision takes exactly one revision"
+msgstr ""
+
+#: bzrlib/builtins.py:1521
+msgid "Tree is up to date at revision {0} of branch {1}"
+msgstr ""
+
+#: bzrlib/builtins.py:1537
+#, python-format
+msgid ""
+"branch has no revision %s\n"
+"bzr update --revision only works for a revision in the branch history"
+msgstr ""
+
+#: bzrlib/builtins.py:1543
+msgid "Updated to revision {0} of branch {1}"
+msgstr ""
+
+#: bzrlib/builtins.py:1547
+msgid ""
+"Your local commits will now show as pending merges with 'bzr status', and "
+"can be committed with 'bzr commit'."
+msgstr ""
+
+#: bzrlib/builtins.py:1556
 msgid "Show information about a working tree, branch or repository."
 msgstr ""
 
-#: bzrlib/builtins.py:1557
+#: bzrlib/builtins.py:1558
 msgid ""
 "This command will show all known locations and formats associated to the\n"
 "tree, branch or repository."
 msgstr ""
 
-#: bzrlib/builtins.py:1560
+#: bzrlib/builtins.py:1561
 msgid ""
 "In verbose mode, statistical information is included with each report.\n"
 "To see extended statistic information, use a verbosity level of 2 or\n"
 "higher by specifying the verbose option multiple times, e.g. -vv."
 msgstr ""
 
-#: bzrlib/builtins.py:1564
+#: bzrlib/builtins.py:1565
 msgid "Branches and working trees will also report any missing revisions."
 msgstr ""
 
-#: bzrlib/builtins.py:1568
+#: bzrlib/builtins.py:1569
 msgid "  Display information on the format and related locations:"
 msgstr ""
 
-#: bzrlib/builtins.py:1570
+#: bzrlib/builtins.py:1571
 msgid "    bzr info"
 msgstr ""
 
-#: bzrlib/builtins.py:1572
+#: bzrlib/builtins.py:1573
 msgid ""
 "  Display the above together with extended format information and\n"
 "  basic statistics (like the number of files in the working tree and\n"
 "  number of revisions in the branch and repository):"
 msgstr ""
 
-#: bzrlib/builtins.py:1576
+#: bzrlib/builtins.py:1577
 msgid "    bzr info -v"
 msgstr ""
 
-#: bzrlib/builtins.py:1578
+#: bzrlib/builtins.py:1579
 msgid "  Display the above together with number of committers to the branch:"
 msgstr ""
 
-#: bzrlib/builtins.py:1580
+#: bzrlib/builtins.py:1581
 msgid "    bzr info -vv"
 msgstr ""
 
-#: bzrlib/builtins.py:1599
+#: bzrlib/builtins.py:1600
 msgid "Remove files or directories."
 msgstr ""
 
-#: bzrlib/builtins.py:1601
+#: bzrlib/builtins.py:1602
 msgid ""
 "This makes Bazaar stop tracking changes to the specified files. Bazaar will\n"
 "delete them if they can easily be recovered using revert otherwise they\n"
@@ -662,25 +891,33 @@
 msgstr ""
 
 # help of 'new' option of 'remove' command
-#: bzrlib/builtins.py:1609
+#: bzrlib/builtins.py:1610
 msgid "Only remove files that have never been committed."
 msgstr ""
 
 # help of 'file-deletion-strategy' option of 'remove' command
-#: bzrlib/builtins.py:1611
+#: bzrlib/builtins.py:1612
 msgid "The file deletion mode to be used."
 msgstr ""
 
 # title of 'file-deletion-strategy' option of 'remove' command
-#: bzrlib/builtins.py:1612
+#: bzrlib/builtins.py:1613
 msgid "Deletion Strategy"
 msgstr ""
 
-#: bzrlib/builtins.py:1703
+#: bzrlib/builtins.py:1626
+msgid "(The --force option is deprecated, rather use --no-backup in future.)"
+msgstr ""
+
+#: bzrlib/builtins.py:1643
+msgid "No matching files."
+msgstr ""
+
+#: bzrlib/builtins.py:1704
 msgid "Reconcile bzr metadata in a branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1705
+#: bzrlib/builtins.py:1706
 msgid ""
 "This can correct data mismatches that may have been caused by\n"
 "previous ghost operations or bzr upgrades. You should only\n"
@@ -688,7 +925,7 @@
 "advises you to run it."
 msgstr ""
 
-#: bzrlib/builtins.py:1710
+#: bzrlib/builtins.py:1711
 msgid ""
 "If a second branch is provided, cross-branch reconciliation is\n"
 "also attempted, which will check that data like the tree root\n"
@@ -696,27 +933,27 @@
 "correctly in both branches."
 msgstr ""
 
-#: bzrlib/builtins.py:1715
+#: bzrlib/builtins.py:1716
 msgid ""
 "At the same time it is run it may recompress data resulting in\n"
 "a potential saving in disk space or performance gain."
 msgstr ""
 
-#: bzrlib/builtins.py:1718
+#: bzrlib/builtins.py:1719
 msgid "The branch *MUST* be on a listable system such as local disk or sftp."
 msgstr ""
 
-#: bzrlib/builtins.py:1782
+#: bzrlib/builtins.py:1783
 msgid "Make a directory into a versioned branch."
 msgstr ""
 
-#: bzrlib/builtins.py:1784
+#: bzrlib/builtins.py:1785
 msgid ""
 "Use this to create an empty branch, or before importing an\n"
 "existing project."
 msgstr ""
 
-#: bzrlib/builtins.py:1787
+#: bzrlib/builtins.py:1788
 msgid ""
 "If there is a repository in a parent directory of the location, then\n"
 "the history of the branch will be stored in the repository.  Otherwise\n"
@@ -724,17 +961,17 @@
 "in the .bzr directory."
 msgstr ""
 
-#: bzrlib/builtins.py:1792
+#: bzrlib/builtins.py:1793
 msgid ""
 "If there is already a branch at the location but it has no working tree,\n"
 "the tree can be populated with 'bzr checkout'."
 msgstr ""
 
-#: bzrlib/builtins.py:1795
+#: bzrlib/builtins.py:1796
 msgid "Recipe for importing a tree of files::"
 msgstr ""
 
-#: bzrlib/builtins.py:1797
+#: bzrlib/builtins.py:1798
 msgid ""
 "    cd ~/project\n"
 "    bzr init\n"
@@ -744,30 +981,51 @@
 msgstr ""
 
 # help of 'create-prefix' option of 'init' command
-#: bzrlib/builtins.py:1808
+#: bzrlib/builtins.py:1809
 msgid "Create the path leading up to the branch if it does not already exist."
 msgstr ""
 
 # help of 'format' option of 'init' command
-#: bzrlib/builtins.py:1811
+#: bzrlib/builtins.py:1812
 msgid "Specify a format for this branch. See \"help formats\"."
 msgstr ""
 
 # help of 'append-revisions-only' option of 'init' command
-#: bzrlib/builtins.py:1819
+#: bzrlib/builtins.py:1820
 msgid "Never change revnos or the existing log.  Append revisions to it only."
 msgstr ""
 
 # help of 'no-tree' option of 'init' command
-#: bzrlib/builtins.py:1822
+#: bzrlib/builtins.py:1823
 msgid "Create a branch without a working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:1899
+#: bzrlib/builtins.py:1843 bzrlib/push.py:108
+#, python-format
+msgid ""
+"Parent directory of %s does not exist.\n"
+"You may supply --create-prefix to create all leading parent directories."
+msgstr ""
+
+#: bzrlib/builtins.py:1877
+msgid ""
+"This branch format cannot be set to append-revisions-only.  Try --default."
+msgstr ""
+
+#: bzrlib/builtins.py:1888
+msgid "Created a {0} (format: {1})\n"
+msgstr ""
+
+#: bzrlib/builtins.py:1897
+#, python-format
+msgid "Using shared repository: %s\n"
+msgstr ""
+
+#: bzrlib/builtins.py:1901
 msgid "Create a shared repository for branches to share storage space."
 msgstr ""
 
-#: bzrlib/builtins.py:1901
+#: bzrlib/builtins.py:1903
 msgid ""
 "New branches created under the repository directory will store their\n"
 "revisions in the repository, not in the branch directory.  For branches\n"
@@ -775,7 +1033,7 @@
 "speeds up the creation of new branches."
 msgstr ""
 
-#: bzrlib/builtins.py:1906
+#: bzrlib/builtins.py:1908
 msgid ""
 "If the --no-trees option is given then the branches in the repository\n"
 "will not have working trees by default.  They will still exist as \n"
@@ -785,23 +1043,23 @@
 "branches, such as on a server."
 msgstr ""
 
-#: bzrlib/builtins.py:1913
+#: bzrlib/builtins.py:1915
 msgid ""
 ":Examples:\n"
 "    Create a shared repository holding just branches::"
 msgstr ""
 
-#: bzrlib/builtins.py:1916
+#: bzrlib/builtins.py:1918
 msgid ""
 "        bzr init-repo --no-trees repo\n"
 "        bzr init repo/trunk"
 msgstr ""
 
-#: bzrlib/builtins.py:1919
+#: bzrlib/builtins.py:1921
 msgid "    Make a lightweight checkout elsewhere::"
 msgstr ""
 
-#: bzrlib/builtins.py:1921
+#: bzrlib/builtins.py:1923
 msgid ""
 "        bzr checkout --lightweight repo/trunk trunk-checkout\n"
 "        cd trunk-checkout\n"
@@ -809,26 +1067,26 @@
 msgstr ""
 
 # help of 'format' option of 'init-repository' command
-#: bzrlib/builtins.py:1929
+#: bzrlib/builtins.py:1931
 msgid ""
 "Specify a format for this repository. See \"bzr help formats\" for details."
 msgstr ""
 
 # title of 'format' option of 'init-repository' command
-#: bzrlib/builtins.py:1933
+#: bzrlib/builtins.py:1935
 msgid "Repository format"
 msgstr ""
 
 # help of 'no-trees' option of 'init-repository' command
-#: bzrlib/builtins.py:1935
+#: bzrlib/builtins.py:1937
 msgid "Branches in the repository will default to not having a working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:1959
+#: bzrlib/builtins.py:1961
 msgid "Show differences in the working tree, between revisions or branches."
 msgstr ""
 
-#: bzrlib/builtins.py:1961
+#: bzrlib/builtins.py:1963
 msgid ""
 "If no arguments are given, all changes for the current tree are listed.\n"
 "If files are given, only the changes in those files are listed.\n"
@@ -838,13 +1096,13 @@
 "given."
 msgstr ""
 
-#: bzrlib/builtins.py:1968
+#: bzrlib/builtins.py:1970
 msgid ""
 "\"bzr diff -p1\" is equivalent to \"bzr diff --prefix old/:new/\", and\n"
 "produces patches suitable for \"patch -p1\"."
 msgstr ""
 
-#: bzrlib/builtins.py:1971
+#: bzrlib/builtins.py:1973
 msgid ""
 "Note that when using the -r argument with a range of revisions, the\n"
 "differences are computed between the two specified revisions.  That\n"
@@ -854,7 +1112,7 @@
 "in the range."
 msgstr ""
 
-#: bzrlib/builtins.py:1978
+#: bzrlib/builtins.py:1980
 msgid ""
 ":Exit values:\n"
 "    1 - changed\n"
@@ -863,113 +1121,113 @@
 "    0 - no change"
 msgstr ""
 
-#: bzrlib/builtins.py:1984
+#: bzrlib/builtins.py:1986
 msgid ""
 ":Examples:\n"
 "    Shows the difference in the working tree versus the last commit::"
 msgstr ""
 
-#: bzrlib/builtins.py:1987
+#: bzrlib/builtins.py:1989
 msgid "        bzr diff"
 msgstr ""
 
-#: bzrlib/builtins.py:1989
+#: bzrlib/builtins.py:1991
 msgid "    Difference between the working tree and revision 1::"
 msgstr ""
 
-#: bzrlib/builtins.py:1991
+#: bzrlib/builtins.py:1993
 msgid "        bzr diff -r1"
 msgstr ""
 
-#: bzrlib/builtins.py:1993
+#: bzrlib/builtins.py:1995
 msgid "    Difference between revision 3 and revision 1::"
 msgstr ""
 
-#: bzrlib/builtins.py:1995
+#: bzrlib/builtins.py:1997
 msgid "        bzr diff -r1..3"
 msgstr ""
 
-#: bzrlib/builtins.py:1997
+#: bzrlib/builtins.py:1999
 msgid "    Difference between revision 3 and revision 1 for branch xxx::"
 msgstr ""
 
-#: bzrlib/builtins.py:1999
+#: bzrlib/builtins.py:2001
 msgid "        bzr diff -r1..3 xxx"
 msgstr ""
 
-#: bzrlib/builtins.py:2001
+#: bzrlib/builtins.py:2003
 msgid "    The changes introduced by revision 2 (equivalent to -r1..2)::"
 msgstr ""
 
-#: bzrlib/builtins.py:2003
+#: bzrlib/builtins.py:2005
 msgid "        bzr diff -c2"
 msgstr ""
 
-#: bzrlib/builtins.py:2005
+#: bzrlib/builtins.py:2007
 msgid ""
 "    To see the changes introduced by revision X::\n"
 "    \n"
 "        bzr diff -cX"
 msgstr ""
 
-#: bzrlib/builtins.py:2009
+#: bzrlib/builtins.py:2011
 msgid ""
 "    Note that in the case of a merge, the -c option shows the changes\n"
 "    compared to the left hand parent. To see the changes against\n"
 "    another parent, use::"
 msgstr ""
 
-#: bzrlib/builtins.py:2013
+#: bzrlib/builtins.py:2015
 msgid "        bzr diff -r<chosen_parent>..X"
 msgstr ""
 
-#: bzrlib/builtins.py:2015
+#: bzrlib/builtins.py:2017
 msgid ""
 "    The changes between the current revision and the previous revision\n"
 "    (equivalent to -c-1 and -r-2..-1)"
 msgstr ""
 
-#: bzrlib/builtins.py:2018
+#: bzrlib/builtins.py:2020
 msgid "        bzr diff -r-2.."
 msgstr ""
 
-#: bzrlib/builtins.py:2020
+#: bzrlib/builtins.py:2022
 msgid "    Show just the differences for file NEWS::"
 msgstr ""
 
-#: bzrlib/builtins.py:2022
+#: bzrlib/builtins.py:2024
 msgid "        bzr diff NEWS"
 msgstr ""
 
-#: bzrlib/builtins.py:2024
+#: bzrlib/builtins.py:2026
 msgid "    Show the differences in working tree xxx for file NEWS::"
 msgstr ""
 
-#: bzrlib/builtins.py:2026
+#: bzrlib/builtins.py:2028
 msgid "        bzr diff xxx/NEWS"
 msgstr ""
 
-#: bzrlib/builtins.py:2028
+#: bzrlib/builtins.py:2030
 msgid "    Show the differences from branch xxx to this working tree:"
 msgstr ""
 
-#: bzrlib/builtins.py:2030
+#: bzrlib/builtins.py:2032
 msgid "        bzr diff --old xxx"
 msgstr ""
 
-#: bzrlib/builtins.py:2032
+#: bzrlib/builtins.py:2034
 msgid "    Show the differences between two branches for file NEWS::"
 msgstr ""
 
-#: bzrlib/builtins.py:2034
+#: bzrlib/builtins.py:2036
 msgid "        bzr diff --old xxx --new yyy NEWS"
 msgstr ""
 
-#: bzrlib/builtins.py:2036
+#: bzrlib/builtins.py:2038
 msgid "    Same as 'bzr diff' but prefix paths with old/ and new/::"
 msgstr ""
 
-#: bzrlib/builtins.py:2038
+#: bzrlib/builtins.py:2040
 msgid ""
 "        bzr diff --prefix old/:new/\n"
 "        \n"
@@ -979,63 +1237,84 @@
 msgstr ""
 
 # help of 'diff-options' option of 'diff' command
-#: bzrlib/builtins.py:2048
+#: bzrlib/builtins.py:2050
 msgid "Pass these options to the external diff program."
 msgstr ""
 
 # help of 'prefix' option of 'diff' command
-#: bzrlib/builtins.py:2051
+#: bzrlib/builtins.py:2053
 msgid ""
 "Set prefixes added to old and new filenames, as two values separated by a "
 "colon. (eg \"old/:new/\")."
 msgstr ""
 
 # help of 'old' option of 'diff' command
-#: bzrlib/builtins.py:2054
+#: bzrlib/builtins.py:2056
 msgid "Branch/tree to compare from."
 msgstr ""
 
 # help of 'new' option of 'diff' command
-#: bzrlib/builtins.py:2058
+#: bzrlib/builtins.py:2060
 msgid "Branch/tree to compare to."
 msgstr ""
 
 # help of 'using' option of 'diff' command
-#: bzrlib/builtins.py:2064
+#: bzrlib/builtins.py:2066
 msgid "Use this command to compare files."
 msgstr ""
 
 # help of 'format' option of 'diff' command
-#: bzrlib/builtins.py:2069
+#: bzrlib/builtins.py:2071
 msgid "Diff format to use."
 msgstr ""
 
 # title of 'format' option of 'diff' command
-#: bzrlib/builtins.py:2071
+#: bzrlib/builtins.py:2073
 msgid "Diff format"
 msgstr ""
 
-#: bzrlib/builtins.py:2121
+#: bzrlib/builtins.py:2095
+msgid "--prefix expects two values separated by a colon (eg \"old/:new/\")"
+msgstr ""
+
+#: bzrlib/builtins.py:2099
+msgid "bzr diff --revision takes exactly one or two revision specifiers"
+msgstr ""
+
+#: bzrlib/builtins.py:2104 bzrlib/builtins.py:2502 bzrlib/builtins.py:2515
+#: bzrlib/builtins.py:2523 bzrlib/builtins.py:4663
+msgid "{0} and {1} are mutually exclusive"
+msgstr ""
+
+#: bzrlib/builtins.py:2124
 msgid ""
 "List files deleted in the working tree.\n"
 "    "
 msgstr ""
 
-#: bzrlib/builtins.py:2199
+#: bzrlib/builtins.py:2202
 msgid "Show the tree root directory."
 msgstr ""
 
-#: bzrlib/builtins.py:2201
+#: bzrlib/builtins.py:2204
 msgid ""
 "The root is the nearest enclosing directory with a .bzr control\n"
 "directory."
 msgstr ""
 
-#: bzrlib/builtins.py:2229
+#: bzrlib/builtins.py:2219
+msgid "The limit argument must be an integer."
+msgstr ""
+
+#: bzrlib/builtins.py:2227
+msgid "The levels argument must be an integer."
+msgstr ""
+
+#: bzrlib/builtins.py:2232
 msgid "Show historical log for a branch or subset of a branch."
 msgstr ""
 
-#: bzrlib/builtins.py:2231
+#: bzrlib/builtins.py:2234
 msgid ""
 "log is bzr's default tool for exploring the history of a branch.\n"
 "The branch to use is taken from the first parameter. If no parameters\n"
@@ -1043,14 +1322,14 @@
 "Here are some simple examples::"
 msgstr ""
 
-#: bzrlib/builtins.py:2236
+#: bzrlib/builtins.py:2239
 msgid ""
 "  bzr log                       log the current branch\n"
 "  bzr log foo.py                log a file in its branch\n"
 "  bzr log http://server/branch  log a branch on a server"
 msgstr ""
 
-#: bzrlib/builtins.py:2240
+#: bzrlib/builtins.py:2243
 msgid ""
 "The filtering, ordering and information shown for each revision can\n"
 "be controlled as explained below. By default, all revisions are\n"
@@ -1060,11 +1339,11 @@
 "were merged."
 msgstr ""
 
-#: bzrlib/builtins.py:2247
+#: bzrlib/builtins.py:2250
 msgid ":Output control:"
 msgstr ""
 
-#: bzrlib/builtins.py:2249
+#: bzrlib/builtins.py:2252
 msgid ""
 "  The log format controls how information about each revision is\n"
 "  displayed. The standard log formats are called ``long``, ``short``\n"
@@ -1072,13 +1351,13 @@
 "  for more details on log formats."
 msgstr ""
 
-#: bzrlib/builtins.py:2254
+#: bzrlib/builtins.py:2257
 msgid ""
 "  The following options can be used to control what information is\n"
 "  displayed::"
 msgstr ""
 
-#: bzrlib/builtins.py:2257
+#: bzrlib/builtins.py:2260
 msgid ""
 "    -l N        display a maximum of N revisions\n"
 "    -n N        display N levels of revisions (0 for all, 1 for collapsed)\n"
@@ -1087,25 +1366,25 @@
 "    --show-ids  display revision-ids (and file-ids), not just revnos"
 msgstr ""
 
-#: bzrlib/builtins.py:2263
+#: bzrlib/builtins.py:2266
 msgid ""
 "  Note that the default number of levels to display is a function of the\n"
 "  log format. If the -n option is not used, the standard log formats show\n"
 "  just the top level (mainline)."
 msgstr ""
 
-#: bzrlib/builtins.py:2267
+#: bzrlib/builtins.py:2270
 msgid ""
 "  Status summaries are shown using status flags like A, M, etc. To see\n"
 "  the changes explained using words like ``added`` and ``modified``\n"
 "  instead, use the -vv option."
 msgstr ""
 
-#: bzrlib/builtins.py:2271
+#: bzrlib/builtins.py:2274
 msgid ":Ordering control:"
 msgstr ""
 
-#: bzrlib/builtins.py:2273
+#: bzrlib/builtins.py:2276
 msgid ""
 "  To display revisions from oldest to newest, use the --forward option.\n"
 "  In most cases, using this option will have little impact on the total\n"
@@ -1113,17 +1392,17 @@
 "  display revisions like --reverse does when it can."
 msgstr ""
 
-#: bzrlib/builtins.py:2278
+#: bzrlib/builtins.py:2281
 msgid ":Revision filtering:"
 msgstr ""
 
-#: bzrlib/builtins.py:2280
+#: bzrlib/builtins.py:2283
 msgid ""
 "  The -r option can be used to specify what revision or range of revisions\n"
 "  to filter against. The various forms are shown below::"
 msgstr ""
 
-#: bzrlib/builtins.py:2283
+#: bzrlib/builtins.py:2286
 msgid ""
 "    -rX      display revision X\n"
 "    -rX..    display revision X and later\n"
@@ -1131,13 +1410,13 @@
 "    -rX..Y   display from X to Y inclusive"
 msgstr ""
 
-#: bzrlib/builtins.py:2288
+#: bzrlib/builtins.py:2291
 msgid ""
 "  See ``bzr help revisionspec`` for details on how to specify X and Y.\n"
 "  Some common examples are given below::"
 msgstr ""
 
-#: bzrlib/builtins.py:2291
+#: bzrlib/builtins.py:2294
 msgid ""
 "    -r-1                show just the tip\n"
 "    -r-10..             show the last 10 mainline revisions\n"
@@ -1147,7 +1426,7 @@
 "    -rdate:yesterday..  show changes since yesterday"
 msgstr ""
 
-#: bzrlib/builtins.py:2298
+#: bzrlib/builtins.py:2301
 msgid ""
 "  When logging a range of revisions using -rX..Y, log starts at\n"
 "  revision Y and searches back in history through the primary\n"
@@ -1157,73 +1436,73 @@
 "  a nested merge revision and the log will be truncated accordingly."
 msgstr ""
 
-#: bzrlib/builtins.py:2305
+#: bzrlib/builtins.py:2308
 msgid ":Path filtering:"
 msgstr ""
 
-#: bzrlib/builtins.py:2307
+#: bzrlib/builtins.py:2310
 msgid ""
 "  If parameters are given and the first one is not a branch, the log\n"
 "  will be filtered to show only those revisions that changed the\n"
 "  nominated files or directories."
 msgstr ""
 
-#: bzrlib/builtins.py:2311
+#: bzrlib/builtins.py:2314
 msgid ""
 "  Filenames are interpreted within their historical context. To log a\n"
 "  deleted file, specify a revision range so that the file existed at\n"
 "  the end or start of the range."
 msgstr ""
 
-#: bzrlib/builtins.py:2315
+#: bzrlib/builtins.py:2318
 msgid ""
 "  Historical context is also important when interpreting pathnames of\n"
 "  renamed files/directories. Consider the following example:"
 msgstr ""
 
-#: bzrlib/builtins.py:2318
+#: bzrlib/builtins.py:2321
 msgid ""
 "  * revision 1: add tutorial.txt\n"
 "  * revision 2: modify tutorial.txt\n"
 "  * revision 3: rename tutorial.txt to guide.txt; add tutorial.txt"
 msgstr ""
 
-#: bzrlib/builtins.py:2322
+#: bzrlib/builtins.py:2325
 msgid "  In this case:"
 msgstr ""
 
-#: bzrlib/builtins.py:2324
+#: bzrlib/builtins.py:2327
 msgid "  * ``bzr log guide.txt`` will log the file added in revision 1"
 msgstr ""
 
-#: bzrlib/builtins.py:2326
+#: bzrlib/builtins.py:2329
 msgid "  * ``bzr log tutorial.txt`` will log the new file added in revision 3"
 msgstr ""
 
-#: bzrlib/builtins.py:2328
+#: bzrlib/builtins.py:2331
 msgid ""
 "  * ``bzr log -r2 -p tutorial.txt`` will show the changes made to\n"
 "    the original file in revision 2."
 msgstr ""
 
-#: bzrlib/builtins.py:2331
+#: bzrlib/builtins.py:2334
 msgid ""
 "  * ``bzr log -r2 -p guide.txt`` will display an error message as there\n"
 "    was no file called guide.txt in revision 2."
 msgstr ""
 
-#: bzrlib/builtins.py:2334
+#: bzrlib/builtins.py:2337
 msgid ""
 "  Renames are always followed by log. By design, there is no need to\n"
 "  explicitly ask for this (and no way to stop logging a file back\n"
 "  until it was last renamed)."
 msgstr ""
 
-#: bzrlib/builtins.py:2338
+#: bzrlib/builtins.py:2341
 msgid ":Other filtering:"
 msgstr ""
 
-#: bzrlib/builtins.py:2340
+#: bzrlib/builtins.py:2343
 msgid ""
 "  The --match option can be used for finding revisions that match a\n"
 "  regular expression in a commit message, committer, author or bug.\n"
@@ -1232,11 +1511,11 @@
 "  --match-message can be used to only match a specific field."
 msgstr ""
 
-#: bzrlib/builtins.py:2346
+#: bzrlib/builtins.py:2349
 msgid ":Tips & tricks:"
 msgstr ""
 
-#: bzrlib/builtins.py:2348
+#: bzrlib/builtins.py:2351
 msgid ""
 "  GUI tools and IDEs are often better at exploring history than command\n"
 "  line tools: you may prefer qlog or viz from qbzr or bzr-gtk, the\n"
@@ -1245,11 +1524,11 @@
 "  <http://wiki.bazaar.canonical.com/IDEIntegration>.  "
 msgstr ""
 
-#: bzrlib/builtins.py:2354
+#: bzrlib/builtins.py:2357
 msgid "  You may find it useful to add the aliases below to ``bazaar.conf``::"
 msgstr ""
 
-#: bzrlib/builtins.py:2356
+#: bzrlib/builtins.py:2359
 msgid ""
 "    [ALIASES]\n"
 "    tip = log -r-1\n"
@@ -1257,20 +1536,20 @@
 "    show = log -v -p"
 msgstr ""
 
-#: bzrlib/builtins.py:2361
+#: bzrlib/builtins.py:2364
 msgid ""
 "  ``bzr tip`` will then show the latest revision while ``bzr top``\n"
 "  will show the last 10 mainline revisions. To see the details of a\n"
 "  particular revision X,  ``bzr show -rX``."
 msgstr ""
 
-#: bzrlib/builtins.py:2365
+#: bzrlib/builtins.py:2368
 msgid ""
 "  If you are interested in looking deeper into a particular merge X,\n"
 "  use ``bzr log -n0 -rX``."
 msgstr ""
 
-#: bzrlib/builtins.py:2368
+#: bzrlib/builtins.py:2371
 msgid ""
 "  ``bzr log -v`` on a branch with lots of history is currently\n"
 "  very slow. A fix for this issue is currently under development.\n"
@@ -1278,7 +1557,7 @@
 "  be given when using the -v option."
 msgstr ""
 
-#: bzrlib/builtins.py:2373
+#: bzrlib/builtins.py:2376
 msgid ""
 "  bzr has a generic full-text matching plugin, bzr-search, that can be\n"
 "  used to find revisions matching user names, commit messages, etc.\n"
@@ -1286,7 +1565,7 @@
 "  a list of words but not others."
 msgstr ""
 
-#: bzrlib/builtins.py:2378
+#: bzrlib/builtins.py:2381
 msgid ""
 "  When exploring non-mainline history on large projects with deep\n"
 "  history, the performance of log can be greatly improved by installing\n"
@@ -1295,132 +1574,168 @@
 msgstr ""
 
 # help of 'forward' option of 'log' command
-#: bzrlib/builtins.py:2387
+#: bzrlib/builtins.py:2390
 msgid "Show from oldest to newest."
 msgstr ""
 
 # help of 'verbose' option of 'log' command
-#: bzrlib/builtins.py:2390
+#: bzrlib/builtins.py:2393
 msgid "Show files changed in each revision."
 msgstr ""
 
 # help of 'change' option of 'log' command
-#: bzrlib/builtins.py:2396
+#: bzrlib/builtins.py:2399
 msgid "Show just the specified revision. See also \"help revisionspec\"."
 msgstr ""
 
 # help of 'authors' option of 'log' command
-#: bzrlib/builtins.py:2400
+#: bzrlib/builtins.py:2403
 msgid "What names to list as authors - first, all or committer."
 msgstr ""
 
 # title of 'authors' option of 'log' command
-#: bzrlib/builtins.py:2401
+#: bzrlib/builtins.py:2404
 msgid "Authors"
 msgstr ""
 
 # help of 'levels' option of 'log' command
-#: bzrlib/builtins.py:2406
+#: bzrlib/builtins.py:2409
 msgid "Number of levels to display - 0 for all, 1 for flat."
 msgstr ""
 
 # help of 'limit' option of 'log' command
-#: bzrlib/builtins.py:2416
+#: bzrlib/builtins.py:2419
 msgid "Limit the output to the first N revisions."
 msgstr ""
 
 # help of 'show-diff' option of 'log' command
-#: bzrlib/builtins.py:2421
+#: bzrlib/builtins.py:2424
 msgid "Show changes made in each revision as a patch."
 msgstr ""
 
-# help of 'include-merges' option of 'log' command
-#: bzrlib/builtins.py:2423
+# help of 'include-merged' option of 'log' command
+#: bzrlib/builtins.py:2426
 msgid "Show merged revisions like --levels 0 does."
 msgstr ""
 
+# help of 'omit-merges' option of 'log' command
+#: bzrlib/builtins.py:2430
+msgid "Do not report commits with more than one parent."
+msgstr ""
+
 # help of 'exclude-common-ancestry' option of 'log' command
-#: bzrlib/builtins.py:2425
+#: bzrlib/builtins.py:2432
 msgid ""
 "Display only the revisions that are not part of both ancestries (require -"
 "rX..Y)"
 msgstr ""
 
 # help of 'signatures' option of 'log' command
-#: bzrlib/builtins.py:2429
+#: bzrlib/builtins.py:2436
 msgid "Show digital signature validity"
 msgstr ""
 
 # help of 'match' option of 'log' command
-#: bzrlib/builtins.py:2432
+#: bzrlib/builtins.py:2439
 msgid "Show revisions whose properties match this expression."
 msgstr ""
 
 # help of 'match-message' option of 'log' command
-#: bzrlib/builtins.py:2436
+#: bzrlib/builtins.py:2443
 msgid "Show revisions whose message matches this expression."
 msgstr ""
 
 # help of 'match-committer' option of 'log' command
-#: bzrlib/builtins.py:2440
+#: bzrlib/builtins.py:2447
 msgid "Show revisions whose committer matches this expression."
 msgstr ""
 
 # help of 'match-author' option of 'log' command
-#: bzrlib/builtins.py:2444
+#: bzrlib/builtins.py:2451
 msgid "Show revisions whose authors match this expression."
 msgstr ""
 
 # help of 'match-bugs' option of 'log' command
-#: bzrlib/builtins.py:2448
+#: bzrlib/builtins.py:2455
 msgid "Show revisions whose bugs match this expression."
 msgstr ""
 
-#: bzrlib/builtins.py:2689
+#: bzrlib/builtins.py:2509
+msgid "--exclude-common-ancestry requires -r with two revisions"
+msgstr ""
+
+#: bzrlib/builtins.py:2537
+#, python-format
+msgid "Path unknown at end or start of revision range: %s"
+msgstr ""
+
+#: bzrlib/builtins.py:2654
+#, python-format
+msgid "bzr %s doesn't accept two revisions in different branches."
+msgstr ""
+
+#: bzrlib/builtins.py:2670
+#, python-format
+msgid "bzr %s --revision takes one or two values."
+msgstr ""
+
+#: bzrlib/builtins.py:2715
 msgid ""
 "List files in a tree.\n"
 "    "
 msgstr ""
 
 # help of 'recursive' option of 'ls' command
-#: bzrlib/builtins.py:2698
+#: bzrlib/builtins.py:2724
 msgid "Recurse into subdirectories."
 msgstr ""
 
 # help of 'from-root' option of 'ls' command
-#: bzrlib/builtins.py:2700
+#: bzrlib/builtins.py:2726
 msgid "Print paths relative to the root of the branch."
 msgstr ""
 
 # help of 'unknown' option of 'ls' command
-#: bzrlib/builtins.py:2702
+#: bzrlib/builtins.py:2728
 msgid "Print unknown files."
 msgstr ""
 
 # help of 'versioned' option of 'ls' command
-#: bzrlib/builtins.py:2703
+#: bzrlib/builtins.py:2729
 msgid "Print versioned files."
 msgstr ""
 
 # help of 'ignored' option of 'ls' command
-#: bzrlib/builtins.py:2706
+#: bzrlib/builtins.py:2732
 msgid "Print ignored files."
 msgstr ""
 
 # help of 'kind' option of 'ls' command
-#: bzrlib/builtins.py:2708
+#: bzrlib/builtins.py:2734
 msgid "List entries of a particular kind: file, directory, symlink."
 msgstr ""
 
-#: bzrlib/builtins.py:2820
+#: bzrlib/builtins.py:2747
+msgid "invalid kind specified"
+msgstr ""
+
+#: bzrlib/builtins.py:2750
+msgid "Cannot set both --verbose and --null"
+msgstr ""
+
+#: bzrlib/builtins.py:2759
+msgid "cannot specify both --from-root and PATH"
+msgstr ""
+
+#: bzrlib/builtins.py:2846
 msgid "Ignore specified files or patterns."
 msgstr ""
 
-#: bzrlib/builtins.py:2822
+#: bzrlib/builtins.py:2848
 msgid "See ``bzr help patterns`` for details on the syntax of patterns."
 msgstr ""
 
-#: bzrlib/builtins.py:2824
+#: bzrlib/builtins.py:2850
 msgid ""
 "If a .bzrignore file does not exist, the ignore command\n"
 "will create one and add the specified files or patterns to the newly\n"
@@ -1429,7 +1744,7 @@
 "the use of the ignore command will require an explicit add command."
 msgstr ""
 
-#: bzrlib/builtins.py:2830
+#: bzrlib/builtins.py:2856
 msgid ""
 "To remove patterns from the ignore list, edit the .bzrignore file.\n"
 "After adding, editing or deleting that file either indirectly by\n"
@@ -1437,7 +1752,7 @@
 "it."
 msgstr ""
 
-#: bzrlib/builtins.py:2835
+#: bzrlib/builtins.py:2861
 msgid ""
 "Bazaar also supports a global ignore file ~/.bazaar/ignore. On Windows\n"
 "the global ignore file can be found in the application data directory as\n"
@@ -1446,20 +1761,20 @@
 "can be edited directly using an editor."
 msgstr ""
 
-#: bzrlib/builtins.py:2841
+#: bzrlib/builtins.py:2867
 msgid ""
 "Patterns prefixed with '!' are exceptions to ignore patterns and take\n"
 "precedence over regular ignores.  Such exceptions are used to specify\n"
 "files that should be versioned which would otherwise be ignored."
 msgstr ""
 
-#: bzrlib/builtins.py:2845
+#: bzrlib/builtins.py:2871
 msgid ""
 "Patterns prefixed with '!!' act as regular ignore patterns, but have\n"
 "precedence over the '!' exception patterns."
 msgstr ""
 
-#: bzrlib/builtins.py:2848
+#: bzrlib/builtins.py:2874
 msgid ""
 ":Notes: \n"
 "    \n"
@@ -1467,63 +1782,63 @@
 "  the shell on Unix."
 msgstr ""
 
-#: bzrlib/builtins.py:2853
+#: bzrlib/builtins.py:2879
 msgid ""
 "* Ignore patterns starting with \"#\" act as comments in the ignore file.\n"
 "  To ignore patterns that begin with that character, use the \"RE:\" prefix."
 msgstr ""
 
-#: bzrlib/builtins.py:2856
+#: bzrlib/builtins.py:2882
 msgid ""
 ":Examples:\n"
 "    Ignore the top level Makefile::"
 msgstr ""
 
-#: bzrlib/builtins.py:2859
+#: bzrlib/builtins.py:2885
 msgid "        bzr ignore ./Makefile"
 msgstr ""
 
-#: bzrlib/builtins.py:2861
+#: bzrlib/builtins.py:2887
 msgid "    Ignore .class files in all directories...::"
 msgstr ""
 
-#: bzrlib/builtins.py:2863
+#: bzrlib/builtins.py:2889
 msgid "        bzr ignore \"*.class\""
 msgstr ""
 
-#: bzrlib/builtins.py:2865
+#: bzrlib/builtins.py:2891
 msgid "    ...but do not ignore \"special.class\"::"
 msgstr ""
 
-#: bzrlib/builtins.py:2867
+#: bzrlib/builtins.py:2893
 msgid "        bzr ignore \"!special.class\""
 msgstr ""
 
-#: bzrlib/builtins.py:2869
+#: bzrlib/builtins.py:2895
 msgid "    Ignore files whose name begins with the \"#\" character::"
 msgstr ""
 
-#: bzrlib/builtins.py:2871
+#: bzrlib/builtins.py:2897
 msgid "        bzr ignore \"RE:^#\""
 msgstr ""
 
-#: bzrlib/builtins.py:2873
+#: bzrlib/builtins.py:2899
 msgid "    Ignore .o files under the lib directory::"
 msgstr ""
 
-#: bzrlib/builtins.py:2875
+#: bzrlib/builtins.py:2901
 msgid "        bzr ignore \"lib/**/*.o\""
 msgstr ""
 
-#: bzrlib/builtins.py:2879
+#: bzrlib/builtins.py:2905
 msgid "        bzr ignore \"RE:lib/.*\\.o\""
 msgstr ""
 
-#: bzrlib/builtins.py:2881
+#: bzrlib/builtins.py:2907
 msgid "    Ignore everything but the \"debian\" toplevel directory::"
 msgstr ""
 
-#: bzrlib/builtins.py:2883
+#: bzrlib/builtins.py:2909
 msgid ""
 "        bzr ignore \"RE:(?!debian/).*\"\n"
 "    \n"
@@ -1536,61 +1851,91 @@
 msgstr ""
 
 # help of 'default-rules' option of 'ignore' command
-#: bzrlib/builtins.py:2897
+#: bzrlib/builtins.py:2923
 msgid "Display the default ignore rules that bzr uses."
 msgstr ""
 
-#: bzrlib/builtins.py:2945
+#: bzrlib/builtins.py:2935
+msgid "ignore requires at least one NAME_PATTERN or --default-rules."
+msgstr ""
+
+#: bzrlib/builtins.py:2946
+#, python-format
+msgid "Invalid ignore pattern found. %s"
+msgid_plural "Invalid ignore patterns found. %s"
+msgstr[0] ""
+msgstr[1] ""
+
+#: bzrlib/builtins.py:2955
+msgid "NAME_PATTERN should not be an absolute path"
+msgstr ""
+
+#: bzrlib/builtins.py:2968
+#, python-format
+msgid ""
+"Warning: the following files are version controlled and match your ignore "
+"pattern:\n"
+"%s\n"
+"These files will continue to be version controlled unless you 'bzr remove' "
+"them.\n"
+msgstr ""
+
+#: bzrlib/builtins.py:2975
 msgid "List ignored files and the patterns that matched them."
 msgstr ""
 
-#: bzrlib/builtins.py:2947
+#: bzrlib/builtins.py:2977
 msgid ""
 "List all the ignored files and the ignore pattern that caused the file to\n"
 "be ignored."
 msgstr ""
 
-#: bzrlib/builtins.py:2950
+#: bzrlib/builtins.py:2980
 msgid "Alternatively, to list just the files::"
 msgstr ""
 
-#: bzrlib/builtins.py:2952
+#: bzrlib/builtins.py:2982
 msgid "    bzr ls --ignored"
 msgstr ""
 
-#: bzrlib/builtins.py:2993
+#: bzrlib/builtins.py:3016
+#, python-format
+msgid "not a valid revision-number: %r"
+msgstr ""
+
+#: bzrlib/builtins.py:3023
 msgid "Export current or past revision to a destination directory or archive."
 msgstr ""
 
-#: bzrlib/builtins.py:2995
+#: bzrlib/builtins.py:3025
 msgid "If no revision is specified this exports the last committed revision."
 msgstr ""
 
-#: bzrlib/builtins.py:2997
+#: bzrlib/builtins.py:3027
 msgid ""
 "Format may be an \"exporter\" name, such as tar, tgz, tbz2.  If none is\n"
 "given, try to find the format with the extension. If no extension\n"
 "is found exports to a directory (equivalent to --format=dir)."
 msgstr ""
 
-#: bzrlib/builtins.py:3001
+#: bzrlib/builtins.py:3031
 msgid ""
 "If root is supplied, it will be used as the root directory inside\n"
 "container formats (tar, zip, etc). If it is not supplied it will default\n"
 "to the exported filename. The root option has no effect for 'dir' format."
 msgstr ""
 
-#: bzrlib/builtins.py:3005
+#: bzrlib/builtins.py:3035
 msgid ""
 "If branch is omitted then the branch containing the current working\n"
 "directory will be used."
 msgstr ""
 
-#: bzrlib/builtins.py:3008
+#: bzrlib/builtins.py:3038
 msgid "Note: Export of tree with non-ASCII filenames to zip is not supported."
 msgstr ""
 
-#: bzrlib/builtins.py:3010
+#: bzrlib/builtins.py:3040
 msgid ""
 "  =================       =========================\n"
 "  Supported formats       Autodetected by extension\n"
@@ -1604,51 +1949,64 @@
 msgstr ""
 
 # help of 'format' option of 'export' command
-#: bzrlib/builtins.py:3024
+#: bzrlib/builtins.py:3054
 msgid "Type of file to export to."
 msgstr ""
 
 # help of 'filters' option of 'export' command
-#: bzrlib/builtins.py:3027
+#: bzrlib/builtins.py:3057
 msgid "Apply content filters to export the convenient form."
 msgstr ""
 
 # help of 'root' option of 'export' command
-#: bzrlib/builtins.py:3031
+#: bzrlib/builtins.py:3061
 msgid "Name of the root directory inside the exported file."
 msgstr ""
 
 # help of 'per-file-timestamps' option of 'export' command
-#: bzrlib/builtins.py:3033
+#: bzrlib/builtins.py:3063
 msgid ""
 "Set modification time of files to that of the last revision in which it was "
 "changed."
 msgstr ""
 
-#: bzrlib/builtins.py:3057
+#: bzrlib/builtins.py:3083
+#, python-format
+msgid "Unsupported export format: %s"
+msgstr ""
+
+#: bzrlib/builtins.py:3087
 msgid "Write the contents of a file as of a given revision to standard output."
 msgstr ""
 
-#: bzrlib/builtins.py:3059
+#: bzrlib/builtins.py:3089
 msgid "If no revision is nominated, the last revision is used."
 msgstr ""
 
-#: bzrlib/builtins.py:3061
+#: bzrlib/builtins.py:3091
 msgid ""
 "Note: Take care to redirect standard output when using this command on a\n"
 "binary file."
 msgstr ""
 
 # help of 'filters' option of 'cat' command
-#: bzrlib/builtins.py:3068
+#: bzrlib/builtins.py:3098
 msgid "Apply content filters to display the convenience form."
 msgstr ""
 
-#: bzrlib/builtins.py:3139
+#: bzrlib/builtins.py:3109
+msgid "bzr cat --revision takes exactly one revision specifier"
+msgstr ""
+
+#: bzrlib/builtins.py:3134 bzrlib/builtins.py:3146
+msgid "{0!r} is not present in revision {1}"
+msgstr ""
+
+#: bzrlib/builtins.py:3169
 msgid "Commit changes into a new revision."
 msgstr ""
 
-#: bzrlib/builtins.py:3141
+#: bzrlib/builtins.py:3171
 msgid ""
 "An explanatory message needs to be given for each commit. This is\n"
 "often done by using the --message option (getting the message from the\n"
@@ -1658,44 +2016,44 @@
 "boilerplate text loaded into the editor, use the --show-diff option."
 msgstr ""
 
-#: bzrlib/builtins.py:3148
+#: bzrlib/builtins.py:3178
 msgid ""
 "By default, the entire tree is committed and the person doing the\n"
 "commit is assumed to be the author. These defaults can be overridden\n"
 "as explained below."
 msgstr ""
 
-#: bzrlib/builtins.py:3152
+#: bzrlib/builtins.py:3182
 msgid ":Selective commits:"
 msgstr ""
 
-#: bzrlib/builtins.py:3154
+#: bzrlib/builtins.py:3184
 msgid ""
 "  If selected files are specified, only changes to those files are\n"
 "  committed.  If a directory is specified then the directory and\n"
 "  everything within it is committed."
 msgstr ""
 
-#: bzrlib/builtins.py:3158
+#: bzrlib/builtins.py:3188
 msgid ""
 "  When excludes are given, they take precedence over selected files.\n"
 "  For example, to commit only changes within foo, but not changes\n"
 "  within foo/bar::"
 msgstr ""
 
-#: bzrlib/builtins.py:3162
+#: bzrlib/builtins.py:3192
 msgid "    bzr commit foo -x foo/bar"
 msgstr ""
 
-#: bzrlib/builtins.py:3164
+#: bzrlib/builtins.py:3194
 msgid "  A selective commit after a merge is not yet supported."
 msgstr ""
 
-#: bzrlib/builtins.py:3166
+#: bzrlib/builtins.py:3196
 msgid ":Custom authors:"
 msgstr ""
 
-#: bzrlib/builtins.py:3168
+#: bzrlib/builtins.py:3198
 msgid ""
 "  If the author of the change is not the same person as the committer,\n"
 "  you can specify the author's name using the --author option. The\n"
@@ -1705,11 +2063,11 @@
 "  author."
 msgstr ""
 
-#: bzrlib/builtins.py:3175
+#: bzrlib/builtins.py:3205
 msgid ":Checks:"
 msgstr ""
 
-#: bzrlib/builtins.py:3177
+#: bzrlib/builtins.py:3207
 msgid ""
 "  A common mistake is to forget to add a new file or directory before\n"
 "  running the commit command. The --strict option checks for unknown\n"
@@ -1718,18 +2076,18 @@
 "  for details."
 msgstr ""
 
-#: bzrlib/builtins.py:3183
+#: bzrlib/builtins.py:3213
 msgid ":Things to note:"
 msgstr ""
 
-#: bzrlib/builtins.py:3185
+#: bzrlib/builtins.py:3215
 msgid ""
 "  If you accidentially commit the wrong changes or make a spelling\n"
 "  mistake in the commit message say, you can use the uncommit command\n"
 "  to undo it. See ``bzr help uncommit`` for details."
 msgstr ""
 
-#: bzrlib/builtins.py:3189
+#: bzrlib/builtins.py:3219
 msgid ""
 "  Hooks can also be configured to run after a commit. This allows you\n"
 "  to trigger updates to external systems like bug trackers. The --fixes\n"
@@ -1738,100 +2096,169 @@
 msgstr ""
 
 # help of 'exclude' option of 'commit' command
-#: bzrlib/builtins.py:3199
+#: bzrlib/builtins.py:3229
 msgid "Do not consider changes made to a given path."
 msgstr ""
 
 # help of 'message' option of 'commit' command
-#: bzrlib/builtins.py:3202
+#: bzrlib/builtins.py:3232
 msgid "Description of the new revision."
 msgstr ""
 
 # help of 'unchanged' option of 'commit' command
-#: bzrlib/builtins.py:3205
+#: bzrlib/builtins.py:3235
 msgid "Commit even if nothing has changed."
 msgstr ""
 
 # help of 'file' option of 'commit' command
-#: bzrlib/builtins.py:3209
+#: bzrlib/builtins.py:3239
 msgid "Take commit message from this file."
 msgstr ""
 
 # help of 'strict' option of 'commit' command
-#: bzrlib/builtins.py:3211
+#: bzrlib/builtins.py:3241
 msgid "Refuse to commit if there are unknown files in the working tree."
 msgstr ""
 
 # help of 'commit-time' option of 'commit' command
-#: bzrlib/builtins.py:3214
+#: bzrlib/builtins.py:3244
 msgid ""
 "Manually set a commit time using commit date format, e.g. '2009-10-10 "
 "08:00:00 +0100'."
 msgstr ""
 
 # help of 'fixes' option of 'commit' command
-#: bzrlib/builtins.py:3217
+#: bzrlib/builtins.py:3247
 msgid "Mark a bug as being fixed by this revision (see \"bzr help bugs\")."
 msgstr ""
 
 # help of 'author' option of 'commit' command
-#: bzrlib/builtins.py:3220
+#: bzrlib/builtins.py:3250
 msgid "Set the author's name, if it's different from the committer."
 msgstr ""
 
 # help of 'local' option of 'commit' command
-#: bzrlib/builtins.py:3223
+#: bzrlib/builtins.py:3253
 msgid ""
 "Perform a local commit in a bound branch.  Local commits are not pushed to "
 "the master branch until a normal commit is performed."
 msgstr ""
 
 # help of 'show-diff' option of 'commit' command
-#: bzrlib/builtins.py:3229
+#: bzrlib/builtins.py:3259
 msgid ""
 "When no message is supplied, show the diff along with the status summary in "
 "the message editor."
 msgstr ""
 
 # help of 'lossy' option of 'commit' command
-#: bzrlib/builtins.py:3232
+#: bzrlib/builtins.py:3262
 msgid ""
 "When committing to a foreign version control system do not push data that "
 "can not be natively represented."
 msgstr ""
 
-#: bzrlib/builtins.py:3406
+#: bzrlib/builtins.py:3280
+#, python-format
+msgid ""
+"No tracker specified for bug %s. Use the form 'tracker:id' or specify a "
+"default bug tracker using the `bugtracker` option.\n"
+"See \"bzr help bugs\" for more information on this feature. Commit refused."
+msgstr ""
+
+#: bzrlib/builtins.py:3289
+#, python-format
+msgid ""
+"Invalid bug %s. Must be in the form of 'tracker:id'. See \"bzr help bugs\" "
+"for more information on this feature.\n"
+"Commit refused."
+msgstr ""
+
+#: bzrlib/builtins.py:3298
+#, python-format
+msgid "Unrecognized bug %s. Commit refused."
+msgstr ""
+
+#: bzrlib/builtins.py:3301
+#, python-format
+msgid ""
+"%s\n"
+"Commit refused."
+msgstr ""
+
+#: bzrlib/builtins.py:3325
+msgid "Could not parse --commit-time: "
+msgstr ""
+
+#: bzrlib/builtins.py:3365
+msgid "please specify either --message or --file"
+msgstr ""
+
+#: bzrlib/builtins.py:3394
+msgid "please specify a commit message with either --message or --file"
+msgstr ""
+
+#: bzrlib/builtins.py:3397
+msgid ""
+"Empty commit message specified. Please specify a commit message with either "
+"--message or --file or leave a blank message with --message \"\"."
+msgstr ""
+
+#: bzrlib/builtins.py:3417
+msgid ""
+"No changes to commit. Please 'bzr add' the files you want to commit, or use "
+"--unchanged to force an empty commit."
+msgstr ""
+
+#: bzrlib/builtins.py:3421
+msgid ""
+"Conflicts detected in working tree.  Use \"bzr conflicts\" to list, \"bzr "
+"resolve FILE\" to resolve."
+msgstr ""
+
+#: bzrlib/builtins.py:3425
+msgid "Commit refused because there are unknown files in the working tree."
+msgstr ""
+
+#: bzrlib/builtins.py:3428
+msgid ""
+"\n"
+"To commit to master branch, run update and then commit.\n"
+"You can also pass --local to commit to continue working disconnected."
+msgstr ""
+
+#: bzrlib/builtins.py:3436
 msgid ""
 "Validate working tree structure, branch consistency and repository history."
 msgstr ""
 
-#: bzrlib/builtins.py:3408
+#: bzrlib/builtins.py:3438
 msgid ""
 "This command checks various invariants about branch and repository storage\n"
 "to detect data corruption or bzr bugs."
 msgstr ""
 
-#: bzrlib/builtins.py:3411
+#: bzrlib/builtins.py:3441
 msgid ""
 "The working tree and branch checks will only give output if a problem is\n"
 "detected. The output fields of the repository check are:"
 msgstr ""
 
-#: bzrlib/builtins.py:3414
+#: bzrlib/builtins.py:3444
 msgid ""
 "revisions\n"
 "    This is just the number of revisions checked.  It doesn't\n"
 "    indicate a problem."
 msgstr ""
 
-#: bzrlib/builtins.py:3418
+#: bzrlib/builtins.py:3448
 msgid ""
 "versionedfiles\n"
 "    This is just the number of versionedfiles checked.  It\n"
 "    doesn't indicate a problem."
 msgstr ""
 
-#: bzrlib/builtins.py:3422
+#: bzrlib/builtins.py:3452
 msgid ""
 "unreferenced ancestors\n"
 "    Texts that are ancestors of other texts, but\n"
@@ -1839,14 +2266,14 @@
 "    subtle problem that Bazaar can work around."
 msgstr ""
 
-#: bzrlib/builtins.py:3427
+#: bzrlib/builtins.py:3457
 msgid ""
 "unique file texts\n"
 "    This is the total number of unique file contents\n"
 "    seen in the checked revisions.  It does not indicate a problem."
 msgstr ""
 
-#: bzrlib/builtins.py:3431
+#: bzrlib/builtins.py:3461
 msgid ""
 "repeated file texts\n"
 "    This is the total number of repeated texts seen\n"
@@ -1855,61 +2282,61 @@
 "    indicate a problem."
 msgstr ""
 
-#: bzrlib/builtins.py:3437
+#: bzrlib/builtins.py:3467
 msgid ""
 "If no restrictions are specified, all Bazaar data that is found at the "
 "given\n"
 "location will be checked."
 msgstr ""
 
-#: bzrlib/builtins.py:3440
+#: bzrlib/builtins.py:3470
 msgid ":Examples:"
 msgstr ""
 
-#: bzrlib/builtins.py:3442
+#: bzrlib/builtins.py:3472
 msgid "    Check the tree and branch at 'foo'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3444
+#: bzrlib/builtins.py:3474
 msgid "        bzr check --tree --branch foo"
 msgstr ""
 
-#: bzrlib/builtins.py:3446
+#: bzrlib/builtins.py:3476
 msgid "    Check only the repository at 'bar'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3448
+#: bzrlib/builtins.py:3478
 msgid "        bzr check --repo bar"
 msgstr ""
 
-#: bzrlib/builtins.py:3450
+#: bzrlib/builtins.py:3480
 msgid "    Check everything at 'baz'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3452
+#: bzrlib/builtins.py:3482
 msgid "        bzr check baz"
 msgstr ""
 
 # help of 'branch' option of 'check' command
-#: bzrlib/builtins.py:3458
+#: bzrlib/builtins.py:3488
 msgid "Check the branch related to the current directory."
 msgstr ""
 
 # help of 'repo' option of 'check' command
-#: bzrlib/builtins.py:3460
+#: bzrlib/builtins.py:3490
 msgid "Check the repository related to the current directory."
 msgstr ""
 
 # help of 'tree' option of 'check' command
-#: bzrlib/builtins.py:3462
+#: bzrlib/builtins.py:3492
 msgid "Check the working tree related to the current directory."
 msgstr ""
 
-#: bzrlib/builtins.py:3476
+#: bzrlib/builtins.py:3506
 msgid "Upgrade a repository, branch or working tree to a newer format."
 msgstr ""
 
-#: bzrlib/builtins.py:3478
+#: bzrlib/builtins.py:3508
 msgid ""
 "When the default format has changed after a major new release of\n"
 "Bazaar, you may be informed during certain operations that you\n"
@@ -1918,7 +2345,7 @@
 "with older repositories or with older versions of Bazaar."
 msgstr ""
 
-#: bzrlib/builtins.py:3484
+#: bzrlib/builtins.py:3514
 msgid ""
 "If you wish to upgrade to a particular format rather than the\n"
 "current default, that can be specified using the --format option.\n"
@@ -1928,7 +2355,7 @@
 "2.x default) so downgrading is not always possible."
 msgstr ""
 
-#: bzrlib/builtins.py:3491
+#: bzrlib/builtins.py:3521
 msgid ""
 "A backup.bzr.~#~ directory is created at the start of the conversion\n"
 "process (where # is a number). By default, this is left there on\n"
@@ -1939,7 +2366,7 @@
 "afterwards."
 msgstr ""
 
-#: bzrlib/builtins.py:3499
+#: bzrlib/builtins.py:3529
 msgid ""
 "If the location given is a shared repository, dependent branches\n"
 "are also converted provided the repository converts successfully.\n"
@@ -1947,132 +2374,158 @@
 "tried."
 msgstr ""
 
-#: bzrlib/builtins.py:3504
+#: bzrlib/builtins.py:3534
 msgid ""
 "For more information on upgrades, see the Bazaar Upgrade Guide,\n"
 "http://doc.bazaar.canonical.com/latest/en/upgrade-guide/."
 msgstr ""
 
 # help of 'format' option of 'upgrade' command
-#: bzrlib/builtins.py:3512
+#: bzrlib/builtins.py:3542
 msgid "Upgrade to a specific format.  See \"bzr help formats\" for details."
 msgstr ""
 
 # title of 'format' option of 'init' command
-#: bzrlib/builtins.py:3516
+#: bzrlib/builtins.py:3546
 msgid "Branch format"
 msgstr ""
 
 # help of 'clean' option of 'upgrade' command
-#: bzrlib/builtins.py:3518
+#: bzrlib/builtins.py:3548
 msgid "Remove the backup.bzr directory if successful."
 msgstr ""
 
-#: bzrlib/builtins.py:3535
+#: bzrlib/builtins.py:3565
 msgid "Show or set bzr user id."
 msgstr ""
 
-#: bzrlib/builtins.py:3537
+#: bzrlib/builtins.py:3567
 msgid ""
 ":Examples:\n"
 "    Show the email of the current user::"
 msgstr ""
 
-#: bzrlib/builtins.py:3540
+#: bzrlib/builtins.py:3570
 msgid "        bzr whoami --email"
 msgstr ""
 
-#: bzrlib/builtins.py:3542
+#: bzrlib/builtins.py:3572
 msgid "    Set the current user::"
 msgstr ""
 
-#: bzrlib/builtins.py:3544
+#: bzrlib/builtins.py:3574
 msgid "        bzr whoami \"Frank Chu <fchu@example.com>\""
 msgstr ""
 
 # help of 'email' option of 'whoami' command
-#: bzrlib/builtins.py:3548
+#: bzrlib/builtins.py:3578
 msgid "Display email address only."
 msgstr ""
 
 # help of 'branch' option of 'whoami' command
-#: bzrlib/builtins.py:3550
+#: bzrlib/builtins.py:3580
 msgid "Set identity for the current branch instead of globally."
 msgstr ""
 
-#: bzrlib/builtins.py:3596
+#: bzrlib/builtins.py:3604
+msgid "--email can only be used to display existing identity"
+msgstr ""
+
+#: bzrlib/builtins.py:3626
 msgid "Print or set the branch nickname."
 msgstr ""
 
-#: bzrlib/builtins.py:3598
+#: bzrlib/builtins.py:3628
 msgid ""
 "If unset, the tree root directory name is used as the nickname.\n"
 "To print the current nickname, execute with no argument."
 msgstr ""
 
-#: bzrlib/builtins.py:3601
+#: bzrlib/builtins.py:3631
 msgid ""
 "Bound branches use the nickname of its master branch unless it is set\n"
 "locally."
 msgstr ""
 
-#: bzrlib/builtins.py:3621
+#: bzrlib/builtins.py:3651
 msgid "Set/unset and display aliases."
 msgstr ""
 
-#: bzrlib/builtins.py:3623
+#: bzrlib/builtins.py:3653
 msgid ""
 ":Examples:\n"
 "    Show the current aliases::"
 msgstr ""
 
-#: bzrlib/builtins.py:3626
+#: bzrlib/builtins.py:3656
 msgid "        bzr alias"
 msgstr ""
 
-#: bzrlib/builtins.py:3628
+#: bzrlib/builtins.py:3658
 msgid "    Show the alias specified for 'll'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3630
+#: bzrlib/builtins.py:3660
 msgid "        bzr alias ll"
 msgstr ""
 
-#: bzrlib/builtins.py:3632
+#: bzrlib/builtins.py:3662
 msgid "    Set an alias for 'll'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3634
+#: bzrlib/builtins.py:3664
 msgid "        bzr alias ll=\"log --line -r-10..-1\""
 msgstr ""
 
-#: bzrlib/builtins.py:3636
+#: bzrlib/builtins.py:3666
 msgid "    To remove an alias for 'll'::"
 msgstr ""
 
-#: bzrlib/builtins.py:3638
+#: bzrlib/builtins.py:3668
 msgid "        bzr alias --remove ll"
 msgstr ""
 
 # help of 'remove' option of 'alias' command
-#: bzrlib/builtins.py:3643
+#: bzrlib/builtins.py:3673
 msgid "Remove the alias."
 msgstr ""
 
-#: bzrlib/builtins.py:3897
+#: bzrlib/builtins.py:3691
+msgid "bzr alias --remove expects an alias to remove."
+msgstr ""
+
+#: bzrlib/builtins.py:3863
+msgid "subunit not available. subunit needs to be installed to use --subunit."
+msgstr ""
+
+#: bzrlib/builtins.py:3880
+msgid ""
+"--benchmark is no longer supported from bzr 2.2; use bzr-usertest instead"
+msgstr ""
+
+#: bzrlib/builtins.py:3927
 msgid "Show version of bzr."
 msgstr ""
 
 # help of 'short' option of 'version' command
-#: bzrlib/builtins.py:3901
+#: bzrlib/builtins.py:3931
 msgid "Print just the version number."
 msgstr ""
 
-#: bzrlib/builtins.py:3948
+#: bzrlib/builtins.py:3950
+msgid "It sure does!\n"
+msgstr ""
+
+#: bzrlib/builtins.py:3974
+#, python-format
+msgid "merge base is revision %s\n"
+msgstr ""
+
+#: bzrlib/builtins.py:3978
 msgid "Perform a three-way merge."
 msgstr ""
 
-#: bzrlib/builtins.py:3950
+#: bzrlib/builtins.py:3980
 msgid ""
 "The source of the merge can be specified either in the form of a branch,\n"
 "or in the form of a path to a file containing a merge directive generated\n"
@@ -2083,20 +2536,20 @@
 "the current working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:3958
+#: bzrlib/builtins.py:3988
 msgid ""
 "When merging from a branch, by default bzr will try to merge in all new\n"
 "work from the other branch, automatically determining an appropriate base\n"
 "revision.  If this fails, you may need to give an explicit base."
 msgstr ""
 
-#: bzrlib/builtins.py:3962
+#: bzrlib/builtins.py:3992
 msgid ""
 "To pick a different ending revision, pass \"--revision OTHER\".  bzr will\n"
 "try to merge in all new work up to and including revision OTHER."
 msgstr ""
 
-#: bzrlib/builtins.py:3965
+#: bzrlib/builtins.py:3995
 msgid ""
 "If you specify two values, \"--revision BASE..OTHER\", only revisions BASE\n"
 "through OTHER, excluding BASE but including OTHER, will be merged.  If this\n"
@@ -2107,15 +2560,15 @@
 "changes from the other branch is not stored in the commit."
 msgstr ""
 
-#: bzrlib/builtins.py:3973
+#: bzrlib/builtins.py:4003
 msgid "Revision numbers are always relative to the source branch."
 msgstr ""
 
-#: bzrlib/builtins.py:3980
+#: bzrlib/builtins.py:4010
 msgid "Use bzr resolve when you have fixed a problem.  See also bzr conflicts."
 msgstr ""
 
-#: bzrlib/builtins.py:3982
+#: bzrlib/builtins.py:4012
 msgid ""
 "If there is no default branch set, the first merge will set it (use\n"
 "--no-remember to avoid setting it). After that, you can omit the branch\n"
@@ -2123,14 +2576,14 @@
 "only be saved if the remote location can be accessed."
 msgstr ""
 
-#: bzrlib/builtins.py:3987
+#: bzrlib/builtins.py:4017
 msgid ""
 "The results of the merge are placed into the destination working\n"
 "directory, where they can be reviewed (with bzr diff), tested, and then\n"
 "committed to record the result of the merge."
 msgstr ""
 
-#: bzrlib/builtins.py:3991
+#: bzrlib/builtins.py:4021
 msgid ""
 "merge refuses to run if there are any uncommitted changes, unless\n"
 "--force is given.  If --force is given, then the changes from the source \n"
@@ -2139,60 +2592,60 @@
 "merge revision which has more than two parents."
 msgstr ""
 
-#: bzrlib/builtins.py:3997
+#: bzrlib/builtins.py:4027
 msgid ""
 "If one would like to merge changes from the working tree of the other\n"
 "branch without merging any committed revisions, the --uncommitted option\n"
 "can be given."
 msgstr ""
 
-#: bzrlib/builtins.py:4001
+#: bzrlib/builtins.py:4031
 msgid ""
 "To select only some changes to merge, use \"merge -i\", which will prompt\n"
 "you to apply each diff hunk and file change, similar to \"shelve\"."
 msgstr ""
 
-#: bzrlib/builtins.py:4004
+#: bzrlib/builtins.py:4034
 msgid ""
 ":Examples:\n"
 "    To merge all new revisions from bzr.dev::"
 msgstr ""
 
-#: bzrlib/builtins.py:4007
+#: bzrlib/builtins.py:4037
 msgid "        bzr merge ../bzr.dev"
 msgstr ""
 
-#: bzrlib/builtins.py:4009
+#: bzrlib/builtins.py:4039
 msgid "    To merge changes up to and including revision 82 from bzr.dev::"
 msgstr ""
 
-#: bzrlib/builtins.py:4011
+#: bzrlib/builtins.py:4041
 msgid "        bzr merge -r 82 ../bzr.dev"
 msgstr ""
 
-#: bzrlib/builtins.py:4013
+#: bzrlib/builtins.py:4043
 msgid "    To merge the changes introduced by 82, without previous changes::"
 msgstr ""
 
-#: bzrlib/builtins.py:4015
+#: bzrlib/builtins.py:4045
 msgid "        bzr merge -r 81..82 ../bzr.dev"
 msgstr ""
 
-#: bzrlib/builtins.py:4017
+#: bzrlib/builtins.py:4047
 msgid "    To apply a merge directive contained in /tmp/merge::"
 msgstr ""
 
-#: bzrlib/builtins.py:4019
+#: bzrlib/builtins.py:4049
 msgid "        bzr merge /tmp/merge"
 msgstr ""
 
-#: bzrlib/builtins.py:4021
+#: bzrlib/builtins.py:4051
 msgid ""
 "    To create a merge revision with three parents from two branches\n"
 "    feature1a and feature1b:"
 msgstr ""
 
-#: bzrlib/builtins.py:4024
+#: bzrlib/builtins.py:4054
 msgid ""
 "        bzr merge ../feature1a\n"
 "        bzr merge ../feature1b --force\n"
@@ -2200,18 +2653,18 @@
 msgstr ""
 
 # help of 'force' option of 'merge' command
-#: bzrlib/builtins.py:4036
+#: bzrlib/builtins.py:4066
 msgid "Merge even if the destination tree has uncommitted changes."
 msgstr ""
 
 # help of 'uncommitted' option of 'merge' command
-#: bzrlib/builtins.py:4042
+#: bzrlib/builtins.py:4072
 msgid ""
 "Apply uncommitted changes from a working copy, instead of branch changes."
 msgstr ""
 
 # help of 'pull' option of 'merge' command
-#: bzrlib/builtins.py:4044
+#: bzrlib/builtins.py:4074
 msgid ""
 "If the destination is already completely merged into the source, pull from "
 "the source rather than merging.  When this happens, you do not need to "
@@ -2219,77 +2672,135 @@
 msgstr ""
 
 # help of 'directory' option of 'merge' command
-#: bzrlib/builtins.py:4049
+#: bzrlib/builtins.py:4079
 msgid ""
 "Branch to merge into, rather than the one containing the working directory."
 msgstr ""
 
 # help of 'preview' option of 'merge' command
-#: bzrlib/builtins.py:4051
+#: bzrlib/builtins.py:4081
 msgid "Instead of merging, show a diff of the merge."
 msgstr ""
 
 # help of 'interactive' option of 'merge' command
-#: bzrlib/builtins.py:4053
+#: bzrlib/builtins.py:4083
 msgid "Select changes interactively."
 msgstr ""
 
-#: bzrlib/builtins.py:4337
+#: bzrlib/builtins.py:4105
+msgid ""
+"Merging into empty branches not currently supported, https://bugs.launchpad."
+"net/bzr/+bug/308562"
+msgstr ""
+
+#: bzrlib/builtins.py:4132
+msgid "Cannot use --uncommitted with bundles or merge directives."
+msgstr ""
+
+#: bzrlib/builtins.py:4143
+msgid "Cannot use --uncommitted and --revision at the same time."
+msgstr ""
+
+#: bzrlib/builtins.py:4163
+msgid "merger: "
+msgstr ""
+
+#: bzrlib/builtins.py:4165 bzrlib/bundle/apply_bundle.py:67
+msgid "Nothing to do."
+msgstr ""
+
+#: bzrlib/builtins.py:4169
+msgid "Cannot pull individual files"
+msgstr ""
+
+#: bzrlib/builtins.py:4177
+msgid "This branch has no commits. (perhaps you would prefer 'bzr pull')"
+msgstr ""
+
+#: bzrlib/builtins.py:4235
+#, python-format
+msgid "Show-base is not supported for this merge type. %s"
+msgstr ""
+
+#: bzrlib/builtins.py:4244
+#, python-format
+msgid "Conflict reduction is not supported for merge type %s."
+msgstr ""
+
+#: bzrlib/builtins.py:4248
+msgid "Cannot do conflict reduction and show base."
+msgstr ""
+
+#: bzrlib/builtins.py:4359
+msgid "No location specified or remembered"
+msgstr ""
+
+#: bzrlib/builtins.py:4361
+msgid "{0} remembered {1} location {2}"
+msgstr ""
+
+#: bzrlib/builtins.py:4367
 msgid "Redo a merge."
 msgstr ""
 
-#: bzrlib/builtins.py:4339
+#: bzrlib/builtins.py:4369
 msgid ""
 "Use this if you want to try a different merge technique while resolving\n"
 "conflicts.  Some merge techniques are better than others, and remerge\n"
 "lets you try different ones on different files."
 msgstr ""
 
-#: bzrlib/builtins.py:4343
+#: bzrlib/builtins.py:4373
 msgid ""
 "The options for remerge have the same meaning and defaults as the ones for\n"
 "merge.  The difference is that remerge can (only) be run when there is a\n"
 "pending merge, and it lets you specify particular files."
 msgstr ""
 
-#: bzrlib/builtins.py:4347
+#: bzrlib/builtins.py:4377
 msgid ""
 ":Examples:\n"
 "    Re-do the merge of all conflicted files, and show the base text in\n"
 "    conflict regions, in addition to the usual THIS and OTHER texts::"
 msgstr ""
 
-#: bzrlib/builtins.py:4351
+#: bzrlib/builtins.py:4381
 msgid "        bzr remerge --show-base"
 msgstr ""
 
-#: bzrlib/builtins.py:4353
+#: bzrlib/builtins.py:4383
 msgid ""
 "    Re-do the merge of \"foobar\", using the weave merge algorithm, with\n"
 "    additional processing to reduce the size of conflict regions::"
 msgstr ""
 
-#: bzrlib/builtins.py:4356
+#: bzrlib/builtins.py:4386
 msgid "        bzr remerge --merge-type weave --reprocess foobar"
 msgstr ""
 
 # help of 'show-base' option of 'merge' command
-#: bzrlib/builtins.py:4363
+#: bzrlib/builtins.py:4393
 msgid "Show base revision text in conflicts."
 msgstr ""
 
-#: bzrlib/builtins.py:4431
+#: bzrlib/builtins.py:4405
+msgid ""
+"Sorry, remerge only works after normal merges.  Not cherrypicking or multi-"
+"merges."
+msgstr ""
+
+#: bzrlib/builtins.py:4461
 msgid "Revert files to a previous revision."
 msgstr ""
 
-#: bzrlib/builtins.py:4433
+#: bzrlib/builtins.py:4463
 msgid ""
 "Giving a list of files will revert only those files.  Otherwise, all files\n"
 "will be reverted.  If the revision is not specified with '--revision', the\n"
 "last committed revision is used."
 msgstr ""
 
-#: bzrlib/builtins.py:4437
+#: bzrlib/builtins.py:4467
 msgid ""
 "To remove only some changes, without reverting to a prior version, use\n"
 "merge instead.  For example, \"merge . -r -2..-3\" (don't forget the \".\")\n"
@@ -2298,14 +2809,14 @@
 "certain changes on a hunk-by-hunk basis, see the shelve command."
 msgstr ""
 
-#: bzrlib/builtins.py:4443
+#: bzrlib/builtins.py:4473
 msgid ""
 "By default, any files that have been manually changed will be backed up\n"
 "first.  (Files changed only by merge are not backed up.)  Backup files have\n"
 "'.~#~' appended to their name, where # is a number."
 msgstr ""
 
-#: bzrlib/builtins.py:4447
+#: bzrlib/builtins.py:4477
 msgid ""
 "When you provide files, you can use their current pathname or the pathname\n"
 "from the target revision.  So you can use revert to \"undelete\" a file by\n"
@@ -2313,7 +2824,7 @@
 "reverted."
 msgstr ""
 
-#: bzrlib/builtins.py:4452
+#: bzrlib/builtins.py:4482
 msgid ""
 "If you have newly added files since the target revision, they will be\n"
 "removed.  If the files to be removed have been changed, backups will be\n"
@@ -2321,7 +2832,7 @@
 "deleted."
 msgstr ""
 
-#: bzrlib/builtins.py:4457
+#: bzrlib/builtins.py:4487
 msgid ""
 "The working tree contains a list of revisions that have been merged but\n"
 "not yet committed. These revisions will be included as additional parents\n"
@@ -2333,7 +2844,7 @@
 "reverting any files."
 msgstr ""
 
-#: bzrlib/builtins.py:4466
+#: bzrlib/builtins.py:4496
 msgid ""
 "Using \"bzr revert --forget-merges\", it is possible to apply all of the\n"
 "changes from a branch in a single revision.  To do this, perform the merge\n"
@@ -2348,35 +2859,35 @@
 msgstr ""
 
 # help of 'no-backup' option of 'revert' command
-#: bzrlib/builtins.py:4480
+#: bzrlib/builtins.py:4510
 msgid "Do not save backups of reverted files."
 msgstr ""
 
 # help of 'forget-merges' option of 'revert' command
-#: bzrlib/builtins.py:4482
+#: bzrlib/builtins.py:4512
 msgid "Remove pending merge marker, without changing any files."
 msgstr ""
 
-#: bzrlib/builtins.py:4513
+#: bzrlib/builtins.py:4543
 msgid ""
 "Show help on a command or other topic.\n"
 "    "
 msgstr ""
 
 # help of 'long' option of 'help' command
-#: bzrlib/builtins.py:4518
+#: bzrlib/builtins.py:4548
 msgid "Show help on all commands."
 msgstr ""
 
-#: bzrlib/builtins.py:4547
+#: bzrlib/builtins.py:4577
 msgid "Show unmerged/unpulled revisions between two branches."
 msgstr ""
 
-#: bzrlib/builtins.py:4549
+#: bzrlib/builtins.py:4579
 msgid "OTHER_BRANCH may be local or remote."
 msgstr ""
 
-#: bzrlib/builtins.py:4551
+#: bzrlib/builtins.py:4581
 msgid ""
 "To filter on a range of revisions, you can use the command -r begin..end\n"
 "-r revision requests a specific revision, -r ..end or -r begin.. are\n"
@@ -2387,100 +2898,134 @@
 "    0 - no missing revisions"
 msgstr ""
 
-#: bzrlib/builtins.py:4561
+#: bzrlib/builtins.py:4591
 msgid ""
 "    Determine the missing revisions between this and the branch at the\n"
 "    remembered pull location::"
 msgstr ""
 
-#: bzrlib/builtins.py:4564
+#: bzrlib/builtins.py:4594
 msgid "        bzr missing"
 msgstr ""
 
-#: bzrlib/builtins.py:4566
+#: bzrlib/builtins.py:4596
 msgid "    Determine the missing revisions between this and another branch::"
 msgstr ""
 
-#: bzrlib/builtins.py:4568
+#: bzrlib/builtins.py:4598
 msgid "        bzr missing http://server/branch"
 msgstr ""
 
-#: bzrlib/builtins.py:4570
+#: bzrlib/builtins.py:4600
 msgid ""
 "    Determine the missing revisions up to a specific revision on the other\n"
 "    branch::"
 msgstr ""
 
-#: bzrlib/builtins.py:4573
+#: bzrlib/builtins.py:4603
 msgid "        bzr missing -r ..-10"
 msgstr ""
 
-#: bzrlib/builtins.py:4575
+#: bzrlib/builtins.py:4605
 msgid ""
 "    Determine the missing revisions up to a specific revision on this\n"
 "    branch::"
 msgstr ""
 
-#: bzrlib/builtins.py:4578
+#: bzrlib/builtins.py:4608
 msgid "        bzr missing --my-revision ..-10"
 msgstr ""
 
 # help of 'reverse' option of 'missing' command
-#: bzrlib/builtins.py:4585
+#: bzrlib/builtins.py:4615
 msgid "Reverse the order of revisions."
 msgstr ""
 
 # help of 'mine-only' option of 'missing' command
-#: bzrlib/builtins.py:4587
+#: bzrlib/builtins.py:4617
 msgid "Display changes in the local branch only."
 msgstr ""
 
 # help of 'this' option of 'missing' command
-#: bzrlib/builtins.py:4588
+#: bzrlib/builtins.py:4618
 msgid "Same as --mine-only."
 msgstr ""
 
 # help of 'theirs-only' option of 'missing' command
-#: bzrlib/builtins.py:4590
+#: bzrlib/builtins.py:4620
 msgid "Display changes in the remote branch only."
 msgstr ""
 
 # help of 'other' option of 'missing' command
-#: bzrlib/builtins.py:4591
+#: bzrlib/builtins.py:4621
 msgid "Same as --theirs-only."
 msgstr ""
 
 # help of 'revision' option of 'missing' command
-#: bzrlib/builtins.py:4596
+#: bzrlib/builtins.py:4626
 msgid ""
 "Filter on other branch revisions (inclusive). See \"help revisionspec\" for "
 "details."
 msgstr ""
 
 # help of 'my-revision' option of 'missing' command
-#: bzrlib/builtins.py:4600
+#: bzrlib/builtins.py:4630
 msgid ""
 "Filter on local branch revisions (inclusive). See \"help revisionspec\" for "
 "details."
 msgstr ""
 
-# help of 'include-merges' option of 'missing' command
-#: bzrlib/builtins.py:4603
+# help of 'include-merged' option of 'missing' command
+#: bzrlib/builtins.py:4633
 msgid "Show all revisions in addition to the mainline ones."
 msgstr ""
 
-#: bzrlib/builtins.py:4719
+#: bzrlib/builtins.py:4687
+msgid "No peer location known or specified."
+msgstr ""
+
+#: bzrlib/builtins.py:4691
+msgid "Using saved parent location: {0}\n"
+msgstr ""
+
+#: bzrlib/builtins.py:4724
+#, python-format
+msgid "You have %d extra revision:\n"
+msgid_plural "You have %d extra revisions:\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: bzrlib/builtins.py:4740
+#, python-format
+msgid "You are missing %d revision:\n"
+msgid_plural "You are missing %d revisions:\n"
+msgstr[0] ""
+msgstr[1] ""
+
+#: bzrlib/builtins.py:4752
+msgid "This branch has no new revisions.\n"
+msgstr ""
+
+#: bzrlib/builtins.py:4755
+msgid "Other branch has no new revisions.\n"
+msgstr ""
+
+#: bzrlib/builtins.py:4760
+msgid "Branches are up to date.\n"
+msgstr ""
+
+#: bzrlib/builtins.py:4771
 msgid "Compress the data within a repository."
 msgstr ""
 
-#: bzrlib/builtins.py:4721
+#: bzrlib/builtins.py:4773
 msgid ""
 "This operation compresses the data within a bazaar repository. As\n"
 "bazaar supports automatic packing of repository, this operation is\n"
 "normally not required to be done manually."
 msgstr ""
 
-#: bzrlib/builtins.py:4725
+#: bzrlib/builtins.py:4777
 msgid ""
 "During the pack operation, bazaar takes a backup of existing repository\n"
 "data, i.e. pack files. This backup is eventually removed by bazaar\n"
@@ -2489,7 +3034,7 @@
 "used."
 msgstr ""
 
-#: bzrlib/builtins.py:4731
+#: bzrlib/builtins.py:4783
 msgid ""
 "Warning: If you use --clean-obsolete-packs and your machine crashes\n"
 "during or immediately after repacking, you may be left with a state\n"
@@ -2498,25 +3043,25 @@
 msgstr ""
 
 # help of 'clean-obsolete-packs' option of 'pack' command
-#: bzrlib/builtins.py:4740
+#: bzrlib/builtins.py:4792
 msgid "Delete obsolete packs to save disk space."
 msgstr ""
 
-#: bzrlib/builtins.py:4754
+#: bzrlib/builtins.py:4806
 msgid "List the installed plugins."
 msgstr ""
 
-#: bzrlib/builtins.py:4756
+#: bzrlib/builtins.py:4808
 msgid ""
 "This command displays the list of installed plugins including\n"
 "version of plugin and a short description of each."
 msgstr ""
 
-#: bzrlib/builtins.py:4759
+#: bzrlib/builtins.py:4811
 msgid "--verbose shows the path where each plugin is located."
 msgstr ""
 
-#: bzrlib/builtins.py:4761
+#: bzrlib/builtins.py:4813
 msgid ""
 "A plugin is an external component for Bazaar that extends the\n"
 "revision control system, by adding or replacing code in Bazaar.\n"
@@ -2525,7 +3070,7 @@
 "customizing log output."
 msgstr ""
 
-#: bzrlib/builtins.py:4767
+#: bzrlib/builtins.py:4819
 msgid ""
 "See the Bazaar Plugin Guide <http://doc.bazaar.canonical.com/plugins/en/>\n"
 "for further information on plugins including where to find them and how to\n"
@@ -2533,94 +3078,122 @@
 "plugins using the Python programming language."
 msgstr ""
 
-#: bzrlib/builtins.py:4783
+#: bzrlib/builtins.py:4835
 msgid "Show testament (signing-form) of a revision."
 msgstr ""
 
 # help of 'long' option of 'testament' command
-#: bzrlib/builtins.py:4786
+#: bzrlib/builtins.py:4838
 msgid "Produce long-format testament."
 msgstr ""
 
 # help of 'strict' option of 'testament' command
-#: bzrlib/builtins.py:4788
+#: bzrlib/builtins.py:4840
 msgid "Produce a strict-format testament."
 msgstr ""
 
-#: bzrlib/builtins.py:4814
+#: bzrlib/builtins.py:4866
 msgid "Show the origin of each line in a file."
 msgstr ""
 
-#: bzrlib/builtins.py:4816
+#: bzrlib/builtins.py:4868
 msgid ""
 "This prints out the given file with an annotation on the left side\n"
 "indicating which revision, author and date introduced the change."
 msgstr ""
 
-#: bzrlib/builtins.py:4819
+#: bzrlib/builtins.py:4871
 msgid ""
 "If the origin is the same for a run of consecutive lines, it is\n"
 "shown only at the top, unless the --all option is given."
 msgstr ""
 
 # help of 'all' option of 'annotate' command
-#: bzrlib/builtins.py:4827
+#: bzrlib/builtins.py:4879
 msgid "Show annotations on all lines."
 msgstr ""
 
 # help of 'long' option of 'annotate' command
-#: bzrlib/builtins.py:4828
+#: bzrlib/builtins.py:4880
 msgid "Show commit date in annotations."
 msgstr ""
 
-#: bzrlib/builtins.py:4931
+#: bzrlib/builtins.py:4967
+msgid "Cannot sign a range of non-revision-history revisions"
+msgstr ""
+
+#: bzrlib/builtins.py:4979
+msgid "Please supply either one revision, or a range."
+msgstr ""
+
+#: bzrlib/builtins.py:4983
 msgid ""
 "Convert the current branch into a checkout of the supplied branch.\n"
 "If no branch is supplied, rebind to the last bound location."
 msgstr ""
 
-#: bzrlib/builtins.py:4934
+#: bzrlib/builtins.py:4986
 msgid ""
 "Once converted into a checkout, commits must succeed on the master branch\n"
 "before they will be applied to the local branch."
 msgstr ""
 
-#: bzrlib/builtins.py:4937
+#: bzrlib/builtins.py:4989
 msgid ""
 "Bound branches use the nickname of its master branch unless it is set\n"
 "locally, in which case binding will update the local nickname to be\n"
 "that of the master."
 msgstr ""
 
-#: bzrlib/builtins.py:4972
+#: bzrlib/builtins.py:5004
+msgid "No location supplied.  This format does not remember old locations."
+msgstr ""
+
+#: bzrlib/builtins.py:5009
+msgid "Branch is already bound"
+msgstr ""
+
+#: bzrlib/builtins.py:5011
+msgid "No location supplied and no previous location known"
+msgstr ""
+
+#: bzrlib/builtins.py:5017
+msgid "These branches have diverged. Try merging, and then bind again."
+msgstr ""
+
+#: bzrlib/builtins.py:5024
 msgid "Convert the current checkout into a regular branch."
 msgstr ""
 
-#: bzrlib/builtins.py:4974
+#: bzrlib/builtins.py:5026
 msgid ""
 "After unbinding, the local branch is considered independent and subsequent\n"
 "commits will be local only."
 msgstr ""
 
-#: bzrlib/builtins.py:4989
+#: bzrlib/builtins.py:5037
+msgid "Local branch is not bound"
+msgstr ""
+
+#: bzrlib/builtins.py:5041
 msgid "Remove the last committed revision."
 msgstr ""
 
-#: bzrlib/builtins.py:4991
+#: bzrlib/builtins.py:5043
 msgid ""
 "--verbose will print out what is being removed.\n"
 "--dry-run will go through all the motions, but not actually\n"
 "remove anything."
 msgstr ""
 
-#: bzrlib/builtins.py:4995
+#: bzrlib/builtins.py:5047
 msgid ""
 "If --revision is specified, uncommit revisions to leave the branch at the\n"
 "specified revision.  For example, \"bzr uncommit -r 15\" will leave the\n"
 "branch at revision 15."
 msgstr ""
 
-#: bzrlib/builtins.py:4999
+#: bzrlib/builtins.py:5051
 msgid ""
 "Uncommit leaves the working tree ready for a new commit.  The only change\n"
 "it may make is to restore any pending merges that were present before\n"
@@ -2628,48 +3201,75 @@
 msgstr ""
 
 # help of 'dry-run' option of 'uncommit' command
-#: bzrlib/builtins.py:5010
+#: bzrlib/builtins.py:5062
 msgid "Don't actually make changes."
 msgstr ""
 
 # help of 'force' option of 'uncommit' command
-#: bzrlib/builtins.py:5011
+#: bzrlib/builtins.py:5063
 msgid "Say yes to all questions."
 msgstr ""
 
 # help of 'keep-tags' option of 'uncommit' command
-#: bzrlib/builtins.py:5013
+#: bzrlib/builtins.py:5065
 msgid "Keep tags that point to removed revisions."
 msgstr ""
 
 # help of 'local' option of 'uncommit' command
-#: bzrlib/builtins.py:5015
+#: bzrlib/builtins.py:5067
 msgid "Only remove the commits from the local branch when in a checkout."
 msgstr ""
 
-#: bzrlib/builtins.py:5101
+#: bzrlib/builtins.py:5116
+msgid "No revisions to uncommit.\n"
+msgstr ""
+
+#: bzrlib/builtins.py:5131
+msgid "Dry-run, pretending to remove the above revisions.\n"
+msgstr ""
+
+#: bzrlib/builtins.py:5134
+msgid "The above revision(s) will be removed.\n"
+msgstr ""
+
+#: bzrlib/builtins.py:5138
+msgid "Uncommit these revisions"
+msgstr ""
+
+#: bzrlib/builtins.py:5141
+msgid "Canceled\n"
+msgstr ""
+
+#: bzrlib/builtins.py:5148
+#, python-format
+msgid ""
+"You can restore the old tip by running:\n"
+"  bzr pull . -r revid:%s\n"
+msgstr ""
+
+#: bzrlib/builtins.py:5153
 msgid "Break a dead lock."
 msgstr ""
 
-#: bzrlib/builtins.py:5103
+#: bzrlib/builtins.py:5155
 msgid ""
 "This command breaks a lock on a repository, branch, working directory or\n"
 "config file."
 msgstr ""
 
-#: bzrlib/builtins.py:5106
+#: bzrlib/builtins.py:5158
 msgid ""
 "CAUTION: Locks should only be broken when you are sure that the process\n"
 "holding the lock has been stopped."
 msgstr ""
 
-#: bzrlib/builtins.py:5109
+#: bzrlib/builtins.py:5161
 msgid ""
 "You can get information on what locks are open via the 'bzr info\n"
 "[location]' command."
 msgstr ""
 
-#: bzrlib/builtins.py:5112
+#: bzrlib/builtins.py:5164
 msgid ""
 ":Examples:\n"
 "    bzr break-lock\n"
@@ -2678,36 +3278,36 @@
 msgstr ""
 
 # help of 'config' option of 'break-lock' command
-#: bzrlib/builtins.py:5121
+#: bzrlib/builtins.py:5173
 msgid "LOCATION is the directory where the config lock is."
 msgstr ""
 
 # help of 'force' option of 'break-lock' command
-#: bzrlib/builtins.py:5123
+#: bzrlib/builtins.py:5175
 msgid "Do not ask for confirmation before breaking the lock."
 msgstr ""
 
-#: bzrlib/builtins.py:5159
+#: bzrlib/builtins.py:5211
 msgid "Run the bzr server."
 msgstr ""
 
 # help of 'inet' option of 'serve' command
-#: bzrlib/builtins.py:5165
+#: bzrlib/builtins.py:5217
 msgid "Serve on stdin/out for use from inetd or sshd."
 msgstr ""
 
 # title of 'protocol' option of 'serve' command
-#: bzrlib/builtins.py:5166
+#: bzrlib/builtins.py:5218
 msgid "protocol"
 msgstr ""
 
 # help of 'protocol' option of 'serve' command
-#: bzrlib/builtins.py:5167
+#: bzrlib/builtins.py:5219
 msgid "Protocol to serve."
 msgstr ""
 
 # help of 'port' option of 'serve' command
-#: bzrlib/builtins.py:5171
+#: bzrlib/builtins.py:5223
 msgid ""
 "Listen for connections on nominated port of the form [hostname:]portnumber.  "
 "Passing 0 as the port number will result in a dynamically allocated port.  "
@@ -2715,12 +3315,12 @@
 msgstr ""
 
 # help of 'directory' option of 'serve' command
-#: bzrlib/builtins.py:5177
+#: bzrlib/builtins.py:5229
 msgid "Serve contents of this directory."
 msgstr ""
 
 # help of 'allow-writes' option of 'serve' command
-#: bzrlib/builtins.py:5179
+#: bzrlib/builtins.py:5231
 msgid ""
 "By default the server is a readonly server.  Supplying --allow-writes "
 "enables write access to the contents of the served directory and below.  "
@@ -2729,83 +3329,110 @@
 "uncontrolled write access to your file system."
 msgstr ""
 
-#: bzrlib/builtins.py:5224
+#: bzrlib/builtins.py:5276
 msgid "Combine a tree into its containing tree."
 msgstr ""
 
-#: bzrlib/builtins.py:5226
+#: bzrlib/builtins.py:5278
 msgid "This command requires the target tree to be in a rich-root format."
 msgstr ""
 
-#: bzrlib/builtins.py:5228
+#: bzrlib/builtins.py:5280
 msgid ""
 "The TREE argument should be an independent tree, inside another tree, but\n"
 "not part of it.  (Such trees can be produced by \"bzr split\", but also by\n"
 "running \"bzr branch\" with the target inside a tree.)"
 msgstr ""
 
-#: bzrlib/builtins.py:5232
+#: bzrlib/builtins.py:5284
 msgid ""
 "The result is a combined tree, with the subtree no longer an independent\n"
 "part.  This is marked as a merge of the subtree into the containing tree,\n"
 "and all history is preserved."
 msgstr ""
 
-#: bzrlib/builtins.py:5270
+#: bzrlib/builtins.py:5302
+#, python-format
+msgid ""
+"Can't join trees because %s doesn't support rich root data.\n"
+"You can use bzr upgrade on the repository."
+msgstr ""
+
+#: bzrlib/builtins.py:5312 bzrlib/builtins.py:5318
+msgid "Cannot join {0}.  {1}"
+msgstr ""
+
+#: bzrlib/builtins.py:5322
 msgid "Split a subdirectory of a tree into a separate tree."
 msgstr ""
 
-#: bzrlib/builtins.py:5272
+#: bzrlib/builtins.py:5324
 msgid ""
 "This command will produce a target tree in a format that supports\n"
 "rich roots, like 'rich-root' or 'rich-root-pack'.  These formats cannot be\n"
 "converted into earlier formats like 'dirstate-tags'."
 msgstr ""
 
-#: bzrlib/builtins.py:5276
+#: bzrlib/builtins.py:5328
 msgid ""
 "The TREE argument should be a subdirectory of a working tree.  That\n"
 "subdirectory will be converted into an independent tree, with its own\n"
 "branch.  Commits in the top-level tree will not apply to the new subtree."
 msgstr ""
 
-#: bzrlib/builtins.py:5397
+#: bzrlib/builtins.py:5408
+msgid "No submit branch specified or known"
+msgstr ""
+
+#: bzrlib/builtins.py:5416 bzrlib/send.py:105
+msgid "No public branch specified or known"
+msgstr ""
+
+#: bzrlib/builtins.py:5421
+msgid "bzr merge-directive takes at most two one revision identifiers"
+msgstr ""
+
+#: bzrlib/builtins.py:5430
+msgid "No revisions to bundle."
+msgstr ""
+
+#: bzrlib/builtins.py:5449
 msgid "Mail or create a merge-directive for submitting changes."
 msgstr ""
 
-#: bzrlib/builtins.py:5399
+#: bzrlib/builtins.py:5451
 msgid "A merge directive provides many things needed for requesting merges:"
 msgstr ""
 
-#: bzrlib/builtins.py:5401
+#: bzrlib/builtins.py:5453
 msgid "* A machine-readable description of the merge to perform"
 msgstr ""
 
-#: bzrlib/builtins.py:5403
+#: bzrlib/builtins.py:5455
 msgid "* An optional patch that is a preview of the changes requested"
 msgstr ""
 
-#: bzrlib/builtins.py:5405
+#: bzrlib/builtins.py:5457
 msgid ""
 "* An optional bundle of revision data, so that the changes can be applied\n"
 "  directly from the merge directive, without retrieving data from a\n"
 "  branch."
 msgstr ""
 
-#: bzrlib/builtins.py:5409
+#: bzrlib/builtins.py:5461
 msgid ""
 "`bzr send` creates a compact data set that, when applied using bzr\n"
 "merge, has the same effect as merging from the source branch.  "
 msgstr ""
 
-#: bzrlib/builtins.py:5412
+#: bzrlib/builtins.py:5464
 msgid ""
 "By default the merge directive is self-contained and can be applied to any\n"
 "branch containing submit_branch in its ancestory without needing access to\n"
 "the source branch."
 msgstr ""
 
-#: bzrlib/builtins.py:5416
+#: bzrlib/builtins.py:5468
 msgid ""
 "If --no-bundle is specified, then Bazaar doesn't send the contents of the\n"
 "revisions, but only a structured request to merge from the\n"
@@ -2814,7 +3441,7 @@
 "included if known, so that people can check it later."
 msgstr ""
 
-#: bzrlib/builtins.py:5422
+#: bzrlib/builtins.py:5474
 msgid ""
 "The submit branch defaults to the parent of the source branch, but can be\n"
 "overridden.  Both submit branch and public branch will be remembered in\n"
@@ -2823,7 +3450,7 @@
 "be changed using --from."
 msgstr ""
 
-#: bzrlib/builtins.py:5428
+#: bzrlib/builtins.py:5480
 msgid ""
 "Both the submit branch and the public branch follow the usual behavior with\n"
 "respect to --remember: If there is no default location set, the first send\n"
@@ -2832,7 +3459,7 @@
 "--remember. The value will only be saved if the location can be accessed."
 msgstr ""
 
-#: bzrlib/builtins.py:5434
+#: bzrlib/builtins.py:5486
 msgid ""
 "In order to calculate those changes, bzr must analyse the submit branch.\n"
 "Therefore it is most efficient for the submit branch to be a local mirror.\n"
@@ -2840,20 +3467,20 @@
 "in the merge directive."
 msgstr ""
 
-#: bzrlib/builtins.py:5439
+#: bzrlib/builtins.py:5491
 msgid ""
 "The default behaviour is to send the merge directive by mail, unless -o is\n"
 "given, in which case it is sent to a file."
 msgstr ""
 
-#: bzrlib/builtins.py:5442
+#: bzrlib/builtins.py:5494
 msgid ""
 "Mail is sent using your preferred mail program.  This should be transparent\n"
 "on Windows (it uses MAPI).  On Unix, it requires the xdg-email utility.\n"
 "If the preferred client can't be found (or used), your editor will be used."
 msgstr ""
 
-#: bzrlib/builtins.py:5446
+#: bzrlib/builtins.py:5498
 msgid ""
 "To use a specific mail program, set the mail_client configuration option.\n"
 "(For Thunderbird 1.5, this works around some bugs.)  Supported values for\n"
@@ -2865,7 +3492,7 @@
 "supported clients."
 msgstr ""
 
-#: bzrlib/builtins.py:5453
+#: bzrlib/builtins.py:5505
 msgid ""
 "If mail is being sent, a to address is required.  This can be supplied\n"
 "either on the commandline, by setting the submit_to configuration\n"
@@ -2873,7 +3500,7 @@
 "in the submit branch."
 msgstr ""
 
-#: bzrlib/builtins.py:5458
+#: bzrlib/builtins.py:5510
 msgid ""
 "Two formats are currently supported: \"4\" uses revision bundle format 4 "
 "and\n"
@@ -2883,13 +3510,13 @@
 "format 1.  It is compatible with Bazaar 0.12 - 0.18."
 msgstr ""
 
-#: bzrlib/builtins.py:5464
+#: bzrlib/builtins.py:5516
 msgid ""
 "The merge directives created by bzr send may be applied using bzr merge or\n"
 "bzr pull by specifying a file containing a merge directive as the location."
 msgstr ""
 
-#: bzrlib/builtins.py:5467
+#: bzrlib/builtins.py:5519
 msgid ""
 "bzr send makes extensive use of public locations to map local locations "
 "into\n"
@@ -2898,90 +3525,90 @@
 msgstr ""
 
 # help of 'output' option of 'send' command
-#: bzrlib/builtins.py:5491
+#: bzrlib/builtins.py:5543
 msgid "Write merge directive to this file or directory; use - for stdout."
 msgstr ""
 
 # help of 'strict' option of 'send' command
-#: bzrlib/builtins.py:5495
+#: bzrlib/builtins.py:5547
 msgid ""
 "Refuse to send if there are uncommitted changes in the working tree, --no-"
 "strict disables the check."
 msgstr ""
 
 # help of 'mail-to' option of 'send' command
-#: bzrlib/builtins.py:5497
+#: bzrlib/builtins.py:5549
 msgid "Mail the request to this address."
 msgstr ""
 
 # help of 'body' option of 'send' command
-#: bzrlib/builtins.py:5501
+#: bzrlib/builtins.py:5553
 msgid "Body for the email."
 msgstr ""
 
 # help of 'no-bundle' option of 'send' command
-#: bzrlib/builtins.py:5554
+#: bzrlib/builtins.py:5606
 msgid "Do not include a bundle in the merge directive."
 msgstr ""
 
 # help of 'no-patch' option of 'send' command
-#: bzrlib/builtins.py:5555
+#: bzrlib/builtins.py:5607
 msgid "Do not include a preview patch in the merge directive."
 msgstr ""
 
 # help of 'remember' option of 'send' command
-#: bzrlib/builtins.py:5558
+#: bzrlib/builtins.py:5610
 msgid "Remember submit and public branch."
 msgstr ""
 
 # help of 'from' option of 'send' command
-#: bzrlib/builtins.py:5560
+#: bzrlib/builtins.py:5612
 msgid ""
 "Branch to generate the submission from, rather than the one containing the "
 "working directory."
 msgstr ""
 
 # title of 'format' option of 'send' command
-#: bzrlib/builtins.py:5570
+#: bzrlib/builtins.py:5622
 msgid "format"
 msgstr ""
 
 # help of 'format' option of 'send' command
-#: bzrlib/builtins.py:5571
+#: bzrlib/builtins.py:5623
 msgid "Use the specified output format."
 msgstr ""
 
-#: bzrlib/builtins.py:5593
+#: bzrlib/builtins.py:5645
 msgid "Create, remove or modify a tag naming a revision."
 msgstr ""
 
-#: bzrlib/builtins.py:5595
+#: bzrlib/builtins.py:5647
 msgid ""
 "Tags give human-meaningful names to revisions.  Commands that take a -r\n"
 "(--revision) option can be given -rtag:X, where X is any previously\n"
 "created tag."
 msgstr ""
 
-#: bzrlib/builtins.py:5599
+#: bzrlib/builtins.py:5651
 msgid ""
 "Tags are stored in the branch.  Tags are copied from one branch to another\n"
 "along when you branch, push, pull or merge."
 msgstr ""
 
-#: bzrlib/builtins.py:5602
+#: bzrlib/builtins.py:5654
 msgid ""
 "It is an error to give a tag name that already exists unless you pass\n"
 "--force, in which case the tag is moved to point to the new revision."
 msgstr ""
 
-#: bzrlib/builtins.py:5605
+#: bzrlib/builtins.py:5657
 msgid ""
 "To rename a tag (change the name but keep it on the same revsion), run "
 "``bzr\n"
 "tag new-name -r tag:old-name`` and then ``bzr tag --delete oldname``."
 msgstr ""
 
-#: bzrlib/builtins.py:5608
+#: bzrlib/builtins.py:5660
 msgid ""
 "If no tag name is specified it will be determined through the \n"
 "'automatic_tag_name' hook. This can e.g. be used to automatically tag\n"
@@ -2990,53 +3617,85 @@
 msgstr ""
 
 # help of 'delete' option of 'tag' command
-#: bzrlib/builtins.py:5618
+#: bzrlib/builtins.py:5670
 msgid "Delete this tag rather than placing it."
 msgstr ""
 
 # help of 'directory' option of 'tag' command
-#: bzrlib/builtins.py:5621
+#: bzrlib/builtins.py:5673
 msgid "Branch in which to place the tag."
 msgstr ""
 
 # help of 'force' option of 'tag' command
-#: bzrlib/builtins.py:5623
+#: bzrlib/builtins.py:5675
 msgid "Replace existing tags."
 msgstr ""
 
-#: bzrlib/builtins.py:5672
+#: bzrlib/builtins.py:5690
+msgid "No tag specified to delete."
+msgstr ""
+
+#: bzrlib/builtins.py:5692
+#, python-format
+msgid "Deleted tag %s."
+msgstr ""
+
+#: bzrlib/builtins.py:5697
+msgid "Tags can only be placed on a single revision, not on a range"
+msgstr ""
+
+#: bzrlib/builtins.py:5706
+msgid "Please specify a tag name."
+msgstr ""
+
+#: bzrlib/builtins.py:5714
+#, python-format
+msgid "Tag %s already exists for that revision."
+msgstr ""
+
+#: bzrlib/builtins.py:5718
+#, python-format
+msgid "Created tag %s."
+msgstr ""
+
+#: bzrlib/builtins.py:5720
+#, python-format
+msgid "Updated tag %s."
+msgstr ""
+
+#: bzrlib/builtins.py:5724
 msgid "List tags."
 msgstr ""
 
-#: bzrlib/builtins.py:5674
+#: bzrlib/builtins.py:5726
 msgid ""
 "This command shows a table of tag names and the revisions they reference."
 msgstr ""
 
 # help of 'directory' option of 'tags' command
-#: bzrlib/builtins.py:5680
+#: bzrlib/builtins.py:5732
 msgid "Branch whose tags should be displayed."
 msgstr ""
 
 # help of 'sort' option of 'tags' command
-#: bzrlib/builtins.py:5682
+#: bzrlib/builtins.py:5734
 msgid "Sort tags by different criteria."
 msgstr ""
 
 # title of 'sort' option of 'tags' command
-#: bzrlib/builtins.py:5682
+#: bzrlib/builtins.py:5734
 msgid "Sorting"
 msgstr ""
 
-#: bzrlib/builtins.py:5727
+#: bzrlib/builtins.py:5779
 msgid "Reconfigure the type of a bzr directory."
 msgstr ""
 
-#: bzrlib/builtins.py:5729
+#: bzrlib/builtins.py:5781
 msgid "A target configuration must be specified."
 msgstr ""
 
-#: bzrlib/builtins.py:5731
+#: bzrlib/builtins.py:5783
 msgid ""
 "For checkouts, the bind-to location will be auto-detected if not specified.\n"
 "The order of preference is\n"
@@ -3047,43 +3706,71 @@
 "If none of these is available, --bind-to must be specified."
 msgstr ""
 
-# title of 'target_type' option of 'reconfigure' command
-#: bzrlib/builtins.py:5745
-msgid "Target type"
-msgstr ""
-
-# help of 'target_type' option of 'reconfigure' command
-#: bzrlib/builtins.py:5746
-msgid "The type to reconfigure the directory to."
+# title of 'tree_type' option of 'reconfigure' command
+#: bzrlib/builtins.py:5797
+msgid "Tree type"
+msgstr ""
+
+# help of 'tree_type' option of 'reconfigure' command
+#: bzrlib/builtins.py:5798
+msgid "The relation between branch and tree."
+msgstr ""
+
+# title of 'repository_type' option of 'reconfigure' command
+#: bzrlib/builtins.py:5808
+msgid "Repository type"
+msgstr ""
+
+# help of 'repository_type' option of 'reconfigure' command
+#: bzrlib/builtins.py:5809
+msgid "Location fo the repository."
+msgstr ""
+
+# title of 'repository_trees' option of 'reconfigure' command
+#: bzrlib/builtins.py:5817
+msgid "Trees in Repository"
+msgstr ""
+
+# help of 'repository_trees' option of 'reconfigure' command
+#: bzrlib/builtins.py:5818
+msgid "Whether new branches in the repository have trees."
 msgstr ""
 
 # help of 'bind-to' option of 'reconfigure' command
-#: bzrlib/builtins.py:5761
+#: bzrlib/builtins.py:5825
 msgid "Branch to bind checkout to."
 msgstr ""
 
 # help of 'force' option of 'reconfigure' command
-#: bzrlib/builtins.py:5763
+#: bzrlib/builtins.py:5827
 msgid "Perform reconfiguration even if local changes will be lost."
 msgstr ""
 
 # help of 'stacked-on' option of 'reconfigure' command
-#: bzrlib/builtins.py:5766
+#: bzrlib/builtins.py:5830
 msgid "Reconfigure a branch to be stacked on another branch."
 msgstr ""
 
 # help of 'unstacked' option of 'reconfigure' command
-#: bzrlib/builtins.py:5770
+#: bzrlib/builtins.py:5834
 msgid ""
 "Reconfigure a branch to be unstacked.  This may require copying substantial "
 "data into it."
 msgstr ""
 
-#: bzrlib/builtins.py:5818
+#: bzrlib/builtins.py:5844
+msgid "Can't use both --stacked-on and --unstacked"
+msgstr ""
+
+#: bzrlib/builtins.py:5858
+msgid "No target configuration specified"
+msgstr ""
+
+#: bzrlib/builtins.py:5893
 msgid "Set the branch of a checkout and update."
 msgstr ""
 
-#: bzrlib/builtins.py:5820
+#: bzrlib/builtins.py:5895
 msgid ""
 "For lightweight checkouts, this changes the branch being referenced.\n"
 "For heavyweight checkouts, this checks that there are no local commits\n"
@@ -3091,17 +3778,17 @@
 "of the new location and binds to it."
 msgstr ""
 
-#: bzrlib/builtins.py:5825
+#: bzrlib/builtins.py:5900
 msgid ""
 "In both cases, the working tree is updated and uncommitted changes\n"
 "are merged. The user can commit or revert these as they desire."
 msgstr ""
 
-#: bzrlib/builtins.py:5828
+#: bzrlib/builtins.py:5903
 msgid "Pending merges need to be committed or reverted before using switch."
 msgstr ""
 
-#: bzrlib/builtins.py:5830
+#: bzrlib/builtins.py:5905
 msgid ""
 "The path to the branch to switch to can be specified relative to the parent\n"
 "directory of the current branch. For example, if you are currently in a\n"
@@ -3109,7 +3796,7 @@
 "/path/to/newbranch."
 msgstr ""
 
-#: bzrlib/builtins.py:5835
+#: bzrlib/builtins.py:5910
 msgid ""
 "Bound branches use the nickname of its master branch unless it is set\n"
 "locally, in which case switching will update the local nickname to be\n"
@@ -3117,20 +3804,28 @@
 msgstr ""
 
 # help of 'force' option of 'switch' command
-#: bzrlib/builtins.py:5843
+#: bzrlib/builtins.py:5918
 msgid "Switch even if local commits will be lost."
 msgstr ""
 
 # help of 'create-branch' option of 'switch' command
-#: bzrlib/builtins.py:5846
+#: bzrlib/builtins.py:5921
 msgid "Create the target branch from this one before switching to it."
 msgstr ""
 
-#: bzrlib/builtins.py:5915
+#: bzrlib/builtins.py:5933
+msgid "You must supply either a revision or a location"
+msgstr ""
+
+#: bzrlib/builtins.py:5944
+msgid "cannot create branch without source branch"
+msgstr ""
+
+#: bzrlib/builtins.py:5990
 msgid "Manage filtered views."
 msgstr ""
 
-#: bzrlib/builtins.py:5917
+#: bzrlib/builtins.py:5992
 msgid ""
 "Views provide a mask over the tree so that users can focus on\n"
 "a subset of a tree when doing their work. After creating a view,\n"
@@ -3140,7 +3835,7 @@
 "must be within the current view."
 msgstr ""
 
-#: bzrlib/builtins.py:5924
+#: bzrlib/builtins.py:5999
 msgid ""
 "In most cases, a view has a short life-span: it is created to make\n"
 "a selected change and is deleted once that change is committed.\n"
@@ -3148,7 +3843,7 @@
 "and switch between them."
 msgstr ""
 
-#: bzrlib/builtins.py:5929
+#: bzrlib/builtins.py:6004
 msgid ""
 "To disable the current view without deleting it, you can switch to\n"
 "the pseudo view called ``off``. This can be useful when you need\n"
@@ -3156,131 +3851,197 @@
 "want to switch back to your view after that."
 msgstr ""
 
-#: bzrlib/builtins.py:5934
+#: bzrlib/builtins.py:6009
 msgid ""
 ":Examples:\n"
 "  To define the current view::"
 msgstr ""
 
-#: bzrlib/builtins.py:5937
+#: bzrlib/builtins.py:6012
 msgid "    bzr view file1 dir1 ..."
 msgstr ""
 
-#: bzrlib/builtins.py:5939
+#: bzrlib/builtins.py:6014
 msgid "  To list the current view::"
 msgstr ""
 
-#: bzrlib/builtins.py:5941
+#: bzrlib/builtins.py:6016
 msgid "    bzr view"
 msgstr ""
 
-#: bzrlib/builtins.py:5943
+#: bzrlib/builtins.py:6018
 msgid "  To delete the current view::"
 msgstr ""
 
-#: bzrlib/builtins.py:5945
+#: bzrlib/builtins.py:6020
 msgid "    bzr view --delete"
 msgstr ""
 
-#: bzrlib/builtins.py:5947
+#: bzrlib/builtins.py:6022
 msgid "  To disable the current view without deleting it::"
 msgstr ""
 
-#: bzrlib/builtins.py:5949
+#: bzrlib/builtins.py:6024
 msgid "    bzr view --switch off"
 msgstr ""
 
-#: bzrlib/builtins.py:5951
+#: bzrlib/builtins.py:6026
 msgid "  To define a named view and switch to it::"
 msgstr ""
 
-#: bzrlib/builtins.py:5953
+#: bzrlib/builtins.py:6028
 msgid "    bzr view --name view-name file1 dir1 ..."
 msgstr ""
 
-#: bzrlib/builtins.py:5955
+#: bzrlib/builtins.py:6030
 msgid "  To list a named view::"
 msgstr ""
 
-#: bzrlib/builtins.py:5957
+#: bzrlib/builtins.py:6032
 msgid "    bzr view --name view-name"
 msgstr ""
 
-#: bzrlib/builtins.py:5959
+#: bzrlib/builtins.py:6034
 msgid "  To delete a named view::"
 msgstr ""
 
-#: bzrlib/builtins.py:5961
+#: bzrlib/builtins.py:6036
 msgid "    bzr view --name view-name --delete"
 msgstr ""
 
-#: bzrlib/builtins.py:5963
+#: bzrlib/builtins.py:6038
 msgid "  To switch to a named view::"
 msgstr ""
 
-#: bzrlib/builtins.py:5965
+#: bzrlib/builtins.py:6040
 msgid "    bzr view --switch view-name"
 msgstr ""
 
-#: bzrlib/builtins.py:5967
+#: bzrlib/builtins.py:6042
 msgid "  To list all views defined::"
 msgstr ""
 
-#: bzrlib/builtins.py:5969
+#: bzrlib/builtins.py:6044
 msgid "    bzr view --all"
 msgstr ""
 
-#: bzrlib/builtins.py:5971
+#: bzrlib/builtins.py:6046
 msgid "  To delete all views::"
 msgstr ""
 
-#: bzrlib/builtins.py:5973
+#: bzrlib/builtins.py:6048
 msgid "    bzr view --delete --all"
 msgstr ""
 
 # help of 'all' option of 'view' command
-#: bzrlib/builtins.py:5980
+#: bzrlib/builtins.py:6055
 msgid "Apply list or delete action to all views."
 msgstr ""
 
 # help of 'delete' option of 'view' command
-#: bzrlib/builtins.py:5983
+#: bzrlib/builtins.py:6058
 msgid "Delete the view."
 msgstr ""
 
 # help of 'name' option of 'view' command
-#: bzrlib/builtins.py:5986
+#: bzrlib/builtins.py:6061
 msgid "Name of the view to define, list or delete."
 msgstr ""
 
 # help of 'switch' option of 'view' command
-#: bzrlib/builtins.py:5990
+#: bzrlib/builtins.py:6065
 msgid "Name of the view to switch to."
 msgstr ""
 
+#: bzrlib/builtins.py:6084
+msgid "Both --delete and a file list specified"
+msgstr ""
+
+#: bzrlib/builtins.py:6087
+msgid "Both --delete and --switch specified"
+msgstr ""
+
 #: bzrlib/builtins.py:6090
+msgid "Deleted all views.\n"
+msgstr ""
+
+#: bzrlib/builtins.py:6092
+msgid "No current view to delete"
+msgstr ""
+
+#: bzrlib/builtins.py:6095
+#, python-format
+msgid "Deleted '%s' view.\n"
+msgstr ""
+
+#: bzrlib/builtins.py:6099
+msgid "Both --switch and a file list specified"
+msgstr ""
+
+#: bzrlib/builtins.py:6102
+msgid "Both --switch and --all specified"
+msgstr ""
+
+#: bzrlib/builtins.py:6105
+msgid "No current view to disable"
+msgstr ""
+
+#: bzrlib/builtins.py:6107
+#, python-format
+msgid "Disabled '%s' view.\n"
+msgstr ""
+
+#: bzrlib/builtins.py:6111 bzrlib/builtins.py:6133
+msgid "Using '{0}' view: {1}\n"
+msgstr ""
+
+#: bzrlib/builtins.py:6114
+msgid "Views defined:\n"
+msgstr ""
+
+#: bzrlib/builtins.py:6123
+msgid "No views defined.\n"
+msgstr ""
+
+#: bzrlib/builtins.py:6130
+msgid "Cannot change the 'off' pseudo view"
+msgstr ""
+
+#: bzrlib/builtins.py:6138
+msgid "No current view.\n"
+msgstr ""
+
+#: bzrlib/builtins.py:6141
+msgid "'{0}' view is: {1}\n"
+msgstr ""
+
+#: bzrlib/builtins.py:6161
+msgid "    <no hooks installed>\n"
+msgstr ""
+
+#: bzrlib/builtins.py:6165
 msgid "Remove a branch."
 msgstr ""
 
-#: bzrlib/builtins.py:6092
+#: bzrlib/builtins.py:6167
 msgid ""
 "This will remove the branch from the specified location but \n"
 "will keep any working tree or repository in place."
 msgstr ""
 
-#: bzrlib/builtins.py:6097
+#: bzrlib/builtins.py:6172
 msgid "  Remove the branch at repo/trunk::"
 msgstr ""
 
-#: bzrlib/builtins.py:6099
+#: bzrlib/builtins.py:6174
 msgid "    bzr remove-branch repo/trunk"
 msgstr ""
 
-#: bzrlib/builtins.py:6115
+#: bzrlib/builtins.py:6190
 msgid "Temporarily set aside some changes from the current tree."
 msgstr ""
 
-#: bzrlib/builtins.py:6117
+#: bzrlib/builtins.py:6192
 msgid ""
 "Shelve allows you to temporarily put changes you've made \"on the shelf\",\n"
 "ie. out of the way, until a later time when you can bring them back from\n"
@@ -3289,11 +4050,11 @@
 "will they survive its deletion."
 msgstr ""
 
-#: bzrlib/builtins.py:6123
+#: bzrlib/builtins.py:6198
 msgid "If shelve --list is specified, previously-shelved changes are listed."
 msgstr ""
 
-#: bzrlib/builtins.py:6125
+#: bzrlib/builtins.py:6200
 msgid ""
 "Shelve is intended to help separate several sets of changes that have\n"
 "been inappropriately mingled.  If you just want to get rid of all changes\n"
@@ -3301,35 +4062,35 @@
 "shelve all text changes at once, use shelve --all."
 msgstr ""
 
-#: bzrlib/builtins.py:6130
+#: bzrlib/builtins.py:6205
 msgid ""
 "If filenames are specified, only the changes to those files will be\n"
 "shelved. Other files will be left untouched."
 msgstr ""
 
-#: bzrlib/builtins.py:6133
+#: bzrlib/builtins.py:6208
 msgid ""
 "If a revision is specified, changes since that revision will be shelved."
 msgstr ""
 
-#: bzrlib/builtins.py:6135
+#: bzrlib/builtins.py:6210
 msgid ""
 "You can put multiple items on the shelf, and by default, 'unshelve' will\n"
 "restore the most recently shelved changes."
 msgstr ""
 
-#: bzrlib/builtins.py:6138
+#: bzrlib/builtins.py:6213
 msgid ""
 "For complicated changes, it is possible to edit the changes in a separate\n"
 "editor program to decide what the file remaining in the working copy\n"
 "should look like.  To do this, add the configuration option"
 msgstr ""
 
-#: bzrlib/builtins.py:6142
+#: bzrlib/builtins.py:6217
 msgid "    change_editor = PROGRAM @new_path @old_path"
 msgstr ""
 
-#: bzrlib/builtins.py:6144
+#: bzrlib/builtins.py:6219
 msgid ""
 "where @new_path is replaced with the path of the new version of the \n"
 "file and @old_path is replaced with the path of the old version of \n"
@@ -3339,35 +4100,39 @@
 msgstr ""
 
 # help of 'all' option of 'shelve' command
-#: bzrlib/builtins.py:6156
+#: bzrlib/builtins.py:6231
 msgid "Shelve all changes."
 msgstr ""
 
 # help of 'writer' option of 'shelve' command
-#: bzrlib/builtins.py:6158
+#: bzrlib/builtins.py:6233
 msgid "Method to use for writing diffs."
 msgstr ""
 
 # title of 'writer' option of 'shelve' command
-#: bzrlib/builtins.py:6158
+#: bzrlib/builtins.py:6233
 msgid "writer"
 msgstr ""
 
 # help of 'list' option of 'shelve' command
-#: bzrlib/builtins.py:6162
+#: bzrlib/builtins.py:6237
 msgid "List shelved changes."
 msgstr ""
 
 # help of 'destroy' option of 'shelve' command
-#: bzrlib/builtins.py:6164
+#: bzrlib/builtins.py:6239
 msgid "Destroy removed changes instead of shelving them."
 msgstr ""
 
-#: bzrlib/builtins.py:6204
+#: bzrlib/builtins.py:6268
+msgid "No shelved changes."
+msgstr ""
+
+#: bzrlib/builtins.py:6279
 msgid "Restore shelved changes."
 msgstr ""
 
-#: bzrlib/builtins.py:6206
+#: bzrlib/builtins.py:6281
 msgid ""
 "By default, the most recently shelved changes are restored. However if you\n"
 "specify a shelf by id those changes will be restored instead.  This works\n"
@@ -3375,91 +4140,282 @@
 msgstr ""
 
 # help of 'action' option of 'unshelve' command
-#: bzrlib/builtins.py:6215
+#: bzrlib/builtins.py:6290
 msgid "The action to perform."
 msgstr ""
 
-#: bzrlib/builtins.py:6237
+#: bzrlib/builtins.py:6312
 msgid "Remove unwanted files from working tree."
 msgstr ""
 
-#: bzrlib/builtins.py:6239
+#: bzrlib/builtins.py:6314
 msgid ""
 "By default, only unknown files, not ignored files, are deleted.  Versioned\n"
 "files are never deleted."
 msgstr ""
 
-#: bzrlib/builtins.py:6242
+#: bzrlib/builtins.py:6317
 msgid ""
 "Another class is 'detritus', which includes files emitted by bzr during\n"
 "normal operations and selftests.  (The value of these files decreases with\n"
 "time.)"
 msgstr ""
 
-#: bzrlib/builtins.py:6246
+#: bzrlib/builtins.py:6321
 msgid ""
 "If no options are specified, unknown files are deleted.  Otherwise, option\n"
 "flags are respected, and may be combined."
 msgstr ""
 
-#: bzrlib/builtins.py:6249
+#: bzrlib/builtins.py:6324
 msgid "To check what clean-tree will do, use --dry-run."
 msgstr ""
 
 # help of 'ignored' option of 'clean-tree' command
-#: bzrlib/builtins.py:6252
+#: bzrlib/builtins.py:6327
 msgid "Delete all ignored files."
 msgstr ""
 
 # help of 'detritus' option of 'clean-tree' command
-#: bzrlib/builtins.py:6253
+#: bzrlib/builtins.py:6328
 msgid ""
 "Delete conflict files, merge and revert backups, and failed selftest dirs."
 msgstr ""
 
 # help of 'unknown' option of 'clean-tree' command
-#: bzrlib/builtins.py:6256
+#: bzrlib/builtins.py:6331
 msgid "Delete files unknown to bzr (default)."
 msgstr ""
 
 # help of 'dry-run' option of 'clean-tree' command
-#: bzrlib/builtins.py:6257
+#: bzrlib/builtins.py:6332
 msgid "Show files to delete instead of deleting them."
 msgstr ""
 
 # help of 'force' option of 'clean-tree' command
-#: bzrlib/builtins.py:6259
+#: bzrlib/builtins.py:6334
 msgid "Do not prompt before deleting."
 msgstr ""
 
-#: bzrlib/cmd_version_info.py:50
+#: bzrlib/bundle/__init__.py:57
+msgid "A directory cannot be a bundle"
+msgstr ""
+
+#: bzrlib/bundle/serializer/v4.py:326
+#, python-format
+msgid "Bundling %d revision."
+msgid_plural "Bundling %d revisions."
+msgstr[0] ""
+msgstr[1] ""
+
+#: bzrlib/bzrdir.py:636
+msgid ""
+"making backup of {0}\n"
+"  to {1}"
+msgstr ""
+
+#: bzrlib/bzrdir.py:659
+msgid "renamed {0} to {1}"
+msgstr ""
+
+#: bzrlib/bzrdir.py:851
+msgid "{0} is{1} redirected to {2}"
+msgstr ""
+
+#: bzrlib/bzrdir.py:1727
+#, python-format
+msgid ""
+"Source repository format does not support stacking, using format:\n"
+"  %s"
+msgstr ""
+
+#: bzrlib/bzrdir.py:1747
+#, python-format
+msgid ""
+"Source branch format does not support stacking, using format:\n"
+"  %s"
+msgstr ""
+
+#: bzrlib/bzrdir.py:1858
+msgid "starting repository conversion"
+msgstr ""
+
+#: bzrlib/check.py:106
+msgid "check"
+msgstr ""
+
+#: bzrlib/check.py:108
+msgid "checking revisions"
+msgstr ""
+
+#: bzrlib/check.py:110
+msgid "checking commit contents"
+msgstr ""
+
+#: bzrlib/check.py:112
+msgid "checking file graphs"
+msgstr ""
+
+#: bzrlib/check.py:116
+msgid "checking branches and trees"
+msgstr ""
+
+#: bzrlib/check.py:203
+msgid "checked repository {0} format {1}"
+msgstr ""
+
+#: bzrlib/check.py:206
+#, python-format
+msgid "%6d revisions"
+msgstr ""
+
+#: bzrlib/check.py:207
+#, python-format
+msgid "%6d file-ids"
+msgstr ""
+
+#: bzrlib/check.py:209
+#, python-format
+msgid "%6d unreferenced text versions"
+msgstr ""
+
+#: bzrlib/check.py:213
+msgid "unreferenced version: {{{0}}} in {1}"
+msgstr ""
+
+#: bzrlib/check.py:216
+#, python-format
+msgid "%6d revisions are missing inventory_sha1"
+msgstr ""
+
+#: bzrlib/check.py:219
+#, python-format
+msgid "%6d revisions are mentioned but not present"
+msgstr ""
+
+#: bzrlib/check.py:222
+#, python-format
+msgid "%6d ghost revisions"
+msgstr ""
+
+#: bzrlib/check.py:227
+#, python-format
+msgid "%6d revisions missing parents in ancestry"
+msgstr ""
+
+#: bzrlib/check.py:231
+#, python-format
+msgid "      %s should be in the ancestry for:"
+msgstr ""
+
+#: bzrlib/check.py:235
+#, python-format
+msgid "%6d inconsistent parents"
+msgstr ""
+
+#: bzrlib/check.py:239
+msgid "      * {0} version {1} has parents {2!r} but should have {3!r}"
+msgstr ""
+
+#: bzrlib/check.py:245
+#, python-format
+msgid "%6d revisions have incorrect parents in the revision index"
+msgstr ""
+
+#: bzrlib/check.py:251
+msgid "       {0} has wrong parents in index: {1!r} should be {2!r}"
+msgstr ""
+
+#: bzrlib/check.py:265
+msgid "Mismatched internal revid {{{0}}} and index revid {{{1}}}"
+msgstr ""
+
+#: bzrlib/check.py:294
+msgid ""
+"Multiple expected sha1s for {0}. {{{1}}} expects {{{2}}}, {{{3}}} expects "
+"{{{4}}}"
+msgstr ""
+
+#: bzrlib/check.py:352
+#, python-format
+msgid "Checking branch at '%s'."
+msgstr ""
+
+#: bzrlib/check.py:372
+#, python-format
+msgid "Checking working tree at '%s'."
+msgstr ""
+
+#: bzrlib/check.py:425 bzrlib/check.py:439
+msgid "No branch found at specified location."
+msgstr ""
+
+#: bzrlib/check.py:427 bzrlib/check.py:437
+msgid "No working tree found at specified location."
+msgstr ""
+
+#: bzrlib/check.py:430
+#, python-format
+msgid "Checking repository at '%s'."
+msgstr ""
+
+#: bzrlib/check.py:441
+msgid "No repository found at specified location."
+msgstr ""
+
+#: bzrlib/clean_tree.py:62
+msgid "Nothing to delete."
+msgstr ""
+
+#: bzrlib/clean_tree.py:108
+#, python-format
+msgid "unable to remove %s"
+msgstr ""
+
+#: bzrlib/clean_tree.py:112
+msgid "deleting paths:"
+msgstr ""
+
+#: bzrlib/clean_tree.py:126
+msgid "unable to remove \"{0}\": {1}."
+msgstr ""
+
+#: bzrlib/clean_tree.py:131
+msgid "No files deleted."
+msgstr ""
+
+#: bzrlib/cmd_version_info.py:45
+msgid "No known version info format {0}. Supported types are: {1}"
+msgstr ""
+
+#: bzrlib/cmd_version_info.py:51
 msgid "Show version information about this tree."
 msgstr ""
 
-#: bzrlib/cmd_version_info.py:52
+#: bzrlib/cmd_version_info.py:53
 msgid ""
 "You can use this command to add information about version into\n"
 "source code of an application. The output can be in one of the\n"
 "supported formats or in a custom format based on a template."
 msgstr ""
 
-#: bzrlib/cmd_version_info.py:56
+#: bzrlib/cmd_version_info.py:57
 msgid "For example::"
 msgstr ""
 
-#: bzrlib/cmd_version_info.py:58
+#: bzrlib/cmd_version_info.py:59
 msgid ""
 "  bzr version-info --custom \\\n"
 "    --template=\"#define VERSION_INFO \\\"Project 1.2.3 (r{revno})\\\"\\n\""
 msgstr ""
 
-#: bzrlib/cmd_version_info.py:61
+#: bzrlib/cmd_version_info.py:62
 msgid ""
 "will produce a C header file with formatted string containing the\n"
 "current revision number. Other supported variables in templates are:"
 msgstr ""
 
-#: bzrlib/cmd_version_info.py:64
+#: bzrlib/cmd_version_info.py:65
 msgid ""
 "  * {date} - date of the last revision\n"
 "  * {build_date} - current date\n"
@@ -3471,35 +4427,40 @@
 msgstr ""
 
 # help of 'format' option of 'version-info' command
-#: bzrlib/cmd_version_info.py:74
+#: bzrlib/cmd_version_info.py:75
 msgid "Select the output format."
 msgstr ""
 
 # help of 'all' option of 'version-info' command
-#: bzrlib/cmd_version_info.py:78
+#: bzrlib/cmd_version_info.py:79
 msgid "Include all possible information."
 msgstr ""
 
 # help of 'check-clean' option of 'version-info' command
-#: bzrlib/cmd_version_info.py:79
+#: bzrlib/cmd_version_info.py:80
 msgid "Check if tree is clean."
 msgstr ""
 
 # help of 'include-history' option of 'version-info' command
-#: bzrlib/cmd_version_info.py:81
+#: bzrlib/cmd_version_info.py:82
 msgid "Include the revision-history."
 msgstr ""
 
 # help of 'include-file-revisions' option of 'version-info' command
-#: bzrlib/cmd_version_info.py:83
+#: bzrlib/cmd_version_info.py:84
 msgid "Include the last revision for each file."
 msgstr ""
 
 # help of 'template' option of 'version-info' command
-#: bzrlib/cmd_version_info.py:84
+#: bzrlib/cmd_version_info.py:85
 msgid "Template for the output."
 msgstr ""
 
+#: bzrlib/commands.py:232
+#, python-format
+msgid "unknown command \"%s\""
+msgstr ""
+
 #: bzrlib/commands.py:479
 msgid "No help for this command."
 msgstr ""
@@ -3551,15 +4512,86 @@
 msgstr ""
 
 #: bzrlib/commands.py:557
-#, python-format
-msgid ":doc:`%s <%s-help>`"
+msgid ":doc:`{0} <{1}-help>`"
 msgstr ""
 
-#: bzrlib/commands.py:560
+#: bzrlib/commands.py:561
 #, python-format
 msgid ":See also: %s"
 msgstr ""
 
+#: bzrlib/commands.py:819 bzrlib/gpg.py:317
+msgid "Only ASCII permitted in option names"
+msgstr ""
+
+#: bzrlib/commands.py:844 bzrlib/commands.py:852
+msgid "command {0!r} needs one or more {1}"
+msgstr ""
+
+#: bzrlib/commands.py:861
+msgid "command {0!r} requires argument {1}"
+msgstr ""
+
+#: bzrlib/commands.py:868
+msgid "extra argument to command {0}: {1}"
+msgstr ""
+
+#: bzrlib/commands.py:965
+#, python-format
+msgid "Profile data written to \"%s\"."
+msgstr ""
+
+#: bzrlib/commit.py:116 bzrlib/commit.py:709
+msgid "added"
+msgstr ""
+
+#: bzrlib/commit.py:116 bzrlib/commit.py:717
+msgid "modified"
+msgstr ""
+
+#: bzrlib/commit.py:130
+#, python-format
+msgid "Committing%s"
+msgstr ""
+
+#: bzrlib/commit.py:133
+#, python-format
+msgid "Committed revision %d."
+msgstr ""
+
+#: bzrlib/commit.py:142
+#, python-format
+msgid "deleted %s"
+msgstr ""
+
+#: bzrlib/commit.py:145
+#, python-format
+msgid "missing %s"
+msgstr ""
+
+#: bzrlib/commit.py:471
+msgid ""
+"Conflicting tags in bound branch:\n"
+"{0}"
+msgstr ""
+
+#: bzrlib/commit.py:711
+msgid "renamed"
+msgstr ""
+
+#: bzrlib/commit.py:946
+msgid "unchanged"
+msgstr ""
+
+#: bzrlib/commit.py:968
+msgid "{0} [{1}] - Stage"
+msgstr ""
+
+#: bzrlib/commit.py:971
+#, python-format
+msgid "%s - Stage"
+msgstr ""
+
 #: bzrlib/commit_signature_commands.py:34
 msgid "Sign all commits by a given committer."
 msgstr ""
@@ -3595,30 +4627,38 @@
 "verification."
 msgstr ""
 
+#: bzrlib/commit_signature_commands.py:145
+msgid "Cannot verify a range of non-revision-history revisions"
+msgstr ""
+
 #: bzrlib/commit_signature_commands.py:166
 msgid "All commits signed with verifiable keys"
 msgstr ""
 
-#: bzrlib/config.py:3277
+#: bzrlib/config.py:448
+msgid "Invalid config value for \"{0}\"  value {1!r} is not an SI unit."
+msgstr ""
+
+#: bzrlib/config.py:3293
 msgid "Display, set or remove a configuration option."
 msgstr ""
 
-#: bzrlib/config.py:3279
+#: bzrlib/config.py:3295
 msgid "Display the active value for a given option."
 msgstr ""
 
-#: bzrlib/config.py:3281
+#: bzrlib/config.py:3297
 msgid ""
 "If --all is specified, NAME is interpreted as a regular expression and all\n"
 "matching options are displayed mentioning their scope. The active value\n"
 "that bzr will take into account is the first one displayed for each option."
 msgstr ""
 
-#: bzrlib/config.py:3285
+#: bzrlib/config.py:3301
 msgid "If no NAME is given, --all .* is implied."
 msgstr ""
 
-#: bzrlib/config.py:3287
+#: bzrlib/config.py:3303
 msgid ""
 "Setting a value is achieved by using name=value without spaces. The value\n"
 "is set in the most relevant scope and can be checked by displaying the\n"
@@ -3626,25 +4666,25 @@
 msgstr ""
 
 # help of 'scope' option of 'config' command
-#: bzrlib/config.py:3298
+#: bzrlib/config.py:3314
 msgid "Reduce the scope to the specified configuration file"
 msgstr ""
 
 # help of 'all' option of 'config' command
-#: bzrlib/config.py:3302
+#: bzrlib/config.py:3318
 msgid "Display all the defined values for the matching options."
 msgstr ""
 
 # help of 'remove' option of 'config' command
-#: bzrlib/config.py:3304
+#: bzrlib/config.py:3320
 msgid "Remove the option from the configuration file"
 msgstr ""
 
-#: bzrlib/conflicts.py:47
+#: bzrlib/conflicts.py:48
 msgid "List files with conflicts."
 msgstr ""
 
-#: bzrlib/conflicts.py:49
+#: bzrlib/conflicts.py:50
 msgid ""
 "Merge will do its best to combine the changes in two branches, but there\n"
 "are some kinds of problems only a human can fix.  When it encounters those,\n"
@@ -3652,32 +4692,32 @@
 "before you should commit."
 msgstr ""
 
-#: bzrlib/conflicts.py:54
+#: bzrlib/conflicts.py:55
 msgid ""
 "Conflicts normally are listed as short, human-readable messages.  If --text\n"
 "is supplied, the pathnames of files with text conflicts are listed,\n"
 "instead.  (This is useful for editing all files with text conflicts.)"
 msgstr ""
 
-#: bzrlib/conflicts.py:58
+#: bzrlib/conflicts.py:59
 msgid "Use bzr resolve when you have fixed a problem."
 msgstr ""
 
 # help of 'text' option of 'conflicts' command
-#: bzrlib/conflicts.py:63
+#: bzrlib/conflicts.py:64
 msgid "List paths of files with text conflicts."
 msgstr ""
 
 # help of 'action' option of 'resolve' command
-#: bzrlib/conflicts.py:95
+#: bzrlib/conflicts.py:96
 msgid "How to resolve the conflict."
 msgstr ""
 
-#: bzrlib/conflicts.py:101
+#: bzrlib/conflicts.py:102
 msgid "Mark a conflict as resolved."
 msgstr ""
 
-#: bzrlib/conflicts.py:108
+#: bzrlib/conflicts.py:109
 msgid ""
 "Once you have fixed a problem, use \"bzr resolve\" to automatically mark\n"
 "text conflicts as fixed, \"bzr resolve FILE\" to mark a specific conflict "
@@ -3686,15 +4726,45 @@
 msgstr ""
 
 # help of 'all' option of 'resolve' command
-#: bzrlib/conflicts.py:116
+#: bzrlib/conflicts.py:117
 msgid "Resolve all conflicts in this tree."
 msgstr ""
 
+#: bzrlib/conflicts.py:124
+msgid "If --all is specified, no FILE may be provided"
+msgstr ""
+
+#: bzrlib/conflicts.py:149
+#, python-format
+msgid "%d conflict auto-resolved."
+msgid_plural "%d conflicts auto-resolved."
+msgstr[0] ""
+msgstr[1] ""
+
+#: bzrlib/conflicts.py:152
+msgid "Remaining conflicts:"
+msgstr ""
+
+#: bzrlib/conflicts.py:157
+msgid "All conflicts resolved."
+msgstr ""
+
+#: bzrlib/conflicts.py:166
+msgid "{0} conflict resolved, {1} remaining"
+msgid_plural "{0} conflicts resolved, {1} remaining"
+msgstr[0] ""
+msgstr[1] ""
+
 # title of 'action' option of 'resolve' command
-#: bzrlib/conflicts.py:688
+#: bzrlib/conflicts.py:692
 msgid "action"
 msgstr ""
 
+#: bzrlib/diff.py:397
+#, python-format
+msgid "*** Ignoring files outside view. View is %s"
+msgstr ""
+
 #: bzrlib/errors.py:215
 msgid "The tree builder is already building a tree."
 msgstr ""
@@ -4899,184 +5969,310 @@
 "%(arguments)s."
 msgstr ""
 
-#: bzrlib/gpg.py:126 bzrlib/gpg.py:464
+#: bzrlib/export_pot.py:123 bzrlib/export_pot.py:129
+#, python-format
+msgid "%r is not found in bzrlib/option.py"
+msgstr ""
+
+#: bzrlib/export_pot.py:185
+#, python-format
+msgid "Exporting messages from builtin command: %s"
+msgstr ""
+
+#: bzrlib/export_pot.py:201
+msgid "Exporting messages from plugin command: {0} in {1}"
+msgstr ""
+
+#: bzrlib/export_pot.py:226
+#, python-format
+msgid "Exporting message from error: %s"
+msgstr ""
+
+#: bzrlib/fetch.py:97
+msgid "Finding revisions"
+msgstr ""
+
+#: bzrlib/fetch.py:102
+msgid "Fetching revisions"
+msgstr ""
+
+#: bzrlib/foreign.py:311
+#, python-format
+msgid "Using saved location: %s\n"
+msgstr ""
+
+#: bzrlib/foreign.py:321
+msgid ""
+"{0!r} and {1!r} are in the same VCS, lossy push not necessary. Please use "
+"regular push."
+msgstr ""
+
+#: bzrlib/gpg.py:116 bzrlib/gpg.py:454
 msgid "{0} commits with valid signatures"
 msgstr ""
 
-#: bzrlib/gpg.py:130 bzrlib/gpg.py:469
+#: bzrlib/gpg.py:120 bzrlib/gpg.py:459
 msgid "{0} commit with unknown key"
 msgid_plural "{0} commits with unknown keys"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/gpg.py:136 bzrlib/gpg.py:476
+#: bzrlib/gpg.py:126 bzrlib/gpg.py:466
 msgid "{0} commit not valid"
 msgid_plural "{0} commits not valid"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/gpg.py:142 bzrlib/gpg.py:483
+#: bzrlib/gpg.py:132 bzrlib/gpg.py:473
 msgid "{0} commit not signed"
 msgid_plural "{0} commits not signed"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/gpg.py:148 bzrlib/gpg.py:490
+#: bzrlib/gpg.py:138 bzrlib/gpg.py:480
 msgid "{0} commit with key now expired"
 msgid_plural "{0} commits with key now expired"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/gpg.py:346
-msgid "No GnuPG key results for pattern: {}"
+#: bzrlib/gpg.py:336
+msgid "No GnuPG key results for pattern: {0}"
 msgstr ""
 
-#: bzrlib/gpg.py:389
+#: bzrlib/gpg.py:379
 msgid "{0} signed {1} commit"
 msgid_plural "{0} signed {1} commits"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/gpg.py:406 bzrlib/gpg.py:422
+#: bzrlib/gpg.py:396 bzrlib/gpg.py:412
 msgid "{0} commit by author {1}"
 msgid_plural "{0} commits by author {1}"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/gpg.py:436
+#: bzrlib/gpg.py:426
 msgid "Unknown key {0} signed {1} commit"
 msgid_plural "Unknown key {0} signed {1} commits"
 msgstr[0] ""
 msgstr[1] ""
 
-#: bzrlib/gpg.py:454
+#: bzrlib/gpg.py:444
 msgid "{0} commit by author {1} with key {2} now expired"
 msgid_plural "{0} commits by author {1} with key {2} now expired"
 msgstr[0] ""
 msgstr[1] ""
 
+#: bzrlib/groupcompress.py:1758
+#, python-format
+msgid "Insert claimed random_id=True, but then inserted %r two times"
+msgstr ""
+
+#: bzrlib/knit.py:1764 bzrlib/knit.py:1800
+msgid "Walking content"
+msgstr ""
+
+#: bzrlib/knit.py:3467
+msgid "annotating"
+msgstr ""
+
+#: bzrlib/lock.py:547
+msgid "{0!r} was {1} locked again"
+msgstr ""
+
+#: bzrlib/log.py:569
+msgid "--exclude-common-ancestry requires two different revisions"
+msgstr ""
+
+#: bzrlib/log.py:571
+#, python-format
+msgid "invalid direction %r"
+msgstr ""
+
+#: bzrlib/log.py:618
+msgid "Start revision not found in left-hand history of end revision."
+msgstr ""
+
+#: bzrlib/log.py:664
+msgid "Start revision not found in history of end revision."
+msgstr ""
+
+#: bzrlib/log.py:1082 bzrlib/log.py:1140
+msgid "Logging revision 0 is invalid."
+msgstr ""
+
+#: bzrlib/log.py:1084 bzrlib/log.py:1142
+msgid "Start revision must be older than the end revision."
+msgstr ""
+
+#: bzrlib/log.py:1828
+#, python-format
+msgid "unknown log formatter: %r"
+msgstr ""
+
+#: bzrlib/log.py:2123
+msgid "fixes bug"
+msgid_plural "fixes bugs"
+msgstr[0] ""
+msgstr[1] ""
+
+#: bzrlib/merge.py:715
+msgid "All changes applied successfully."
+msgstr ""
+
+#: bzrlib/merge.py:717
+#, python-format
+msgid "%d conflicts encountered."
+msgstr ""
+
+#: bzrlib/merge.py:862 bzrlib/merge.py:1910
+msgid "Preparing file merge"
+msgstr ""
+
+#: bzrlib/multiparent.py:424
+msgid "Importing revisions"
+msgstr ""
+
 # help of 'help' option
-#: bzrlib/option.py:515
+#: bzrlib/option.py:530
 msgid "Show help message."
 msgstr ""
 
 # help of 'usage' option
-#: bzrlib/option.py:517
+#: bzrlib/option.py:532
 msgid "Show usage message and options."
 msgstr ""
 
 # help of 'verbose' option
-#: bzrlib/option.py:519
+#: bzrlib/option.py:534
 msgid "Display more information."
 msgstr ""
 
 # help of 'quiet' option
-#: bzrlib/option.py:522
+#: bzrlib/option.py:537
 msgid "Only display errors and warnings."
 msgstr ""
 
 # help of 'overwrite' option
-#: bzrlib/option.py:527
+#: bzrlib/option.py:542
 msgid "Ignore differences between branches and overwrite unconditionally."
 msgstr ""
 
 # help of 'message' option
-#: bzrlib/option.py:538
+#: bzrlib/option.py:553
 msgid "Message string."
 msgstr ""
 
 # help of 'null' option
-#: bzrlib/option.py:541
+#: bzrlib/option.py:556
 msgid "Use an ASCII NUL (\\0) separator rather than a newline."
 msgstr ""
 
 # help of 'profile' option
-#: bzrlib/option.py:544
+#: bzrlib/option.py:559
 msgid "Show performance profiling information."
 msgstr ""
 
 # help of 'revision' option
-#: bzrlib/option.py:548
+#: bzrlib/option.py:563
 msgid "See \"help revisionspec\" for details."
 msgstr ""
 
 # help of 'change' option
-#: bzrlib/option.py:553
+#: bzrlib/option.py:568
 msgid ""
 "Select changes introduced by the specified revision. See also \"help "
 "revisionspec\"."
 msgstr ""
 
 # help of 'show-ids' option
-#: bzrlib/option.py:555
+#: bzrlib/option.py:570
 msgid "Show internal object ids."
 msgstr ""
 
 # help of 'timezone' option
-#: bzrlib/option.py:558
+#: bzrlib/option.py:573
 msgid "Display timezone as local, original, or utc."
 msgstr ""
 
 # help of 'log-format' option
-#: bzrlib/option.py:563
+#: bzrlib/option.py:578
 msgid "Use specified log format."
 msgstr ""
 
 # title of 'log-format' option
-#: bzrlib/option.py:565
+#: bzrlib/option.py:580
 msgid "Log format"
 msgstr ""
 
 # help of 'long' option
-#: bzrlib/option.py:567
+#: bzrlib/option.py:582
 msgid "Use detailed log format. Same as --log-format long"
 msgstr ""
 
 # help of 'short' option
-#: bzrlib/option.py:569
+#: bzrlib/option.py:584
 msgid "Use moderately short log format. Same as --log-format short"
 msgstr ""
 
 # help of 'line' option
-#: bzrlib/option.py:570
+#: bzrlib/option.py:585
 msgid "Use log format with one line per revision. Same as --log-format line"
 msgstr ""
 
 # help of 'merge-type' option
-#: bzrlib/option.py:573
+#: bzrlib/option.py:588
 msgid "Select a particular merge algorithm."
 msgstr ""
 
 # title of 'merge-type' option
-#: bzrlib/option.py:575
+#: bzrlib/option.py:590
 msgid "Merge algorithm"
 msgstr ""
 
 # help of 'remember' option
-#: bzrlib/option.py:577
+#: bzrlib/option.py:592
 msgid "Remember the specified location as a default."
 msgstr ""
 
 # help of 'reprocess' option
-#: bzrlib/option.py:579
+#: bzrlib/option.py:594
 msgid "Reprocess to reduce spurious conflicts."
 msgstr ""
 
 # help of 'dry-run' option
-#: bzrlib/option.py:582
+#: bzrlib/option.py:597
 msgid "Show what would be done, but don't actually do anything."
 msgstr ""
 
 # help of 'name-from-revision' option
-#: bzrlib/option.py:583
+#: bzrlib/option.py:598
 msgid "The path name in the old tree."
 msgstr ""
 
 # help of 'directory' option
-#: bzrlib/option.py:585
+#: bzrlib/option.py:600
 msgid "Branch to operate on, instead of working directory"
 msgstr ""
 
+#: bzrlib/osutils.py:93
+msgid "Parameter {0!r} encoding is unsupported by {1} application locale."
+msgstr ""
+
+#: bzrlib/osutils.py:194
+msgid "lstat/stat of ({0!r}): {1!r}"
+msgstr ""
+
+#: bzrlib/osutils.py:929 bzrlib/osutils.py:940
+#, python-format
+msgid "sorry, %r not allowed in path"
+msgstr ""
+
+#: bzrlib/osutils.py:1158
+#, python-format
+msgid "%r is too short to calculate a relative path"
+msgstr ""
+
 # help of 'plugin' option of 'bash-completion' command
 #: bzrlib/plugins/bash_completion/bashcomp.py:407
 msgid "Enable completions for the selected plugin (default: all plugins)"
@@ -5310,13 +6506,538 @@
 msgid "  bzr lp-find-proposal -r annotate:README:1"
 msgstr ""
 
+#: bzrlib/push.py:54
+msgid "Created new branch."
+msgstr ""
+
+#: bzrlib/push.py:96
+#, python-format
+msgid ""
+"Target directory %s already contains a .bzr directory, but it is not valid."
+msgstr ""
+
+#: bzrlib/push.py:99
+#, python-format
+msgid ""
+"Target directory %s already exists, but does not have a .bzr directory. "
+"Supply --use-existing-dir to push there anyway."
+msgstr ""
+
+#: bzrlib/push.py:120
+#, python-format
+msgid "Too many redirections trying to make %s."
+msgstr ""
+
+#: bzrlib/push.py:145
+msgid ""
+"These branches have diverged.  See \"bzr help diverged-branches\" for more "
+"information."
+msgstr ""
+
+#: bzrlib/push.py:149
+#, python-format
+msgid ""
+"It is not possible to losslessly push to %s. You may want to use dpush "
+"instead."
+msgstr ""
+
+#: bzrlib/push.py:155
+#, python-format
+msgid ""
+"At %s you have a valid .bzr control directory, but not a branch or "
+"repository. This is an unsupported configuration. Please move the target "
+"directory out of the way and try again."
+msgstr ""
+
+#: bzrlib/reconcile.py:96
+#, python-format
+msgid "Reconciling branch %s"
+msgstr ""
+
+#: bzrlib/reconcile.py:102
+#, python-format
+msgid "Reconciling repository %s"
+msgstr ""
+
+#: bzrlib/reconcile.py:104
+msgid "Reconciling repository"
+msgstr ""
+
+#: bzrlib/reconcile.py:110
+#, python-format
+msgid "%s cannot canonicalize CHKs."
+msgstr ""
+
+#: bzrlib/reconcile.py:118
+msgid "Reconcile aborted: revision index has inconsistent parents."
+msgstr ""
+
+#: bzrlib/reconcile.py:120
+msgid "Run \"bzr check\" for more details."
+msgstr ""
+
+#: bzrlib/reconcile.py:122
+msgid "Reconciliation complete."
+msgstr ""
+
+#: bzrlib/reconcile.py:165
+msgid "Fixing last revision info {0}  => {1}"
+msgstr ""
+
+#: bzrlib/reconcile.py:172
+msgid "revision_history ok."
+msgstr ""
+
+#: bzrlib/reconcile.py:233
+msgid "Reading inventory data"
+msgstr ""
+
+#: bzrlib/reconcile.py:253 bzrlib/reconcile.py:383
+msgid "Inventory ok."
+msgstr ""
+
+#: bzrlib/reconcile.py:255 bzrlib/reconcile.py:385
+msgid "Backing up inventory"
+msgstr ""
+
+#: bzrlib/reconcile.py:257
+msgid "Backup inventory created."
+msgstr ""
+
+#: bzrlib/reconcile.py:273 bzrlib/reconcile.py:404
+msgid "Writing weave"
+msgstr ""
+
+#: bzrlib/reconcile.py:276 bzrlib/reconcile.py:407
+msgid "Inventory regenerated."
+msgstr ""
+
+#: bzrlib/reconcile.py:370 bzrlib/reconcile.py:372 bzrlib/reconcile.py:375
+msgid "Reading indexes"
+msgstr ""
+
+#: bzrlib/reconcile.py:379 bzrlib/reconcile.py:381
+msgid "Checking unused inventories"
+msgstr ""
+
+#: bzrlib/reconcile.py:387
+msgid "Backup Inventory created"
+msgstr ""
+
+#: bzrlib/reconcile.py:445
+msgid "Fixing text parents"
+msgstr ""
+
+#: bzrlib/reconfigure.py:52
+msgid "{0} is now stacked on {1}\n"
+msgstr ""
+
+#: bzrlib/reconfigure.py:67
+#, python-format
+msgid "%s is now not stacked\n"
+msgstr ""
+
+#: bzrlib/remote.py:1886
+msgid "Copying repository content as tarball..."
+msgstr ""
+
+#: bzrlib/rename_map.py:68
+msgid "Calculating hashes"
+msgstr ""
+
+#: bzrlib/rename_map.py:106
+msgid "Determining hash hits"
+msgstr ""
+
+#: bzrlib/rename_map.py:241
+msgid "{0} => {1}"
+msgstr ""
+
+#: bzrlib/repository.py:284
+#, python-format
+msgid "bzr: ERROR (ignored): %s"
+msgstr ""
+
+#: bzrlib/repository.py:1806
+msgid "Moving repository to repository.backup"
+msgstr ""
+
+#: bzrlib/repository.py:1813
+msgid "Creating new repository"
+msgstr ""
+
+#: bzrlib/repository.py:1818
+msgid "Copying content"
+msgstr ""
+
+#: bzrlib/repository.py:1822
+msgid "Deleting old repository content"
+msgstr ""
+
+#: bzrlib/repository.py:1824
+msgid "repository converted"
+msgstr ""
+
+#: bzrlib/revisionspec.py:914
+msgid "Using {0} {1}"
+msgstr ""
+
+#: bzrlib/send.py:56
+#, python-format
+msgid "Mail client \"%s\" does not support specifying body"
+msgstr ""
+
+#: bzrlib/send.py:60
+msgid "--remember requires a branch to be specified."
+msgstr ""
+
+#: bzrlib/send.py:74
+msgid "No submit branch known or specified"
+msgstr ""
+
+#: bzrlib/send.py:77
+msgid "Using saved {0} location \"{1}\" to determine what changes to submit."
+msgstr ""
+
+#: bzrlib/send.py:94
+#, python-format
+msgid "No such send format '%s'."
+msgstr ""
+
+#: bzrlib/send.py:111
+msgid "bzr send takes at most two one revision identifiers"
+msgstr ""
+
+#: bzrlib/send.py:124
+msgid "No revisions to submit."
+msgstr ""
+
+#: bzrlib/send.py:135
+msgid ""
+"- not supported for merge directives that use more than one output file."
+msgstr ""
+
+#: bzrlib/send.py:177
+msgid "Format 0.9 does not permit bundle with no patch"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:45
+#, python-format
+msgid "Shelve adding file \"%(path)s\"?"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:46
+msgid "Shelve binary changes?"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:47
+msgid "Shelve changing \"%s\" from %(other)s to %(this)s?"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:49
+#, python-format
+msgid "Shelve removing file \"%(path)s\"?"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:50
+#, python-format
+msgid "Shelve %d change(s)?"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:51
+msgid "Shelve?"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:52
+#, python-format
+msgid ""
+"Shelve changing target of \"%(path)s\" from \"%(other)s\" to \"%(this)s\"?"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:54
+#, python-format
+msgid "Shelve renaming \"%(other)s\" => \"%(this)s\"?"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:69
+#, python-format
+msgid "Changes shelved with id \"%d\"."
+msgstr ""
+
+#: bzrlib/shelf_ui.py:73
+msgid "Selected changes destroyed."
+msgstr ""
+
+#: bzrlib/shelf_ui.py:77
+msgid "Selected changes:"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:97
+#, python-format
+msgid "Delete file \"%(path)s\"?"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:98
+msgid "Apply binary changes?"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:99
+#, python-format
+msgid "Change \"%(path)s\" from %(this)s to %(other)s?"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:101
+#, python-format
+msgid "Add file \"%(path)s\"?"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:102
+#, python-format
+msgid "Apply %d change(s)?"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:103
+msgid "Apply change?"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:104
+#, python-format
+msgid "Change target of \"%(path)s\" from \"%(this)s\" to \"%(other)s\"?"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:106
+#, python-format
+msgid "Rename \"%(this)s\" => \"%(other)s\"?"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:265
+msgid "You need a controlling terminal."
+msgstr ""
+
+#: bzrlib/shelf_ui.py:415
+msgid "No changes are shelved."
+msgstr ""
+
+#: bzrlib/shelf_ui.py:473
+#, python-format
+msgid "Using changes with id \"%d\"."
+msgstr ""
+
+#: bzrlib/shelf_ui.py:477
+#, python-format
+msgid "Message: %s"
+msgstr ""
+
+#: bzrlib/shelf_ui.py:489
+#, python-format
+msgid "Deleted changes with id \"%d\"."
+msgstr ""
+
+#: bzrlib/smart/medium.py:565
+msgid "HPSS calls: {0} ({1} vfs) {2}"
+msgstr ""
+
+#: bzrlib/smart/server.py:355
+#, python-format
+msgid "listening on port: %s"
+msgstr ""
+
+#: bzrlib/switch.py:67
+msgid "Pending merges must be committed or reverted before using switch."
+msgstr ""
+
+#: bzrlib/switch.py:94
+msgid ""
+"Cannot switch as local commits found in the checkout. Commit these to the "
+"bound branch or use --force to throw them away."
+msgstr ""
+
+#: bzrlib/switch.py:99
+#, python-format
+msgid ""
+"Unable to connect to current master branch %(target)s: %(error)s To switch "
+"anyway, use --force."
+msgstr ""
+
+#: bzrlib/switch.py:108
+msgid "Cannot switch a branch, only a checkout."
+msgstr ""
+
+#: bzrlib/switch.py:144
+#, python-format
+msgid "Tree is up to date at revision %d."
+msgstr ""
+
+#: bzrlib/switch.py:150
+#, python-format
+msgid "Updated to revision %d."
+msgstr ""
+
+#: bzrlib/transform.py:1730 bzrlib/transform.py:1741 bzrlib/transform.py:1743
+msgid "Apply phase"
+msgstr ""
+
+#: bzrlib/transform.py:1769 bzrlib/transform.py:1837
+msgid "removing file"
+msgstr ""
+
+#: bzrlib/transform.py:1787 bzrlib/transform.py:1872
+msgid "adding file"
+msgstr ""
+
+#: bzrlib/transform.py:2587
+msgid "Building tree"
+msgstr ""
+
+#: bzrlib/transform.py:2677 bzrlib/transform.py:2704
+msgid "Adding file contents"
+msgstr ""
+
+#: bzrlib/transform.py:3051
+msgid "Resolution pass"
+msgstr ""
+
+#: bzrlib/tree.py:635
+msgid "*** {0} content-filter: {1} => {2!r}"
+msgstr ""
+
+#: bzrlib/upgrade.py:76
+#, python-format
+msgid "This is a checkout. The branch (%s) needs to be upgraded separately."
+msgstr ""
+
+#: bzrlib/upgrade.py:99
+#, python-format
+msgid "cannot upgrade from bzrdir format %s"
+msgstr ""
+
+#: bzrlib/upgrade.py:102
+#, python-format
+msgid "starting upgrade of %s"
+msgstr ""
+
+#: bzrlib/upgrade.py:109
+msgid "finished"
+msgstr ""
+
+#: bzrlib/upgrade.py:119
+msgid "Deleting backup.bzr"
+msgstr ""
+
+#: bzrlib/upgrade.py:150
+msgid ""
+"\n"
+"SUMMARY: {0} upgrades attempted, {1} succeeded, {2} failed"
+msgstr ""
+
+#: bzrlib/upgrade.py:207
+#, python-format
+msgid "Found %d dependent branches - upgrading ..."
+msgstr ""
+
+#: bzrlib/upgrade.py:275
+msgid "Upgrading bzrdirs"
+msgstr ""
+
+#: bzrlib/upgrade.py:281
+#, python-format
+msgid "Upgrading %s"
+msgstr ""
+
+#: bzrlib/upgrade.py:282
+msgid "Upgrading {0} {1} ..."
+msgstr ""
+
+#: bzrlib/upgrade.py:296
+msgid "Removing backup ..."
+msgstr ""
+
+#: bzrlib/upgrade.py:300
+msgid "failed to clean-up {0}: {1}"
+msgstr ""
+
+#: bzrlib/vf_repository.py:1091
+msgid "inventories"
+msgstr ""
+
+#: bzrlib/vf_repository.py:1117
+msgid "texts"
+msgstr ""
+
+#: bzrlib/vf_repository.py:1572 bzrlib/vf_repository.py:1581
+msgid "Calculating text parents"
+msgstr ""
+
+#: bzrlib/vf_repository.py:1657
+msgid "Fetch texts"
+msgstr ""
+
+#: bzrlib/vf_repository.py:2468
+msgid "loading text store"
+msgstr ""
+
+#: bzrlib/vf_repository.py:2474
+msgid "checking text graph"
+msgstr ""
+
+#: bzrlib/vf_repository.py:2924 bzrlib/vf_repository.py:2938
+#: bzrlib/vf_repository.py:3053
+msgid "Transferring revisions"
+msgstr ""
+
+#: bzrlib/win32utils.py:132
+msgid "Failed to GetProcessMemoryInfo()"
+msgstr ""
+
+#: bzrlib/win32utils.py:153
+msgid "Cannot debug memory on win32 without ctypes or win32process"
+msgstr ""
+
+#: bzrlib/win32utils.py:158
+msgid "WorkingSize {0:>7}KiB\tPeakWorking {1:>7}KiB\t{2}"
+msgstr ""
+
+#: bzrlib/win32utils.py:166
+#, python-format
+msgid "WorkingSize       %8d KiB"
+msgstr ""
+
+#: bzrlib/win32utils.py:167
+#, python-format
+msgid "PeakWorking       %8d KiB"
+msgstr ""
+
+#: bzrlib/win32utils.py:168
+#, python-format
+msgid "PagefileUsage     %8d KiB"
+msgstr ""
+
+#: bzrlib/win32utils.py:169
+#, python-format
+msgid "PeakPagefileUsage %8d KiB"
+msgstr ""
+
+#: bzrlib/win32utils.py:171
+#, python-format
+msgid "PrivateUsage      %8d KiB"
+msgstr ""
+
+#: bzrlib/win32utils.py:172
+#, python-format
+msgid "PageFaultCount    %8d"
+msgstr ""
+
+#: bzrlib/workingtree.py:1502
+msgid "Rerun update after fixing the conflicts."
+msgstr ""
+
 #: dummy/help_topics/authentication/summary.txt:1
 msgid "Information on configuring authentication"
 msgstr ""
 
 #: dummy/help_topics/basic/detail.txt:1
 msgid ""
-"Bazaar 2.5.0dev1 -- a free distributed version-control tool\n"
+"Bazaar 2.5.0dev2 -- a free distributed version-control tool\n"
 "http://bazaar.canonical.com/"
 msgstr ""
 
@@ -6879,8 +8600,6 @@
 "fetch-ghosts       Attempt to retrieve ghosts from another branch. "
 "[bzrtools]\n"
 "graph-ancestry     Produce ancestry graphs using dot. [bzrtools]\n"
-"grep               Print lines matching PATTERN for specified files and\n"
-"                   revisions. [grep]\n"
 "heads              Show all revisions in a repository not having "
 "descendants.\n"
 "                   [bzrtools]\n"

